@@ -47,8 +47,12 @@ struct preferred_codecvt : std::codecvt_byname<wchar_t, char, std::mbstate_t>
 {
     preferred_codecvt() : std::codecvt_byname<wchar_t, char, std::mbstate_t>("C") {}
     ~preferred_codecvt() = default;
+
+    static std::locale::id id;
 };
 
+std::locale::id preferred_codecvt::id;
+
 struct Printer
 {
     Printer();
@@ -167,6 +171,8 @@ void Printer::printhelp(BackgroundInfo const& region)
             "  o Switch workspace: Meta-Alt-[F1|F2|F3|F4]",
             "  o Switch workspace taking active window: Meta-Ctrl-[F1|F2|F3|F4]",
             "",
+            "  o Invert colors: Ctrl-I",
+            "",
             "  o To exit: Ctrl-Alt-BkSp",
         };
 
