@@ -21,26 +21,35 @@
 #include <miral/cursor_theme.h>
 #include <miral/display_configuration_option.h>
 #include <miral/input_configuration.h>
-#include <miral/minimal_window_manager.h>
+#include <miral/keymap.h>
+#include <miral/live_config.h>
+#include <miral/live_config_ini_file.h>
+#include <miral/floating_window_manager.h>
 #include <miral/config_file.h>
 #include <miral/runner.h>
 #include <miral/set_window_management_policy.h>
 #include <miral/wayland_extensions.h>
 #include <miral/x11_support.h>
+#include <miral/cursor_scale.h>
+#include <miral/output_filter.h>
+#include <miral/bounce_keys.h>
+#include <miral/slow_keys.h>
+#include <miral/hover_click.h>
+#include <miral/append_keyboard_event_filter.h>
 
-#include "mir/abnormal_exit.h"
-#include "mir/main_loop.h"
-#include "mir/options/option.h"
-#include "mir/report_exception.h"
-#include "mir/server.h"
-#include "mir/log.h"
+#include <mir/abnormal_exit.h>
+#include <mir/main_loop.h>
+#include <mir/options/option.h>
+#include <mir/report_exception.h>
+#include <mir/server.h>
 
 #include <boost/exception/diagnostic_information.hpp>
 
 #include <chrono>
 #include <cstdlib>
-#include <iostream>
-#include <mutex>
+#include <linux/input-event-codes.h>
+
+#include <miral/sticky_keys.h>
 
 namespace mir { class AbnormalExit; }
 
@@ -69,7 +78,6 @@ void add_timeout_option_to(mir::Server& server)
     });
 }
 
-
 // Create some input filters (we need to keep them or they deactivate)
 struct InputFilters
 {
@@ -114,107 +122,6 @@ catch (std::exception const& error)
 catch (...)
 {
 }
-
-class InputConfigFile
-{
-public:
-    InputConfigFile(miral::MirRunner& runner, std::filesystem::path file) :
-        config_file{
-            runner,
-            file,
-            miral::ConfigFile::Mode::reload_on_change,
-            [this](std::istream& istream, std::filesystem::path const& path) {loader(istream, path); }}
-    {
-        runner.add_start_callback([this]
-            {
-                std::lock_guard lock{config_mutex};
-                apply_config();
-            });
-    }
-
-    void operator()(mir::Server& server)
-    {
-        input_configuration(server);
-    }
-
-private:
-    miral::InputConfiguration input_configuration;
-    miral::InputConfiguration::Mouse mouse = input_configuration.mouse();
-    miral::InputConfiguration::Touchpad touchpad = input_configuration.touchpad();
-    miral::InputConfiguration::Keyboard keyboard = input_configuration.keyboard();
-    std::mutex config_mutex;
-    miral::ConfigFile config_file;
-
-    void apply_config()
-    {
-        input_configuration.mouse(mouse);
-        input_configuration.touchpad(touchpad);
-        input_configuration.keyboard(keyboard);
-    };
-
-    void loader(std::istream& in, std::filesystem::path const& path)
-    {
-        std::cout << "** Reloading: " << path << std::endl;
-
-        std::lock_guard lock{config_mutex};
-
-        for (std::string line; std::getline(in, line);)
-        {
-            std::cout << line << std::endl;
-
-            if (line == "mir_pointer_handedness_right")
-                mouse.handedness(mir_pointer_handedness_right);
-            if (line == "mir_pointer_handedness_left")
-                mouse.handedness(mir_pointer_handedness_left);
-
-            if (line == "mir_touchpad_scroll_mode_none")
-                touchpad.scroll_mode(mir_touchpad_scroll_mode_none);
-            if (line == "mir_touchpad_scroll_mode_two_finger_scroll")
-                touchpad.scroll_mode(mir_touchpad_scroll_mode_two_finger_scroll);
-            if (line == "mir_touchpad_scroll_mode_edge_scroll")
-                touchpad.scroll_mode(mir_touchpad_scroll_mode_edge_scroll);
-            if (line == "mir_touchpad_scroll_mode_button_down_scroll")
-                touchpad.scroll_mode(mir_touchpad_scroll_mode_button_down_scroll);
-
-            if (line.contains("="))
-            {
-                auto const eq = line.find_first_of("=");
-                auto const key = line.substr(0, eq);
-                auto const value = line.substr(eq+1);
-
-                auto const parse_and_validate = [](std::string const& key, std::string_view val) -> std::optional<int>
-                {
-                    auto const int_val = std::atoi(val.data());
-                    if (int_val < 0)
-                    {
-                        mir::log_warning(
-                            "Config value %s does not support negative values. Ignoring the supplied value (%d)...",
-                            key.c_str(), int_val);
-                        return std::nullopt;
-                    }
-
-                    return int_val;
-                };
-
-                if (key == "repeat_rate")
-                {
-                    auto const parsed = parse_and_validate(key, value);
-                    if (parsed)
-                        keyboard.set_repeat_rate(*parsed);
-                }
-
-                if (key == "repeat_delay")
-                {
-                    auto const parsed = parse_and_validate(key, value);
-                    if (parsed)
-                        keyboard.set_repeat_delay(*parsed);
-                }
-            }
-        }
-
-        apply_config();
-    }
-};
 }
 
 int main(int argc, char const* argv[])
@@ -222,9 +129,24 @@ try
 {
     miral::MirRunner runner{argc, argv, "mir/mir_demo_server.config"};
 
-    InputConfigFile input_configuration{runner, "mir_demo_server.input"};
+    miral::live_config::IniFile config_store;
     runner.set_exception_handler(exception_handler);
 
+    miral::CursorScale cursor_scale{config_store};
+    miral::OutputFilter output_filter{config_store};
+    miral::InputConfiguration input_configuration{config_store};
+    miral::BounceKeys bounce_keys{config_store};
+    miral::SlowKeys slow_keys{config_store};
+    miral::StickyKeys sticky_keys{config_store};
+    miral::Keymap keymap{config_store};
+    miral::HoverClick hover_click{config_store};
+
+    miral::ConfigFile config_file{
+        runner,
+        "mir_demo_server.live-config",
+        miral::ConfigFile::Mode::reload_on_change,
+        [&config_store](auto&... args){ config_store.load_file(args...); }};
+
     std::function<void()> shutdown_hook{[]{}};
     runner.add_stop_callback([&] { shutdown_hook(); });
 
@@ -241,12 +163,19 @@ try
         miral::display_configuration_options,
         miral::X11Support{},
         wayland_extensions,
-        miral::set_window_management_policy<miral::MinimalWindowManager>(),
+        miral::set_window_management_policy<miral::FloatingWindowManager>(),
         add_timeout_option_to,
         miral::CursorTheme{"default:DMZ-White"},
         input_filters,
         test_runner,
-        std::ref(input_configuration),
+        output_filter,
+        input_configuration,
+        cursor_scale,
+        bounce_keys,
+        slow_keys,
+        sticky_keys,
+        hover_click,
+        keymap,
     });
 
     // Propagate any test failure
