@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,7 +17,7 @@
 #ifndef EXAMPLE_INPUT_EVENT_FILTER_H_
 #define EXAMPLE_INPUT_EVENT_FILTER_H_
 
-#include "mir/input/event_filter.h"
+#include <mir/input/event_filter.h>
 
 #include <functional>
 #include <memory>
