@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -16,13 +16,13 @@
 
 #include "server_example_input_filter.h"
 
-#include "mir/server.h"
+#include <mir/server.h>
 
-#include "mir/compositor/compositor.h"
-#include "mir/graphics/display.h"
-#include "mir/graphics/display_configuration.h"
-#include "mir/input/composite_event_filter.h"
-#include "mir/options/option.h"
+#include <mir/compositor/compositor.h>
+#include <mir/graphics/display.h>
+#include <mir/graphics/display_configuration.h>
+#include <mir/input/composite_event_filter.h>
+#include <mir/options/option.h>
 
 #include <linux/input.h>
 
@@ -215,7 +215,7 @@ auto me::make_printing_input_filter_for(mir::Server& server)
 -> std::shared_ptr<mi::EventFilter>
 {
     static const char* const print_input_events = "print-input-events";
-    static const char* const print_input_events_descr = "List input events on std::cout";
+    static const char* const print_input_events_descr = "List input events on stdout.";
 
     server.add_configuration_option(print_input_events, print_input_events_descr, mir::OptionType::null);
 
@@ -235,7 +235,7 @@ auto me::make_screen_rotation_filter_for(mir::Server& server)
 -> std::shared_ptr<input::EventFilter>
 {
     static const char* const screen_rotation = "screen-rotation";
-    static const char* const screen_rotation_descr = "Rotate screen on Ctrl-Alt-<Arrow>";
+    static const char* const screen_rotation_descr = "Rotate screen on Ctrl-Alt-<Arrow>.";
 
     server.add_configuration_option(screen_rotation, screen_rotation_descr, mir::OptionType::null);
 
