@@ -15,12 +15,12 @@
  */
 
 #include "server_example_test_client.h"
-#include "mir/fd.h"
-#include "mir/server.h"
-#include "mir/main_loop.h"
-#include "mir/logging/logger.h"
-#include "mir/log.h"
-#include "mir/options/option.h"
+#include <mir/fd.h>
+#include <mir/server.h>
+#include <mir/main_loop.h>
+#include <mir/logging/logger.h>
+#include <mir/log.h>
+#include <mir/options/option.h>
 
 #include <chrono>
 #include <future>
@@ -113,7 +113,7 @@ me::TestClientRunner::TestClientRunner() : self{std::make_shared<Self>()} {}
 void me::TestClientRunner::operator()(mir::Server& server)
 {
     static const char* const test_client_opt = "test-client";
-    static const char* const test_client_descr = "client executable";
+    static const char* const test_client_descr = "Client executable";
 
     static const char* const test_timeout_opt = "test-timeout";
     static const char* const test_timeout_descr = "Seconds to run before sending SIGTERM to client";
