@@ -17,7 +17,7 @@
 #ifndef MIR_DISPATCH_DISPATCHABLE_H_
 #define MIR_DISPATCH_DISPATCHABLE_H_
 
-#include "mir/fd.h"
+#include <mir/fd.h>
 
 namespace mir
 {
