@@ -17,9 +17,11 @@
 #ifndef MIR_EVENTS_TOUCH_CONTACT_H_
 #define MIR_EVENTS_TOUCH_CONTACT_H_
 
-#include "mir_toolkit/event.h"
+#include <mir_toolkit/event.h>
 #include "contact_state.h"
-#include "mir/geometry/point.h"
+#include <mir/geometry/point.h>
+
+#include <optional>
 
 namespace mir
 {
@@ -92,6 +94,7 @@ struct TouchContactV2
     MirTouchAction action;
     MirTouchTooltype tooltype;
     geometry::PointF position;
+    std::optional<geometry::PointF> local_position;
     float pressure;
     float touch_major;
     float touch_minor;
