@@ -17,9 +17,9 @@
 #ifndef MIR_INPUT_KEYBOARD_CONFIGURATION_H_
 #define MIR_INPUT_KEYBOARD_CONFIGURATION_H_
 
-#include "mir_toolkit/common.h"
-#include "mir_toolkit/mir_input_device_types.h"
-#include "mir/input/keymap.h"
+#include <mir_toolkit/common.h>
+#include <mir_toolkit/mir_input_device_types.h>
+#include <mir/input/keymap.h>
 
 #include <iosfwd>
 #include <memory>
