@@ -1,5 +1,5 @@
 /*
- * Copyright © 2016 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -17,8 +17,8 @@
 #ifndef MIR_INPUT_TOUCH_SCREEN_CONFIGURATION_H_
 #define MIR_INPUT_TOUCH_SCREEN_CONFIGURATION_H_
 
-#include "mir_toolkit/common.h"
-#include "mir_toolkit/mir_input_device_types.h"
+#include <mir_toolkit/common.h>
+#include <mir_toolkit/mir_input_device_types.h>
 #include <memory>
 #include <iosfwd>
 
