@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -18,15 +18,11 @@
 #define MIR_CORE_ANONYMOUS_SHM_FILE_H_
 
 #include "shm_file.h"
-#include "mir/fd.h"
+#include <mir/fd.h>
 
 namespace mir
 {
 
-namespace detail
-{
-}
-
 class AnonymousShmFile : public ShmFile
 {
 public:
