@@ -24,6 +24,8 @@ namespace mir { class Server; }
 
 namespace miral
 {
+namespace live_config { class Store; }
+
 /// Load a keymap
 class Keymap
 {
@@ -38,6 +40,15 @@ public:
     /// Options is a comma separated list.
     /// e.g. "gb" or "us+dvorak"
     explicit Keymap(std::string const& keymap);
+
+    /// Construct a `Keymap` instance with access to a live config store.
+    /// \remark Since MirAL 5.5
+    explicit Keymap(live_config::Store& config_store);
+
+    /// Construct a `Keymap` instance that tracks the system locale1 dbus node
+    /// \remark Since MirAL 5.5
+    static auto system_locale1() -> Keymap;
+
     ~Keymap();
     Keymap(Keymap const& that);
     auto operator=(Keymap const& rhs) -> Keymap&;
@@ -50,6 +61,8 @@ public:
 private:
     struct Self;
     std::shared_ptr<Self> self;
+
+    Keymap(std::unique_ptr<Self>&& self);
 };
 }
 
