@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021 Canonical, Ltd.
+ * Copyright (C) Canonical, Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License version 3, as published by
@@ -17,17 +17,17 @@
 #ifndef MIROIL_DISPLAY_LISTENER_WRAPPER_H
 #define MIROIL_DISPLAY_LISTENER_WRAPPER_H
 
-#include "mir/geometry/forward.h"
+#include <mir/geometry/forward.h>
 
 #include <memory>
 
-namespace mir { 
+namespace mir {
     namespace compositor { class DisplayListener; }
 }
 
 namespace miroil
 {
-    
+
 class DisplayListenerWrapper
 {
 public:
@@ -38,7 +38,7 @@ public:
     void remove_display(mir::geometry::Rectangle const& area);
 
 private:
-    std::shared_ptr<mir::compositor::DisplayListener> const& display_listener;     
+    std::shared_ptr<mir::compositor::DisplayListener> const& display_listener;
 };
 
 }
