@@ -16,14 +16,17 @@
 #ifndef MIR_GRAPHICS_BUFFER_BASIC_H_
 #define MIR_GRAPHICS_BUFFER_BASIC_H_
 
-#include "mir/graphics/buffer.h"
-#include "mir/graphics/buffer_id.h"
+#include <mir/graphics/buffer.h>
+#include <mir/graphics/buffer_id.h>
 
 namespace mir
 {
 namespace graphics
 {
 
+/// Automatically implements #Buffer::id.
+///
+/// IDs are not guaranteed to be stable across executions of Mir.
 class BufferBasic : public Buffer
 {
 public:
