@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -18,8 +18,9 @@
 #ifndef MIR_GRAPHICS_CURSOR_H_
 #define MIR_GRAPHICS_CURSOR_H_
 
-#include "mir/geometry/size.h"
-#include "mir/geometry/point.h"
+#include <mir/geometry/size.h>
+#include <mir/geometry/point.h>
+#include <mir/graphics/renderable.h>
 
 #include <memory>
 
@@ -28,14 +29,20 @@ namespace mir
 namespace graphics
 {
 class CursorImage;
+class Renderable;
 class Cursor
 {
 public:
-    virtual void show(CursorImage const& cursor_image) = 0;
+    virtual void show(std::shared_ptr<CursorImage> const& cursor_image) = 0;
     virtual void hide() = 0;
 
     virtual void move_to(geometry::Point position) = 0;
 
+    virtual void scale(float new_scale) = 0;
+
+    virtual auto renderable() -> std::shared_ptr<Renderable> = 0;
+
+    virtual auto needs_compositing() const -> bool = 0;
 protected:
     Cursor() = default;
     virtual ~Cursor() = default;
