@@ -1,5 +1,5 @@
 /*
- * Copyright © 2016 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -17,7 +17,7 @@
 #ifndef MIR_GRAPHICS_FRAME_H_
 #define MIR_GRAPHICS_FRAME_H_
 
-#include "mir/time/posix_timestamp.h"
+#include <mir/time/posix_timestamp.h>
 #include <cstdint>
 
 namespace mir { namespace graphics {
