@@ -18,11 +18,13 @@
 #define MIR_GRAPHICS_RENDERABLE_H_
 
 #include <optional>
-#include <mir/geometry/rectangle.h>
 #include <glm/glm.hpp>
 #include <memory>
 #include <vector>
 
+#include <mir/geometry/rectangles.h>
+#include <mir_toolkit/common.h>
+
 namespace mir
 {
 
@@ -78,10 +80,30 @@ public:
      */
     virtual glm::mat4 transformation() const = 0;
 
+    /**
+     * The orientation of the buffer.
+     */
+    virtual MirOrientation orientation() const = 0;
+
+    /**
+     * The mirror mode of the buffer.
+     */
+    virtual MirMirrorMode mirror_mode() const = 0;
+
     virtual bool shaped() const = 0;  // meaning the pixel format has alpha
 
     virtual auto surface_if_any() const
         -> std::optional<mir::scene::Surface const*> = 0;
+
+    /*
+     * Opaque region of the potentially transparent surface in absolute
+     * coordinates.
+     *
+     * Absolute coordinates are computed relative to the top left of
+     * #screen_position. #transformation is not applied.
+     */
+    virtual auto opaque_region() const -> std::optional<geometry::Rectangles> = 0;
+
 protected:
     Renderable() = default;
     Renderable(Renderable const&) = delete;
