@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014-2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -17,7 +17,7 @@
 #ifndef MIR_INPUT_INPUT_DEVICE_INFO_H_
 #define MIR_INPUT_INPUT_DEVICE_INFO_H_
 
-#include "mir/input/device_capability.h"
+#include <mir/input/device_capability.h>
 
 #include <cstdint>
 #include <string>
