@@ -17,7 +17,7 @@
 #ifndef MIR_OPTIONS_CONFIGURATION_H_
 #define MIR_OPTIONS_CONFIGURATION_H_
 
-#include "mir/options/option.h"
+#include <mir/options/option.h>
 
 #include <memory>
 
@@ -41,8 +41,6 @@ extern char const* const cursor_opt;
 extern char const* const fatal_except_opt;
 extern char const* const debug_opt;
 extern char const* const composite_delay_opt;
-extern char const* const enable_key_repeat_opt;
-extern char const* const enable_mouse_keys_opt;
 extern char const* const x11_display_opt;
 extern char const* const x11_scale_opt;
 extern char const* const wayland_extensions_opt;
@@ -69,6 +67,7 @@ extern char const* const null_console;
 extern char const* const auto_console;
 
 extern char const* const vt_option_name;
+extern char const* const vt_switching_option_name;
 
 class Configuration
 {
