@@ -17,7 +17,8 @@
 #ifndef MIR_TEST_DOUBLES_STUB_CURSOR_H_
 #define MIR_TEST_DOUBLES_STUB_CURSOR_H_
 
-#include "mir/graphics/cursor.h"
+#include <mir/graphics/cursor.h>
+#include <memory>
 
 namespace mir
 {
@@ -28,9 +29,12 @@ namespace doubles
 
 struct StubCursor : public graphics::Cursor
 {
-    void show(graphics::CursorImage const&) override {}
+    void show(std::shared_ptr<graphics::CursorImage> const&) override {}
     void hide() override {}
     void move_to(geometry::Point) override {}
+    void scale(float) override {}
+    auto renderable() -> std::shared_ptr<graphics::Renderable> override { return nullptr; }
+    auto needs_compositing() const -> bool override { return false; }
 };
 
 }
