@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,8 +17,8 @@
 #ifndef MIR_TEST_FRAMEWORK_FAKE_INPUT_DEVICE_H_
 #define MIR_TEST_FRAMEWORK_FAKE_INPUT_DEVICE_H_
 
-#include "mir_toolkit/events/event.h"
-#include "mir/test/event_factory.h"
+#include <mir_toolkit/events/event.h>
+#include <mir/test/event_factory.h>
 #include <chrono>
 #include <functional>
 #include <vector>
