@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,10 +17,10 @@
 #ifndef MIR_TEST_FRAMEWORK_STUB_SERVER_PLATFORM_FACTORY_
 #define MIR_TEST_FRAMEWORK_STUB_SERVER_PLATFORM_FACTORY_
 
-#include "mir/geometry/rectangle.h"
+#include <mir/geometry/rectangle.h>
 
-#include "mir/graphics/platform.h"
-#include "mir/module_deleter.h"
+#include <mir/graphics/platform.h>
+#include <mir/module_deleter.h>
 #include <vector>
 #include <memory>
 #include <string>
