@@ -64,12 +64,10 @@ struct TestDisplayServer : private TestRuntimeEnvironment
     void add_stop_callback(std::function<void()> const& stop_callback);
 
     /// Add signal handler to the server's main loop.
-    /// \remark Since MirAL 3.7
     void register_signal_handler(std::initializer_list<int> signals, std::function<void(int)> const& handler);
 
-    /// Add a watch on a file descriptor. 
+    /// Add a watch on a file descriptor.
     /// The handler will be triggered when there is data to read on the Fd.
-    /// \remark Since MirAL 3.7
     auto register_fd_handler(mir::Fd fd, std::function<void(int)> const& handler)
     -> std::unique_ptr<miral::FdHandle>;
 
@@ -101,14 +99,15 @@ struct TestDisplayServer : private TestRuntimeEnvironment
     /// \note call after start_server()
     void invoke_runner(std::function<void(MirRunner& runner)> const& f);
 
+    mir::Server& server() const { return *server_running; }
 private:
     MirRunner runner;
+    mir::Server* server_running{nullptr};
 
     WindowManagerTools tools{nullptr};
     mir::test::AutoJoinThread server_thread;
     std::mutex mutex;
     std::condition_variable started;
-    mir::Server* server_running{nullptr};
     std::function<void(mir::Server&)> init_server = [](auto&){};
 };
 }
