@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/dispatch/readable_fd.h"
+#include <mir/dispatch/readable_fd.h>
 
 mir::dispatch::ReadableFd::ReadableFd(Fd fd, std::function<void()> const& on_readable) :
     fd{fd},
