@@ -14,11 +14,11 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/events/event.h"
-#include "mir/events/input_event.h"
-#include "mir/events/keyboard_event.h"
-#include "mir/events/pointer_event.h"
-#include "mir/events/touch_event.h"
+#include <mir/events/event.h>
+#include <mir/events/input_event.h>
+#include <mir/events/keyboard_event.h>
+#include <mir/events/pointer_event.h>
+#include <mir/events/touch_event.h>
 
 MirInputEvent::MirInputEvent(MirInputEventType input_type,
                              MirInputDeviceId dev,
