@@ -1,5 +1,5 @@
 /*
- * Copyright © 2021 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -14,8 +14,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/events/input_event.h"
-#include "mir/events/keyboard_resync_event.h"
+#include <mir/events/input_event.h>
+#include <mir/events/keyboard_resync_event.h>
 
 MirKeyboardResyncEvent::MirKeyboardResyncEvent() :
     MirInputEvent(mir_input_event_type_keyboard_resync)
