@@ -14,7 +14,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/events/resize_event.h"
+#include <mir/events/resize_event.h>
 
 MirResizeEvent::MirResizeEvent() : MirEvent(mir_event_type_resize)
 {
@@ -54,4 +54,3 @@ void MirResizeEvent::set_height(int height)
 {
     height_ = height;
 }
-
