@@ -15,7 +15,7 @@
  */
 
 #include <boost/throw_exception.hpp>
-#include "mir/events/touch_event.h"
+#include <mir/events/touch_event.h>
 
 #include <stdexcept>
 
