@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/log.h"
+#include <mir/log.h>
 
 #define MIR_HANDLE_EVENT_EXCEPTION(expr) \
     try                                  \
