@@ -17,10 +17,10 @@
 #define MIR_LOG_COMPONENT "input-event-access"
 
 
-#include "mir/events/event_type_to_string.h"
-#include "mir/events/event_private.h"
-#include "mir/fatal.h"
-#include "mir/log.h"
+#include <mir/events/event_type_to_string.h>
+#include <mir/events/event_private.h>
+#include <mir/fatal.h>
+#include <mir/log.h>
 #include <mir_toolkit/events/input/pointer_event.h>
 
 #include "../handle_event_exception.h"
@@ -333,4 +333,4 @@ bool mir_pointer_event_axis_stop(MirPointerEvent const* pev, MirPointerAxis axis
    default:
        mir::fatal_error_abort("Invalid axis enumeration %d", axis);
    }
-})
\ No newline at end of file
+})
