@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/libname.h"
+#include <mir/libname.h>
 
 #include <dlfcn.h>
 
