@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -14,12 +14,17 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/log.h"
-#include "mir/logging/logger.h"
+#include <mir/log.h>
+#include <mir/logging/logger.h>
+#include <chrono>
 #include <cstdio>
-
 #include <exception>
+#include <format>
+#include <iostream>
+#include <sstream>
+
 #include <boost/exception/diagnostic_information.hpp>
+#include <errno.h>
 
 namespace mir {
 
@@ -84,4 +89,36 @@ void log(
     }
 }
 
+void security_log(
+    logging::Severity severity,
+    std::string const& event,
+    std::string const& description)
+{
+    auto now = std::chrono::system_clock::now();
+    auto time_t = std::chrono::system_clock::to_time_t(now);
+
+    std::stringstream ss;
+    ss << std::put_time(std::gmtime(&time_t), "%FT%TZ");
+
+    auto message = std::format(
+        "{{"
+            "\"datetime\": \"{}\", "
+            "\"appid\": \"{}\", "
+            "\"event\": \"{}\", "
+            "\"level\": \"{}\", "
+            "\"description\": \"{}\" "
+        "}}",
+        ss.str(),
+        program_invocation_short_name ? program_invocation_short_name : "<unknown>",
+        event,
+        (severity == logging::Severity::critical ? "CRITICAL" :
+         severity == logging::Severity::error ? "ERROR" :
+         severity == logging::Severity::warning ? "WARN" :
+         severity == logging::Severity::informational ? "INFO" :
+         severity == logging::Severity::debug ? "DEBUG" : "UNKNOWN"),
+        description
+    );
+    logging::log(severity, message, "security");
+}
+
 } // namespace mir
