@@ -1,5 +1,5 @@
 /*
- * Copyright © 2022 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/logging/file_logger.h"
+#include <mir/logging/file_logger.h>
 
 #include <iostream>
 
