@@ -1,5 +1,5 @@
 /*
- * Copyright © 2022 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -15,7 +15,7 @@
 
  */
 
-#include "mir/logging/multi_logger.h"
+#include <mir/logging/multi_logger.h>
 
 namespace ml = mir::logging;
 
