@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir_toolkit/cursors.h"
+#include <mir_toolkit/cursors.h>
 
 // Cursor names are from CSS3: https://www.w3.org/TR/css-ui-3/#propdef-cursor
 extern "C" char const* const mir_default_cursor_name = "default";
