@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License version 2 or 3 as
@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/report/lttng/tracepoint_provider.h"
+#include <mir/report/lttng/tracepoint_provider.h>
 
 #include <boost/throw_exception.hpp>
 #include <stdexcept>
