@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-#include "mir/fd.h"
+#include <mir/fd.h>
 #include <unistd.h>
 #include <algorithm>
 
@@ -34,7 +34,7 @@ mir::Fd::Fd(int raw_fd) :
             if (!fd) return;
             if (*fd > mir::Fd::invalid) ::close(*fd);
             delete fd;
-        }} 
+        }}
 {
 }
 
