@@ -41,15 +41,6 @@ public:
     virtual std::shared_ptr<graphics::DisplayConfiguration> base_configuration() = 0;
     virtual void configure(std::shared_ptr<scene::Session> const&, std::shared_ptr<graphics::DisplayConfiguration> const&) = 0;
 
-    virtual void set_base_configuration(std::shared_ptr<graphics::DisplayConfiguration> const&) = 0;
-    virtual void preview_base_configuration(
-        std::weak_ptr<scene::Session> const& session,
-        std::shared_ptr<graphics::DisplayConfiguration> const& new_configuration,
-        std::chrono::seconds timeout) = 0;
-    virtual void confirm_base_configuration(
-        std::shared_ptr<scene::Session> const& session,
-        std::shared_ptr<graphics::DisplayConfiguration> const& confirmed_configuration) = 0;
-
 protected:
     DisplayChanger() = default;
     DisplayChanger(DisplayChanger const&) = delete;
