@@ -17,7 +17,7 @@
 #ifndef MIR_FRONTEND_PROMPT_SESSION_H_
 #define MIR_FRONTEND_PROMPT_SESSION_H_
 
-#include "mir_toolkit/common.h"
+#include <mir_toolkit/common.h>
 
 #include <sys/types.h>
 #include <vector>
