@@ -17,12 +17,15 @@
 #ifndef MIR_FRONTEND_WAYLAND_H
 #define MIR_FRONTEND_WAYLAND_H
 
+#include <mir/graphics/display_configuration.h>
+
 #include <memory>
 #include <string>
 #include <vector>
 
 struct wl_client;
 struct wl_resource;
+namespace mir::wayland { class Client; }
 
 namespace mir
 {
@@ -48,6 +51,21 @@ auto get_standard_extensions() -> std::vector<std::string>;
 
 /// Returns all extensions core Mir supports
 auto get_supported_extensions() -> std::vector<std::string>;
+
+class WaylandTools
+{
+public:
+    WaylandTools() = default;
+    virtual ~WaylandTools() = default;
+    WaylandTools(WaylandTools const&) = delete;
+    WaylandTools& operator=(WaylandTools const&) = delete;
+
+    virtual void for_each_output_binding(
+        wayland::Client* client,
+        graphics::DisplayConfigurationOutputId output,
+        std::function<void(struct wl_resource* output)> const& callback) = 0;
+
+};
 }
 }
 
