@@ -14,7 +14,7 @@
 #ifndef MIR_GRAPHICS_DEFAULT_DISPLAY_CONFIGURATION_POLICY_H_
 #define MIR_GRAPHICS_DEFAULT_DISPLAY_CONFIGURATION_POLICY_H_
 
-#include "mir/graphics/display_configuration_policy.h"
+#include <mir/graphics/display_configuration_policy.h>
 
 namespace mir
 {
