@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -18,7 +18,7 @@
 #ifndef MIR_INPUT_CURSOR_IMAGES_H_
 #define MIR_INPUT_CURSOR_IMAGES_H_
 
-#include "mir/geometry/size.h"
+#include <mir/geometry/size.h>
 
 #include <memory>
 #include <string>
