@@ -17,9 +17,9 @@
 #ifndef MIR_INPUT_DEVICE_H_
 #define MIR_INPUT_DEVICE_H_
 
-#include "mir/input/device_capability.h"
-#include "mir_toolkit/event.h"
-#include "mir/optional_value.h"
+#include <mir/input/device_capability.h>
+#include <mir_toolkit/event.h>
+#include <mir/optional_value.h>
 
 #include <memory>
 
