@@ -1,5 +1,5 @@
 /*
- * Copyright © 2022 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,7 +17,7 @@
 #ifndef MIR_INPUT_KEYBOARD_OBSERVER_H_
 #define MIR_INPUT_KEYBOARD_OBSERVER_H_
 
-#include "mir/events/input_event.h"
+#include <mir/events/input_event.h>
 #include <memory>
 
 namespace mir
