@@ -17,7 +17,7 @@
 #ifndef MIR_INPUT_TOUCH_VISUALIZER_H_
 #define MIR_INPUT_TOUCH_VISUALIZER_H_
 
-#include "mir/geometry/point.h"
+#include <mir/geometry/point.h>
 
 #include <vector>
 
@@ -36,15 +36,15 @@ public:
     struct Spot
     {
         geometry::Point touch_location;
-        
+
         // If pressure is zero, the touch-point can be interpreted as a hover.
         float pressure;
     };
-    
+
     // Toggle visualization of touches
     virtual void enable() = 0;
     virtual void disable() = 0;
-    
+
     // Visualize a given set of touches statelessly.
     virtual void visualize_touches(std::vector<Spot> const& touches) = 0;
 
