@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,7 +17,7 @@
 #ifndef MIR_LOCKABLE_CALLBACK_WRAPPER_H_
 #define MIR_LOCKABLE_CALLBACK_WRAPPER_H_
 
-#include "mir/lockable_callback.h"
+#include <mir/lockable_callback.h>
 
 #include <functional>
 #include <memory>
