@@ -17,12 +17,13 @@
 #ifndef MIR_SCENE_SURFACE_H_
 #define MIR_SCENE_SURFACE_H_
 
-#include "mir/graphics/renderable.h"
-#include "mir/input/surface.h"
-#include "mir/frontend/surface.h"
-#include "mir/compositor/compositor_id.h"
-#include "mir/optional_value.h"
-#include "mir/observer_registrar.h"
+#include <mir/graphics/renderable.h>
+#include <mir/input/surface.h>
+#include <mir/frontend/surface.h>
+#include <mir/compositor/compositor_id.h>
+#include <mir/flags.h>
+#include <mir/optional_value.h>
+#include <mir/observer_registrar.h>
 #include "surface_state_tracker.h"
 
 #include <vector>
@@ -65,7 +66,7 @@ public:
     /// Size of the surface including window frame (if any)
     virtual geometry::Size window_size() const = 0;
 
-    virtual graphics::RenderableList generate_renderables(compositor::CompositorID id) const = 0; 
+    virtual graphics::RenderableList generate_renderables(compositor::CompositorID id) const = 0;
 
     virtual MirWindowType type() const = 0;
     virtual MirWindowState state() const = 0;
@@ -90,12 +91,15 @@ public:
     virtual void set_input_region(std::vector<geometry::Rectangle> const& region) = 0;
     virtual std::vector<geometry::Rectangle> get_input_region() const = 0;
 
+    virtual void set_opaque_region(geometry::Rectangles const& region) = 0;
+
     /// Given value is the frame size of the window
     virtual void resize(geometry::Size const& window_size) = 0;
     virtual void set_transformation(glm::mat4 const& t) = 0;
     virtual void set_alpha(float alpha) = 0;
     virtual void set_orientation(MirOrientation orientation) = 0;
-    
+    virtual void set_mirror_mode(MirMirrorMode mirror_mode) = 0;
+
     virtual void set_cursor_image(std::shared_ptr<graphics::CursorImage> const& image) override = 0;
     virtual std::shared_ptr<graphics::CursorImage> cursor_image() const override = 0;
 
@@ -110,6 +114,7 @@ public:
     virtual int query(MirWindowAttrib attrib) const = 0;
 
     virtual void rename(std::string const& title) = 0;
+    virtual std::list<StreamInfo> get_streams() const = 0;
     virtual void set_streams(std::list<StreamInfo> const& streams) = 0;
 
     virtual void set_confine_pointer_state(MirPointerConfinementState state) = 0;
@@ -157,6 +162,25 @@ public:
     virtual auto focus_mode() const -> MirFocusMode = 0;
     virtual void set_focus_mode(MirFocusMode focus_mode) = 0;
     ///@}
+
+    /// Used when the surface is in a tiled layout to describe the
+    /// edges that are touching another part of the tiling grid.
+    /// @{
+    virtual auto tiled_edges() const -> Flags<MirTiledEdge> = 0;
+    virtual void set_tiled_edges(Flags<MirTiledEdge> flags) = 0;
+    ///@}
+
+    /// Manage the size bounds
+    /// @{
+    virtual auto min_width() const -> geometry::Width = 0;
+    virtual auto max_width() const -> geometry::Width = 0;
+    virtual auto min_height() const -> geometry::Height = 0;
+    virtual auto max_height() const -> geometry::Height = 0;
+    virtual void set_min_width(geometry::Width width) = 0;
+    virtual void set_max_width(geometry::Width width) = 0;
+    virtual void set_min_height(geometry::Height height) = 0;
+    virtual void set_max_height(geometry::Height height) = 0;
+    ///@}
 };
 }
 }
