@@ -17,8 +17,9 @@
 #ifndef MIR_SERVER_H_
 #define MIR_SERVER_H_
 
-#include "mir/shell/window_manager_builder.h"
-#include "mir_toolkit/common.h"
+#include <mir/graphics/display_configuration.h>
+#include <mir/shell/window_manager_builder.h>
+#include <mir_toolkit/common.h>
 
 #include <functional>
 #include <memory>
@@ -26,15 +27,17 @@
 #include <vector>
 
 struct wl_display;
+struct wl_resource;
+namespace mir::wayland { class Client; }
 
 namespace mir
 {
 template<class Observer>
 class ObserverRegistrar;
 
-namespace compositor { class Compositor; class DisplayBufferCompositorFactory; class CompositorReport; }
-namespace graphics { class Cursor; class DisplayPlatform; class RenderingPlatform; class Display; class GLConfig; class DisplayConfigurationPolicy; class DisplayConfigurationObserver; }
-namespace input { class CompositeEventFilter; class InputDispatcher; class CursorListener; class CursorImages; class TouchVisualizer; class InputDeviceHub; class InputDeviceRegistry;}
+namespace compositor { class Compositor; class DisplayBufferCompositorFactory; class CompositorReport; class ScreenShooterFactory; class Scene; }
+namespace graphics { class Cursor; class DisplayPlatform; class RenderingPlatform; class Display; class GLConfig; class DisplayConfigurationPolicy; class DisplayConfigurationObserver; class GraphicBufferAllocator; class CursorImage; class OutputFilter; }
+namespace input { class CompositeEventFilter; class InputDispatcher; class CursorObserverMultiplexer; class CursorImages; class TouchVisualizer; class InputDeviceHub; class InputDeviceRegistry;}
 namespace logging { class Logger; }
 namespace options { class Option; }
 namespace frontend
@@ -65,6 +68,7 @@ class SessionCoordinator;
 class SurfaceFactory;
 class Session;
 class SessionLock;
+class SceneReport;
 }
 namespace input
 {
@@ -74,6 +78,10 @@ namespace renderer
 {
 class RendererFactory;
 }
+namespace time
+{
+class Clock;
+}
 
 class Fd;
 class MainLoop;
@@ -308,14 +316,20 @@ public:
     /// Sets an override functor for the renderer_factory
     void override_the_renderer_factory(Builder<renderer::RendererFactory> const& renderer_factory_builder);
 
+    void override_the_accessibility_manager(Builder<shell::AccessibilityManager> const& accessibility_manager_factory_builder);
+
+    /// Allows for overriding the central clock used for alarms and other
+    /// timekeeping. Exclusively used for testing at the moment.
+    void override_the_clock(Builder<time::Clock> const& clock_builder);
+
     /// Each of the wrap functions takes a wrapper functor of the same form
     template<typename T> using Wrapper = std::function<std::shared_ptr<T>(std::shared_ptr<T> const&)>;
 
     /// Sets a wrapper functor for creating the cursor.
     void wrap_cursor(Wrapper<graphics::Cursor> const& cursor_builder);
 
-    /// Sets a wrapper functor for creating the cursor listener.
-    void wrap_cursor_listener(Wrapper<input::CursorListener> const& wrapper);
+    /// Sets a wrapper functor for creating the cursor observer multiplexer.
+    void wrap_cursor_observer_multiplexer(Wrapper<input::CursorObserverMultiplexer> const& wrapper);
 
     /// Sets a wrapper functor for creating the per-display rendering code.
     void wrap_display_buffer_compositor_factory(
@@ -329,9 +343,6 @@ public:
 
     /// Sets a wrapper functor for creating the surface stack.
     void wrap_surface_stack(Wrapper<shell::SurfaceStack> const& surface_stack);
-
-    /// Sets a wrapper functor for creating the application not responding detector.
-    void wrap_application_not_responding_detector(Wrapper<scene::ApplicationNotRespondingDetector> const & anr_detector);
 /** @} */
 
 /** @name Getting access to Mir subsystems
@@ -349,12 +360,15 @@ public:
     /// \return the composite event filter.
     auto the_composite_event_filter() const -> std::shared_ptr<input::CompositeEventFilter>;
 
-    /// \return the cursor listener.
-    auto the_cursor_listener() const -> std::shared_ptr<input::CursorListener>;
+    /// \return the cursor observer multiplexer.
+    auto the_cursor_observer_multiplexer() const -> std::shared_ptr<input::CursorObserverMultiplexer>;
 
     /// \return the cursor
     auto the_cursor() const -> std::shared_ptr<graphics::Cursor>;
 
+    /// \return the output filter.
+    auto the_output_filter() const -> std::shared_ptr<graphics::OutputFilter>;
+
     /// \return the focus controller.
     auto the_focus_controller() const -> std::shared_ptr<shell::FocusController>;
 
@@ -428,6 +442,10 @@ public:
     auto the_display_configuration_observer_registrar() const ->
         std::shared_ptr<ObserverRegistrar<graphics::DisplayConfigurationObserver>>;
 
+    /// \return the DisplayConfigurationObserver
+    auto the_display_configuration_observer() const ->
+        std::shared_ptr<graphics::DisplayConfigurationObserver>;
+
     /// \return a registrar to add and remove SeatObservers
     auto the_seat_observer_registrar() const ->
         std::shared_ptr<ObserverRegistrar<input::SeatObserver>>;
@@ -462,11 +480,6 @@ public:
     /// \param connect_handler callback to be invoked when the client connects
     auto open_client_wayland(ConnectHandler const& connect_handler) -> int;
 
-    /// Get a file descriptor that can be used to connect a prompt provider
-    /// It can be passed to another process, or used directly with mir_connect()
-    /// using the format "fd://%d".
-    auto open_prompt_socket() -> Fd;
-
     /// Get a file descriptor that can be used to connect a Wayland client
     /// It can be passed to another process, or used with wl_display_connect_to_fd()
     auto open_wayland_client_socket() -> Fd;
@@ -478,9 +491,6 @@ public:
             wl_display*,
             std::function<void(std::function<void()>&& work)> const&)> builder);
 
-    void set_wayland_extension_filter(
-        std::function<bool(std::shared_ptr<scene::Session> const&, char const*)> const& extension_filter);
-
     /// Get the name of the Wayland endpoint (if any) usable as a $WAYLAND_DISPLAY value
     auto wayland_display() const -> std::optional<std::string>;
 
@@ -489,12 +499,42 @@ public:
 
     auto get_activation_token() const -> std::string;
 
-    /// Overrides the standard set of Wayland extensions (mir::frontend::get_standard_extensions()) with a new list
-    void set_enabled_wayland_extensions(std::vector<std::string> const& extensions);
+    /// Set a policy for the provided wayland extension.
+    ///
+    /// Only clients for which the \p policy returns `true` will be offered the global \p interface_name.
+    ///
+    /// \param interface_name the interface to apply the policy on
+    /// \param policy the policy predicate with the session and interface name provided
+    ///               as arguments.
+    void set_wayland_extension_policy(
+        std::string const& interface_name,
+        std::function<bool(std::shared_ptr<scene::Session> const&, char const*)> const& policy);
 /** @} */
 
     auto the_decoration_strategy() const -> std::shared_ptr<DecorationStrategy>;
     void set_the_decoration_strategy(std::shared_ptr<DecorationStrategy> strategy);
+
+    auto the_buffer_allocator() const -> std::shared_ptr<graphics::GraphicBufferAllocator>;
+
+    auto the_default_cursor_image() const -> std::shared_ptr<graphics::CursorImage>;
+
+    auto the_scene_report() const -> std::shared_ptr<scene::SceneReport>;
+
+    auto the_scene() const -> std::shared_ptr<compositor::Scene>;
+
+    auto the_screen_shooter_factory() const -> std::shared_ptr<compositor::ScreenShooterFactory>;
+
+    /** @name Wayland tools
+     * These facilitate shells implementing Wayland protocol extensions.
+     * They should be called while the server is running (i.e. run() has been called and
+     * not exited) otherwise they throw a std::logic_error.
+     * @{ */
+    void for_each_output_binding(
+        wayland::Client* client,
+        graphics::DisplayConfigurationOutputId output,
+        std::function<void(wl_resource* output)> const& callback);
+    /** @} */
+
 private:
     struct ServerConfiguration;
     struct Self;
