@@ -17,7 +17,7 @@
 #ifndef MIR_SHELL_FOCUS_CONTROLLER_H_
 #define MIR_SHELL_FOCUS_CONTROLLER_H_
 
-#include "mir/geometry/forward.h"
+#include <mir/geometry/forward.h>
 
 #include <stddef.h>
 #include <memory>
