@@ -17,7 +17,7 @@
 #ifndef MIR_SHELL_SHELL_WRAPPER_H_
 #define MIR_SHELL_SHELL_WRAPPER_H_
 
-#include "mir/shell/shell.h"
+#include <mir/shell/shell.h>
 
 namespace mir
 {
@@ -54,8 +54,7 @@ public:
     auto open_session(
         pid_t client_pid,
         Fd socket_fd,
-        std::string const& name,
-        std::shared_ptr<frontend::EventSink> const& sink) -> std::shared_ptr<scene::Session> override;
+        std::string const& name) -> std::shared_ptr<scene::Session> override;
 
     void close_session(std::shared_ptr<scene::Session> const& session) override;
 
@@ -71,7 +70,6 @@ public:
 
     auto create_surface(
         std::shared_ptr<scene::Session> const& session,
-        wayland::Weak<frontend::WlSurface> const& wayland_surface,
         SurfaceSpecification const& params,
         std::shared_ptr<scene::SurfaceObserver> const& observer,
         Executor* observer_executor) -> std::shared_ptr<scene::Surface> override;
