@@ -1,5 +1,5 @@
 /*
- * Copyright © 2020 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3,
@@ -17,8 +17,8 @@
 #ifndef MIR_APPLICATION_INFO_INTERNAL_H
 #define MIR_APPLICATION_INFO_INTERNAL_H
 
-#include "miral/application_info.h"
-#include "miral/window.h"
+#include <miral/application_info.h>
+#include <miral/window.h>
 
 struct miral::ApplicationInfo::Self
 {
