@@ -17,7 +17,7 @@
 #include "basic_window_manager.h"
 #include "display_configuration_listeners.h"
 
-#include "miral/window_manager_tools.h"
+#include <miral/window_manager_tools.h>
 
 #include <mir/log.h>
 #include <mir/executor.h>
@@ -964,9 +964,6 @@ void miral::BasicWindowManager::send_tree_to_back(Window const& root)
 {
     auto const& info = info_for(root);
 
-    if (auto parent = info.parent())
-        raise_tree(parent);
-
     focus_controller->send_to_back(collect_windows(info));
 }
 
@@ -1215,6 +1212,11 @@ void miral::BasicWindowManager::modify_window(WindowInfo& window_info, WindowSpe
     if (modifications.state().is_set())
     {
         set_state(window_info, modifications.state().value());
+
+        if (modifications.state().value() == mir_window_state_minimized)
+        {
+            send_tree_to_back(window_info.window());
+        }
     }
     else if (modifications.output_id().is_set())
     {
@@ -2747,17 +2749,14 @@ void miral::BasicWindowManager::remove_output_from_display_areas(Locker const&,
     // Remove the output from all areas that contain it
     for (auto const& area : display_areas)
     {
-        auto const removed = std::remove_if(
-            area->contained_outputs.begin(),
-            area->contained_outputs.end(),
+        auto const num_removed = std::erase_if(
+            area->contained_outputs,
             [&](Output const& area_output)
             {
                 return area_output.is_same_output(output);
             });
-        bool const output_removed{removed != area->contained_outputs.end()};
-        area->contained_outputs.erase(removed, area->contained_outputs.end());
 
-        if (output_removed)
+        if (num_removed > 0)
         {
             area->area = area->bounding_rectangle_of_contained_outputs();
         }
