@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "miral/display_configuration_option.h"
+#include <miral/display_configuration_option.h>
 #include "static_display_config.h"
 
 #include <mir/graphics/default_display_configuration_policy.h>
@@ -23,6 +23,7 @@
 #include <mir/server.h>
 
 #include <algorithm>
+#include <format>
 
 namespace mg = mir::graphics;
 using namespace mir::geometry;
@@ -30,25 +31,24 @@ using namespace mir::geometry;
 namespace
 {
 char const* const display_config_opt = "display-config";
-char const* const display_config_descr = "Display configuration [{clone,sidebyside,single,static=<filename>}]";
 
-//char const* const clone_opt_val = "clone";
+char const* const clone_opt_val = "clone";
 char const* const sidebyside_opt_val = "sidebyside";
 char const* const single_opt_val = "single";
 char const* const static_opt_val = "static=";
 
 char const* const display_alpha_opt = "translucent";
-char const* const display_alpha_descr = "Select a display mode with alpha[{on,off}]";
+char const* const display_alpha_descr = "Select a display mode with alpha channel. [{on,off}]";
 
 char const* const display_alpha_off = "off";
 char const* const display_alpha_on = "on";
 
 char const* const display_scale_opt = "display-scale";
-char const* const display_scale_descr = "Scale for all displays";
+char const* const display_scale_descr = "Pixel scale for all displays, e.g. 2.0.";
 char const* const display_scale_default = "1.0";
 
 char const* const display_autoscale_opt = "display-autoscale";
-char const* const display_autoscale_descr = "Target height in logical pixels for all displays";
+char const* const display_autoscale_descr = "Automatically set pixel scale for displays so they have specified logical height in pixels, e.g. 1080.";
 
 class PixelFormatSelector : public mg::DisplayConfigurationPolicy
 {
@@ -178,7 +178,14 @@ void AutoscaleSetter::apply_to(mg::UserDisplayConfigurationOutput& output)
 void miral::display_configuration_options(mir::Server& server)
 {
     // Add choice of monitor configuration
-    server.add_configuration_option(display_config_opt, display_config_descr,   sidebyside_opt_val);
+    server.add_configuration_option(display_config_opt,
+                                    std::format("Display configuration:\n"
+                                                 " - `{}`: all screens show the same content.\n"
+                                                 " - `{}`: each screen placed to the right of the previous one.\n"
+                                                 " - `{}`: only the first screen used.\n"
+                                                 " - `{}filename`: use layout specified in <filename>.",
+                                                 clone_opt_val, sidebyside_opt_val, single_opt_val, static_opt_val),
+                                    sidebyside_opt_val);
     server.add_configuration_option(display_alpha_opt,  display_alpha_descr,    display_alpha_off);
     server.add_configuration_option(display_scale_opt,  display_scale_descr,    display_scale_default);
     server.add_configuration_option(display_autoscale_opt,  display_autoscale_descr, mir::OptionType::integer);
