@@ -17,17 +17,18 @@
 #include "input_device_config.h"
 #include "input_device_configuration_options.h"
 
-#include "mir/abnormal_exit.h"
-#include "mir/input/device.h"
-#include "mir/input/device_capability.h"
-#include "mir/input/input_device_hub.h"
-#include "mir/input/input_device_observer.h"
-#include "mir/input/mir_pointer_config.h"
-#include "mir/input/mir_touchpad_config.h"
-#include "mir/options/option.h"
-#include "mir/server.h"
-#include "mir_toolkit/mir_input_device_types.h"
-#include "mir/log.h"
+#include <mir/abnormal_exit.h>
+#include <mir/input/device.h>
+#include <mir/input/device_capability.h>
+#include <mir/input/input_device_hub.h>
+#include <mir/input/input_device_observer.h>
+#include <mir/input/mir_pointer_config.h>
+#include <mir/input/mir_touchpad_config.h>
+#include <mir/options/configuration.h>
+#include <mir/options/option.h>
+#include <mir/server.h>
+#include <mir_toolkit/mir_input_device_types.h>
+#include <mir/log.h>
 
 #include <format>
 #include <optional>
@@ -82,6 +83,8 @@ char const* const touchpad_click_mode_area = "area";
 char const* const touchpad_click_mode_clickfinger = "clickfinger";
 char const* const touchpad_middle_mouse_button_emulation_opt= "touchpad-middle-mouse-button-emulation";
 
+char const* const key_repeat_rate_opt = "key-repeat-rate";
+char const* const key_repeat_delay_opt = "key-repeat-delay";
 
 template<double lo, double hi>
 auto clamp(std::optional<double> opt_val)-> std::optional<double>
@@ -199,68 +202,100 @@ auto to_handedness(std::optional<std::string> const& opt_val)-> std::optional<Mi
 
 void miral::add_input_device_configuration_options_to(mir::Server& server)
 {
-    server.add_configuration_option(mouse_handedness_opt, std::format("Select mouse laterality: [{}, {}]", right, left),
+    server.add_configuration_option(mouse_handedness_opt, std::format("Mouse laterality:\n"
+                                                                      " - `{}`: left button is primary.\n"
+                                                                      " - `{}`: right button is primary.",
+                                                                      right, left),
     mir::OptionType::string);
     server.add_configuration_option(mouse_cursor_acceleration_opt,
-                                    "Select acceleration profile for mice and trackballs [none, adaptive]",
+                                    std::format("Acceleration profile for mice and trackballs:\n"
+                                                " - `{}`: no acceleration.\n"
+                                                " - `{}`: cursor is accelerated.",
+                                                acceleration_none,
+                                                acceleration_adaptive),
                                     mir::OptionType::string);
     server.add_configuration_option(mouse_cursor_acceleration_bias_opt,
-                                    "Set the pointer acceleration speed of mice within a range of [-1.0, 1.0]",
+                                    "Pointer acceleration speed of mice. "
+                                    "Must be within range of [-1.0, 1.0].",
                                     mir::OptionType::real);
     server.add_configuration_option(mouse_scroll_speed_opt,
-                                    "Scales mouse scroll. Use negative values for natural scrolling",
+                                    "Mouse scroll speed scaling factor. "
+                                    "Use negative values for natural scrolling.",
                                     mir::OptionType::real);
     server.add_configuration_option(mouse_hscroll_speed_override_opt,
-                                    "Scales mouse horizontal scroll. Use negative values for natural scrolling",
+                                    "Mouse horizontal scroll speed scaling factor. "
+                                    "Use negative values for natural scrolling.",
                                     mir::OptionType::real);
     server.add_configuration_option(mouse_vscroll_speed_override_opt,
-                                    "Scales mouse vertical scroll. Use negative values for natural scrolling",
+                                    "Mouse vertical scroll speed scaling factor. "
+                                    "Use negative values for natural scrolling.",
                                     mir::OptionType::real);
     server.add_configuration_option(disable_while_typing_opt,
-                                    "Disable touchpad while typing on keyboard configuration [true, false]",
+                                    "Disable touchpad while typing on keyboard. [true, false]",
                                     mir::OptionType::boolean);
     server.add_configuration_option(disable_with_external_mouse_opt,
-                                    "Disable touchpad if an external pointer device is plugged in [true, false]",
+                                    "Disable touchpad if an external pointer device is plugged in. [true, false]",
                                     mir::OptionType::boolean);
     server.add_configuration_option(touchpad_tap_to_click_opt,
-                                    "Enable or disable tap-to-click on this device, with"
-                                    " 1, 2, 3 finger tap mapping to left, right, middle click, respectively [true, false]",
+                                    "Enable or disable tap-to-click on this device. "
+				    "If enabled 1, 2, and 3 finger taps are mapped to left, right, middle click events. [true, false]",
                                     mir::OptionType::boolean);
     server.add_configuration_option(touchpad_cursor_acceleration_opt,
-                                    "Select acceleration profile for touchpads [none, adaptive]",
+                                    std::format("Acceleration profile for touchpads:\n"
+                                                " - `{}`: no acceleration.\n"
+                                                " - `{}`: cursor accelerates.",
+                                                acceleration_none,
+                                                acceleration_adaptive),
                                     mir::OptionType::string);
     server.add_configuration_option(touchpad_cursor_acceleration_bias_opt,
-                                    "Set the pointer acceleration speed of touchpads within a range of [-1.0, 1.0]",
+                                    "Pointer acceleration speed scaling factor for touchpads. "
+                                    "Must be within range of [-1.0, 1.0].",
                                     mir::OptionType::real);
     server.add_configuration_option(touchpad_scroll_speed_opt,
-                                    "Scales touchpad scroll. Use negative values for natural scrolling",
+                                    "Touchpad scroll scaling factor. "
+                                    "Use negative values for natural scrolling.",
                                     mir::OptionType::real);
     server.add_configuration_option(touchpad_hscroll_speed_override_opt,
-                                    "Scales touchpad horizontal scroll. Use negative values for natural scrolling",
+                                    "Touchpad horizontal scroll scaling factor. "
+                                    "Use negative values for natural scrolling.",
                                     mir::OptionType::real);
     server.add_configuration_option(touchpad_vscroll_speed_override_opt,
-                                    "Scales touchpad vertical scroll. Use negative values for natural scrolling",
+                                    "Touchpad vertical scroll scaling factor. "
+                                    "Use negative values for natural scrolling.",
                                     mir::OptionType::real);
 
     server.add_configuration_option(touchpad_scroll_mode_opt,
-                                    std::format("Select scroll mode for touchpads: [{}, {}, {}]",
+                                    std::format("Scroll mode for touchpads. "
+                                                "Generates scroll events when:\n"
+                                                " - `{}`: single finger moves on right or bottom edges of touchpad.\n"
+                                                " - `{}`: two fingers move horizontally or vertically.\n"
+                                                " - `{}`: mouse button held down.",
                                                 touchpad_scroll_mode_edge,
                                                 touchpad_scroll_mode_two_finger,
                                                 touchpad_scroll_mode_button_down_scroll),
                                     mir::OptionType::string);
 
     server.add_configuration_option(touchpad_click_mode_opt,
-                                    std::format("Select click mode for touchpads: [{}, {}, {}]",
-                                        touchpad_click_mode_none,
-                                        touchpad_click_mode_area,
-                                        touchpad_click_mode_clickfinger),
+                                    std::format("Click mode for touchpad. "
+                                                "Left, middle and right button click events generated when:\n"
+                                                " - `{}`: no events generated.\n"
+                                                " - `{}`: single finger tap on left, middle or right area.\n"
+                                                " - `{}`: one, two or three fingers present when touchpad pushed down.",
+                                                touchpad_click_mode_none,
+                                                touchpad_click_mode_area,
+                                                touchpad_click_mode_clickfinger),
                                     mir::OptionType::string);
 
     server.add_configuration_option(touchpad_middle_mouse_button_emulation_opt,
-                                    "Converts a simultaneous left and right button click into a middle button",
+                                    "Generate middle mouse button click from a simultaneous left and right button click.",
                                     mir::OptionType::boolean);
 
-    server.add_init_callback([&]()
+    // 25 rate and 600 delay are the default in Weston and Sway
+    server.add_configuration_option(key_repeat_rate_opt, "Number of milliseconds between generated key repeat events.", 25);
+    server.add_configuration_option(key_repeat_delay_opt, "Number of millisecond to hold down a key before generating repeat events.", 600);
+
+    server.add_init_callback(
+        [&]()
         {
             auto const input_config = InputDeviceConfig::the_input_configuration(server.get_options());
             server.the_input_device_hub()->add_observer(input_config);
@@ -286,6 +321,10 @@ miral::InputDeviceConfig::InputDeviceConfig(std::shared_ptr<mir::options::Option
         convert_to_scroll_mode(get_optional<std::string>(options, touchpad_scroll_mode_opt)),
         get_optional<bool>(options, touchpad_tap_to_click_opt),
         get_optional<bool>(options, touchpad_middle_mouse_button_emulation_opt)
+    },
+    keyboard_config{
+        get_optional<int>(options, key_repeat_rate_opt),
+        get_optional<int>(options, key_repeat_delay_opt),
     }
 {
 }
@@ -390,3 +429,48 @@ void miral::MouseInputConfiguration::apply_to(mi::Device& device) const
     }
 }
 
+void miral::MouseInputConfiguration::merge(MouseInputConfiguration const& other)
+{
+    if (!acceleration)
+        acceleration = other.acceleration;
+    if (!acceleration_bias)
+        acceleration_bias = other.acceleration_bias;
+    if (!handedness)
+        handedness = other.handedness;
+    if (!hscroll_speed)
+        hscroll_speed = other.hscroll_speed;
+    if (!vscroll_speed)
+        vscroll_speed = other.vscroll_speed;
+}
+
+void miral::TouchpadInputConfiguration::merge(TouchpadInputConfiguration const& other)
+{
+    if (!disable_while_typing)
+        disable_while_typing = other.disable_while_typing;
+    if (!disable_with_external_mouse)
+        disable_with_external_mouse = other.disable_with_external_mouse;
+    if (!acceleration)
+        acceleration = other.acceleration;
+    if (!acceleration_bias)
+        acceleration_bias = other.acceleration_bias;
+    if (!vscroll_speed)
+        vscroll_speed = other.vscroll_speed;
+    if (!hscroll_speed)
+        hscroll_speed = other.hscroll_speed;
+    if (!click_mode)
+        click_mode = other.click_mode;
+    if (!scroll_mode)
+        scroll_mode = other.scroll_mode;
+    if (!tap_to_click)
+        tap_to_click = other.tap_to_click;
+    if (!middle_button_emulation)
+        middle_button_emulation = other.middle_button_emulation;
+}
+
+void miral::KeyboardInputConfiguration::merge(KeyboardInputConfiguration const& other)
+{
+    if (!repeat_rate)
+        repeat_rate = other.repeat_rate;
+    if (!repeat_delay)
+        repeat_delay = other.repeat_delay;
+}
