@@ -1,5 +1,5 @@
 /*
- * Copyright © 2016-2020 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3 as
@@ -14,13 +14,14 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "miral/internal_client.h"
+#include <miral/internal_client.h>
 #include "join_client_threads.h"
 
 #include <mir/main_loop.h>
 #include <mir/server.h>
 #include <mir/scene/session.h>
 #include <mir/raii.h>
+#include <wayland-client-core.h>
 
 #define MIR_LOG_COMPONENT "miral::Internal Client"
 #include <mir/log.h>
@@ -87,7 +88,8 @@ class WlInternalClientRunner : public Base, public virtual InternalClientRunner
 public:
     WlInternalClientRunner(
         std::function<void(struct ::wl_display* display)> client_code,
-        std::function<void(std::weak_ptr<mir::scene::Session> const session)> connect_notification);
+        std::function<void(std::weak_ptr<mir::scene::Session> const session)> connect_notification,
+        std::function<void()> handle_stop);
 
     void run(mir::Server& server) override;
     void join_client_thread() override;
@@ -98,14 +100,17 @@ private:
     std::thread thread;
     std::function<void(struct ::wl_display* display)> const client_code;
     std::function<void(std::weak_ptr<mir::scene::Session> const session)> const connect_notification;
+    std::function<void()> handle_stop;
 };
 
 template<typename Base>
 WlInternalClientRunner<Base>::WlInternalClientRunner(
     std::function<void(struct ::wl_display* display)> client_code,
-    std::function<void(std::weak_ptr<mir::scene::Session> const session)> connect_notification) :
+    std::function<void(std::weak_ptr<mir::scene::Session> const session)> connect_notification,
+    std::function<void()> handle_stop) :
     client_code(std::move(client_code)),
-    connect_notification(std::move(connect_notification))
+    connect_notification(std::move(connect_notification)),
+    handle_stop(std::move(handle_stop))
 {
 }
 
@@ -125,7 +130,14 @@ void WlInternalClientRunner<Base>::run(mir::Server& server)
                 {
                     auto const deleter = mir::raii::deleter_for(display, &wl_display_disconnect);
                     client_code(display);
-                    wl_display_roundtrip(display);
+                    /* If the client code encountered a protocol error then the display
+                     * is no longer useable. Empirically, this tends to mean that
+                     * wl_display_roundtrip() hangs indifinitely.
+                     */
+                    if (!wl_display_get_error(display))
+                    {
+                        wl_display_roundtrip(display);
+                    }
                 }
             }
             catch (std::exception const&)
@@ -148,6 +160,7 @@ void WlInternalClientRunner<Base>::join_client_thread()
 {
     if (thread.joinable())
     {
+        handle_stop();
         thread.join();
     }
 }
@@ -155,7 +168,15 @@ void WlInternalClientRunner<Base>::join_client_thread()
 miral::StartupInternalClient::StartupInternalClient(
     std::function<void(struct ::wl_display* display)> client_code,
     std::function<void(std::weak_ptr<mir::scene::Session> const session)> connect_notification) :
-    internal_client(std::make_shared<WlInternalClientRunner<Self>>(std::move(client_code), std::move(connect_notification)))
+    internal_client(std::make_shared<WlInternalClientRunner<Self>>(std::move(client_code), std::move(connect_notification), []{}))
+{
+}
+
+miral::StartupInternalClient::StartupInternalClient(
+    std::function<void(struct ::wl_display* display)> client_code,
+    std::function<void(std::weak_ptr<mir::scene::Session> const session)> connect_notification,
+    std::function<void()> handle_stop)
+    : internal_client(std::make_shared<WlInternalClientRunner<Self>>(std::move(client_code), std::move(connect_notification), std::move(handle_stop)))
 {
 }
 
@@ -189,7 +210,7 @@ void miral::InternalClientLauncher::launch(
     std::function<void(struct ::wl_display* display)> const& client_code,
     std::function<void(std::weak_ptr<mir::scene::Session> const session)> const& connect_notification) const
 {
-    self->runner = std::make_shared<WlInternalClientRunner<Self>>(client_code, connect_notification);
+    self->runner = std::make_shared<WlInternalClientRunner<Self>>(client_code, connect_notification, []{});
     self->server->the_main_loop()->enqueue(this, [this] { self->runner->run(*self->server); });
     register_runner(self->server, self->runner);
 }
