@@ -19,6 +19,7 @@
 #include <mir/scene/surface.h>
 
 #include <algorithm>
+#include <ranges>
 
 namespace
 {
@@ -31,13 +32,13 @@ bool visible(miral::Window const& window)
 
 void miral::MRUWindowList::push(Window const& window)
 {
-    windows.erase(remove(begin(windows), end(windows), window), end(windows));
+    std::erase(windows, window);
     windows.push_back(window);
 }
 
 void miral::MRUWindowList::insert_below_top(Window const& window)
 {
-    windows.erase(remove(begin(windows), end(windows), window), end(windows));
+    std::erase(windows, window);
     if(!windows.empty())
         windows.insert(windows.end()-1, window);
     else
@@ -46,7 +47,7 @@ void miral::MRUWindowList::insert_below_top(Window const& window)
 
 void miral::MRUWindowList::erase(Window const& window)
 {
-    windows.erase(remove(begin(windows), end(windows), window), end(windows));
+    std::erase(windows, window);
 }
 
 auto miral::MRUWindowList::top() const -> Window
@@ -57,8 +58,8 @@ auto miral::MRUWindowList::top() const -> Window
 
 void miral::MRUWindowList::enumerate(Enumerator const& enumerator) const
 {
-    for (auto i = windows.rbegin(); i != windows.rend(); ++i)
-        if (visible(*i))
-            if (!enumerator(const_cast<Window&>(*i)))
+    for (auto const& window : std::ranges::reverse_view(windows))
+        if (visible(window))
+            if (!enumerator(const_cast<Window&>(window)))
                 break;
 }
