@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "miral/window_info.h"
+#include <miral/window_info.h>
 #include "window_info_internal.h"
 
 #include <mir/scene/surface.h>
@@ -303,7 +303,10 @@ auto miral::WindowInfo::restore_rect() const -> mir::geometry::Rectangle
         }
 
         // Halfway between current size and min size is reasonable for a maximized/fullscreen window
-        auto const min_size_disp = Displacement{as_delta(self->min_width), as_delta(self->min_height)};
+        std::shared_ptr<mir::scene::Surface> const surface{self->window};
+        auto const min_size_disp = surface ?
+            Displacement{as_delta(surface->min_width()), as_delta(surface->min_height())} :
+            Displacement{};
         Size const reasonable_size{as_size(
             (as_displacement(self->window.size()) - min_size_disp) * 0.5
             + min_size_disp)};
@@ -341,22 +344,50 @@ auto miral::WindowInfo::children() const -> std::vector <Window> const&
 
 auto miral::WindowInfo::min_width() const -> mir::geometry::Width
 {
-    return self->min_width;
+    if (std::shared_ptr<mir::scene::Surface> const surface{self->window})
+    {
+        return surface->min_width();
+    }
+    else
+    {
+        return Width{0};
+    }
 }
 
 auto miral::WindowInfo::min_height() const -> mir::geometry::Height
 {
-    return self->min_height;
+    if (std::shared_ptr<mir::scene::Surface> const surface{self->window})
+    {
+        return surface->min_height();
+    }
+    else
+    {
+        return Height{0};
+    }
 }
 
 auto miral::WindowInfo::max_width() const -> mir::geometry::Width
 {
-    return self->max_width;
+    if (std::shared_ptr<mir::scene::Surface> const surface{self->window})
+    {
+        return surface->max_width();
+    }
+    else
+    {
+        return Width{std::numeric_limits<int>::max()};
+    }
 }
 
 auto miral::WindowInfo::max_height() const -> mir::geometry::Height
 {
-    return self->max_height;
+    if (std::shared_ptr<mir::scene::Surface> const surface{self->window})
+    {
+        return surface->max_height();
+    }
+    else
+    {
+        return Height{std::numeric_limits<int>::max()};
+    }
 }
 
 auto miral::WindowInfo::userdata() const -> std::shared_ptr<void>
@@ -490,3 +521,9 @@ auto miral::WindowInfo::visible_on_lock_screen() const -> bool
     std::shared_ptr<mir::scene::Surface> const surface = self->window;
     return surface ? surface->visible_on_lock_screen() : false;
 }
+
+auto miral::WindowInfo::tiled_edges() const -> mir::Flags<MirTiledEdge>
+{
+    std::shared_ptr<mir::scene::Surface> const surface = self->window;
+    return surface ? surface->tiled_edges() : mir::Flags(mir_tiled_edge_none);
+}
