@@ -14,8 +14,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "miral/window_manager_tools.h"
-#include "miral/zone.h"
+#include <miral/window_manager_tools.h>
+#include <miral/zone.h>
 #include "window_manager_tools_implementation.h"
 
 miral::WindowManagerTools::WindowManagerTools(WindowManagerToolsImplementation* tools) :
@@ -145,4 +145,4 @@ void miral::WindowManagerTools::for_each_window_in_workspace(
 { tools->for_each_window_in_workspace(workspace, callback); }
 
 void miral::WindowManagerTools::move_cursor_to(mir::geometry::PointF point)
-{ tools->move_cursor_to(point); }
\ No newline at end of file
+{ tools->move_cursor_to(point); }
