@@ -1,5 +1,5 @@
 /*
- * Copyright © 2002 Keith Packard
+ * Copyright © Keith Packard
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -726,7 +726,7 @@ _XcursorBuildFullname (const char *dir, const char *subdir, const char *file)
 static const char *
 _XcursorNextPath (const char *path)
 {
-    char    *colon = strchr (path, ':');
+    const char    *colon = strchr (path, ':');
 
     if (!colon)
 	return NULL;
