@@ -14,32 +14,40 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/graphics/linux_dmabuf.h"
-#include "mir/fd.h"
-#include "mir/graphics/drm_formats.h"
+#include <mir/graphics/linux_dmabuf.h>
+#include <mir/anonymous_shm_file.h>
+#include <mir/fd.h>
+#include <mir/graphics/drm_formats.h>
 #include "egl_buffer_copy.h"
 
+#include <mir/synchronised.h>
+#include <mir_toolkit/common.h>
 #include "wayland_wrapper.h"
-#include "mir/wayland/protocol_error.h"
-#include "mir/wayland/client.h"
-#include "mir/graphics/egl_extensions.h"
-#include "mir/graphics/egl_error.h"
-#include "mir/graphics/texture.h"
-#include "mir/graphics/program_factory.h"
-#include "mir/graphics/buffer.h"
-#include "mir/graphics/buffer_basic.h"
-#include "mir/graphics/dmabuf_buffer.h"
-#include "mir/graphics/egl_context_executor.h"
+#include <mir/wayland/protocol_error.h>
+#include <mir/wayland/client.h>
+#include <mir/graphics/egl_extensions.h>
+#include <mir/graphics/egl_error.h>
+#include <mir/graphics/texture.h>
+#include <mir/graphics/program_factory.h>
+#include <mir/graphics/buffer.h>
+#include <mir/graphics/buffer_basic.h>
+#include <mir/graphics/dmabuf_buffer.h>
+#include <mir/graphics/egl_context_executor.h>
+#include <mir/renderer/sw/pixel_source.h>
 
 #include <EGL/egl.h>
 #include <cstdint>
 #include <cstring>
 #include <stdexcept>
+#include <sys/ioctl.h>
+#include <sys/mman.h>
+#include <sys/stat.h>
+#include <system_error>
+#include <linux/dma-buf.h>
 
 #define MIR_LOG_COMPONENT "linux-dmabuf-import"
-#include "mir/log.h"
+#include <mir/log.h>
 
-#include <mutex>
 #include <vector>
 #include <optional>
 #include <utility>
@@ -51,6 +59,17 @@ namespace mg = mir::graphics;
 namespace mgc = mg::common;
 namespace mw = mir::wayland;
 namespace geom = mir::geometry;
+namespace mrs = mir::renderer::software;
+
+namespace
+{
+    template <typename T>
+    void wl_array_add(wl_array *array, T value)
+    {
+        if (auto d = static_cast<T*>(wl_array_add(array, sizeof(T))))
+            *d = value;
+    }
+}
 
 
 class mg::DmaBufFormatDescriptors
@@ -608,7 +627,7 @@ public:
     LinuxDmaBufParams(
         wl_resource* new_resource,
         std::shared_ptr<mg::DMABufEGLProvider> provider)
-        : mir::wayland::LinuxBufferParamsV1(new_resource, Version<3>{}),
+        : mir::wayland::LinuxBufferParamsV1(new_resource, Version<5>{}),
           consumed{false},
           provider{std::move(provider)}
     {
@@ -856,6 +875,86 @@ private:
     }
 };
 
+class LinuxDmaBufFeedback : public mir::wayland::LinuxDmabufFeedbackV1
+{
+public:
+    LinuxDmaBufFeedback(
+        wl_resource* new_resource,
+        struct wl_resource* surface,
+        std::shared_ptr<mg::DMABufEGLProvider> provider)
+        : mir::wayland::LinuxDmabufFeedbackV1(new_resource, Version<5>{}),
+          provider{std::move(provider)}
+    {
+        // We have the same feedback regardless of surface.
+        (void)surface;
+
+        // Build table in shared memory.
+        struct Format
+        {
+            uint32_t format;
+            uint32_t padding; /* unused */
+            uint64_t modifier;
+        };
+        auto const& formats = this->provider->supported_formats();
+        size_t format_table_length = 0;
+        for (auto i = 0u; i < formats.num_formats(); ++i)
+        {
+            format_table_length += formats[i].modifiers.size();
+        }
+        mir::AnonymousShmFile shm_buffer{format_table_length * sizeof(Format)};
+        Format *data = static_cast<Format*>(shm_buffer.base_ptr());
+        size_t k = 0;
+        for (auto i = 0u; i < formats.num_formats(); ++i)
+        {
+            auto format = formats[i];
+            for (auto j = 0u; j < format.modifiers.size(); ++j)
+            {
+                data[k].format = format.format;
+                data[k].padding = 0;
+                data[k].modifier = format.modifiers[j];
+                k++;
+            }
+        }
+
+        {
+            send_format_table_event(mir::Fd{mir::IntOwnedFd{shm_buffer.fd()}}, format_table_length * sizeof(Format));
+            wl_array main_device = {};
+            wl_array_init(&main_device);
+            wl_array_add<dev_t>(&main_device, this->provider->devnum());
+            send_main_device_event(&main_device);
+            wl_array_release(&main_device);
+        }
+
+        {
+            // We only currently support one device, which accessess all formats.
+            wl_array device = {};
+            wl_array_init(&device);
+            wl_array_add<dev_t>(&device, this->provider->devnum());
+            send_tranche_target_device_event(&device);
+            wl_array_release(&device);
+        }
+        send_tranche_flags_event(0);
+
+        {
+            wl_array indicies = {};
+            wl_array_init(&indicies);
+            for (auto i = 0u; i < format_table_length; ++i)
+            {
+                uint32_t *index = static_cast<uint32_t*>(wl_array_add(&indicies, sizeof(uint32_t)));
+                *index = i;
+            }
+            send_tranche_formats_event(&indicies);
+            wl_array_release(&indicies);
+        }
+        send_tranche_done_event();
+
+        send_done_event();
+    }
+
+private:
+    std::shared_ptr<mg::DMABufEGLProvider> const provider;
+};
+
 GLuint get_tex_id()
 {
     GLuint tex;
@@ -942,6 +1041,8 @@ public:
     void add_syncpoint() override
     {
     }
+
+
 private:
     GLuint const tex;
     BufferGLDescription const& desc;
@@ -973,12 +1074,13 @@ public:
         std::function<void()>&& on_consumed,
         std::function<void()>&& on_release)
         : dpy{dpy},
-          tex{dpy, extensions, dma_buf, descriptor, std::move(egl_delegate)},
+          tex{dpy, extensions, dma_buf, descriptor, egl_delegate},
           provider_{std::move(provider)},
-          on_consumed{std::move(on_consumed)},
+          on_consumed_{std::move(on_consumed)},
           on_release{std::move(on_release)},
           size_{dma_buf.size()},
           has_alpha{format_has_known_alpha(dma_buf.format()).value_or(true)},  // Has-alpha is the safe default for unknown formats
+          egl_executor{std::move(egl_delegate)},
           planes_{dma_buf.planes()},
           modifier_{dma_buf.modifier()},
           format_{dma_buf.format()}
@@ -1022,15 +1124,43 @@ public:
         return this;
     }
 
+    auto map_readable() const -> std::unique_ptr<mrs::Mapping<std::byte const>> override
+    {
+        auto consumed = on_consumed_.lock_mut();
+        (*consumed)();
+        *consumed = [](){};
+
+        if (modifier().value_or(DRM_FORMAT_MOD_INVALID) == DRM_FORMAT_MOD_LINEAR &&
+            format().as_mir_format().has_value())
+        {
+            // Fastpath; we can just mmap the memory
+            return std::unique_ptr<DmaBufMapping>{new DmaBufMapping{*this}};
+        }
+        else if (auto const info = format().info())
+        {
+            if (info->components().has_value())
+            {
+                return std::unique_ptr<GLMapping>(new GLMapping{*this});
+            }
+        }
+        BOOST_THROW_EXCEPTION((
+            mg::UnmappableBuffer{"Unsupported buffer format for direct CPU access"}));
+    }
+
+    void on_consumed() override
+    {
+        auto consumed = on_consumed_.lock();
+        (*consumed)();
+        *consumed = [](){};
+    }
+
     auto as_texture() -> DMABufTex*
     {
         /* We only get asked for a texture when the Renderer is about to
          * texture from this buffer; it's a good indication that the buffer
          * has been consumed.
          */
-        std::lock_guard lock{consumed_mutex};
         on_consumed();
-        on_consumed = [](){};
 
         return &tex;
     }
@@ -1060,34 +1190,186 @@ public:
         return provider_;
     }
 private:
+    friend class DmaBufMapping;
+    class DmaBufMapping : public mrs::Mapping<std::byte const>
+    {
+    public:
+        DmaBufMapping(DmabufTexBuffer const& parent)
+            : parent{parent}
+        {
+            if (!parent.format().as_mir_format().has_value())
+            {
+                BOOST_THROW_EXCEPTION((mg::UnmappableBuffer{"Format unrepresentable in mir_pixel_format"}));
+            }
+            if (parent.planes().size() != 1)
+            {
+                BOOST_THROW_EXCEPTION((mg::UnmappableBuffer{"Multiplanar formats not supported"}));
+            }
+            auto& info = parent.planes().front();
+            data_ = ::mmap(
+                nullptr,
+                info.stride * parent.size().height.as<size_t>(),
+                PROT_READ,
+                MAP_SHARED_VALIDATE,
+                info.dma_buf,
+                info.offset);
+            if (data_ == MAP_FAILED)
+            {
+                BOOST_THROW_EXCEPTION((
+                    std::system_error{
+                        errno,
+                        std::system_category(),
+                        "Failed to map DMABuf"}));
+            }
+            struct dma_buf_sync sync{.flags = DMA_BUF_SYNC_READ | DMA_BUF_SYNC_START};
+            if (ioctl(info.dma_buf, DMA_BUF_IOCTL_SYNC, &sync) == -1)
+            {
+                // TODO: ioctl documentation says we should retry on EAGAIN and EINTR
+                BOOST_THROW_EXCEPTION((
+                    std::system_error{
+                        errno,
+                        std::system_category(),
+                        "Failed to notify kernel of dma-buf CPU read"
+                    }
+                ));
+            }
+        }
+
+        ~DmaBufMapping()
+        {
+            struct dma_buf_sync sync{.flags = DMA_BUF_SYNC_END};
+            ioctl(parent.planes().front().dma_buf, DMA_BUF_IOCTL_SYNC, &sync);
+
+            munmap(data_, len());
+        }
+
+        auto data() const -> std::byte const* override
+        {
+            return static_cast<std::byte const*>(data_);
+        }
+
+        auto len() const -> size_t override
+        {
+            return size().height.as<size_t>() * stride().as<size_t>();
+        }
+
+        auto format() const -> MirPixelFormat override
+        {
+           return parent.format_.as_mir_format().value_or(mir_pixel_format_invalid);
+        }
+
+        auto stride() const -> geom::Stride override
+        {
+            return geom::Stride{parent.planes().front().stride};
+        }
+
+        auto size() const -> geom::Size override
+        {
+            return parent.size();
+        }
+    private:
+        DmabufTexBuffer const& parent;
+        void* data_;
+    };
+
+    friend class GLMapping;
+    class GLMapping : public mrs::Mapping<std::byte const>
+    {
+    public:
+        GLMapping(DmabufTexBuffer const& parent)
+            : parent{parent}
+        {
+            auto data_promise = std::make_shared<std::promise<std::unique_ptr<std::byte const[]>>>();
+            parent.egl_executor->spawn(
+                [data_promise, &parent]()
+                {
+                    GLuint fbo{0};
+
+                    GLsizei width = parent.size_.width.as_int();
+                    GLsizei height = parent.size_.height.as_int();
+
+                    auto pixels = std::make_unique<std::byte[]>(static_cast<size_t>(width) * height * 4uz);
+
+                    glGenFramebuffers(1, &fbo);
+                    glBindFramebuffer(GL_FRAMEBUFFER, fbo);
+                    glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, parent.tex.tex_id(), 0);
+
+                    glReadPixels(0, 0, width, height, GL_RGBA, GL_UNSIGNED_BYTE, pixels.get());
+
+                    glBindFramebuffer(GL_FRAMEBUFFER, 0);
+                    glDeleteFramebuffers(1, &fbo);
+
+                    data_promise->set_value(std::unique_ptr<std::byte const[]>(pixels.release()));
+                });
+            data_ = data_promise->get_future();
+        }
+
+        auto data() const -> std::byte const* override
+        {
+            return data_.get().get();
+        }
+
+        auto len() const -> size_t override
+        {
+            return size().height.as<size_t>() * stride().as<size_t>();
+        }
+
+        auto format() const -> MirPixelFormat override
+        {
+            // Because we're reading through GL the underlying format doesn't matter
+            return mir_pixel_format_argb_8888;
+        }
+
+        auto stride() const -> geom::Stride override
+        {
+            return geom::Stride{size().width.as_uint32_t() * 4};
+        }
+
+        auto size() const -> geom::Size override
+        {
+            return parent.size();
+        }
+
+    private:
+        DmabufTexBuffer const& parent;
+        std::shared_future<std::unique_ptr<std::byte const[]>> data_;
+    };
+
     EGLDisplay const dpy;
     DMABufTex tex;
 
     std::shared_ptr<mg::DMABufEGLProvider> const provider_;
 
-    std::mutex consumed_mutex;
-    std::function<void()> on_consumed;
+    mir::Synchronised<std::function<void()>> on_consumed_;
     std::function<void()> const on_release;
 
     geom::Size const size_;
     bool const has_alpha;
 
+    std::shared_ptr<mgc::EGLContextExecutor> const egl_executor;
     std::vector<mg::DMABufBuffer::PlaneDescriptor> const planes_;
     std::optional<uint64_t> const modifier_;
     mg::DRMFormat const format_;
 };
 
-
 }
 
-class mg::LinuxDmaBufUnstable::Instance : public mir::wayland::LinuxDmabufV1
+class mg::LinuxDmaBuf::Instance : public mir::wayland::LinuxDmabufV1
 {
 public:
     Instance(
         wl_resource* new_resource,
         std::shared_ptr<mg::DMABufEGLProvider> provider)
-        : mir::wayland::LinuxDmabufV1(new_resource, Version<3>{}),
+        : mir::wayland::LinuxDmabufV1(new_resource, Version<5>{}),
           provider{std::move(provider)}
+    {
+        if (wl_resource_get_version(new_resource) < 4)
+        {
+            send_formats();
+        }
+    }
+private:
+    void send_formats()
     {
         auto const& formats = this->provider->supported_formats();
         for (auto i = 0u; i < formats.num_formats(); ++i)
@@ -1105,24 +1387,34 @@ public:
             }
         }
     }
-private:
+
     void create_params(struct wl_resource* params_id) override
     {
         new LinuxDmaBufParams{params_id, provider};
     }
 
+    void get_default_feedback(struct wl_resource* params_id) override
+    {
+        new LinuxDmaBufFeedback{params_id, nullptr, provider};
+    }
+
+    void get_surface_feedback(struct wl_resource* params_id, struct wl_resource* surface) override
+    {
+        new LinuxDmaBufFeedback{params_id, surface, provider};
+    }
+
     std::shared_ptr<mg::DMABufEGLProvider> const provider;
 };
 
-mg::LinuxDmaBufUnstable::LinuxDmaBufUnstable(
+mg::LinuxDmaBuf::LinuxDmaBuf(
     wl_display* display,
     std::shared_ptr<mg::DMABufEGLProvider> provider)
-    : mir::wayland::LinuxDmabufV1::Global(display, Version<3>{}),
+    : mir::wayland::LinuxDmabufV1::Global(display, Version<5>{}),
       provider{std::move(provider)}
 {
 }
 
-auto mg::LinuxDmaBufUnstable::buffer_from_resource(
+auto mg::LinuxDmaBuf::buffer_from_resource(
     wl_resource* buffer,
     std::function<void()>&& on_consumed,
     std::function<void()>&& on_release,
@@ -1139,9 +1431,44 @@ auto mg::LinuxDmaBufUnstable::buffer_from_resource(
     return nullptr;
 }
 
-void mg::LinuxDmaBufUnstable::bind(wl_resource* new_resource)
+void mg::LinuxDmaBuf::bind(wl_resource* new_resource)
 {
-    new LinuxDmaBufUnstable::Instance{new_resource, provider};
+    new LinuxDmaBuf::Instance{new_resource, provider};
+}
+
+namespace
+{
+dev_t get_devnum(EGLDisplay dpy)
+{
+    try
+    {
+        mg::EGLExtensions::DeviceQuery device_query_ext;
+        EGLDeviceEXT device;
+        device_query_ext.eglQueryDisplayAttribEXT(dpy, EGL_DEVICE_EXT, reinterpret_cast<EGLAttrib*>(&device));
+        const char *device_path = device_query_ext.eglQueryDeviceStringEXT(device, EGL_DRM_DEVICE_FILE_EXT);
+        if (device_path == nullptr)
+        {
+            mir::log_info(
+                "Unable to determine linux-dmabuf device: no device path returned from EGL");
+            return 0;
+        }
+        struct stat device_stat = {};
+        if (stat(device_path, &device_stat) == -1)
+        {
+            mir::log_info(
+                "Unable to determine linux-dmabuf device: unable to stat device path: %s", strerror(errno));
+            return 0;
+        }
+
+        return device_stat.st_rdev;
+    }
+    catch (std::runtime_error const& error)
+    {
+        mir::log_info(
+            "Unable to determine linux-dmabuf device: %s", error.what());
+        return 0;
+    }
+}
 }
 
 mg::DMABufEGLProvider::DMABufEGLProvider(
@@ -1153,6 +1480,7 @@ mg::DMABufEGLProvider::DMABufEGLProvider(
     : dpy{dpy},
       egl_extensions{std::move(egl_extensions)},
       dmabuf_export_ext{mg::EGLExtensions::MESADmaBufExport::extension_if_supported(dpy)},
+      devnum_{get_devnum(dpy)},
       formats{std::make_unique<DmaBufFormatDescriptors>(dpy, dmabuf_ext)},
       egl_delegate{std::move(egl_delegate)},
       allocate_importable_image{std::move(allocate_importable_image)},
@@ -1162,6 +1490,11 @@ mg::DMABufEGLProvider::DMABufEGLProvider(
 
 mg::DMABufEGLProvider::~DMABufEGLProvider() = default;
 
+auto mg::DMABufEGLProvider::devnum() const -> dev_t
+{
+    return devnum_;
+}
+
 auto mg::DMABufEGLProvider::supported_formats() const -> mg::DmaBufFormatDescriptors const&
 {
     return *formats;
@@ -1204,7 +1537,7 @@ void mg::DMABufEGLProvider::validate_import(DMABufBuffer const& dma_buf)
     }
 }
 
-auto mg::DMABufEGLProvider::as_texture(std::shared_ptr<Buffer> buffer)
+auto mg::DMABufEGLProvider::as_texture(std::shared_ptr<NativeBufferBase> buffer)
     -> std::shared_ptr<gl::Texture>
 {
     if (auto dmabuf_tex = std::dynamic_pointer_cast<DmabufTexBuffer>(buffer))
