@@ -1,5 +1,5 @@
 /*
- * Copyright © 2018 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/graphics/program_factory.h"
+#include <mir/graphics/program_factory.h>
 
 // Included here to ensure we have a single definition of the ProgramFactory symbols
 mir::graphics::gl::ProgramFactory::~ProgramFactory() = default;
