@@ -14,14 +14,16 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/options/program_option.h"
-#include "mir/shared_library.h"
-#include "mir/options/default_configuration.h"
-#include "mir/graphics/platform.h"
-#include "mir/abnormal_exit.h"
-#include "mir/shared_library_prober.h"
-#include "mir/logging/null_shared_library_prober_report.h"
+#include <mir/options/default_configuration.h>
 
+#include <mir/options/program_option.h>
+#include <mir/shared_library.h>
+#include <mir/graphics/platform.h>
+#include <mir/abnormal_exit.h>
+#include <mir/shared_library_prober.h>
+#include <mir/logging/null_shared_library_prober_report.h>
+
+#include <algorithm>
 #include <format>
 
 namespace mo = mir::options;
@@ -41,7 +43,6 @@ char const* const mo::fatal_except_opt            = "on-fatal-error-except";
 char const* const mo::debug_opt                   = "debug";
 char const* const mo::composite_delay_opt         = "composite-delay";
 char const* const mo::enable_key_repeat_opt       = "enable-key-repeat";
-char const* const mo::enable_mouse_keys_opt       = "enable-mouse-keys";
 char const* const mo::x11_display_opt             = "enable-x11";
 char const* const mo::x11_scale_opt               = "x11-scale";
 char const* const mo::wayland_extensions_opt      = "wayland-extensions";
@@ -66,6 +67,7 @@ char const* const mo::null_console = "none";
 char const* const mo::auto_console = "auto";
 
 char const* const mo::vt_option_name = "vt";
+char const* const mo::vt_switching_option_name = "vt-switching";
 
 
 namespace
@@ -144,68 +146,75 @@ mo::DefaultConfiguration::DefaultConfiguration(
     namespace po = boost::program_options;
 
     add_options()
-        (arw_server_socket_opt, "Make socket filename globally rw (equivalent to chmod a=rw)")
+        (arw_server_socket_opt, "Make server Wayland socket readable and writeable by all users. "
+            "For debugging purposes only.")
         (platform_display_libs, po::value<std::string>(),
-            "Libraries to use for platform output support (default: autodetect)")
+            "Comma separated list of libraries to use for platform output support, e.g. `mir:x11,mir:wayland`. "
+            "If not provided the libraries are autodetected.")
         (platform_rendering_libs, po::value<std::string>(),
-            "Libraries to use for platform rendering support (default: autodetect)")
+            "Comma separated list of libraries to use for platform rendering support, e.g. `mir:egl-generic`. "
+            "If not provided the libraries are autodetected.")
         (platform_input_lib, po::value<std::string>(),
-            "Library to use for platform input support (default: input-stub.so)")
+            "Library to use for platform input support, e.g. `mir:stub-input`. "
+            "If not provided this is autodetected.")
         (platform_path, po::value<std::string>()->default_value(MIR_SERVER_PLATFORM_PATH),
-            "Directory to look for platform libraries (default: " MIR_SERVER_PLATFORM_PATH ")")
+            "Directory to look for platform libraries.")
         (enable_input_opt, po::value<bool>()->default_value(enable_input_default),
             "Enable input.")
         (compositor_report_opt, po::value<std::string>()->default_value(off_opt_value),
-            "Compositor reporting [{log,lttng,off}]")
+            "Configure compositor reporting. [{off,log,lttng}]")
         (display_report_opt, po::value<std::string>()->default_value(off_opt_value),
-            "How to handle the Display report. [{log,lttng,off}]")
+            "Configure display reporting. [{off,log,lttng}]")
         (input_report_opt, po::value<std::string>()->default_value(off_opt_value),
-            "How to handle to Input report. [{log,lttng,off}]")
+            "Configure input reporting. [{off,log,lttng}]")
         (seat_report_opt, po::value<std::string>()->default_value(off_opt_value),
-            "How to handle to Seat report. [{log,off}]")
+            "Configure seat reporting. [{off,log}]")
         (scene_report_opt, po::value<std::string>()->default_value(off_opt_value),
-            "How to handle the scene report. [{log,lttng,off}]")
+            "Configure scene reporting. [{off,log,lttng}]")
         (shared_library_prober_report_opt, po::value<std::string>()->default_value(log_opt_value),
-            "How to handle the SharedLibraryProber report. [{log,lttng,off}]")
+            "Configure shared library prober reporting. [{log,off,lttng}]")
         (shell_report_opt, po::value<std::string>()->default_value(off_opt_value),
-         "How to handle the Shell report. [{log,off}]")
+            "Configure shell reporting. [{off,log}]")
         (composite_delay_opt, po::value<int>()->default_value(0),
-            "Compositor frame delay in milliseconds (how long to wait for new "
-            "frames from clients before compositing). Higher values result in "
-            "lower latency but risk causing frame skipping. "
-            "Default: A negative value means decide automatically.")
+            "Number of milliseconds to wait for new frames from clients before compositing. "
+            "Higher values result in lower latency but risk causing frame skipping.")
         (touchspots_opt,
-            "Display visualization of touchspots (e.g. for screencasting).")
+            "Enable visual feedback of touch events. "
+            "Useful for screencasting.")
         (cursor_opt,
             po::value<std::string>()->default_value("auto"),
-            "Cursor (mouse pointer) to use [{auto,null,software}]")
+            "Cursor type:\n"
+            " - `auto`: use hardware if available, or fallback to software.\n"
+            " - `null`: cursor disabled.\n"
+            " - `software`: always use software cursor.")
         (enable_key_repeat_opt, po::value<bool>()->default_value(true),
-             "Enable server generated key repeat")
-        (enable_mouse_keys_opt, po::value<bool>()->default_value(false),
-             "Enable mousekeys (controlling the mouse with the numpad)")
+            "Enable server generated key repeat.")
         (idle_timeout_opt, po::value<int>()->default_value(0),
-            "Time (in seconds) Mir will remain idle before turning off the display "
+            "Number of seconds Mir will remain idle before turning off the display "
             "when the session is not locked, or 0 to keep display on forever.")
         (idle_timeout_when_locked_opt, po::value<int>()->default_value(0),
-            "Time (in seconds) Mir will remain idle before turning off the display "
+            "Number of seconds Mir will remain idle before turning off the display "
             "when the session is locked, or 0 to keep the display on forever.")
-        (fatal_except_opt, "On \"fatal error\" conditions [e.g. drivers behaving "
-            "in unexpected ways] throw an exception (instead of a core dump)")
-        (debug_opt, "Enable extra development debugging. "
-            "This is only interesting for people doing Mir server or client development.")
+        (fatal_except_opt, "Throw an exception when a fatal error condition occurs. "
+            "This replaces the default behaviour of dumping core and can make it easier to diagnose issues.")
+        (debug_opt, "Enable debugging information. "
+            "Useful when developing Mir servers.")
         (console_provider,
             po::value<std::string>()->default_value("auto"),
-            "Console device handling\n"
-            "How Mir handles console-related tasks (device handling, VT switching, etc)\n"
-            "Options:\n"
-            "logind: use logind\n"
-            "vt: use the Linux VT subsystem. Requires root.\n"
-            "none: support no console-related tasks. Useful for nested platforms which do not "
-                "need raw device access and which don't have a VT concept\n"
-            "auto: detect the appropriate provider.")
+            "Method used to handle console-related tasks (device handling, VT switching, etc):\n"
+            " - `logind`: use logind.\n"
+            " - `vt`: use the Linux VT subsystem. Requires root.\n"
+            " - `none`: support no console-related tasks. Useful for nested platforms which do not "
+            "need raw device access and which don't have a VT concept.\n"
+            " - `auto`: detect the appropriate provider.")
         (vt_option_name,
             boost::program_options::value<int>()->default_value(0),
-            "[requires --console-provider=vt] VT to run on or 0 to use current.");
+            "VT to run on or 0 to use current. "
+            "Only used when `--console-provider=vt`.")
+        (vt_switching_option_name,
+            boost::program_options::value<bool>()->default_value(true),
+            "Enable VT switching on Ctrl+Alt+F*. "
+            "Only used when `--console-provider=vt|logind`.");
 
         add_platform_options();
 }
@@ -333,6 +342,109 @@ auto mo::DefaultConfiguration::options_for(SharedLibrary const& module) const ->
     return parsed_options;
 }
 
+namespace
+{
+std::string escape_markdown(std::string const& text)
+{
+    std::stringstream escaped_text;
+
+    for (char const c : text)
+    {
+        switch(c)
+        {
+        case '&':
+            escaped_text << "&amp;";
+            break;
+        case '<':
+            escaped_text << "&lt;";
+            break;
+        case '>':
+            escaped_text << "&gt;";
+            break;
+        case '\"':
+            escaped_text << "&quot;";
+            break;
+        case '\'':
+            escaped_text << "&apos;";
+            break;
+        default:
+            escaped_text << c;
+            break;
+        }
+    }
+
+    return escaped_text.str();
+}
+
+std::string make_markdown_label(std::string const& text)
+{
+    std::ostringstream label;
+
+    for (char const c : text)
+    {
+        if ((c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z') || (c >= '0' && c <= '9'))
+            label << c;
+        else
+            label << '-';
+    }
+
+    return label.str();
+}
+
+namespace
+{
+auto compare_options(boost::shared_ptr<boost::program_options::option_description> const& lhs, boost::shared_ptr<boost::program_options::option_description> const& rhs) -> bool
+{
+    return rhs->long_name() > lhs->long_name();
+}
+
+auto compare_library_names(std::shared_ptr<mir::SharedLibrary> const& lhs, std::shared_ptr<mir::SharedLibrary> const& rhs) -> bool
+{
+    auto const lhs_desc = lhs->load_function<mir::graphics::DescribeModule>("describe_graphics_module", MIR_SERVER_GRAPHICS_PLATFORM_VERSION);
+    auto const rhs_desc = rhs->load_function<mir::graphics::DescribeModule>("describe_graphics_module", MIR_SERVER_GRAPHICS_PLATFORM_VERSION);
+
+    return strcmp(rhs_desc()->name, lhs_desc()->name) > 0;
+}
+
+auto option_default_to_string(boost::shared_ptr<boost::program_options::option_description> const& desc) -> std::string
+{
+    boost::any default_value;
+    if (!desc->semantic()->apply_default(default_value))
+        return "";
+
+    if (default_value.type() == typeid(bool))
+        return std::to_string(boost::any_cast<bool>(default_value));
+    else if (default_value.type() == typeid(int))
+        return std::to_string(boost::any_cast<int>(default_value));
+    else if (default_value.type() == typeid(std::string))
+        return boost::any_cast<std::string>(default_value);
+    else
+        return "";
+}
+}
+
+std::string options_to_markdown(const std::string& module_name, const boost::program_options::options_description& desc)
+{
+    std::ostringstream text;
+
+    auto options = std::vector<boost::shared_ptr<boost::program_options::option_description>>(desc.options());
+    std::sort(options.begin(), options.end(), &compare_options);
+    for (auto& o: options)
+    {
+        text << "\n";
+        text << "(" << make_markdown_label(module_name) << "-" << make_markdown_label(o->long_name()) << ")=\n";
+        text << "### `" << o->long_name() << "`\n";
+        text << "\n";
+        text << escape_markdown(o->description()) << "\n";
+        auto default_value = option_default_to_string(o);
+        if (!default_value.empty())
+            text << "\nDefaults to `" << default_value << "`.\n";
+    }
+
+    return text.str();
+}
+}
+
 void mo::DefaultConfiguration::parse_arguments(
     boost::program_options::options_description desc,
     mo::ProgramOption& options,
@@ -344,9 +456,11 @@ void mo::DefaultConfiguration::parse_arguments(
     try
     {
         desc.add_options()
-            ("help,h", "this help text");
+            ("help,h", "Show command line help.");
         desc.add_options()
-            ("version,V", "display Mir version and exit");
+            ("help-markdown", "Show command line options in markdown format suitable for including into a document.");
+        desc.add_options()
+            ("version,V", "Display Mir version and exit.");
 
         options.parse_arguments(desc, argc, argv);
 
@@ -398,6 +512,29 @@ void mo::DefaultConfiguration::parse_arguments(
             BOOST_THROW_EXCEPTION(mir::ExitWithOutput(help_text.str()));
         }
 
+        if (options.is_set("help-markdown"))
+        {
+            std::ostringstream help_text;
+            help_text << "## Options\n";
+            help_text << options_to_markdown("global", desc);
+
+            auto platforms = std::vector<std::shared_ptr<mir::SharedLibrary>>(platform_libraries);
+            std::sort(platforms.begin(), platforms.end(), &compare_library_names);
+
+            for (auto& platform : platforms)
+            {
+                auto& module_desc = module_options_desc.at(platform->get_handle());
+                if (!module_desc.options().empty())
+                {
+                    auto const describe_module = platform->load_function<mir::graphics::DescribeModule>("describe_graphics_module", MIR_SERVER_GRAPHICS_PLATFORM_VERSION);
+                    auto const module_name = describe_module()->name;
+                    help_text << "## Options for " << module_name << " platform\n";
+                    help_text << options_to_markdown(module_name, module_desc);
+                }
+            }
+            BOOST_THROW_EXCEPTION(mir::ExitWithOutput(help_text.str()));
+        }
+
         if (options.is_set("version"))
         {
             std::ostringstream mir_version;
