@@ -14,15 +14,20 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/graphics/platform.h"
-#include "mir/fd.h"
+#include <mir/graphics/platform.h>
+#include <mir/fd.h>
 
 namespace mir::graphics::atomic
 {
+class GbmQuirks;
 class GBMDisplayAllocator : public graphics::GBMDisplayAllocator
 {
 public:
-    GBMDisplayAllocator(mir::Fd drm_fd, std::shared_ptr<struct gbm_device> atomic, geometry::Size size);
+    GBMDisplayAllocator(
+        mir::Fd drm_fd,
+        std::shared_ptr<struct gbm_device> gbm,
+        geometry::Size size,
+        std::shared_ptr<GbmQuirks> const& gbm_quirks);
 
     auto supported_formats() const -> std::vector<DRMFormat> override;
 
@@ -33,5 +38,6 @@ private:
     mir::Fd const fd;
     std::shared_ptr<struct gbm_device> const gbm;
     geometry::Size const size;
+    std::shared_ptr<GbmQuirks> const gbm_quirks;
 };
 }
