@@ -17,13 +17,13 @@
 #include "atomic_kms_output.h"
 #include "kms-utils/drm_mode_resources.h"
 #include "kms_framebuffer.h"
-#include "mir/graphics/display_configuration.h"
-#include "mir/graphics/drm_formats.h"
-#include "mir/graphics/gamma_curves.h"
-#include "mir_toolkit/common.h"
+#include <mir/graphics/display_configuration.h>
+#include <mir/graphics/drm_formats.h>
+#include <mir/graphics/gamma_curves.h>
+#include <mir_toolkit/common.h>
 #include "kms-utils/kms_connector.h"
-#include "mir/fatal.h"
-#include "mir/log.h"
+#include <mir/fatal.h>
+#include <mir/log.h>
 #include <drm_fourcc.h>
 #include <drm_mode.h>
 #include <span>
@@ -276,7 +276,7 @@ geom::Size mga::AtomicKMSOutput::size() const
     return {mode.hdisplay, mode.vdisplay};
 }
 
-int mga::AtomicKMSOutput::max_refresh_rate() const
+unsigned mga::AtomicKMSOutput::max_refresh_rate() const
 {
     auto conf = configuration.lock();
     if (conf->connector->connection == DRM_MODE_DISCONNECTED)
@@ -322,8 +322,8 @@ bool mga::AtomicKMSOutput::set_crtc(FBHandle const& fb)
     /* Source viewport. Coordinates are 16.16 fixed point format */
     update.add_property(*conf->plane_props, "SRC_X", conf->fb_offset.dx.as_uint32_t() << 16);
     update.add_property(*conf->plane_props, "SRC_Y", conf->fb_offset.dy.as_uint32_t() << 16);
-    update.add_property(*conf->plane_props, "SRC_W", width << 16);
-    update.add_property(*conf->plane_props, "SRC_H", height << 16);
+    update.add_property(*conf->plane_props, "SRC_W", static_cast<uint64_t>(width) << 16);
+    update.add_property(*conf->plane_props, "SRC_H", static_cast<uint64_t>(height) << 16);
 
     /* Destination viewport. Coordinates are *not* 16.16 */
     update.add_property(*conf->plane_props, "CRTC_X", 0);
@@ -533,7 +533,7 @@ bool mga::AtomicKMSOutput::ensure_crtc(Configuration& to_update)
         return false;
 
     // Update the connector as we may unexpectedly fail in find_crtc_and_index_for_connector()
-    // https://github.com/MirServer/mir/issues/2661
+    // https://github.com/canonical/mir/issues/2661
     to_update.connector = kms::get_connector(drm_fd_, to_update.connector->connector_id);
 
     if (to_update.connector->connection != DRM_MODE_CONNECTED)
@@ -890,10 +890,10 @@ void mga::AtomicKMSOutput::update_from_hardware_state(
         modes.push_back({size, vrefresh_hz});
 
         if (kms_modes_are_equal(&mode_info, current_mode_info))
-            current_mode_index = m;
+            current_mode_index = static_cast<uint32_t>(m);
 
         if ((mode_info.type & DRM_MODE_TYPE_PREFERRED) == DRM_MODE_TYPE_PREFERRED)
-            preferred_mode_index = m;
+            preferred_mode_index = static_cast<uint32_t>(m);
     }
 
     /* Fallback for VMWare which fails to specify a matching current mode (bug:1661295) */
@@ -902,7 +902,7 @@ void mga::AtomicKMSOutput::update_from_hardware_state(
             drmModeModeInfo &mode_info = connector->modes[m];
 
             if (strcmp(mode_info.name, "preferred") == 0)
-                current_mode_index = m;
+                current_mode_index = static_cast<uint32_t>(m);
         }
     }
 
@@ -921,7 +921,7 @@ void mga::AtomicKMSOutput::update_from_hardware_state(
     output.current_mode_index = current_mode_index;
     output.subpixel_arrangement = kms_subpixel_to_mir_subpixel(connector->subpixel);
     output.gamma = gamma;
-    output.edid = edid;
+    output.display_info = DisplayInfo{edid};
 }
 
 int mga::AtomicKMSOutput::drm_fd() const
@@ -933,4 +933,3 @@ bool mga::AtomicKMSOutput::has_cursor_image() const
 {
     return cursor_image_set;
 }
-
