@@ -19,45 +19,47 @@
 
 #include "buffer_allocator.h"
 #include "cpu_copy_output_surface.h"
-#include "mir/anonymous_shm_file.h"
-#include "mir/graphics/display_sink.h"
-#include "mir/graphics/drm_formats.h"
-#include "mir/graphics/egl_resources.h"
-#include "mir/graphics/gl_config.h"
-#include "mir/graphics/platform.h"
+#include "egl_helpers.h"
+#include <mir/anonymous_shm_file.h>
+#include <mir/graphics/display_sink.h>
+#include <mir/graphics/drm_formats.h>
+#include <mir/graphics/egl_context_executor.h>
+#include <mir/graphics/egl_resources.h>
+#include <mir/graphics/gl_config.h>
+#include <mir/graphics/platform.h>
 #include "shm_buffer.h"
-#include "mir/graphics/buffer_properties.h"
-#include "mir/renderer/gl/context.h"
-#include "mir/graphics/display.h"
+#include <mir/graphics/buffer_properties.h>
+#include <mir/renderer/gl/context.h>
+#include <mir/graphics/display.h>
 #include "wayland-eglstream-controller.h"
-#include "mir/graphics/egl_error.h"
-#include "mir/graphics/texture.h"
-#include "mir/graphics/program_factory.h"
-#include "mir/graphics/program.h"
-#include "mir/graphics/display.h"
-#include "mir/renderer/gl/context.h"
-#include "mir/raii.h"
-#include "mir/wayland/protocol_error.h"
-#include "mir/wayland/wayland_base.h"
-#include "mir/renderer/gl/gl_surface.h"
+#include <mir/graphics/egl_error.h>
+#include <mir/graphics/texture.h>
+#include <mir/graphics/program_factory.h>
+#include <mir/graphics/program.h>
+#include <mir/graphics/display.h>
+#include <mir/renderer/gl/context.h>
+#include <mir/raii.h>
+#include <mir/wayland/protocol_error.h>
+#include <mir/wayland/wayland_base.h>
+#include <mir/renderer/gl/gl_surface.h>
+#include <optional>
 
 #define MIR_LOG_COMPONENT "platform-eglstream-kms"
-#include "mir/log.h"
+#include <mir/log.h>
 
 #include <wayland-server-core.h>
 
+#include <cstdint>
 #include <mutex>
 #include <drm_fourcc.h>
 
 #include <boost/throw_exception.hpp>
 #include <boost/exception/errinfo_errno.hpp>
 
-#include <cassert>
-
-
 namespace mg  = mir::graphics;
 namespace mge = mg::eglstream;
 namespace mgc = mg::common;
+namespace mrs = mir::renderer::software;
 namespace geom = mir::geometry;
 
 #ifndef EGL_WL_wayland_eglstream
@@ -83,7 +85,7 @@ std::shared_ptr<mg::Buffer> mge::BufferAllocator::alloc_software_buffer(geom::Si
                 "Trying to create SHM buffer with unsupported pixel format"));
     }
 
-    return std::make_shared<mgc::MemoryBackedShmBuffer>(size, format, egl_delegate);
+    return std::make_shared<mgc::MemoryBackedShmBuffer>(size, format);
 }
 
 std::vector<MirPixelFormat> mge::BufferAllocator::supported_pixel_formats()
@@ -97,7 +99,7 @@ namespace
 
 GLuint gen_texture_handle()
 {
-    GLuint tex;
+    GLuint tex{0};
     glGenTextures(1, &tex);
     return tex;
 }
@@ -174,7 +176,7 @@ struct BoundEGLStream
 {
     static void associate_stream(wl_resource* buffer, std::shared_ptr<mir::renderer::gl::Context> ctx, EGLStreamKHR stream)
     {
-        BoundEGLStream* me;
+        BoundEGLStream* me{nullptr};
         if (auto notifier = wl_resource_get_destroy_listener(buffer, &on_buffer_destroyed))
         {
             /* We're associating a buffer which has an existing stream with a new stream?
@@ -262,8 +264,7 @@ struct BoundEGLStream
     {
         if (auto notifier = wl_resource_get_destroy_listener(buffer, &on_buffer_destroyed))
         {
-            BoundEGLStream* me;
-            me = wl_container_of(notifier, me, destruction_listener);
+            BoundEGLStream* me = wl_container_of(notifier, me, destruction_listener);
             return TextureHandle{me->consumer_sync, me->producer};
         }
         BOOST_THROW_EXCEPTION((std::runtime_error{"Buffer does not have an associated EGLStream"}));
@@ -275,14 +276,13 @@ private:
             std::is_standard_layout<BoundEGLStream>::value,
             "BoundEGLStream must be Standard Layout for wl_container_of to be defined behaviour");
 
-        BoundEGLStream* me;
-        me = wl_container_of(listener, me, destruction_listener);
+        BoundEGLStream* me = wl_container_of(listener, me, destruction_listener);
         delete me;
     }
 
     std::shared_ptr<Sync> const consumer_sync{std::make_shared<Sync>()};
     std::shared_ptr<EGLStreamTextureConsumer const> producer;
-    wl_listener destruction_listener;
+    wl_listener destruction_listener = {};
 };
 }
 
@@ -297,7 +297,7 @@ try
         wl_resource_get_user_data(eglstream_controller_resource));
 
     EGLAttrib const attribs[] = {
-        EGL_WAYLAND_EGLSTREAM_WL, (EGLAttrib)buffer,
+        EGL_WAYLAND_EGLSTREAM_WL, reinterpret_cast<EGLAttrib>(buffer), //TICS !cppcoreguidelines-pro-type-reinterpret-cast: EGLAttrib is intptr_t, and the API requires that we pass the buffer pointer in
         EGL_NONE
     };
 
@@ -330,7 +330,8 @@ void mge::BufferAllocator::bind_eglstream_controller(
     uint32_t version,
     uint32_t id)
 {
-    auto resource = wl_resource_create(client, &wl_eglstream_controller_interface, version, id);
+    auto const resolved_version = static_cast<int>(version);    // Wayland inexplicably passes version as a uint32_t, but uses `int` in wl_resource_create
+    auto resource = wl_resource_create(client, &wl_eglstream_controller_interface, resolved_version, id);
 
     if (resource == nullptr)
     {
@@ -420,6 +421,7 @@ class EGLStreamBuffer :
 {
 public:
     EGLStreamBuffer(
+        std::shared_ptr<mgc::EGLContextExecutor> executor,
         BoundEGLStream::TextureHandle tex,
         std::function<void()>&& on_consumed,
         MirPixelFormat format,
@@ -428,6 +430,7 @@ public:
         : size_{size},
           layout_{layout},
           format{format},
+          executor{std::move(executor)},
           tex{std::move(tex)},
           on_consumed{std::move(on_consumed)}
     {
@@ -448,6 +451,12 @@ public:
         return this;
     }
 
+    std::unique_ptr<mrs::Mapping<std::byte const>> map_readable() const override
+    {
+        on_consumed();
+        return std::make_unique<GLMapping>(*this);
+    }
+
     mg::gl::Program const& shader(mg::gl::ProgramFactory& cache) const override
     {
         static int shader_id{0};
@@ -488,9 +497,72 @@ public:
     }
 
 private:
+    class GLMapping : public mrs::Mapping<std::byte const>
+    {
+    public:
+        GLMapping(EGLStreamBuffer const& parent)
+            : parent{parent}
+        {
+            auto data_promise = std::make_shared<std::promise<std::unique_ptr<std::byte const[]>>>();
+            parent.executor->spawn(
+                [data_promise, &parent]()
+                {
+                    GLuint fbo{0};
+
+                    GLsizei width = parent.size_.width.as_int();
+                    GLsizei height = parent.size_.height.as_int();
+
+                    auto pixels = std::make_unique<std::byte[]>(static_cast<size_t>(width) * height * 4uz);
+
+                    glGenFramebuffers(1, &fbo);
+                    glBindFramebuffer(GL_FRAMEBUFFER, fbo);
+                    glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, parent.tex.tex_id(), 0);
+
+                    glReadPixels(0, 0, width, height, GL_RGBA, GL_UNSIGNED_BYTE, pixels.get());
+
+                    glBindFramebuffer(GL_FRAMEBUFFER, 0);
+                    glDeleteFramebuffers(1, &fbo);
+
+                    data_promise->set_value(std::unique_ptr<std::byte const[]>(pixels.release()));
+                });
+            data_ = data_promise->get_future();
+        }
+
+        auto data() const -> std::byte const* override
+        {
+            return data_.get().get();
+        }
+
+        auto len() const -> size_t override
+        {
+            return size().height.as<size_t>() * stride().as<size_t>();
+        }
+
+        auto format() const -> MirPixelFormat override
+        {
+            // Because we're reading through GL the underlying format doesn't matter
+           return mir_pixel_format_argb_8888;
+        }
+
+        auto stride() const -> geom::Stride override
+        {
+            return geom::Stride{size().width.as_uint32_t() * 4};
+        }
+
+        auto size() const -> geom::Size override
+        {
+            return parent.size();
+        }
+
+    private:
+        EGLStreamBuffer const& parent;
+        std::shared_future<std::unique_ptr<std::byte const[]>> data_;
+    };
+
     mir::geometry::Size const size_;
     Layout const layout_;
     MirPixelFormat const format;
+    std::shared_ptr<mgc::EGLContextExecutor> const executor;
     BoundEGLStream::TextureHandle tex;
     std::function<void()> on_consumed;
 };
@@ -500,14 +572,15 @@ std::shared_ptr<mir::graphics::Buffer>
 mir::graphics::eglstream::BufferAllocator::buffer_from_resource(
     wl_resource* buffer,
     std::function<void()>&& on_consumed,
-    std::function<void()>&& /*on_release*/)
+    std::function<void()>&& /*on_release*/) //TICS !cppcoreguidelines-rvalue-reference-param-not-moved: We don't use this parameter *at all*.
 {
+
     auto context_guard = mir::raii::paired_calls(
         [this]() { wayland_ctx->make_current(); },
         [this]() { wayland_ctx->release_current(); });
     auto dpy = eglGetCurrentDisplay();
 
-    EGLint width, height;
+    EGLint width{0}, height{0};
     if (extensions(dpy).eglQueryWaylandBufferWL(dpy, buffer, EGL_WIDTH, &width) != EGL_TRUE)
     {
         BOOST_THROW_EXCEPTION(mg::egl_error("Failed to query Wayland buffer width"));
@@ -519,7 +592,7 @@ mir::graphics::eglstream::BufferAllocator::buffer_from_resource(
     mg::gl::Texture::Layout const layout =
         [&]()
         {
-            EGLint y_inverted;
+            EGLint y_inverted{false};
             if (extensions(dpy).eglQueryWaylandBufferWL(dpy, buffer, EGL_WAYLAND_Y_INVERTED_WL, &y_inverted) != EGL_TRUE)
             {
                 // If querying Y_INVERTED fails, we must have the default, GL, layout
@@ -536,6 +609,7 @@ mir::graphics::eglstream::BufferAllocator::buffer_from_resource(
         }();
 
     return std::make_shared<EGLStreamBuffer>(
+        egl_delegate,
         BoundEGLStream::texture_for_buffer(buffer),
         std::move(on_consumed),
         mir_pixel_format_argb_8888,
@@ -544,13 +618,12 @@ mir::graphics::eglstream::BufferAllocator::buffer_from_resource(
 }
 
 auto mge::BufferAllocator::buffer_from_shm(
-    std::shared_ptr<renderer::software::RWMappableBuffer> data,
+    std::shared_ptr<renderer::software::RWMappable> data,
     std::function<void()>&& on_consumed,
     std::function<void()>&& on_release) -> std::shared_ptr<Buffer>
 {
     return std::make_shared<mgc::NotifyingMappableBackedShmBuffer>(
         std::move(data),
-        egl_delegate,
         std::move(on_consumed),
         std::move(on_release));
 }
@@ -588,7 +661,7 @@ public:
     }
 
 private:
-    GLuint id;
+    GLuint id{0};
 };
 
 using TextureHandle = GLHandle<&glGenTextures, &glDeleteTextures>;
@@ -650,6 +723,28 @@ public:
         eglMakeCurrent(dpy, EGL_NO_SURFACE, EGL_NO_SURFACE, EGL_NO_CONTEXT);
     }
 
+    ~EGLStreamOutputSurface()
+    {
+        // Capture current EGL state to restore, if the current context is not the one we're destroying
+        auto const egl_restore =
+            [this]() -> std::optional<mgc::CacheEglState>
+            {
+                if (ctx != eglGetCurrentContext())
+                {
+                    return {mgc::CacheEglState{}};
+                }
+
+                // We *are* the current context; release the current context, so we can destroy resources.
+                eglMakeCurrent(dpy, EGL_NO_SURFACE, EGL_NO_SURFACE, EGL_NO_CONTEXT);
+                // We don't need to restore EGL state
+                return std::nullopt;
+            }();
+
+        // Free our EGL resources
+        eglDestroySurface(dpy, surface);
+        eglDestroyContext(dpy, ctx);
+    }
+
     void bind() override
     {
     }
@@ -710,7 +805,7 @@ auto pick_stream_surface_config(EGLDisplay dpy, mg::GLConfig const& gl_config) -
         EGL_NONE
     };
 
-    EGLConfig egl_config;
+    EGLConfig egl_config{nullptr};
     EGLint num_egl_configs{0};
 
     if (eglChooseConfig(dpy, config_attr, &egl_config, 1, &num_egl_configs) == EGL_FALSE ||
@@ -722,8 +817,11 @@ auto pick_stream_surface_config(EGLDisplay dpy, mg::GLConfig const& gl_config) -
 }
 }
 
-mge::GLRenderingProvider::GLRenderingProvider(EGLDisplay dpy, std::unique_ptr<mir::renderer::gl::Context> ctx)
+mge::GLRenderingProvider::GLRenderingProvider(
+    EGLDisplay dpy,
+    std::unique_ptr<mir::renderer::gl::Context> ctx)
     : dpy{dpy},
+      egl_delegate{std::make_shared<mgc::EGLContextExecutor>(ctx->make_share_context())},
       ctx{std::move(ctx)}
 {
 }
@@ -733,7 +831,12 @@ mge::GLRenderingProvider::~GLRenderingProvider() = default;
 auto mir::graphics::eglstream::GLRenderingProvider::as_texture(std::shared_ptr<Buffer> buffer)
     -> std::shared_ptr<gl::Texture>
 {
-    return std::dynamic_pointer_cast<gl::Texture>(std::move(buffer));
+    std::shared_ptr<NativeBufferBase> native_buffer{buffer, buffer->native_buffer_base()};
+    if (auto shm = std::dynamic_pointer_cast<mgc::ShmBuffer>(native_buffer))
+    {
+        return shm->texture_for_provider(egl_delegate, this);
+    }
+    return std::dynamic_pointer_cast<gl::Texture>(std::move(native_buffer));
 }
 
 auto mge::GLRenderingProvider::surface_for_sink(
