@@ -17,11 +17,11 @@
 #ifndef MIR_PLATFORMS_EGLSTREAM_BUFFER_ALLOCATOR_
 #define MIR_PLATFORMS_EGLSTREAM_BUFFER_ALLOCATOR_
 
-#include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/graphics/buffer_id.h"
-#include "mir/graphics/egl_extensions.h"
-#include "mir/graphics/egl_context_executor.h"
-#include "mir/graphics/platform.h"
+#include <mir/graphics/graphic_buffer_allocator.h>
+#include <mir/graphics/buffer_id.h>
+#include <mir/graphics/egl_extensions.h>
+#include <mir/graphics/egl_context_executor.h>
+#include <mir/graphics/platform.h>
 
 #include "wayland-eglstream-controller.h"
 
@@ -68,7 +68,7 @@ public:
         std::function<void()>&& on_release) override;
 
     auto buffer_from_shm(
-        std::shared_ptr<renderer::software::RWMappableBuffer> shm_data,
+        std::shared_ptr<renderer::software::RWMappable> shm_data,
         std::function<void()>&& on_consumed,
         std::function<void()>&& on_release) -> std::shared_ptr<Buffer> override;
 
@@ -111,6 +111,7 @@ public:
         GLConfig const& gl_config) -> std::unique_ptr<gl::OutputSurface> override;
 private:
     EGLDisplay dpy;
+    std::shared_ptr<common::EGLContextExecutor> const egl_delegate;
     std::unique_ptr<renderer::gl::Context> const ctx;
 };
 
