@@ -17,11 +17,11 @@
 #ifndef MIR_PLATFORMS_EGLSTREAM_KMS_PLATFORM_H_
 #define MIR_PLATFORMS_EGLSTREAM_KMS_PLATFORM_H_
 
-#include "mir/graphics/platform.h"
-#include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/graphics/display.h"
-#include "mir/renderer/gl/context.h"
-#include "mir/fd.h"
+#include <mir/graphics/platform.h>
+#include <mir/graphics/graphic_buffer_allocator.h>
+#include <mir/graphics/display.h>
+#include <mir/renderer/gl/context.h>
+#include <mir/fd.h>
 
 #include <EGL/egl.h>
 #include <EGL/eglext.h>
