@@ -18,19 +18,19 @@
 
 #include "platform.h"
 #include "utils.h"
-#include "mir/graphics/platform.h"
-#include "mir/options/option.h"
-#include "mir/options/configuration.h"
-#include "mir/module_deleter.h"
-#include "mir/assert_module_entry_point.h"
-#include "mir/libname.h"
-#include "mir/log.h"
-#include "mir/graphics/egl_error.h"
+#include <mir/graphics/platform.h>
+#include <mir/options/option.h>
+#include <mir/options/configuration.h>
+#include <mir/module_deleter.h>
+#include <mir/assert_module_entry_point.h>
+#include <mir/libname.h>
+#include <mir/log.h>
+#include <mir/graphics/egl_error.h>
 #include "one_shot_device_observer.h"
-#include "mir/raii.h"
+#include <mir/raii.h>
 #include "kms-utils/drm_mode_resources.h"
-#include "mir/graphics/egl_logger.h"
-#include "mir/udev/wrapper.h"
+#include <mir/graphics/egl_logger.h>
+#include <mir/udev/wrapper.h>
 
 #include <boost/throw_exception.hpp>
 #include <xf86drm.h>
@@ -244,7 +244,8 @@ auto probe_rendering_platform(
             std::vector<char const*> missing_extensions;
             for (char const* extension : {
                 "EGL_KHR_stream_consumer_gltexture",
-                "EGL_NV_stream_attrib"})
+                "EGL_NV_stream_attrib",
+                "EGL_WL_bind_wayland_display"})
             {
                 if (!epoxy_has_egl_extension(display, extension))
                 {
@@ -320,7 +321,7 @@ auto probe_display_platform(
     for (char const* extension : {
         "EGL_EXT_platform_base",
         "EGL_EXT_platform_device",
-        "EGL_EXT_device_base",})
+        "EGL_EXT_device_base"})
     {
         if (!epoxy_has_egl_extension(EGL_NO_DISPLAY, extension))
         {
@@ -535,13 +536,19 @@ auto probe_display_platform(
                             version->major,
                             version->minor);
                         mir::log_warning(
-                            "This driver is known to interact badly with Mir. See https://github.com/MirServer/mir/issues/650");
+                            "This driver is known to interact badly with Mir. See https://github.com/canonical/mir/issues/650");
                         mir::log_warning(
                             "Mir will not auto-load the eglstream-kms platform on this driver. To proceed anyway, manually specify the platform library.");
                         continue;
                     }
                 }
 
+                if(!epoxy_has_egl_extension(display, "EGL_WL_bind_wayland_display"))
+                {
+                    mir::log_warning("Display does not support EGL_WL_bind_wayland_display. Will skip this device.");
+                    continue;
+                }
+
                 if (epoxy_has_egl_extension(display, "EGL_EXT_output_base"))
                 {
                     supported_devices.back().support_level = mg::probe::best;
@@ -583,4 +590,3 @@ mir::ModuleProperties const* describe_graphics_module()
     mir::assert_entry_point_signature<mg::DescribeModule>(&describe_graphics_module);
     return &description;
 }
-
