@@ -19,18 +19,18 @@
 #include "libinput_device_ptr.h"
 #include "button_utils.h"
 
-#include "mir/input/input_sink.h"
-#include "mir/input/input_report.h"
-#include "mir/input/device_capability.h"
-#include "mir/input/pointer_settings.h"
-#include "mir/input/touchpad_settings.h"
-#include "mir/input/input_device_info.h"
-#include "mir/events/event_builders.h"
-#include "mir/geometry/displacement.h"
-#include "mir/dispatch/dispatchable.h"
-#include "mir/fd.h"
-#include "mir/log.h"
-#include "mir/raii.h"
+#include <mir/input/input_sink.h>
+#include <mir/input/input_report.h>
+#include <mir/input/device_capability.h>
+#include <mir/input/pointer_settings.h>
+#include <mir/input/touchpad_settings.h>
+#include <mir/input/input_device_info.h>
+#include <mir/events/event_builders.h>
+#include <mir/geometry/displacement.h>
+#include <mir/dispatch/dispatchable.h>
+#include <mir/fd.h>
+#include <mir/log.h>
+#include <mir/raii.h>
 
 #include <libinput.h>
 #include <linux/input.h>  // only used to get constants for input reports
@@ -471,7 +471,7 @@ void mie::LibInputDevice::update_device_info()
         touchscreen = mi::TouchscreenSettings{};
 
         // FIXME: We need a way to populate output_id sensibly. {alan_g}
-        // https://github.com/MirServer/mir/issues/611
+        // https://github.com/canonical/mir/issues/611
         touchscreen.value().mapping_mode = mir_touchscreen_mapping_mode_to_output;
     }
 
