@@ -15,10 +15,10 @@
  */
 
 #include "platform.h"
-#include "mir/udev/wrapper.h"
-#include "mir/fd.h"
-#include "mir/assert_module_entry_point.h"
-#include "mir/libname.h"
+#include <mir/udev/wrapper.h>
+#include <mir/fd.h>
+#include <mir/assert_module_entry_point.h>
+#include <mir/libname.h>
 
 #include <memory>
 #include <string>
