@@ -15,28 +15,31 @@
  */
 
 #include "buffer_allocator.h"
-#include "mir/graphics/gl_config.h"
-#include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/graphics/linux_dmabuf.h"
-#include "mir/graphics/dmabuf_buffer.h"
-#include "mir/renderer/sw/pixel_source.h"
-#include "mir/graphics/platform.h"
+#include "kms/quirks.h"
+#include <mir/graphics/buffer.h>
+#include <mir/graphics/gl_config.h>
+#include <mir/graphics/graphic_buffer_allocator.h>
+#include <mir/graphics/linux_dmabuf.h>
+#include <mir/graphics/dmabuf_buffer.h>
+#include <mir/renderer/sw/pixel_source.h>
+#include <mir/graphics/platform.h>
 #include "shm_buffer.h"
-#include "mir/graphics/egl_context_executor.h"
-#include "mir/graphics/egl_extensions.h"
-#include "mir/graphics/egl_error.h"
-#include "mir/raii.h"
-#include "mir/graphics/display.h"
-#include "mir/renderer/gl/context.h"
-#include "mir/graphics/egl_wayland_allocator.h"
-#include "mir/executor.h"
-#include "mir/renderer/gl/gl_surface.h"
-#include "mir/graphics/display_sink.h"
+#include <mir/graphics/egl_context_executor.h>
+#include <mir/graphics/egl_extensions.h>
+#include <mir/graphics/egl_error.h>
+#include <mir/raii.h>
+#include <mir/graphics/display.h>
+#include <mir/renderer/gl/context.h>
+#include <mir/graphics/egl_wayland_allocator.h>
+#include <mir/executor.h>
+#include <mir/renderer/gl/gl_surface.h>
+#include <mir/graphics/display_sink.h>
 #include "kms/egl_helper.h"
-#include "mir/graphics/drm_formats.h"
-#include "mir/graphics/egl_error.h"
+#include <mir/graphics/drm_formats.h>
+#include <mir/graphics/egl_error.h>
 #include "cpu_copy_output_surface.h"
 #include "surfaceless_egl_context.h"
+#include <mir/graphics/drm_syncobj.h>
 
 #include <boost/throw_exception.hpp>
 #include <boost/exception/errinfo_errno.hpp>
@@ -46,9 +49,9 @@
 #include <GLES2/gl2.h>
 #include <GLES2/gl2ext.h>
 
+#include <memory>
 #include <optional>
 #include <stdexcept>
-#include <cassert>
 #include <fcntl.h>
 #include <xf86drm.h>
 #include <drm_fourcc.h>
@@ -84,7 +87,7 @@ std::shared_ptr<mg::Buffer> mgg::BufferAllocator::alloc_software_buffer(
                 "Trying to create SHM buffer with unsupported pixel format"));
     }
 
-    return std::make_shared<mgc::MemoryBackedShmBuffer>(size, format, egl_delegate);
+    return std::make_shared<mgc::MemoryBackedShmBuffer>(size, format);
 }
 
 std::vector<MirPixelFormat> mgg::BufferAllocator::supported_pixel_formats()
@@ -139,30 +142,7 @@ void mgg::BufferAllocator::bind_display(wl_display* display, std::shared_ptr<Exe
         if (dmabuf_provider)
         {
             mg::EGLExtensions::EXTImageDmaBufImportModifiers modifier_ext{dpy};
-            dmabuf_extension =
-                std::unique_ptr<LinuxDmaBufUnstable, std::function<void(LinuxDmaBufUnstable*)>>(
-                    new LinuxDmaBufUnstable{
-                        display,
-                        dmabuf_provider,
-                    },
-                    [wayland_executor](LinuxDmaBufUnstable* global)
-                    {
-                        // The global must be destroyed on the Wayland thread
-                        wayland_executor->spawn(
-                            [global]()
-                            {
-                                /* This is safe against double-frees, as the WaylandExecutor
-                                 * guarantees that work scheduled will only run while the Wayland
-                                 * event loop is running, and the main loop is stopped before
-                                 * wl_display_destroy() frees any globals
-                                 *
-                                 * This will, however, leak the global if the main loop is destroyed
-                                 * before the buffer allocator. Fixing that requires work in the
-                                 * wrapper generator.
-                                 */
-                                delete global;
-                            });
-                    });
+            dmabuf_extension = std::make_unique<LinuxDmaBuf>(display, dmabuf_provider);
             mir::log_info("Enabled linux-dmabuf import support");
         }
     }
@@ -182,15 +162,16 @@ void mgg::BufferAllocator::bind_display(wl_display* display, std::shared_ptr<Exe
 
 void mgg::BufferAllocator::unbind_display(wl_display* display)
 {
+    auto context_guard = mir::raii::paired_calls(
+        [this]() { ctx->make_current(); },
+        [this]() { ctx->release_current(); });
+    auto dpy = eglGetCurrentDisplay();
+
     if (egl_display_bound)
     {
-        auto context_guard = mir::raii::paired_calls(
-            [this]() { ctx->make_current(); },
-            [this]() { ctx->release_current(); });
-        auto dpy = eglGetCurrentDisplay();
-
         mg::wayland::unbind_display(dpy, display, *egl_extensions);
     }
+    dmabuf_extension.reset();
 }
 
 std::shared_ptr<mg::Buffer> mgg::BufferAllocator::buffer_from_resource(
@@ -219,13 +200,12 @@ std::shared_ptr<mg::Buffer> mgg::BufferAllocator::buffer_from_resource(
 }
 
 auto mgg::BufferAllocator::buffer_from_shm(
-    std::shared_ptr<renderer::software::RWMappableBuffer> data,
+    std::shared_ptr<renderer::software::RWMappable> data,
     std::function<void()>&& on_consumed,
     std::function<void()>&& on_release) -> std::shared_ptr<Buffer>
 {
     return std::make_shared<mgc::NotifyingMappableBackedShmBuffer>(
         std::move(data),
-        egl_delegate,
         std::move(on_consumed),
         std::move(on_release));
 }
@@ -237,11 +217,16 @@ auto mgg::BufferAllocator::shared_egl_context() -> EGLContext
 
 auto mgg::GLRenderingProvider::as_texture(std::shared_ptr<Buffer> buffer) -> std::shared_ptr<gl::Texture>
 {
-    if (auto dmabuf_texture = dmabuf_provider->as_texture(buffer))
+    std::shared_ptr<NativeBufferBase> native_buffer{buffer, buffer->native_buffer_base()};
+    if (auto dmabuf_texture = dmabuf_provider->as_texture(native_buffer))
     {
         return dmabuf_texture;
     }
-    else if (auto tex = std::dynamic_pointer_cast<gl::Texture>(buffer))
+    else if (auto shm = std::dynamic_pointer_cast<mgc::ShmBuffer>(native_buffer))
+    {
+        return shm->texture_for_provider(egl_delegate, this);
+    }
+    else if (auto tex = std::dynamic_pointer_cast<gl::Texture>(native_buffer))
     {
         return tex;
     }
@@ -258,22 +243,30 @@ public:
         EGLContext share_context,
         mg::GLConfig const& config,
         mg::GBMDisplayAllocator& display,
-        mg::DRMFormat format)
+        mg::DRMFormat format,
+        std::shared_ptr<mgg::GbmQuirks> const& quirks)
         : GBMOutputSurface(
               dpy,
-              create_renderable(dpy, share_context, format, config, display))
+              create_renderable(dpy, share_context, format, config, display),
+              quirks)
     {
     }
 
     ~GBMOutputSurface()
     {
-        eglDestroySurface(dpy, egl_surf);
+        quirks->egl_destroy_surface(dpy, egl_surf);
+
+        // If we're the current context, release it so that resources can be destroyed.
+        if (eglGetCurrentContext() == ctx)
+        {
+            eglMakeCurrent(dpy, EGL_NO_SURFACE, EGL_NO_SURFACE, EGL_NO_CONTEXT);
+        }
         eglDestroyContext(dpy, ctx);
     }
 
     void bind() override
     {
-        if (!gbm_surface_has_free_buffers(*surface))
+        if (!quirks->gbm_surface_has_free_buffers(*surface))
         {
             BOOST_THROW_EXCEPTION((std::logic_error{"Attempt to render to GBM surface before releasing previous front buffer"}));
         }
@@ -306,7 +299,7 @@ public:
 
     auto size() const -> geom::Size override
     {
-        EGLint width, height;
+        EGLint width{0}, height{0};
         if (eglQuerySurface(dpy, egl_surf, EGL_WIDTH, &width) != EGL_TRUE)
         {
             BOOST_THROW_EXCEPTION((mg::egl_error("Failed to query surface width")));
@@ -326,7 +319,7 @@ public:
 private:
     static auto get_matching_configs(EGLDisplay dpy, EGLint const attr[]) -> std::vector<EGLConfig>
     {
-        EGLint num_egl_configs;
+        EGLint num_egl_configs{0};
 
         // First query the number of matching configs…
         if ((eglChooseConfig(dpy, attr, nullptr, 0, &num_egl_configs) == EGL_FALSE) ||
@@ -369,7 +362,7 @@ private:
 
         for (auto const& config : get_matching_configs(dpy, config_attr))
         {
-            EGLint id;
+            EGLint id{DRM_FORMAT_INVALID};
             if (eglGetConfigAttrib(dpy, config, EGL_NATIVE_VISUAL_ID, &id) == EGL_FALSE)
             {
                 mir::log_warning(
@@ -472,11 +465,13 @@ private:
 
     GBMOutputSurface(
         EGLDisplay dpy,
-        std::tuple<std::unique_ptr<mg::GBMDisplayAllocator::GBMSurface>, EGLContext, EGLSurface> renderables)
+        std::tuple<std::unique_ptr<mg::GBMDisplayAllocator::GBMSurface>, EGLContext, EGLSurface> renderables,
+        std::shared_ptr<mgg::GbmQuirks> const& quirks)
         : surface{std::move(std::get<0>(renderables))},
           egl_surf{std::get<2>(renderables)},
           dpy{dpy},
-          ctx{std::get<1>(renderables)}
+          ctx{std::get<1>(renderables)},
+          quirks{quirks}
     {
     }
 
@@ -484,6 +479,7 @@ private:
     EGLSurface const egl_surf;
     EGLDisplay const dpy;
     EGLContext const ctx;
+    std::shared_ptr<mgg::GbmQuirks> const quirks;
 };
 }
 
@@ -538,7 +534,8 @@ auto mgg::GLRenderingProvider::surface_for_sink(
                     ctx,
                     config,
                     *gbm_allocator,
-                    DRMFormat{DRM_FORMAT_XRGB8888});
+                    DRMFormat{DRM_FORMAT_XRGB8888},
+                    quirks);
             }
         }
     }
@@ -551,9 +548,50 @@ auto mgg::GLRenderingProvider::surface_for_sink(
         config);
 }
 
-auto mgg::GLRenderingProvider::make_framebuffer_provider(DisplaySink& /*sink*/)
+auto mgg::GLRenderingProvider::import_syncobj(Fd const& syncobj_fd)
+    -> std::unique_ptr<drm::Syncobj>
+{
+    uint32_t handle{0};
+    if (auto err = drmSyncobjFDToHandle(drm_fd, syncobj_fd, &handle))
+    {
+        BOOST_THROW_EXCEPTION((
+            std::system_error{
+                -err,
+                std::system_category(),
+                "Failed to import DRM syncobj"}));
+    }
+    return std::make_unique<drm::Syncobj>(drm_fd, handle);
+}
+
+auto mgg::GLRenderingProvider::make_framebuffer_provider(DisplaySink& sink)
     -> std::unique_ptr<FramebufferProvider>
 {
+    if(auto* allocator = sink.acquire_compatible_allocator<DmaBufDisplayAllocator>())
+    {
+        struct FooFramebufferProvider: public FramebufferProvider
+        {
+        public:
+            FooFramebufferProvider(DmaBufDisplayAllocator* allocator) : allocator{allocator}
+            {
+            }
+
+            auto buffer_to_framebuffer(std::shared_ptr<Buffer> buffer) -> std::unique_ptr<Framebuffer> override
+            {
+                if(auto dma_buf = std::dynamic_pointer_cast<mir::graphics::DMABufBuffer>(buffer))
+                {
+                    return allocator->framebuffer_for(dma_buf);
+                }
+
+                return {};
+            }
+
+        private:
+            DmaBufDisplayAllocator* allocator;
+        };
+
+        return std::make_unique<FooFramebufferProvider>(allocator);
+    }
+
     // TODO: Make this not a null implementation, so bypass/overlays can work again
     class NullFramebufferProvider : public FramebufferProvider
     {
@@ -569,15 +607,19 @@ auto mgg::GLRenderingProvider::make_framebuffer_provider(DisplaySink& /*sink*/)
 }
 
 mgg::GLRenderingProvider::GLRenderingProvider(
+    Fd drm_fd,
     std::shared_ptr<mg::GBMDisplayProvider> associated_display,
     std::shared_ptr<mgc::EGLContextExecutor> egl_delegate,
     std::shared_ptr<mg::DMABufEGLProvider> dmabuf_provider,
     EGLDisplay dpy,
-    EGLContext ctx)
-    : bound_display{std::move(associated_display)},
+    EGLContext ctx,
+    std::shared_ptr<GbmQuirks> const& quirks)
+    : drm_fd{std::move(drm_fd)},
+      bound_display{std::move(associated_display)},
       dpy{dpy},
       ctx{ctx},
       dmabuf_provider{std::move(dmabuf_provider)},
-      egl_delegate{std::move(egl_delegate)}
+      egl_delegate{std::move(egl_delegate)},
+      quirks{quirks}
 {
 }
