@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -18,12 +18,12 @@
 #ifndef MIR_GRAPHICS_GBM_CURSOR_H_
 #define MIR_GRAPHICS_GBM_CURSOR_H_
 
-#include "mir/graphics/cursor.h"
-#include "mir/geometry/point.h"
-#include "mir/geometry/displacement.h"
+#include <mir/graphics/cursor.h>
+#include <mir/geometry/point.h>
+#include <mir/geometry/displacement.h>
 
-#include "mir_toolkit/common.h"
-#include "mir/synchronised.h"
+#include <mir_toolkit/common.h>
+#include <mir/synchronised.h>
 
 #include <gbm.h>
 
@@ -39,6 +39,11 @@ namespace graphics
 class CursorImage;
 class DisplayConfigurationOutput;
 
+namespace common
+{
+class MemoryBackedShmBuffer;
+}
+
 namespace gbm
 {
 class KMSOutputContainer;
@@ -64,12 +69,12 @@ class Cursor : public graphics::Cursor
 {
 public:
     Cursor(
-        KMSOutputContainer& output_container,
+        std::shared_ptr<KMSOutputContainer> const& output_container,
         std::shared_ptr<CurrentConfiguration> const& current_configuration);
 
     ~Cursor() noexcept;
 
-    void show(CursorImage const& cursor_image) override;
+    void show(std::shared_ptr<CursorImage> const& cursor_image) override;
     void hide() override;
 
     void move_to(geometry::Point position) override;
@@ -77,6 +82,12 @@ public:
     void suspend();
     void resume();
 
+    void scale(float) override;
+
+    auto renderable() -> std::shared_ptr<Renderable> override;
+
+    auto needs_compositing() const -> bool override;
+
 private:
     enum ForceCursorState { UpdateState, ForceState };
     struct GBMBOWrapper;
@@ -90,18 +101,18 @@ private:
         size_t count);
     void pad_and_write_image_data_locked(
         std::lock_guard<std::mutex> const&,
-        GBMBOWrapper& buffer);
+        GBMBOWrapper& gbm_buffer);
     void clear(std::lock_guard<std::mutex> const&);
 
     GBMBOWrapper& buffer_for_output(KMSOutput const& output);
-    
+
     std::mutex guard;
 
-    KMSOutputContainer& output_container;
+    std::weak_ptr<KMSOutputContainer> output_container;
     geometry::Point current_position;
     geometry::Displacement hotspot;
     geometry::Size size;
-    std::vector<uint8_t> argb8888;
+    std::shared_ptr<common::MemoryBackedShmBuffer> buffer;
 
     bool visible;
     bool last_set_failed;
@@ -132,6 +143,9 @@ private:
     uint32_t min_buffer_height;
 
     std::shared_ptr<CurrentConfiguration> const current_configuration;
+
+    std::shared_ptr<CursorImage> current_cursor_image;
+    float current_scale{1.0};
 };
 }
 }
