@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -17,7 +17,7 @@
 #ifndef MIR_GRAPHICS_GBM_KMS_DISPLAY_CONFIGURATION_H_
 #define MIR_GRAPHICS_GBM_KMS_DISPLAY_CONFIGURATION_H_
 
-#include "mir/graphics/display_configuration.h"
+#include <mir/graphics/display_configuration.h>
 #include <memory>
 
 namespace mir
