@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -15,7 +15,7 @@
  */
 
 #include "kms_page_flipper.h"
-#include "mir/graphics/display_report.h"
+#include <mir/graphics/display_report.h>
 
 #include <stdexcept>
 #include <boost/throw_exception.hpp>
