@@ -14,26 +14,27 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/graphics/platform.h"
+#include <mir/graphics/platform.h>
 #define MIR_LOG_COMPONENT "gbm-kms"
-#include "mir/log.h"
+#include <mir/log.h>
 
 #include "platform.h"
 #include "display_helpers.h"
 #include "quirks.h"
 #include "kms-utils/drm_mode_resources.h"
-#include "mir/options/program_option.h"
-#include "mir/options/option.h"
-#include "mir/options/configuration.h"
-#include "mir/udev/wrapper.h"
-#include "mir/module_deleter.h"
-#include "mir/assert_module_entry_point.h"
-#include "mir/libname.h"
-#include "mir/console_services.h"
+#include <mir/options/program_option.h>
+#include <mir/options/option.h>
+#include <mir/options/configuration.h>
+#include <mir/udev/wrapper.h>
+#include <mir/module_deleter.h>
+#include <mir/assert_module_entry_point.h>
+#include <mir/libname.h>
+#include <mir/console_services.h>
 #include "one_shot_device_observer.h"
-#include "mir/graphics/egl_error.h"
-#include "mir/graphics/gl_config.h"
-#include "mir/graphics/egl_logger.h"
+#include <mir/graphics/egl_error.h>
+#include <mir/graphics/gl_config.h>
+#include <mir/graphics/egl_logger.h>
+#include "quirk_common.h"
 
 #include <EGL/egl.h>
 #include <GLES2/gl2.h>
@@ -78,12 +79,13 @@ mir::UniqueModulePtr<mg::DisplayPlatform> create_display_platform(
 auto create_rendering_platform(
     mg::SupportedDevice const& device,
     std::vector<std::shared_ptr<mg::DisplayPlatform>> const& platforms,
-    mo::Option const&,
+    mo::Option const& options,
     mir::EmergencyCleanupRegistry&) -> mir::UniqueModulePtr<mg::RenderingPlatform>
 {
     mir::assert_entry_point_signature<mg::CreateRenderPlatform>(&create_rendering_platform);
 
-    return mir::make_module_ptr<mgg::RenderingPlatform>(*device.device, platforms);
+    return mir::make_module_ptr<mgg::RenderingPlatform>(
+        *device.device, platforms, mgg::Quirks{options}.gbm_quirks_for(*device.device));
 }
 
 void add_graphics_platform_options(boost::program_options::options_description& config)
@@ -92,7 +94,7 @@ void add_graphics_platform_options(boost::program_options::options_description&
     config.add_options()
         (bypass_option_name,
          boost::program_options::value<bool>()->default_value(false),
-         "[platform-specific] utilize the bypass optimization for fullscreen surfaces.");
+         "Enable bypass optimization for fullscreen surfaces.");
     mgg::Quirks::add_quirks_option(config);
 }
 
@@ -166,6 +168,13 @@ auto probe_display_platform(
             continue;
         }
 
+        auto driver_name = mg::common::get_device_driver(device.parent().get());
+        if(std::strcmp(driver_name, "nvidia") == 0)
+        {
+            mir::log_info("Not probing device %s due to the GBM display platform being incompatible with Nvidia", device.devnode());
+            continue;
+        }
+
         auto const devnum = device.devnum();
         if (devnum == makedev(0, 0))
         {
@@ -209,7 +218,7 @@ auto probe_display_platform(
                         std::string{"Failed to set DRM interface version on device "} + device.devnode()}));
                 }
 
-                // For now, we *also* require our DisplayPlatform to support creating a HW EGL context                
+                // For now, we *also* require our DisplayPlatform to support creating a HW EGL context
                 mgg::helpers::GBMHelper gbm_device{tmp_fd};
                 mgg::helpers::EGLHelper egl{MinimalGLConfig()};
 
@@ -287,7 +296,7 @@ auto probe_display_platform(
                         mir::log_warning("Unexpected error from drmCheckModesettingSupported(): %s (%i), "
                                          "but continuing anyway", strerror(err), err);
                         mir::log_warning("Please file a bug at "
-                                         "https://github.com/MirServer/mir/issues containing this message");
+                                         "https://github.com/canonical/mir/issues containing this message");
                         supported_devices.back().support_level = mg::probe::supported;
                     }
                 }
@@ -327,7 +336,7 @@ auto probe_rendering_platform(
         }
         if (platform->acquire_provider<mg::CPUAddressableDisplayProvider>())
         {
-            /* We *can* support this output, but with slower buffer copies 
+            /* We *can* support this output, but with slower buffer copies
              * If another platform supports this device better, let it.
              */
             maximum_suitability = mg::probe::supported;
@@ -484,4 +493,3 @@ mir::ModuleProperties const* describe_graphics_module()
     mir::assert_entry_point_signature<mg::DescribeModule>(&describe_graphics_module);
     return &description;
 }
-
