@@ -16,11 +16,11 @@
 
 #include "real_kms_output.h"
 #include "kms_framebuffer.h"
-#include "mir/graphics/display_configuration.h"
+#include <mir/graphics/display_configuration.h>
 #include "page_flipper.h"
 #include "kms-utils/kms_connector.h"
-#include "mir/fatal.h"
-#include "mir/log.h"
+#include <mir/fatal.h>
+#include <mir/log.h>
 #include <string.h> // strcmp
 
 #include <boost/throw_exception.hpp>
@@ -131,7 +131,7 @@ geom::Size mgg::RealKMSOutput::size() const
     return {mode.hdisplay, mode.vdisplay};
 }
 
-int mgg::RealKMSOutput::max_refresh_rate() const
+unsigned mgg::RealKMSOutput::max_refresh_rate() const
 {
     if (connector->connection == DRM_MODE_DISCONNECTED)
         return 1;
@@ -324,7 +324,7 @@ bool mgg::RealKMSOutput::ensure_crtc()
         return false;
 
     // Update the connector as we may unexpectedly fail in find_crtc_and_index_for_connector()
-    // https://github.com/MirServer/mir/issues/2661
+    // https://github.com/canonical/mir/issues/2661
     connector = kms::get_connector(drm_fd_, connector->connector_id);
     current_crtc = mgk::find_crtc_for_connector(drm_fd_, connector);
 
@@ -605,7 +605,7 @@ void mgg::RealKMSOutput::update_from_hardware_state(
     output.current_mode_index = current_mode_index;
     output.subpixel_arrangement = kms_subpixel_to_mir_subpixel(connector->subpixel);
     output.gamma = gamma;
-    output.edid = edid;
+    output.display_info = DisplayInfo{edid};
 }
 
 int mgg::RealKMSOutput::drm_fd() const
@@ -617,4 +617,3 @@ bool mgg::RealKMSOutput::connected() const
 {
     return connector->connection == DRM_MODE_CONNECTED;
 }
-
