@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/renderer/gl/context.h"
+#include <mir/renderer/gl/context.h>
 
 #include <EGL/egl.h>
 
@@ -27,17 +27,17 @@ public:
     SurfacelessEGLContext(EGLDisplay dpy, EGLContext share_with);
 
     ~SurfacelessEGLContext() override;
-    
+
     void make_current() const override;
-    
+
     void release_current() const override;
-    
+
     auto make_share_context() const -> std::unique_ptr<Context> override;
     explicit operator EGLContext() override;
 
     auto egl_display() const -> EGLDisplay;
-private:    
+private:
     EGLDisplay const dpy;
     EGLContext const ctx;
 };
-}
\ No newline at end of file
+}
