@@ -16,9 +16,9 @@
  */
 
 #include "displayclient.h"
-#include "mir/fatal.h"
+#include <mir/fatal.h>
 #include "wl_egl_display_provider.h"
-#include "mir/graphics/platform.h"
+#include <mir/graphics/platform.h>
 #include <mir/graphics/pixel_format_utils.h>
 
 #include <wayland-client.h>
@@ -164,12 +164,14 @@ void mgw::DisplayClient::Output::geometry(
     int32_t physical_width,
     int32_t physical_height,
     int32_t subpixel,
-    const char */*make*/,
-    const char */*model*/,
+    const char *make,
+    const char *model,
     int32_t transform)
 {
     dcout.top_left = {x, y};
     dcout.physical_size_mm = {physical_width, physical_height};
+    dcout.display_info.vendor = make;
+    dcout.display_info.model = model;
 
     switch (subpixel)
     {
@@ -753,7 +755,7 @@ void mgw::DisplayClient::touch_motion(
 void mgw::DisplayClient::touch_frame(wl_touch* /*touch*/)
 {
 }
-    
+
 void mgw::DisplayClient::touch_cancel(wl_touch* /*touch*/)
 {
 }
