@@ -1,5 +1,5 @@
 /*
- * Copyright © 2019 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -16,9 +16,9 @@
 
 #include "display.h"
 #include "input_platform.h"
-#include "mir/module_properties.h"
-#include "mir/assert_module_entry_point.h"
-#include "mir/libname.h"
+#include <mir/module_properties.h>
+#include <mir/assert_module_entry_point.h>
+#include <mir/libname.h>
 
 namespace mo = mir::options;
 namespace mi = mir::input;
