@@ -17,8 +17,8 @@
 #ifndef MIR_GRAPHICS_WAYLAND_PLATFORM_H_
 #define MIR_GRAPHICS_WAYLAND_PLATFORM_H_
 
-#include "mir/graphics/platform.h"
-#include "mir/graphics/display.h"
+#include <mir/graphics/platform.h>
+#include <mir/graphics/display.h>
 
 #include <wayland-client.h>
 #include <wayland-egl.h>
