@@ -1,5 +1,5 @@
 /*
- * Copyright © 2019 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -35,7 +35,7 @@ struct WaylandDisplay
 };
 
 char const* wayland_host_option_name{"wayland-host"};
-char const* wayland_host_option_description{"Socket name for host compositor"};
+char const* wayland_host_option_description{"Display name for host compositor, e.g. `wayland-0`."};
 }
 
 void mpw::add_connection_options(boost::program_options::options_description& config)
