@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -17,12 +17,12 @@
 #ifndef MIR_INPUT_X_INPUT_DEVICE_H_
 #define MIR_INPUT_X_INPUT_DEVICE_H_
 
-#include "mir/input/input_device.h"
-#include "mir/input/input_device_info.h"
-#include "mir_toolkit/event.h"
-#include "mir/geometry/point.h"
-#include "mir/geometry/displacement.h"
-#include "mir/optional_value.h"
+#include <mir/input/input_device.h>
+#include <mir/input/input_device_info.h>
+#include <mir_toolkit/event.h>
+#include <mir/geometry/point.h>
+#include <mir/geometry/displacement.h>
+#include <mir/optional_value.h>
 
 #include <chrono>
 #include <optional>
