@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -16,8 +16,8 @@
 #ifndef MIR_INPUT_X_INPUT_PLATFORM_H_
 #define MIR_INPUT_X_INPUT_PLATFORM_H_
 
-#include "mir/input/platform.h"
-#include "mir/geometry/forward.h"
+#include <mir/input/platform.h>
+#include <mir/geometry/forward.h>
 #include <memory>
 #include <functional>
 #include <optional>
