@@ -17,13 +17,14 @@
 #ifndef MIR_COMPOSITOR_BASIC_SCREEN_SHOOTER_H_
 #define MIR_COMPOSITOR_BASIC_SCREEN_SHOOTER_H_
 
-#include "mir/compositor/screen_shooter.h"
-#include "mir/graphics/platform.h"
-#include "mir/renderer/renderer_factory.h"
-#include "mir/renderer/sw/pixel_source.h"
-#include "mir/time/clock.h"
+#include <mir/compositor/screen_shooter.h>
+#include <mir/graphics/platform.h>
+#include <mir/renderer/renderer_factory.h>
+#include <mir/renderer/sw/pixel_source.h>
+#include <mir/time/clock.h>
 
 #include <mutex>
+#include <glm/glm.hpp>
 
 namespace mir
 {
@@ -33,6 +34,11 @@ namespace renderer
 class Renderer;
 class RendererFactory;
 }
+namespace graphics
+{
+class Cursor;
+class OutputFilter;
+}
 namespace compositor
 {
 class Scene;
@@ -47,13 +53,19 @@ public:
         std::span<std::shared_ptr<graphics::GLRenderingProvider>> const& providers,
         std::shared_ptr<renderer::RendererFactory> render_factory,
         std::shared_ptr<graphics::GraphicBufferAllocator> const& buffer_allocator,
-        std::shared_ptr<mir::graphics::GLConfig> const& config);
+        std::shared_ptr<mir::graphics::GLConfig> const& config,
+        std::shared_ptr<graphics::OutputFilter> const& output_filter,
+        std::shared_ptr<graphics::Cursor> const& cursor);
 
     void capture(
-        std::shared_ptr<renderer::software::WriteMappableBuffer> const& buffer,
+        std::shared_ptr<renderer::software::WriteMappable> const& buffer,
         geometry::Rectangle const& area,
+        glm::mat2 const& transform,
+        bool overlay_cursor,
         std::function<void(std::optional<time::Timestamp>)>&& callback) override;
 
+    CompositorID id() const override;
+
 private:
     struct Self
     {
@@ -64,13 +76,17 @@ private:
             std::shared_ptr<time::Clock> const& clock,
             std::shared_ptr<graphics::GLRenderingProvider> provider,
             std::shared_ptr<renderer::RendererFactory> render_factory,
-            std::shared_ptr<mir::graphics::GLConfig> const& config);
+            std::shared_ptr<mir::graphics::GLConfig> const& config,
+            std::shared_ptr<graphics::OutputFilter> const& output_filter,
+std::shared_ptr<graphics::Cursor> const& cursor);
 
         auto render(
-            std::shared_ptr<renderer::software::WriteMappableBuffer> const& buffer,
-            geometry::Rectangle const& area) -> time::Timestamp;
+            std::shared_ptr<renderer::software::WriteMappable> const& buffer,
+            geometry::Rectangle const& area,
+            glm::mat2 const& transform,
+            bool overlay_cursor) -> time::Timestamp;
 
-        auto renderer_for_buffer(std::shared_ptr<renderer::software::WriteMappableBuffer> buffer)
+        auto renderer_for_buffer(std::shared_ptr<renderer::software::WriteMappable> buffer)
             -> renderer::Renderer&;
 
         std::mutex mutex;
@@ -89,6 +105,8 @@ private:
         std::unique_ptr<graphics::DisplaySink> offscreen_sink;
         std::shared_ptr<OneShotBufferDisplayProvider> const output;
         std::shared_ptr<mir::graphics::GLConfig> config;
+        std::shared_ptr<graphics::OutputFilter> const output_filter;
+        std::shared_ptr<graphics::Cursor> cursor;
     };
     std::shared_ptr<Self> const self;
     Executor& executor;
