@@ -16,27 +16,36 @@
 
 #include "default_display_buffer_compositor.h"
 
-#include "mir/compositor/compositor_report.h"
-#include "mir/compositor/scene.h"
-#include "mir/compositor/scene_element.h"
-#include "mir/graphics/renderable.h"
-#include "mir/graphics/display_sink.h"
-#include "mir/graphics/buffer.h"
-#include "mir/graphics/platform.h"
-#include "mir/compositor/buffer_stream.h"
-#include "mir/renderer/renderer.h"
+#include <mir/compositor/compositor_report.h>
+#include <mir/compositor/scene.h>
+#include <mir/compositor/scene_element.h>
+#include <mir/graphics/dmabuf_buffer.h>
+#include <mir/graphics/renderable.h>
+#include <mir/graphics/display_sink.h>
+#include <mir/graphics/buffer.h>
+#include <mir/graphics/output_filter.h>
+#include <mir/graphics/platform.h>
+#include <mir/compositor/buffer_stream.h>
+#include <mir/renderer/renderer.h>
 #include "occlusion.h"
+#include <memory>
+
+#define MIR_LOG_COMPONENT "compositor"
+#include <mir/log.h>
 
 namespace mc = mir::compositor;
 namespace mg = mir::graphics;
 
+
 mc::DefaultDisplayBufferCompositor::DefaultDisplayBufferCompositor(
     mg::DisplaySink& display_sink,
     graphics::GLRenderingProvider& gl_provider,
     std::shared_ptr<mir::renderer::Renderer> const& renderer,
+    std::shared_ptr<mir::graphics::OutputFilter> const& output_filter,
     std::shared_ptr<CompositorReport> const& report) :
     display_sink(display_sink),
     renderer(renderer),
+    output_filter(output_filter),
     fb_adaptor{gl_provider.make_framebuffer_provider(display_sink)},
     report(report)
 {
@@ -51,14 +60,14 @@ bool mc::DefaultDisplayBufferCompositor::composite(mc::SceneElementSequence&& sc
     report->began_frame(this);
 
     auto const& view_area = display_sink.view_area();
-    auto const& occlusions = mc::filter_occlusions_from(scene_elements, view_area);
+    auto [occluded_elements, visible_elements] = mc::split_occluded_and_visible(std::move(scene_elements), view_area);
 
-    for (auto const& element : occlusions)
+    for (auto const& element : occluded_elements)
         element->occluded();
 
     mg::RenderableList renderable_list;
-    renderable_list.reserve(scene_elements.size());
-    for (auto const& element : scene_elements)
+    renderable_list.reserve(visible_elements.size());
+    for (auto const& element : visible_elements)
     {
         element->rendered();
         renderable_list.push_back(element->renderable());
@@ -66,13 +75,13 @@ bool mc::DefaultDisplayBufferCompositor::composite(mc::SceneElementSequence&& sc
 
     /*
      * Note: Buffer lifetimes are ensured by the two objects holding
-     *       references to them; scene_elements and renderable_list.
-     *       So no buffer is going to be releaswayland_executored back to the client till
+     *       references to them; visible_elements and renderable_list.
+     *       So no buffer is going to be released back to the client till
      *       both of those containers get destroyed (end of the function).
      *       Actually, there's a third reference held by the texture cache
      *       in GLRenderer, but that gets released earlier in render().
      */
-    scene_elements.clear();  // Those in use are still in renderable_list
+    visible_elements.clear();  // Those in use are still in renderable_list
 
     std::vector<mg::DisplayElement> framebuffers;
     framebuffers.reserve(renderable_list.size());
@@ -117,6 +126,7 @@ bool mc::DefaultDisplayBufferCompositor::composite(mc::SceneElementSequence&& sc
     {
         renderer->set_output_transform(display_sink.transformation());
         renderer->set_viewport(view_area);
+        renderer->set_output_filter(output_filter->filter());
 
         display_sink.set_next_image(renderer->render(renderable_list));
 
