@@ -17,8 +17,8 @@
 #ifndef MIR_COMPOSITOR_MULTI_THREADED_COMPOSITOR_H_
 #define MIR_COMPOSITOR_MULTI_THREADED_COMPOSITOR_H_
 
-#include "mir/compositor/compositor.h"
-#include "mir/geometry/forward.h"
+#include <mir/compositor/compositor.h>
+#include <mir/geometry/forward.h>
 
 #include <memory>
 #include <vector>
@@ -30,6 +30,7 @@ namespace mir
 namespace graphics
 {
 class Display;
+class Cursor;
 }
 namespace scene
 {
@@ -62,6 +63,7 @@ public:
         std::shared_ptr<Scene> const& scene,
         std::shared_ptr<DisplayListener> const& display_listener,
         std::shared_ptr<CompositorReport> const& compositor_report,
+        std::shared_ptr<graphics::Cursor> const& cursor,
         std::chrono::milliseconds fixed_composite_delay,  // -1 = automatic
         bool compose_on_start);
     ~MultiThreadedCompositor();
@@ -78,6 +80,7 @@ private:
     std::shared_ptr<Scene> const scene;
     std::shared_ptr<DisplayListener> const display_listener;
     std::shared_ptr<CompositorReport> const report;
+    std::shared_ptr<graphics::Cursor> const cursor;
 
     std::vector<std::unique_ptr<CompositingFunctor>> thread_functors;
 
