@@ -15,8 +15,8 @@
  */
 
 #include "null_screen_shooter.h"
-#include "mir/log.h"
-#include "mir/executor.h"
+#include <mir/log.h>
+#include <mir/executor.h>
 
 namespace mc = mir::compositor;
 namespace mrs = mir::renderer::software;
@@ -28,8 +28,10 @@ mc::NullScreenShooter::NullScreenShooter(Executor& executor)
 }
 
 void mc::NullScreenShooter::capture(
-    std::shared_ptr<mrs::WriteMappableBuffer> const&,
+    std::shared_ptr<mrs::WriteMappable> const&,
     geom::Rectangle const&,
+    glm::mat2 const&,
+    bool,
     std::function<void(std::optional<time::Timestamp>)>&& callback)
 {
     log_warning("Failed to capture screen because NullScreenShooter is in use");
@@ -38,3 +40,8 @@ void mc::NullScreenShooter::capture(
             callback(std::nullopt);
         });
 }
+
+mc::CompositorID mc::NullScreenShooter::id() const
+{
+    return this;
+}
