@@ -17,7 +17,9 @@
 #ifndef MIR_COMPOSITOR_NULL_SCREEN_SHOOTER_H_
 #define MIR_COMPOSITOR_NULL_SCREEN_SHOOTER_H_
 
-#include "mir/compositor/screen_shooter.h"
+#include <glm/fwd.hpp>
+
+#include <mir/compositor/screen_shooter.h>
 
 namespace mir
 {
@@ -25,17 +27,21 @@ class Executor;
 namespace compositor
 {
 
-/// An implementation of ScreenShooter than always calls the callback with an error
+/// An implementation of ScreenShooter that always calls the callback with an error
 class NullScreenShooter: public ScreenShooter
 {
 public:
     NullScreenShooter(Executor& executor);
 
     void capture(
-        std::shared_ptr<renderer::software::WriteMappableBuffer> const& buffer,
+        std::shared_ptr<renderer::software::WriteMappable> const& buffer,
         geometry::Rectangle const& area,
+        glm::mat2 const& transform,
+        bool overlay_cursor,
         std::function<void(std::optional<time::Timestamp>)>&& callback) override;
 
+    CompositorID id() const override;
+
 private:
     Executor& executor;
 };
