@@ -17,14 +17,16 @@
 #ifndef MIR_COMPOSITOR_OCCLUSION_H_
 #define MIR_COMPOSITOR_OCCLUSION_H_
 
-#include "mir/compositor/scene.h"
+#include <mir/compositor/scene.h>
 
 namespace mir
 {
 namespace compositor
 {
 
-SceneElementSequence filter_occlusions_from(SceneElementSequence& list, geometry::Rectangle const& area);
+using OccludedElementSequence = SceneElementSequence;
+std::pair<OccludedElementSequence, SceneElementSequence> split_occluded_and_visible(
+    SceneElementSequence&& list, geometry::Rectangle const& area);
 
 } // namespace compositor
 } // namespace mir
