@@ -15,16 +15,16 @@
  */
 
 #include "linux_virtual_terminal.h"
-#include "mir/graphics/display_report.h"
-#include "mir/graphics/event_handler_register.h"
-#include "mir/fd.h"
-#include "mir/emergency_cleanup_registry.h"
+#include <mir/graphics/display_report.h>
+#include <mir/graphics/event_handler_register.h>
+#include <mir/fd.h>
+#include <mir/emergency_cleanup_registry.h>
 #include "ioctl_vt_switcher.h"
-#include "mir/raii.h"
-#include "mir/synchronised.h"
+#include <mir/raii.h>
+#include <mir/synchronised.h>
 
 #define MIR_LOG_COMPONTENT "VT-handler"
-#include "mir/log.h"
+#include <mir/log.h>
 
 #include <boost/throw_exception.hpp>
 #include <boost/exception/errinfo_errno.hpp>
@@ -317,7 +317,6 @@ mir::LinuxVirtualTerminal::LinuxVirtualTerminal(
       prev_tcattr(),
       active{true}
 {
-    struct termios tcattr;
     if (fops->ioctl(vt_fd.fd(), KDGETMODE, &prev_kd_mode) < 0)
     {
         BOOST_THROW_EXCEPTION(
@@ -350,7 +349,7 @@ mir::LinuxVirtualTerminal::LinuxVirtualTerminal(
     }
 
     fops->tcgetattr(vt_fd.fd(), &prev_tcattr);
-    tcattr = prev_tcattr;
+    auto tcattr = prev_tcattr;
     tcattr.c_iflag = IGNPAR | IGNBRK;
     cfsetispeed(&tcattr, B9600);
     tcattr.c_oflag = 0;
@@ -534,7 +533,7 @@ int mir::LinuxVirtualTerminal::find_active_vt_number()
 
         if (fd >= 0)
         {
-            struct vt_stat vts;
+            struct vt_stat vts{};
             auto status = fops->ioctl(fd, VT_GETSTATE, &vts);
             fops->close(fd);
 
