@@ -14,32 +14,33 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/default_server_configuration.h"
-#include "mir/fatal.h"
-#include "mir/options/default_configuration.h"
-#include "mir/glib_main_loop.h"
-#include "mir/default_server_status_listener.h"
-#include "mir/emergency_cleanup.h"
-#include "mir/frontend/wayland.h"
+#include <mir/default_server_configuration.h>
+#include <mir/fatal.h>
+#include <mir/options/default_configuration.h>
+#include <mir/glib_main_loop.h>
+#include <mir/default_server_status_listener.h>
+#include <mir/emergency_cleanup.h>
+#include <mir/frontend/wayland.h>
 
-#include "mir/logging/dumb_console_logger.h"
-#include "mir/options/option.h"
-#include "mir/options/program_option.h"
-#include "mir/frontend/session_credentials.h"
-#include "mir/frontend/session_authorizer.h"
-#include "mir/graphics/cursor.h"
-#include "mir/scene/null_session_listener.h"
-#include "mir/graphics/display.h"
-#include "mir/input/cursor_listener.h"
-#include "mir/input/vt_filter.h"
-#include "mir/input/input_manager.h"
-#include "mir/time/steady_clock.h"
-#include "mir/geometry/rectangles.h"
-#include "mir/scene/null_prompt_session_listener.h"
+#include <mir/logging/dumb_console_logger.h>
+#include <mir/options/option.h>
+#include <mir/options/program_option.h>
+#include <mir/frontend/session_credentials.h>
+#include <mir/frontend/session_authorizer.h>
+#include <mir/graphics/cursor.h>
+#include <mir/scene/null_session_listener.h>
+#include <mir/graphics/display.h>
+#include <mir/input/cursor_observer.h>
+#include <mir/input/vt_filter.h>
+#include <mir/input/input_manager.h>
+#include <mir/time/steady_clock.h>
+#include <mir/geometry/rectangles.h>
+#include <mir/scene/null_prompt_session_listener.h>
 #include "default_emergency_cleanup.h"
-#include "mir/graphics/platform.h"
-#include "mir/console_services.h"
-#include "mir/decoration_strategy.h"
+#include <mir/graphics/platform.h>
+#include <mir/console_services.h>
+#include <mir/decoration_strategy.h>
+#include <mir/scene/session.h>
 
 namespace mc = mir::compositor;
 namespace geom = mir::geometry;
@@ -51,6 +52,19 @@ namespace ms = mir::scene;
 namespace msh = mir::shell;
 namespace mi = mir::input;
 
+namespace
+{
+std::map<std::string, mir::ServerConfiguration::WaylandProtocolExtensionFilter> get_default_wayland_extension_policy_map()
+{
+    std::map<std::string, mir::ServerConfiguration::WaylandProtocolExtensionFilter> result;
+    for (auto const& extension : mir::frontend::get_supported_extensions())
+        result[extension] = [](auto const&, const char*) { return false; };
+    for (auto const& extension: mir::frontend::get_standard_extensions())
+        result[extension] = [](auto const&, const char*) { return true; };
+    return result;
+}
+}
+
 mir::DefaultServerConfiguration::DefaultServerConfiguration(int argc, char const* argv[]) :
         DefaultServerConfiguration(std::make_shared<mo::DefaultConfiguration>(argc, argv))
 {
@@ -58,7 +72,16 @@ mir::DefaultServerConfiguration::DefaultServerConfiguration(int argc, char const
 
 mir::DefaultServerConfiguration::DefaultServerConfiguration(std::shared_ptr<mo::Configuration> const& configuration_options) :
     configuration_options(configuration_options),
-    enabled_wayland_extensions(frontend::get_standard_extensions())
+    wayland_extension_policy_map(get_default_wayland_extension_policy_map()),
+    wayland_extension_filter([this](auto const& session, auto const& interface_name)
+    {
+        auto const it = wayland_extension_policy_map.find(interface_name);
+        if (it != wayland_extension_policy_map.end())
+            return it->second(session, interface_name)
+                || session->process_id() == getpid();
+
+        return true;
+    })
 {
 }
 
