@@ -1,5 +1,5 @@
 /*
- * Copyright © 2012 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -14,20 +14,21 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/display_server.h"
-#include "mir/server_configuration.h"
-#include "mir/main_loop.h"
-#include "mir/server_status_listener.h"
-#include "mir/display_changer.h"
+#include <mir/display_server.h>
+#include <mir/server_configuration.h>
+#include <mir/main_loop.h>
+#include <mir/server_status_listener.h>
+#include <mir/display_changer.h>
+#include <mir/console_services.h>
 
-#include "mir/compositor/compositor.h"
-#include "mir/frontend/connector.h"
-#include "mir/graphics/display.h"
-#include "mir/graphics/display_configuration.h"
-#include "mir/input/input_manager.h"
-#include "mir/input/input_dispatcher.h"
-#include "mir/log.h"
-#include "mir/unwind_helpers.h"
+#include <mir/compositor/compositor.h>
+#include <mir/frontend/connector.h>
+#include <mir/graphics/display.h>
+#include <mir/graphics/display_configuration.h>
+#include <mir/input/input_manager.h>
+#include <mir/input/input_dispatcher.h>
+#include <mir/log.h>
+#include <mir/unwind_helpers.h>
 
 #include <boost/exception/diagnostic_information.hpp>
 
@@ -82,13 +83,14 @@ struct mir::DisplayServer::Private
           server_status_listener{config.the_server_status_listener()},
           display_changer{config.the_display_changer()},
           idle_handler{config.the_idle_handler()},
-          stop_callback{config.the_stop_callback()}
+          stop_callback{config.the_stop_callback()},
+          console_services{config.the_console_services()}
     {
         display->register_configuration_change_handler(
             *main_loop,
             [this] { return configure_display(); });
 
-        display->register_pause_resume_handlers(
+        console_services->register_switch_handlers(
             *main_loop,
             [this] { return pause(); },
             [this] { return resume(); });
@@ -188,7 +190,7 @@ struct mir::DisplayServer::Private
         std::shared_ptr<graphics::DisplayConfiguration> conf =
             display->configuration();
 
-        display_changer->configure_for_hardware_change(conf);
+        display_changer->configure(conf);
     }
 
     std::shared_ptr<EmergencyCleanup> const emergency_cleanup; // Hold this so it does not get freed prematurely
@@ -204,7 +206,7 @@ struct mir::DisplayServer::Private
     std::shared_ptr<mir::DisplayChanger> const display_changer;
     std::shared_ptr<msh::IdleHandler> const idle_handler;
     std::function<void()> const stop_callback;
-
+    std::shared_ptr<mir::ConsoleServices> const console_services;
 };
 
 mir::DisplayServer::DisplayServer(ServerConfiguration& config) :
