@@ -15,17 +15,18 @@
  */
 
 #include "input_method_v1.h"
-#include "mir/scene/text_input_hub.h"
-#include "mir/shell/surface_specification.h"
-#include "mir/shell/shell.h"
-#include "mir/scene/session.h"
-#include "mir/scene/surface.h"
-#include "mir/log.h"
+#include <mir/scene/text_input_hub.h>
+#include <mir/shell/surface_specification.h>
+#include <mir/shell/shell.h>
+#include <mir/scene/session.h>
+#include <mir/scene/surface.h>
+#include <mir/log.h>
 #include "wl_surface.h"
 #include "output_manager.h"
 #include "window_wl_surface_role.h"
 #include "input_method_common.h"
 #include <deque>
+#include <ranges>
 
 namespace mf = mir::frontend;
 namespace ms = mir::scene;
@@ -36,8 +37,8 @@ class mf::InputMethodV1::Instance : wayland::InputMethodV1
 {
 public:
     Instance(wl_resource* new_resource,
-         std::shared_ptr<scene::TextInputHub> const text_input_hub,
-         std::shared_ptr<Executor> const wayland_executor)
+         std::shared_ptr<scene::TextInputHub> const& text_input_hub,
+         std::shared_ptr<Executor> const& wayland_executor)
         : InputMethodV1{new_resource, Version<1>()},
           text_input_hub(text_input_hub),
           state_observer{std::make_shared<StateObserver>(this)}
@@ -168,7 +169,7 @@ private:
     public:
         InputMethodContextV1(
             mf::InputMethodV1::Instance* method,
-            std::shared_ptr<scene::TextInputHub> const text_input_hub)
+            std::shared_ptr<scene::TextInputHub> const& text_input_hub)
             : wayland::InputMethodContextV1(*static_cast<wayland::InputMethodV1*>(method)),
               text_input_hub(text_input_hub)
         {
@@ -231,11 +232,11 @@ private:
         auto find_serial(uint32_t done_count) const -> std::optional<ms::TextInputStateSerial>
         {
             // Loop in reverse order because the serial we're looking for will generally be at the end
-            for (auto it = serials.rbegin(); it != serials.rend(); it++)
+            for (auto const& serial_pair : std::ranges::reverse_view(serials))
             {
-                if (it->first == done_count)
+                if (serial_pair.first == done_count)
                 {
-                    return it->second;
+                    return serial_pair.second;
                 }
             }
             return std::nullopt;
@@ -381,8 +382,8 @@ private:
 
 mf::InputMethodV1::InputMethodV1(
     wl_display *display,
-    std::shared_ptr<Executor> const wayland_executor,
-    std::shared_ptr<scene::TextInputHub> const text_input_hub)
+    std::shared_ptr<Executor> const& wayland_executor,
+    std::shared_ptr<scene::TextInputHub> const& text_input_hub)
     : Global(display, Version<1>()),
       wayland_executor(wayland_executor),
       text_input_hub(text_input_hub)
@@ -400,18 +401,20 @@ class mf::InputPanelV1::Instance : wayland::InputPanelV1
 {
 public:
     Instance(
-        std::shared_ptr<Executor> const wayland_executor,
-        std::shared_ptr<shell::Shell> const shell,
+        std::shared_ptr<Executor> const& wayland_executor,
+        std::shared_ptr<shell::Shell> const& shell,
         WlSeat* seat,
         OutputManager* const output_manager,
         wl_resource* new_resource,
-        std::shared_ptr<scene::TextInputHub> const text_input_hub)
-        : InputPanelV1{new_resource, Version<1>()},
-          wayland_executor{wayland_executor},
-          shell{shell},
-          seat{seat},
-          output_manager{output_manager},
-          text_input_hub{text_input_hub}
+        std::shared_ptr<scene::TextInputHub> const& text_input_hub,
+        std::shared_ptr<SurfaceRegistry> const& surface_registry) :
+        InputPanelV1{new_resource, Version<1>()},
+        wayland_executor{wayland_executor},
+        shell{shell},
+        seat{seat},
+        output_manager{output_manager},
+        text_input_hub{text_input_hub},
+        surface_registry{surface_registry}
     {}
 
 private:
@@ -422,12 +425,13 @@ private:
     public:
         InputPanelSurfaceV1(
             wl_resource* id,
-            std::shared_ptr<Executor> const wayland_executor,
+            std::shared_ptr<Executor> const& wayland_executor,
             WlSeat* seat,
             WlSurface* surface,
-            std::shared_ptr<shell::Shell> shell,
+            std::shared_ptr<shell::Shell> const& shell,
             OutputManager* const output_manager,
-            std::shared_ptr<scene::TextInputHub> text_input_hub)
+            std::shared_ptr<scene::TextInputHub> const& text_input_hub,
+            std::shared_ptr<SurfaceRegistry> const& surface_registry)
             : wayland::InputPanelSurfaceV1(id, Version<1>()),
               WindowWlSurfaceRole(
                   *wayland_executor,
@@ -435,7 +439,8 @@ private:
                   wayland::InputPanelSurfaceV1::client,
                   surface,
                   shell,
-                  output_manager),
+                  output_manager,
+                  surface_registry),
               output_manager(output_manager),
               text_input_hub{text_input_hub},
               state_observer{std::make_shared<StateObserver>(this)}
@@ -471,6 +476,7 @@ private:
             std::optional<geometry::Point> const& /*new_top_left*/,
             geometry::Size const& /*new_size*/) override {};
         virtual void handle_close_request() override {};
+        virtual void handle_tiled_edges(Flags<MirTiledEdge> /*tiled_edges*/) override {}
         virtual void handle_commit() override
         {
             auto surface_opt = scene_surface();
@@ -558,7 +564,8 @@ private:
             WlSurface::from(surface),
             shell,
             output_manager,
-            text_input_hub);
+            text_input_hub,
+            surface_registry);
     }
 
     std::shared_ptr<Executor> const wayland_executor;
@@ -566,21 +573,24 @@ private:
     WlSeat* seat;
     OutputManager* const output_manager;
     std::shared_ptr<scene::TextInputHub> const text_input_hub;
+    std::shared_ptr<SurfaceRegistry> const surface_registry;
 };
 
 mf::InputPanelV1::InputPanelV1(
     wl_display* display,
-    std::shared_ptr<Executor> const wayland_executor,
-    std::shared_ptr<shell::Shell> const shell,
+    std::shared_ptr<Executor> const& wayland_executor,
+    std::shared_ptr<shell::Shell> const& shell,
     WlSeat* seat,
     OutputManager* const output_manager,
-    std::shared_ptr<scene::TextInputHub> const text_input_hub)
+    std::shared_ptr<scene::TextInputHub> const& text_input_hub,
+    std::shared_ptr<SurfaceRegistry> const& surface_registry)
     : Global(display, Version<1>()),
       wayland_executor{wayland_executor},
       shell{shell},
       seat{seat},
       output_manager{output_manager},
-      text_input_hub{text_input_hub}
+      text_input_hub{text_input_hub},
+      surface_registry{surface_registry}
 {}
 
 void mf::InputPanelV1::bind(wl_resource *new_resource)
@@ -591,6 +601,7 @@ void mf::InputPanelV1::bind(wl_resource *new_resource)
         seat,
         output_manager,
         new_resource,
-        text_input_hub
+        text_input_hub,
+        surface_registry,
     };
 }
