@@ -22,11 +22,11 @@
 #include "wayland_utils.h"
 #include "output_manager.h"
 
-#include "mir/shell/surface_specification.h"
-#include "mir/log.h"
-#include "mir/wayland/weak.h"
-#include "mir/wayland/client.h"
-#include "mir/wayland/protocol_error.h"
+#include <mir/shell/surface_specification.h>
+#include <mir/log.h>
+#include <mir/wayland/weak.h>
+#include <mir/wayland/client.h>
+#include <mir/wayland/protocol_error.h>
 #include <boost/throw_exception.hpp>
 #include <deque>
 #include <vector>
@@ -189,6 +189,7 @@ private:
         std::optional<geometry::Point> const& /*new_top_left*/,
         geometry::Size const& /*new_size*/) override;
     void handle_close_request() override;
+    void handle_tiled_edges(Flags<MirTiledEdge> /*tiled_edges*/) override {}
     void surface_destroyed() override;
 
     void destroy_role() const override
@@ -219,14 +220,16 @@ private:
 mf::LayerShellV1::LayerShellV1(
     struct wl_display* display,
     Executor& wayland_executor,
-    std::shared_ptr<msh::Shell> shell,
+    std::shared_ptr<msh::Shell> const& shell,
     WlSeat& seat,
-    OutputManager* output_manager)
+    OutputManager* output_manager,
+    std::shared_ptr<SurfaceRegistry> const& surface_registry)
     : Global(display, Version<4>()),
       wayland_executor{wayland_executor},
       shell{shell},
       seat{seat},
-      output_manager{output_manager}
+      output_manager{output_manager},
+      surface_registry{surface_registry}
 {
 }
 
@@ -287,7 +290,8 @@ mf::LayerSurfaceV1::LayerSurfaceV1(
           wayland::LayerSurfaceV1::client,
           surface,
           layer_shell.shell,
-          layer_shell.output_manager)
+          layer_shell.output_manager,
+          layer_shell.surface_registry)
 {
     // TODO: Error if surface has buffer attached or committed
     shell::SurfaceSpecification spec;
@@ -588,12 +592,7 @@ void mf::LayerSurfaceV1::get_popup(struct wl_resource* popup)
 
     // Ideally we'd do this in a callback when popups are destroyed, but in practice waiting until a new popup is
     // created to clear out the destroyed ones is fine
-    popups.erase(
-        std::remove_if(
-            popups.begin(),
-            popups.end(),
-            [](auto popup) { return !popup; }),
-        popups.end());
+    std::erase_if(popups, [](auto const& popup) { return !popup; });
     popups.push_back(mw::make_weak(popup_window_role));
 }
 
