@@ -1,5 +1,5 @@
 /*
- * Copyright © 2018 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3,
@@ -35,6 +35,7 @@ namespace frontend
 {
 class WlSeat;
 class OutputManager;
+class SurfaceRegistry;
 
 class LayerShellV1 : public wayland::LayerShellV1::Global
 {
@@ -42,9 +43,10 @@ public:
     LayerShellV1(
         wl_display* display,
         Executor& wayland_executor,
-        std::shared_ptr<shell::Shell> shell,
+        std::shared_ptr<shell::Shell> const& shell,
         WlSeat& seat,
-        OutputManager* output_manager);
+        OutputManager* output_manager,
+        std::shared_ptr<SurfaceRegistry> const& surface_registry);
 
     static auto get_window(wl_resource* surface) -> std::shared_ptr<scene::Surface>;
 
@@ -52,6 +54,7 @@ public:
     std::shared_ptr<shell::Shell> const shell;
     WlSeat& seat;
     OutputManager* const output_manager;
+    std::shared_ptr<SurfaceRegistry> const surface_registry;
 
 private:
     class Instance;
