@@ -21,12 +21,13 @@
 #include <mir/graphics/null_display_configuration_observer.h>
 
 #include "wayland_wrapper.h"
-#include "mir/wayland/weak.h"
+#include <mir/wayland/weak.h>
 
 #include <optional>
 #include <memory>
 #include <vector>
 #include <unordered_map>
+#include <tuple>
 
 namespace mir
 {
@@ -38,7 +39,7 @@ namespace frontend
 class DisplayChanger;
 class OutputGlobal;
 
-class OutputConfigListener
+class OutputConfigListener : public virtual wayland::LifetimeTracker
 {
 public:
     // Returns true if the wl_output needs to send a done event
@@ -86,7 +87,7 @@ private:
     void instance_destroyed(OutputInstance* instance);
 
     graphics::DisplayConfigurationOutput output_config;
-    std::vector<OutputConfigListener*> listeners;
+    std::vector<wayland::Weak<OutputConfigListener>> listeners;
     std::unordered_map<wayland::Client*, std::vector<OutputInstance*>> instances;
 };
 
@@ -119,6 +120,8 @@ public:
     void add_listener(OutputManagerListener* listener);
     void remove_listener(OutputManagerListener* listener);
 
+    static auto from_output_transform(int32_t transform) -> std::tuple<MirOrientation, MirMirrorMode>;
+    static auto to_output_transform(MirOrientation orientation, MirMirrorMode mirror_mode) -> int32_t;
 private:
     void handle_configuration_change(std::shared_ptr<graphics::DisplayConfiguration const> const& config);
 
