@@ -15,14 +15,14 @@
  */
 
 #include "shm.h"
-#include "mir/graphics/drm_formats.h"
+#include <mir/graphics/drm_formats.h>
 #include "../shm_backing.h"
-#include "mir/log.h"
-#include "mir/wayland/protocol_error.h"
+#include <mir/log.h>
+#include <mir/wayland/protocol_error.h>
 
-#include "mir/wayland/weak.h"
-#include "mir/executor.h"
-#include "mir/renderer/sw/pixel_source.h"
+#include <mir/wayland/weak.h>
+#include <mir/executor.h>
+#include <mir/renderer/sw/pixel_source.h>
 #include "wayland_wrapper.h"
 
 #include <drm_fourcc.h>
@@ -52,7 +52,7 @@ mf::ShmBuffer::ShmBuffer(
 
 namespace
 {
-class ErrorNotifyingRWMappableBuffer : public mrs::RWMappableBuffer
+class ErrorNotifyingRWMappableBuffer : public mrs::RWMappable
 {
 public:
     ErrorNotifyingRWMappableBuffer(
@@ -67,9 +67,8 @@ public:
     auto stride() const -> mir::geometry::Stride override;
     auto format() const -> MirPixelFormat override;
 
-    auto map_readable() -> std::unique_ptr<mrs::Mapping<unsigned char const>> override;
-    auto map_writeable() -> std::unique_ptr<mrs::Mapping<unsigned char>> override;
-    auto map_rw() -> std::unique_ptr<mrs::Mapping<unsigned char>> override;
+    auto map_writeable() -> std::unique_ptr<mrs::Mapping<std::byte>> override;
+    auto map_rw() -> std::unique_ptr<mrs::Mapping<std::byte>> override;
 
     void notify_access_error() const;
 private:
@@ -116,7 +115,7 @@ public:
         return parent.size();
     }
 
-    auto data() -> T* override
+    auto data() const -> T* override
     {
         return reinterpret_cast<T*>(mapping->data());
     }
@@ -184,23 +183,18 @@ auto ErrorNotifyingRWMappableBuffer::format() const -> MirPixelFormat
     return format_;
 }
 
-auto ErrorNotifyingRWMappableBuffer::map_rw() -> std::unique_ptr<mrs::Mapping<unsigned char>>
+auto ErrorNotifyingRWMappableBuffer::map_rw() -> std::unique_ptr<mrs::Mapping<std::byte>>
 {
-    return std::make_unique<ErrorNotifyingMapping<unsigned char>>(data->map_rw(), *this);
+    return std::make_unique<ErrorNotifyingMapping<std::byte>>(data->map_rw(), *this);
 }
 
-auto ErrorNotifyingRWMappableBuffer::map_readable() -> std::unique_ptr<mrs::Mapping<unsigned char const>>
+auto ErrorNotifyingRWMappableBuffer::map_writeable() -> std::unique_ptr<mrs::Mapping<std::byte>>
 {
-    return std::make_unique<ErrorNotifyingMapping<unsigned char const>>(data->map_ro(), *this);
-}
-
-auto ErrorNotifyingRWMappableBuffer::map_writeable() -> std::unique_ptr<mrs::Mapping<unsigned char>>
-{
-    return std::make_unique<ErrorNotifyingMapping<unsigned char>>(data->map_wo(), *this);
+    return std::make_unique<ErrorNotifyingMapping<std::byte>>(data->map_wo(), *this);
 }
 }
 
-auto mf::ShmBuffer::data() -> std::shared_ptr<mrs::RWMappableBuffer>
+auto mf::ShmBuffer::data() -> std::shared_ptr<mrs::RWMappable>
 {
     return std::make_shared<ErrorNotifyingRWMappableBuffer>(
         wayland::make_weak<mf::ShmBuffer>(this),
