@@ -18,12 +18,13 @@
 
 #include "wl_seat.h"
 #include "wl_surface.h"
-#include "mir/executor.h"
-#include "mir/scene/text_input_hub.h"
+#include <mir/executor.h>
+#include <mir/scene/text_input_hub.h>
 
 #include <boost/throw_exception.hpp>
 #include <mir/wayland/client.h>
 #include <deque>
+#include <ranges>
 
 namespace mf = mir::frontend;
 namespace mw = mir::wayland;
@@ -331,11 +332,11 @@ void mf::TextInputV2::send_text_change(ms::TextInputChange const& change)
 auto mf::TextInputV2::find_client_serial(ms::TextInputStateSerial state_serial) const -> std::optional<uint32_t>
 {
     // Loop in reverse order because the serial we're looking for will generally be at the end
-    for (auto it = state_serials.rbegin(); it != state_serials.rend(); it++)
+    for (auto const& serial_pair : std::ranges::reverse_view(state_serials))
     {
-        if (it->hub_serial == state_serial)
+        if (serial_pair.hub_serial == state_serial)
         {
-            return it->client_serial;
+            return serial_pair.client_serial;
         }
     }
     return std::nullopt;
