@@ -16,7 +16,8 @@
 
 #include "wayland_connector.h"
 
-#include "mir/shell/token_authority.h"
+#include <mir/shell/token_authority.h>
+#include <mir/graphics/platform.h>
 #include "wl_client.h"
 #include "wl_data_device_manager.h"
 #include "wayland_utils.h"
@@ -30,13 +31,16 @@
 #include "desktop_file_manager.h"
 #include "foreign_toplevel_manager_v1.h"
 #include "wp_viewporter.h"
+#include "linux_drm_syncobj.h"
+#include "surface_registry.h"
 
-#include "mir/main_loop.h"
-#include "mir/thread_name.h"
-#include "mir/log.h"
-#include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/frontend/wayland.h"
+#include <mir/main_loop.h>
+#include <mir/thread_name.h>
+#include <mir/log.h>
+#include <mir/graphics/graphic_buffer_allocator.h>
+#include <mir/frontend/wayland.h>
 
+#include <future>
 #include <optional>
 #include <sys/eventfd.h>
 #include <sys/stat.h>
@@ -70,7 +74,7 @@ public:
         std::shared_ptr<mir::Executor> const& wayland_executor,
         std::shared_ptr<mir::Executor> const& frame_callback_executor,
         std::shared_ptr<mg::GraphicBufferAllocator> const& allocator)
-        : Global(display, Version<4>()),
+        : Global(display, Version<6>()),
           allocator{allocator},
           wayland_executor{wayland_executor},
           frame_callback_executor{frame_callback_executor}
@@ -89,7 +93,7 @@ private:
     {
     public:
         Instance(wl_resource* new_resource, WlCompositor* compositor)
-            : mw::Compositor{new_resource, Version<4>()},
+            : mw::Compositor{new_resource, Version<6>()},
               compositor{compositor}
         {
         }
@@ -236,7 +240,7 @@ mf::WaylandConnector::WaylandConnector(
     std::shared_ptr<ms::Clipboard> const& primary_selection_clipboard,
     std::shared_ptr<ms::TextInputHub> const& text_input_hub,
     std::shared_ptr<ms::IdleHub> const& idle_hub,
-    std::shared_ptr<mc::ScreenShooter> const& screen_shooter,
+    std::shared_ptr<mc::ScreenShooterFactory> const& screen_shooter_factory,
     std::shared_ptr<MainLoop> const& main_loop,
     bool arw_socket,
     std::unique_ptr<WaylandExtensions> extensions_,
@@ -245,7 +249,8 @@ mf::WaylandConnector::WaylandConnector(
     std::shared_ptr<scene::SessionLock> const& session_lock,
     std::shared_ptr<mir::DecorationStrategy> const& decoration_strategy,
     std::shared_ptr<scene::SessionCoordinator> const& session_coordinator,
-    std::shared_ptr<shell::TokenAuthority> const& token_authority)
+    std::shared_ptr<shell::TokenAuthority> const& token_authority,
+    std::vector<std::shared_ptr<mg::RenderingPlatform>> const& render_platforms)
     : extension_filter{extension_filter},
       display{wl_display_create(), &cleanup_display},
       pause_signal{eventfd(0, EFD_CLOEXEC | EFD_SEMAPHORE)},
@@ -290,6 +295,7 @@ mf::WaylandConnector::WaylandConnector(
         std::make_shared<FrameExecutor>(*main_loop),
         this->allocator);
     subcompositor_global = std::make_unique<mf::WlSubcompositor>(display.get());
+    auto const surface_registry = std::make_shared<mf::SurfaceRegistry>();
     seat_global = std::make_unique<mf::WlSeat>(
         display.get(),
         *executor,
@@ -297,7 +303,8 @@ mf::WaylandConnector::WaylandConnector(
         input_hub,
         keyboard_observer_registrar,
         seat,
-        accessibility_manager);
+        accessibility_manager,
+        surface_registry);
     output_manager = std::make_unique<mf::OutputManager>(
         display.get(),
         executor,
@@ -328,19 +335,36 @@ mf::WaylandConnector::WaylandConnector(
         input_device_registry,
         composite_event_filter,
         allocator,
-        screen_shooter,
+        screen_shooter_factory,
         main_loop,
         desktop_file_manager,
         session_lock_,
         decoration_strategy,
         session_coordinator,
         keyboard_observer_registrar,
-        token_authority});
+        token_authority,
+        surface_registry});
 
     shm_global = std::make_unique<WlShm>(display.get(), executor);
 
     viewporter = std::make_unique<WpViewporter>(display.get());
 
+    {
+        std::vector<std::shared_ptr<mg::DRMRenderingProvider>> providers;
+        for (auto platform : render_platforms)
+        {
+            if (auto provider = mg::RenderingPlatform::acquire_provider<mg::DRMRenderingProvider>(platform))
+            {
+                providers.push_back(std::move(provider));
+            }
+        }
+        if (!providers.empty())
+        {
+            mir::log_debug("Detected DRM Syncobj capable rendering platform. Enabling linux_drm_syncobj_v1 explicit sync support.");
+            drm_syncobj = std::make_unique<LinuxDRMSyncobjManager>(display.get(), providers);
+        }
+    }
+
     char const* wayland_display = nullptr;
 
     if (auto const display_name = getenv("WAYLAND_DISPLAY"))
@@ -392,27 +416,45 @@ mf::WaylandConnector::WaylandConnector(
     pause_source = wl_event_loop_add_fd(wayland_loop, pause_signal, WL_EVENT_READABLE, &halt_eventloop, display.get());
 }
 
+namespace
+{
+void unbind_display(mg::GraphicBufferAllocator& allocator, wl_display* display) noexcept
+try
+{
+    allocator.unbind_display(display);
+}
+catch (...)
+{
+    mir::log(
+        mir::logging::Severity::warning,
+        MIR_LOG_COMPONENT,
+        std::current_exception(),
+        "Failed to unbind EGL display");
+}
+}
+
 mf::WaylandConnector::~WaylandConnector()
 {
     wl_display_destroy_clients(display.get());
 
-    try
-    {
-        allocator->unbind_display(display.get());
-    }
-    catch (...)
-    {
-        log(
-            logging::Severity::warning,
-            MIR_LOG_COMPONENT,
-            std::current_exception(),
-            "Failed to unbind EGL display");
-    }
-
     if (dispatch_thread.joinable())
     {
+        auto cleanup_promise = std::make_shared<std::promise<void>>();
+        auto cleanup_done = cleanup_promise->get_future();
+        executor->spawn(
+            [cleanup_promise, this]()
+            {
+                unbind_display(*allocator, display.get());
+                cleanup_promise->set_value();
+            });
+        cleanup_done.get();
+
         stop();
     }
+    else
+    {
+        unbind_display(*allocator, display.get());
+    }
     wl_event_source_remove(pause_source);
 }
 
@@ -431,10 +473,7 @@ void mf::WaylandConnector::stop()
 {
     if (eventfd_write(pause_signal, 1) < 0)
     {
-        BOOST_THROW_EXCEPTION((std::system_error{
-            errno,
-            std::system_category(),
-            "Failed to send IPC eventloop pause signal"}));
+        log_error("WaylandConnector::stop() failed to send IPC eventloop pause signal: %s (%i)", strerror(errno), errno);
     }
     if (dispatch_thread.joinable())
     {
@@ -538,6 +577,17 @@ auto mf::WaylandConnector::get_extension(std::string const& name) const -> std::
     return extensions->get_extension(name);
 }
 
+void mf::WaylandConnector::for_each_output_binding(
+    wayland::Client* client,
+    graphics::DisplayConfigurationOutputId output,
+    std::function<void(wl_resource* output)> const& callback)
+{
+    if (auto const& og = output_manager->output_for(output))
+    {
+        (*og)->for_each_output_bound_by(client, [&](OutputInstance* o) { callback(o->resource); });
+    }
+}
+
 bool mf::WaylandConnector::wl_display_global_filter_func_thunk(wl_client const* client, wl_global const* global, void *data)
 {
     return static_cast<WaylandConnector*>(data)->wl_display_global_filter_func(client, global);
