@@ -17,13 +17,14 @@
 #ifndef MIR_FRONTEND_WAYLAND_CONNECTOR_H_
 #define MIR_FRONTEND_WAYLAND_CONNECTOR_H_
 
-#include "mir/shell/token_authority.h"
+#include <mir/shell/token_authority.h>
 #include "wayland_wrapper.h"
 
-#include "mir/fd.h"
-#include "mir/frontend/connector.h"
-#include "mir/frontend/drag_icon_controller.h"
-#include "mir/optional_value.h"
+#include <mir/fd.h>
+#include <mir/frontend/connector.h>
+#include <mir/frontend/drag_icon_controller.h>
+#include <mir/frontend/wayland.h>
+#include <mir/optional_value.h>
 
 #include <wayland-server-core.h>
 #include <unordered_map>
@@ -41,7 +42,7 @@ class DecorationStrategy;
 
 namespace compositor
 {
-class ScreenShooter;
+class ScreenShooterFactory;
 }
 
 namespace input
@@ -56,6 +57,7 @@ namespace graphics
 {
 class GraphicBufferAllocator;
 class DisplayConfigurationObserver;
+class RenderingPlatform;
 }
 namespace shell
 {
@@ -89,7 +91,9 @@ class WlShm;
 class WlSubcompositor;
 class WlSurface;
 class WpViewporter;
+class LinuxDRMSyncobjManager;
 class DesktopFileManager;
+class SurfaceRegistry;
 
 class WaylandExtensions
 {
@@ -111,7 +115,7 @@ public:
         std::shared_ptr<input::InputDeviceRegistry> input_device_registry;
         std::shared_ptr<input::CompositeEventFilter> composite_event_filter;
         std::shared_ptr<graphics::GraphicBufferAllocator> graphic_buffer_allocator;
-        std::shared_ptr<compositor::ScreenShooter> screen_shooter;
+        std::shared_ptr<compositor::ScreenShooterFactory> screen_shooter_factory;
         std::shared_ptr<MainLoop> main_loop;
         std::shared_ptr<DesktopFileManager> desktop_file_manager;
         std::shared_ptr<scene::SessionLock> session_lock;
@@ -119,6 +123,7 @@ public:
         std::shared_ptr<scene::SessionCoordinator> session_coordinator;
         std::shared_ptr<ObserverRegistrar<input::KeyboardObserver>> keyboard_observer_registrar;
         std::shared_ptr<shell::TokenAuthority> token_authority;
+        std::shared_ptr<SurfaceRegistry> surface_registry;
     };
 
     WaylandExtensions() = default;
@@ -141,7 +146,7 @@ private:
     std::unordered_map<std::string, std::shared_ptr<void>> extension_protocols;
 };
 
-class WaylandConnector : public Connector
+class WaylandConnector : public Connector, public WaylandTools
 {
 public:
     using WaylandProtocolExtensionFilter = std::function<bool(std::shared_ptr<scene::Session> const&, char const*)>;
@@ -164,7 +169,7 @@ public:
         std::shared_ptr<scene::Clipboard> const& primary_selection_clipboard,
         std::shared_ptr<scene::TextInputHub> const& text_input_hub,
         std::shared_ptr<scene::IdleHub> const& idle_hub,
-        std::shared_ptr<compositor::ScreenShooter> const& screen_shooter,
+        std::shared_ptr<compositor::ScreenShooterFactory> const& screen_shooter_factory,
         std::shared_ptr<MainLoop> const& main_loop,
         bool arw_socket,
         std::unique_ptr<WaylandExtensions> extensions,
@@ -173,7 +178,8 @@ public:
         std::shared_ptr<scene::SessionLock> const& session_lock,
         std::shared_ptr<DecorationStrategy> const& decoration_strategy,
         std::shared_ptr<scene::SessionCoordinator> const& session_coordinator,
-        std::shared_ptr<shell::TokenAuthority> const& token_authority);
+        std::shared_ptr<shell::TokenAuthority> const& token_authority,
+        std::vector<std::shared_ptr<graphics::RenderingPlatform>> const& render_platforms);
 
     ~WaylandConnector() override;
 
@@ -196,6 +202,11 @@ public:
     auto get_extension(std::string const& name) const -> std::shared_ptr<void>;
 
 private:
+    void for_each_output_binding(
+        wayland::Client* client,
+        graphics::DisplayConfigurationOutputId output,
+        std::function<void(wl_resource* output)> const& callback) override;
+
     bool wl_display_global_filter_func(wl_client const* client, wl_global const* global) const;
     static bool wl_display_global_filter_func_thunk(wl_client const* client, wl_global const* global, void* data);
 
@@ -220,6 +231,7 @@ private:
     std::unique_ptr<WlDataDeviceManager> data_device_manager_global;
     std::unique_ptr<WlShm> shm_global;
     std::unique_ptr<WpViewporter> viewporter;
+    std::unique_ptr<LinuxDRMSyncobjManager> drm_syncobj;
     std::shared_ptr<Executor> const executor;
     std::shared_ptr<graphics::GraphicBufferAllocator> const allocator;
     std::shared_ptr<shell::Shell> const shell;
