@@ -14,22 +14,26 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <ranges>
+
 #include "fractional-scale-v1_wrapper.h"
 #include "fractional_scale_v1.h"
-#include "mir/default_server_configuration.h"
+#include <mir/default_server_configuration.h>
 
-#include "mir/frontend/wayland.h"
-#include "mir/graphics/platform.h"
-#include "mir/log.h"
-#include "mir/options/default_configuration.h"
-#include "mir/scene/session.h"
+#include <mir/frontend/wayland.h>
+#include <mir/graphics/platform.h>
+#include <mir/log.h>
+#include <mir/options/default_configuration.h>
+#include <mir/scene/session.h>
 
+#include "ext_image_capture_v1.h"
 #include "foreign_toplevel_manager_v1.h"
+#include "foreign_toplevel_list_v1.h"
 #include "idle_inhibit_v1.h"
 #include "input_method_v1.h"
 #include "input_method_v2.h"
 #include "layer_shell_v1.h"
-#include "mir/shell/accessibility_manager.h"
+#include <mir/shell/accessibility_manager.h>
 #include "mir_shell.h"
 #include "pointer_constraints_unstable_v1.h"
 #include "primary_selection_v1.h"
@@ -51,6 +55,7 @@
 #include "xdg_shell_stable.h"
 #include "xdg_shell_v6.h"
 #include "xwayland_wm_shell.h"
+#include "data_control_v1.h"
 
 namespace mf = mir::frontend;
 namespace ms = mir::scene;
@@ -85,7 +90,8 @@ std::vector<ExtensionBuilder> const internal_extension_builders = {
                 *ctx.wayland_executor,
                 ctx.shell,
                 ctx.seat,
-                ctx.output_manager);
+                ctx.output_manager,
+                ctx.surface_registry);
         }),
     make_extension_builder<mw::XdgShellV6>([](auto const& ctx)
         {
@@ -94,7 +100,8 @@ std::vector<ExtensionBuilder> const internal_extension_builders = {
                 *ctx.wayland_executor,
                 ctx.shell,
                 *ctx.seat,
-                ctx.output_manager);
+                ctx.output_manager,
+                ctx.surface_registry);
         }),
     make_extension_builder<mw::XdgWmBase>([](auto const& ctx)
         {
@@ -103,7 +110,8 @@ std::vector<ExtensionBuilder> const internal_extension_builders = {
                 *ctx.wayland_executor,
                 ctx.shell,
                 *ctx.seat,
-                ctx.output_manager);
+                ctx.output_manager,
+                ctx.surface_registry);
         }),
     make_extension_builder<mw::LayerShellV1>([](auto const& ctx)
         {
@@ -112,7 +120,8 @@ std::vector<ExtensionBuilder> const internal_extension_builders = {
                 *ctx.wayland_executor,
                 ctx.shell,
                 *ctx.seat,
-                ctx.output_manager);
+                ctx.output_manager,
+                ctx.surface_registry);
         }),
     make_extension_builder<mw::XdgOutputManagerV1>([](auto const& ctx)
         {
@@ -127,6 +136,14 @@ std::vector<ExtensionBuilder> const internal_extension_builders = {
                 ctx.surface_stack,
                 ctx.desktop_file_manager);
         }),
+    make_extension_builder<mw::ExtForeignToplevelListV1>([](auto const& ctx)
+	{
+            return create_ext_foreign_toplevel_list_v1(
+                ctx.display,
+                ctx.wayland_executor,
+                ctx.surface_stack,
+                ctx.desktop_file_manager);
+	}),
     make_extension_builder<mw::RelativePointerManagerV1>([](auto const& ctx)
         {
             return mf::create_relative_pointer_unstable_v1(ctx.display, ctx.shell);
@@ -174,7 +191,8 @@ std::vector<ExtensionBuilder> const internal_extension_builders = {
               ctx.shell,
               ctx.seat,
               ctx.output_manager,
-              ctx.text_input_hub
+              ctx.text_input_hub,
+              ctx.surface_registry
           );
       }),
     make_extension_builder<mw::InputMethodManagerV2>([](auto const& ctx)
@@ -198,7 +216,21 @@ std::vector<ExtensionBuilder> const internal_extension_builders = {
                 ctx.display,
                 ctx.wayland_executor,
                 ctx.graphic_buffer_allocator,
-                ctx.screen_shooter,
+                ctx.screen_shooter_factory,
+                ctx.surface_stack);
+        }),
+    make_extension_builder<mw::OutputImageCaptureSourceManagerV1>([](auto const& ctx)
+        {
+            return mf::create_ext_output_image_capture_source_manager_v1(
+                ctx.display);
+        }),
+    make_extension_builder<mw::ImageCopyCaptureManagerV1>([](auto const& ctx)
+        {
+            return mf::create_ext_image_copy_capture_manager_v1(
+                ctx.display,
+                ctx.wayland_executor,
+                ctx.graphic_buffer_allocator,
+                ctx.screen_shooter_factory,
                 ctx.surface_stack);
         }),
     make_extension_builder<mw::PrimarySelectionDeviceManagerV1>([](auto const& ctx)
@@ -214,7 +246,8 @@ std::vector<ExtensionBuilder> const internal_extension_builders = {
                 ctx.session_lock,
                 *ctx.seat,
                 ctx.output_manager,
-                ctx.surface_stack);
+                ctx.surface_stack,
+                ctx.surface_registry);
         }),
     make_extension_builder<mw::MirShellV1>([](auto const& ctx)
         {
@@ -239,6 +272,13 @@ std::vector<ExtensionBuilder> const internal_extension_builders = {
                 *ctx.wayland_executor,
                 ctx.token_authority);
         }),
+    make_extension_builder<mw::DataControlManagerV1>([](auto const& ctx)
+        {
+            return mf::create_data_control_manager_v1(
+                    ctx.display,
+                    ctx.main_clipboard,
+                    ctx.primary_selection_clipboard);
+        }),
 };
 
 ExtensionBuilder const xwayland_builder {
@@ -250,7 +290,8 @@ ExtensionBuilder const xwayland_builder {
                 ctx.session_authorizer,
                 ctx.main_clipboard,
                 *ctx.seat,
-                ctx.surface_stack);
+                ctx.surface_stack,
+                ctx.surface_registry);
         }
 };
 
@@ -363,9 +404,8 @@ std::shared_ptr<mf::Connector>
             auto options = the_options();
             bool const arw_socket = options->is_set(options::arw_server_socket_opt);
 
-            auto wayland_extensions = std::set<std::string>{
-                enabled_wayland_extensions.begin(),
-                enabled_wayland_extensions.end()};
+            auto const extension_keys = wayland_extension_policy_map | std::views::keys;
+            std::set<std::string> const wayland_extensions(std::ranges::begin(extension_keys), std::ranges::end(extension_keys));
 
             auto const x11_enabled = options->is_set(mo::x11_display_opt) && options->get<bool>(mo::x11_display_opt);
 
@@ -387,7 +427,7 @@ std::shared_ptr<mf::Connector>
                 the_primary_selection_clipboard(),
                 the_text_input_hub(),
                 the_idle_hub(),
-                the_screen_shooter(),
+                the_screen_shooter_factory(),
                 the_main_loop(),
                 arw_socket,
                 configure_wayland_extensions(
@@ -399,7 +439,8 @@ std::shared_ptr<mf::Connector>
                 the_session_lock(),
                 the_decoration_strategy(),
                 the_session_coordinator(),
-                the_token_authority());
+                the_token_authority(),
+                the_rendering_platforms());
         });
 }
 
@@ -412,14 +453,11 @@ void mir::DefaultServerConfiguration::add_wayland_extension(
     wayland_extension_hooks.push_back({name, builder});
 }
 
-void mir::DefaultServerConfiguration::set_wayland_extension_filter(WaylandProtocolExtensionFilter const& extension_filter)
+void mir::DefaultServerConfiguration::set_wayland_extension_policy(
+    std::string const& interface_name,
+    WaylandProtocolExtensionFilter const& policy)
 {
-    wayland_extension_filter = extension_filter;
-}
-
-void mir::DefaultServerConfiguration::set_enabled_wayland_extensions(std::vector<std::string> const& extensions)
-{
-    enabled_wayland_extensions = extensions;
+    wayland_extension_policy_map[interface_name] = policy;
 }
 
 auto mir::frontend::get_window(wl_resource* surface) -> std::shared_ptr<ms::Surface>
