@@ -1,5 +1,5 @@
 /*
- * Copyright © 2018 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3,
@@ -17,8 +17,8 @@
 #ifndef MIR_FRONTEND_EXECUTOR_H
 #define MIR_FRONTEND_EXECUTOR_H
 
-#include "mir/executor.h"
-#include "mir/fd.h"
+#include <mir/executor.h>
+#include <mir/fd.h>
 
 #include <wayland-server-core.h>
 
