@@ -1,5 +1,5 @@
 /*
- * Copyright © 2022 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3,
@@ -17,7 +17,7 @@
 #ifndef MIR_FRONTEND_WAYLAND_TIMESPEC_H
 #define MIR_FRONTEND_WAYLAND_TIMESPEC_H
 
-#include "mir/time/types.h"
+#include <mir/time/types.h>
 
 namespace mir
 {
