@@ -17,19 +17,18 @@
 #include "window_wl_surface_role.h"
 
 #include "output_manager.h"
+#include "surface_registry.h"
 #include "wayland_utils.h"
 #include "wl_surface.h"
 #include "wayland_surface_observer.h"
 #include "wl_seat.h"
-#include "null_event_sink.h"
-
-#include "mir/frontend/wayland.h"
-#include "mir/wayland/client.h"
-#include "mir/shell/surface_specification.h"
-#include "mir/shell/shell.h"
-#include "mir/scene/surface.h"
-#include "mir/events/input_event.h"
-#include "mir/log.h"
+#include <mir/frontend/wayland.h>
+#include <mir/wayland/client.h>
+#include <mir/shell/surface_specification.h>
+#include <mir/shell/shell.h>
+#include <mir/scene/surface.h>
+#include <mir/events/input_event.h>
+#include <mir/log.h>
 
 #include <boost/throw_exception.hpp>
 
@@ -68,7 +67,8 @@ mf::WindowWlSurfaceRole::WindowWlSurfaceRole(
     mw::Client* client,
     WlSurface* surface,
     std::shared_ptr<msh::Shell> const& shell,
-    OutputManager* output_manager)
+    OutputManager* output_manager,
+    std::shared_ptr<SurfaceRegistry> const& surface_registry)
     : surface{surface},
       client{client},
       shell{shell},
@@ -77,7 +77,8 @@ mf::WindowWlSurfaceRole::WindowWlSurfaceRole(
       wayland_executor{wayland_executor},
       observer{std::make_shared<WaylandSurfaceObserver>(wayland_executor, seat, surface, this)},
       committed_min_size{0, 0},
-      committed_max_size{max_possible_size}
+      committed_max_size{max_possible_size},
+      surface_registry{surface_registry}
 {
     spec().type = mir_window_type_freestyle;
     surface->set_role(this);
@@ -104,6 +105,7 @@ mf::WindowWlSurfaceRole::~WindowWlSurfaceRole()
     if (auto const scene_surface = weak_scene_surface.lock())
     {
         shell->destroy_surface(session, scene_surface);
+        surface_registry->remove_surface(scene_surface);
         weak_scene_surface.reset();
     }
 }
@@ -366,6 +368,13 @@ void mf::WindowWlSurfaceRole::commit(WlSurfaceState const& state)
 
         if (pending_changes)
         {
+            // TODO: The whole size handling needs to be straightened out
+            if (!pending_explicit_width && !pending_explicit_height)
+            {
+                auto content_size = scene_surface->content_size();
+                clear_pending_if_unchanged(pending_changes->width, content_size.width);
+                clear_pending_if_unchanged(pending_changes->height, content_size.height);
+            }
             clear_pending_if_unchanged(pending_changes->min_width,  committed_min_size.width);
             clear_pending_if_unchanged(pending_changes->min_height, committed_min_size.height);
             clear_pending_if_unchanged(pending_changes->max_width,  committed_max_size.width);
@@ -447,6 +456,8 @@ auto mf::WindowWlSurfaceRole::output_config_changed(graphics::DisplayConfigurati
 {
     if (surface)
     {
+        auto const prev_scale = max_output_scale();
+
         if (auto id_it{std::ranges::find(pending_enter_events, config.id)}; id_it != pending_enter_events.end())
         {
             if (auto* global{output_manager->output_for(config.id).value_or(nullptr)})
@@ -459,6 +470,7 @@ auto mf::WindowWlSurfaceRole::output_config_changed(graphics::DisplayConfigurati
                             fractional_scale.value().output_entered(config);
                         surface.value().send_enter_event(instance->resource);
                         pending_enter_events.erase(id_it);
+                        output_scales[config.id] = std::ceil(config.scale);
                     });
             }
         }
@@ -468,6 +480,14 @@ auto mf::WindowWlSurfaceRole::output_config_changed(graphics::DisplayConfigurati
             if (auto const fractional_scale = surface.value().get_fractional_scale())
                 fractional_scale.value().scale_change_on_output(config);
             pending_rescale_events.erase(id_it);
+            output_scales[config.id] = std::ceil(config.scale);
+        }
+
+        auto const max_scale = max_output_scale();
+
+        if (prev_scale != max_scale)
+        {
+            surface.value().send_preferred_buffer_scale_event_if_supported(max_scale);
         }
     }
 
@@ -482,6 +502,18 @@ mir::shell::SurfaceSpecification& mf::WindowWlSurfaceRole::spec()
     return *pending_changes;
 }
 
+auto mir::frontend::WindowWlSurfaceRole::max_output_scale() const -> int
+{
+    int current_max = 1;
+    for (auto const& [_, scale] : output_scales)
+    {
+        if (scale > current_max)
+            current_max = scale;
+    }
+
+    return current_max;
+}
+
 void mf::WindowWlSurfaceRole::create_scene_surface()
 {
     if (weak_scene_surface.lock() || !surface)
@@ -495,7 +527,8 @@ void mf::WindowWlSurfaceRole::create_scene_surface()
     mods.input_shape = std::vector<geom::Rectangle>{};
     surface.value().populate_surface_data(mods.streams.value(), mods.input_shape.value(), {});
 
-    auto const scene_surface = shell->create_surface(session, surface, mods, observer, &wayland_executor);
+    auto const scene_surface = shell->create_surface(session, mods, observer, &wayland_executor);
+    surface_registry->add_surface(scene_surface, surface);
     weak_scene_surface = scene_surface;
 
     if (mods.min_width)  committed_min_size.width  = mods.min_width.value();
@@ -522,11 +555,14 @@ void mf::WindowWlSurfaceRole::handle_enter_output(graphics::DisplayConfiguration
     bool event_sent{};
     if (surface)
     {
+        auto const prev_scale = max_output_scale();
+
         if (auto* global{output_manager->output_for(id).value_or(nullptr)})
         {
             auto const& config{global->current_config()};
             if (config.id == id)
             {
+                output_scales[config.id] = std::ceil(config.scale);
                 if (auto const fractional_scale = surface.value().get_fractional_scale())
                     fractional_scale.value().output_entered(config);
 
@@ -539,6 +575,13 @@ void mf::WindowWlSurfaceRole::handle_enter_output(graphics::DisplayConfiguration
                     });
             }
         }
+
+        auto const max_scale = max_output_scale();
+
+        if (prev_scale != max_scale)
+        {
+            surface.value().send_preferred_buffer_scale_event_if_supported(max_scale);
+        }
     }
     if (!event_sent)
     {
