@@ -20,12 +20,13 @@
 #include "output_manager.h"
 #include "wl_surface_role.h"
 
-#include "mir/wayland/weak.h"
-#include "mir/wayland/lifetime_tracker.h"
-#include "mir/geometry/displacement.h"
-#include "mir/geometry/size.h"
-#include "mir/geometry/rectangle.h"
-#include "mir/graphics/display_configuration.h"
+#include <mir/flags.h>
+#include <mir/wayland/weak.h>
+#include <mir/wayland/lifetime_tracker.h>
+#include <mir/geometry/displacement.h>
+#include <mir/geometry/size.h>
+#include <mir/geometry/rectangle.h>
+#include <mir/graphics/display_configuration.h>
 
 #include <mir_toolkit/common.h>
 
@@ -58,10 +59,10 @@ namespace frontend
 class WaylandSurfaceObserver;
 class WlSurface;
 class WlSeat;
+class SurfaceRegistry;
 
 class WindowWlSurfaceRole
     : public WlSurfaceRole,
-      public virtual wayland::LifetimeTracker,
       public OutputManagerListener,
       public OutputConfigListener
 {
@@ -72,7 +73,8 @@ public:
         wayland::Client* client,
         WlSurface* surface,
         std::shared_ptr<shell::Shell> const& shell,
-        OutputManager* output_manager);
+        OutputManager* output_manager,
+        std::shared_ptr<SurfaceRegistry> const& surface_registry);
 
     ~WindowWlSurfaceRole() override;
 
@@ -114,6 +116,7 @@ public:
         std::optional<geometry::Point> const& new_top_left,
         geometry::Size const& new_size) = 0;
     virtual void handle_close_request() = 0;
+    virtual void handle_tiled_edges(Flags<MirTiledEdge> tiled_edges) = 0;
 
 protected:
     /// The size the window will be after the next commit
@@ -169,6 +172,8 @@ private:
 
     shell::SurfaceSpecification& spec();
 
+    std::map<graphics::DisplayConfigurationOutputId, int> output_scales;
+    auto max_output_scale() const -> int;
     // Ask the derived class to destroy the wayland role object (as only it can do that)
     virtual void destroy_role() const = 0;
 
@@ -176,6 +181,7 @@ private:
 
     std::vector<graphics::DisplayConfigurationOutputId> pending_enter_events;
     std::vector<graphics::DisplayConfigurationOutputId> pending_rescale_events;
+    std::shared_ptr<SurfaceRegistry> const surface_registry;
 };
 
 }
