@@ -1,5 +1,5 @@
 /*
- * Copyright © 2021 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3,
@@ -17,12 +17,11 @@
 #include "wl_client.h"
 #include "std_layout_uptr.h"
 
-#include "null_event_sink.h"
-#include "mir/frontend/session_authorizer.h"
-#include "mir/frontend/session_credentials.h"
-#include "mir/shell/shell.h"
-#include "mir/scene/session.h"
-#include "mir/fatal.h"
+#include <mir/frontend/session_authorizer.h>
+#include <mir/frontend/session_credentials.h>
+#include <mir/shell/shell.h>
+#include <mir/scene/session.h>
+#include <mir/fatal.h>
 
 #include <wayland-server-core.h>
 
@@ -152,8 +151,7 @@ void mf::WlClient::handle_client_created(wl_listener* listener, void* data)
     auto session = construction_context->shell->open_session(
         client_pid,
         Fd{IntOwnedFd{wl_client_get_fd(client)}},
-        "",
-        std::make_shared<mf::NullEventSink>());
+        "");
 
     // Can't use std::make_shared because WlClient constructor is private
     auto shared = std::shared_ptr<mf::WlClient>{
@@ -164,7 +162,7 @@ void mf::WlClient::handle_client_created(wl_listener* listener, void* data)
     client_context->destroy_listener.notify = &handle_client_destroyed;
     wl_client_add_destroy_listener(client, &client_context->destroy_listener);
 
-    client_context->client->owned_self = move(shared);
+    client_context->client->owned_self = std::move(shared);
 
     (*construction_context->client_created_callback)(*client_context->client);
 }
