@@ -21,18 +21,18 @@
 #include "wl_seat.h"
 #include "relative-pointer-unstable-v1_wrapper.h"
 
-#include "mir/log.h"
-#include "mir/executor.h"
-#include "mir/frontend/wayland.h"
-#include "mir/scene/surface.h"
-#include "mir/frontend/buffer_stream.h"
-#include "mir/geometry/displacement.h"
-#include "mir/graphics/cursor_image.h"
-#include "mir/graphics/buffer.h"
-#include "mir/renderer/sw/pixel_source.h"
-#include "mir/compositor/buffer_stream.h"
-#include "mir/events/pointer_event.h"
-#include "mir/wayland/client.h"
+#include <mir/log.h>
+#include <mir/executor.h>
+#include <mir/frontend/wayland.h>
+#include <mir/scene/surface.h>
+#include <mir/frontend/buffer_stream.h>
+#include <mir/geometry/displacement.h>
+#include <mir/graphics/cursor_image.h>
+#include <mir/graphics/buffer.h>
+#include <mir/renderer/sw/pixel_source.h>
+#include <mir/compositor/buffer_stream.h>
+#include <mir/events/pointer_event.h>
+#include <mir/wayland/client.h>
 
 #include <linux/input-event-codes.h>
 #include <boost/throw_exception.hpp>
@@ -52,7 +52,7 @@ class BufferCursorImage : public mg::CursorImage
 {
 public:
     BufferCursorImage(std::shared_ptr<mg::Buffer> buffer, geom::Displacement const& hotspot)
-        : BufferCursorImage(buffer_to_mapping_if_possible(buffer), hotspot)
+        : BufferCursorImage(buffer->map_readable(), hotspot)
     {
     }
 
@@ -72,29 +72,16 @@ public:
     }
 
 private:
-    BufferCursorImage(std::unique_ptr<mrs::Mapping<unsigned char const>> mapping, geom::Displacement const& hotspot)
+    BufferCursorImage(std::unique_ptr<mrs::Mapping<std::byte const>> mapping, geom::Displacement const& hotspot)
         : size_{mapping->size()},
-          data{std::make_unique<unsigned char[]>(mapping->len())},
+          data{std::make_unique<std::byte[]>(mapping->len())},
           hotspot_{hotspot}
     {
         ::memcpy(data.get(), mapping->data(), mapping->len());
     }
 
-    static auto buffer_to_mapping_if_possible(std::shared_ptr<mg::Buffer> const& buffer)
-        -> std::unique_ptr<mrs::Mapping<unsigned char const>>
-    {
-        auto const mappable_buffer = mrs::as_read_mappable_buffer(buffer);
-        if (!mappable_buffer)
-        {
-            BOOST_THROW_EXCEPTION(
-                std::runtime_error{
-                    "Attempt to create cursor from non-CPU-readable buffer. Rendering will be incomplete"});
-        }
-        return mappable_buffer->map_readable();
-    }
-
     geom::Size const size_;
-    std::unique_ptr<unsigned char[]> const data;
+    std::unique_ptr<std::byte[]> const data;
     geom::Displacement const hotspot_;
 };
 
@@ -175,7 +162,7 @@ auto mf::WlPointer::linux_button_to_mir_button(int linux_button) -> std::optiona
 }
 
 mf::WlPointer::WlPointer(wl_resource* new_resource)
-    : Pointer(new_resource, Version<8>()),
+    : Pointer(new_resource, Version<9>()),
       cursor{std::make_unique<NullCursor>()}
 {
 }
