@@ -14,6 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "surface_registry.h"
 #include "wayland_wrapper.h"
 
 #include "wl_seat.h"
@@ -25,18 +26,18 @@
 #include "wl_touch.h"
 #include "wl_data_device.h"
 
-#include "mir/executor.h"
-#include "mir/wayland/client.h"
-#include "mir/observer_registrar.h"
-#include "mir/input/input_device_observer.h"
-#include "mir/input/input_device_hub.h"
-#include "mir/input/device.h"
-#include "mir/input/parameter_keymap.h"
-#include "mir/input/mir_keyboard_config.h"
-#include "mir/input/keyboard_observer.h"
-#include "mir/scene/surface.h"
-#include "mir/shell/accessibility_manager.h"
-#include "mir_toolkit/events/input/pointer_event.h"
+#include <mir/executor.h>
+#include <mir/wayland/client.h>
+#include <mir/observer_registrar.h>
+#include <mir/input/input_device_observer.h>
+#include <mir/input/input_device_hub.h>
+#include <mir/input/device.h>
+#include <mir/input/parameter_keymap.h>
+#include <mir/input/mir_keyboard_config.h>
+#include <mir/input/keyboard_observer.h>
+#include <mir/scene/surface.h>
+#include <mir/shell/accessibility_manager.h>
+#include <mir_toolkit/events/input/pointer_event.h>
 
 #include <mutex>
 #include <algorithm>
@@ -143,8 +144,9 @@ class mf::WlSeat::KeyboardObserver
     : public input::KeyboardObserver
 {
 public:
-    KeyboardObserver(WlSeat& seat)
-        : seat{seat}
+    KeyboardObserver(WlSeat& seat, std::shared_ptr<mf::SurfaceRegistry> const surface_registry) :
+        seat{seat},
+        surface_registry{surface_registry}
     {
     }
 
@@ -161,9 +163,9 @@ public:
 
     void keyboard_focus_set(std::shared_ptr<mi::Surface> const& surface) override
     {
-        if (auto const scene_surface = dynamic_cast<ms::Surface*>(surface.get()))
+        if (auto const wayland_surface = surface_registry->lookup_wayland_surface(surface))
         {
-            seat.set_focus_to(mw::as_nullable_ptr(scene_surface->wayland_surface()));
+            seat.set_focus_to(mw::as_nullable_ptr(*wayland_surface));
         }
         else
         {
@@ -173,6 +175,7 @@ public:
 
 private:
     WlSeat& seat;
+    std::shared_ptr<mf::SurfaceRegistry> const surface_registry;
 };
 
 class mf::WlSeat::Instance : public wayland::Seat
@@ -195,8 +198,9 @@ mf::WlSeat::WlSeat(
     std::shared_ptr<mi::InputDeviceHub> const& input_hub,
     std::shared_ptr<ObserverRegistrar<input::KeyboardObserver>> const& keyboard_observer_registrar,
     std::shared_ptr<mi::Seat> const& seat,
-    std::shared_ptr<shell::AccessibilityManager> const& accessibility_manager)
-    :   Global(display, Version<8>()),
+    std::shared_ptr<shell::AccessibilityManager> const& accessibility_manager,
+    std::shared_ptr<mf::SurfaceRegistry> const& surface_registry)
+    :   Global(display, Version<9>()),
         keymap{std::make_shared<input::ParameterKeymap>()},
         config_observer{
             std::make_shared<ConfigObserver>(
@@ -206,7 +210,7 @@ mf::WlSeat::WlSeat(
                     keymap = new_keymap;
                 })},
         keyboard_observer_registrar{keyboard_observer_registrar},
-        keyboard_observer{std::make_shared<KeyboardObserver>(*this)},
+        keyboard_observer{std::make_shared<KeyboardObserver>(*this, surface_registry)},
         focus_listeners{std::make_shared<ListenerList<FocusListener>>()},
         pointer_listeners{std::make_shared<ListenerList<PointerEventDispatcher>>()},
         keyboard_listeners{std::make_shared<ListenerList<WlKeyboard>>()},
@@ -311,7 +315,7 @@ void mf::WlSeat::set_focus_to(WlSurface* new_surface)
 }
 
 mf::WlSeat::Instance::Instance(wl_resource* new_resource, mf::WlSeat* seat)
-    : mw::Seat(new_resource, Version<8>()),
+    : mw::Seat(new_resource, Version<9>()),
       seat{seat}
 {
     // TODO: Read the actual capabilities. Do we have a keyboard? Mouse? Touch?
