@@ -36,13 +36,15 @@ namespace frontend
 {
 class WlSeat;
 class OutputManager;
+class SurfaceRegistry;
 
 auto create_wl_shell(
     wl_display* display,
     Executor& wayland_executor,
     std::shared_ptr<shell::Shell> const& shell,
     WlSeat* seat,
-    OutputManager* const output_manager) -> std::shared_ptr<wayland::Shell::Global>;
+    OutputManager* const output_manager,
+    std::shared_ptr<SurfaceRegistry> const& surface_registry) -> std::shared_ptr<wayland::Shell::Global>;
 
 auto get_wl_shell_window(wl_resource* surface) -> std::shared_ptr<scene::Surface>;
 }
