@@ -15,39 +15,44 @@
  */
 
 #include "wl_surface.h"
-
+#include "output_manager.h"
 #include "fractional_scale_v1.h"
-#include "mir/wayland/weak.h"
+#include <mir/wayland/weak.h>
 #include "viewporter_wrapper.h"
+#include "wayland_connector.h"
 #include "wayland_utils.h"
 #include "wl_surface_role.h"
 #include "wl_subcompositor.h"
 #include "wl_region.h"
 #include "shm.h"
 #include "resource_lifetime_tracker.h"
+#include "linux_drm_syncobj.h"
 
 #include "wayland_wrapper.h"
 
 #include "wayland_frontend.tp.h"
 
-#include "mir/wayland/protocol_error.h"
-#include "mir/wayland/client.h"
-#include "mir/graphics/buffer_properties.h"
-#include "mir/scene/session.h"
-#include "mir/frontend/wayland.h"
-#include "mir/compositor/buffer_stream.h"
-#include "mir/executor.h"
-#include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/scene/surface.h"
-#include "mir/shell/surface_specification.h"
-#include "mir/log.h"
+#include <mir/wayland/protocol_error.h>
+#include <mir/wayland/client.h>
+#include <mir/graphics/buffer_properties.h>
+#include <mir/scene/session.h>
+#include <mir/frontend/wayland.h>
+#include <mir/compositor/buffer_stream.h>
+#include <mir/executor.h>
+#include <mir/graphics/graphic_buffer_allocator.h>
+#include <mir/scene/surface.h>
+#include <mir/shell/surface_specification.h>
+#include <mir/log.h>
 #include "wp_viewporter.h"
 
 #include <chrono>
+#include <ranges>
 #include <boost/throw_exception.hpp>
+#include <algorithm>
 #include <cmath>
 #include <limits>
 #include <optional>
+#include <wayland-server-core.h>
 #include <wayland-server-protocol.h>
 
 namespace mf = mir::frontend;
@@ -55,6 +60,13 @@ namespace geom = mir::geometry;
 namespace mw = mir::wayland;
 namespace msh = mir::shell;
 
+struct mf::WlSurface::PendingBufferState
+{
+    WlSurface* surf;
+    Fd eventfd;
+    mf::SyncPoint release;
+};
+
 mf::WlSurfaceState::Callback::Callback(wl_resource* new_resource)
     : mw::Callback{new_resource, Version<1>()}
 {
@@ -68,6 +80,12 @@ void mf::WlSurfaceState::update_from(WlSurfaceState const& source)
     if (source.scale)
         scale = source.scale;
 
+    if (source.orientation)
+        orientation = source.orientation;
+
+    if (source.mirror_mode)
+        mirror_mode = source.mirror_mode;
+
     if (source.offset)
         offset = source.offset;
 
@@ -83,6 +101,9 @@ void mf::WlSurfaceState::update_from(WlSurfaceState const& source)
 
     if (source.surface_data_invalidated)
         surface_data_invalidated = true;
+
+    if (source.release_fence)
+        release_fence = source.release_fence;
 }
 
 bool mf::WlSurfaceState::surface_data_needs_refresh() const
@@ -97,7 +118,7 @@ mf::WlSurface::WlSurface(
     std::shared_ptr<Executor> const& wayland_executor,
     std::shared_ptr<Executor> const& frame_callback_executor,
     std::shared_ptr<graphics::GraphicBufferAllocator> const& allocator)
-    : Surface(new_resource, Version<4>()),
+    : Surface(new_resource, Version<6>()),
         session{client->client_session()},
         stream{session->create_buffer_stream({{}, mir_pixel_format_invalid, graphics::BufferUsage::undefined})},
         allocator{allocator},
@@ -139,9 +160,9 @@ auto mf::WlSurface::subsurface_at(geom::Point point) -> std::optional<WlSurface*
     }
     point = point - offset_;
     // loop backwards so the first subsurface we find that accepts the input is the topmost one
-    for (auto child_it = children.rbegin(); child_it != children.rend(); ++child_it)
+    for (auto const& child : std::ranges::reverse_view(children))
     {
-        if (auto result = (*child_it)->subsurface_at(point))
+        if (auto result = child->subsurface_at(point))
             return result;
     }
     geom::Rectangle surface_rect = {geom::Point{}, buffer_size_.value_or(geom::Size{})};
@@ -200,12 +221,81 @@ void mf::WlSurface::add_subsurface(WlSubsurface* child)
 
 void mf::WlSurface::remove_subsurface(WlSubsurface* child)
 {
-    children.erase(
-        std::remove(
-            children.begin(),
-            children.end(),
-            child),
-        children.end());
+    auto it = std::find(children.begin(), children.end(), child);
+    if (it != children.end())
+    {
+        // Adjust parent_z_index if we're removing a child from before it
+        if (it - children.begin() < parent_z_index)
+        {
+            parent_z_index--;
+        }
+        children.erase(it);
+    }
+}
+
+bool mf::WlSurface::has_subsurface_with_surface(WlSurface* surface) const
+{
+    return std::any_of(
+        children.begin(),
+        children.end(),
+        [surface](auto const* child) { return child->get_surface() == surface; });
+}
+
+void mf::WlSurface::reorder_subsurface(WlSubsurface* child, WlSurface* sibling_surface, SubsurfacePlacement placement)
+{
+    if (!pending_surface_order)
+    {
+        std::list<WlSubsurface*> surfaces(children.begin(), children.begin()+parent_z_index);
+        surfaces.push_back(nullptr); // Special entry marking the parent position
+        surfaces.insert(surfaces.end(), children.begin()+parent_z_index, children.end());
+
+        pending_surface_order = surfaces;
+    }
+
+    // Find the child in the pending order
+    if (auto const child_pos = std::find(pending_surface_order->begin(), pending_surface_order->end(), child);
+        child_pos == pending_surface_order->end())
+    {
+        log_warning(
+            "Subsurface (wl_surface@%u) attempted to reorder but not found in parent's (wl_surface@%u) children list",
+            wl_resource_get_id(child->get_surface()->raw_resource()),
+            wl_resource_get_id(raw_resource()));
+        return;
+    }
+    else
+    {
+        pending_surface_order->erase(child_pos);
+    }
+
+    // If sibling is this surface (the parent) use nullptr to represent it
+    auto const target = (sibling_surface != this) ? sibling_surface : nullptr;
+
+    // Find which subsurface has this sibling surface
+    auto sibling_it = std::find_if(
+        pending_surface_order->begin(),
+        pending_surface_order->end(),
+        [target](auto const* s) { return s ? s->get_surface() == target : target == nullptr; });
+
+    if (sibling_it == pending_surface_order->end())
+    {
+        log_warning(
+            "Subsurface (wl_surface@%u) attempted to reorder relative to a sibling (wl_surface@%u) not found in parent's (wl_surface@%u) children list",
+            wl_resource_get_id(child->get_surface()->raw_resource()),
+            wl_resource_get_id(sibling_surface->raw_resource()),
+            wl_resource_get_id(raw_resource()));
+        return;
+    }
+
+    if (placement == SubsurfacePlacement::above)
+    {
+        // Place just above sibling (after it in the list, higher z-order)
+        pending_surface_order->insert(std::next(sibling_it), child);
+    }
+    else
+    {
+        // Place just below sibling (before it in the list, lower z-order)
+        pending_surface_order->insert(sibling_it, child);
+    }
 }
 
 void mf::WlSurface::refresh_surface_data_now()
@@ -217,7 +307,14 @@ void mf::WlSurface::populate_surface_data(std::vector<shell::StreamSpecification
                                           std::vector<geom::Rectangle>& input_shape_accumulator,
                                           geometry::Displacement const& parent_offset) const
 {
-    geometry::Displacement offset = parent_offset + offset_;
+    auto const offset = parent_offset + offset_;
+    std::span const children_below_parent{children.begin(), children.begin() + parent_z_index};
+    std::span const children_above_parent{children.begin() + parent_z_index, children.end()};
+
+    for (auto const& c : children_below_parent)
+    {
+        c->populate_surface_data(buffer_streams, input_shape_accumulator, offset);
+    }
 
     buffer_streams.push_back(msh::StreamSpecification{stream, offset});
     geom::Rectangle surface_rect = {geom::Point{} + offset, buffer_size_.value_or(geom::Size{})};
@@ -244,9 +341,9 @@ void mf::WlSurface::populate_surface_data(std::vector<shell::StreamSpecification
         input_shape_accumulator.push_back(surface_rect);
     }
 
-    for (WlSubsurface* subsurface : children)
+    for (auto const& c : children_above_parent)
     {
-        subsurface->populate_surface_data(buffer_streams, input_shape_accumulator, offset);
+        c->populate_surface_data(buffer_streams, input_shape_accumulator, offset);
     }
 }
 
@@ -307,8 +404,13 @@ void mf::WlSurface::frame(wl_resource* new_callback)
 
 void mf::WlSurface::set_opaque_region(std::optional<wl_resource*> const& region)
 {
-    (void)region;
-    // This isn't essential, but could enable optimizations
+    pending.opaque_region = region.transform([](auto*r)
+        {
+            geom::Rectangles opaque_region;
+            for (auto const& subregion : WlRegion::from(r)->rectangle_vector())
+                opaque_region.add(subregion);
+            return opaque_region;
+        });
 }
 
 void mf::WlSurface::set_input_region(std::optional<wl_resource*> const& region)
@@ -345,10 +447,24 @@ void mf::WlSurface::commit(WlSurfaceState const& state)
     bool needs_buffer_submission =
         state.scale ||                                               // If the scale has changed, or...
         state.viewport ||                                            // ...we've added a viewport, or...
+        state.orientation ||                                         // ...we've changed orientation, or...
+        state.mirror_mode ||                                         // ...we've change mirror mode, or...
         (viewport && viewport.value().changed_since_last_resolve()); // ...the viewport has changed...
                                                                      // ...then we'll need to submit a new frame, even if the client hasn't
                                                                      // attached a new buffer.
 
+    if (role)
+    {
+        if (auto const scene_surface = role->scene_surface())
+        {
+            if (state.orientation)
+                scene_surface.value()->set_orientation(state.orientation.value());
+            if (state.mirror_mode)
+                scene_surface.value()->set_mirror_mode(state.mirror_mode.value());
+            if (state.opaque_region)
+                scene_surface.value()->set_opaque_region(state.opaque_region.value());
+        }
+     }
 
     if (state.buffer)
     {
@@ -367,7 +483,18 @@ void mf::WlSurface::commit(WlSurfaceState const& state)
         }
         else
         {
-            auto release_buffer = [executor = wayland_executor, weak_buffer]()
+            std::function<void()> release_buffer;
+
+            if (state.release_fence)
+            {
+                release_buffer = [release = *state.release_fence]() mutable
+                    {
+                        release.signal();
+                    };
+            }
+            else
+            {
+                release_buffer = [executor = wayland_executor, weak_buffer]()
                 {
                     executor->spawn([weak_buffer]()
                         {
@@ -377,6 +504,8 @@ void mf::WlSurface::commit(WlSurfaceState const& state)
                             }
                         });
                 };
+            }
+
             auto executor_send_frame_callbacks = [executor = wayland_executor, weak_self = mw::make_weak(this)]()
                 {
                     executor->spawn([weak_self]()
@@ -419,6 +548,14 @@ void mf::WlSurface::commit(WlSurfaceState const& state)
     }
     else
     {
+        if (state.release_fence)
+        {
+            throw wayland::ProtocolError{
+                sync_timeline.value().resource,
+                SyncTimeline::Error::no_buffer,
+            "Timeline release sync point set, but no buffer committed"};
+        }
+
         /*
          * Frame request committed with no associated buffer.
          * The Wayland protocol says that
@@ -465,6 +602,7 @@ void mf::WlSurface::commit(WlSurfaceState const& state)
                 }
             );
         }
+
     }
 
     if (needs_buffer_submission && current_buffer)
@@ -509,28 +647,151 @@ void mf::WlSurface::commit()
     if (pending.input_shape && *pending.input_shape == input_shape)
         pending.input_shape = std::nullopt;
 
-    // order is important
-    auto const state = std::move(pending);
-    pending = WlSurfaceState();
-    role->commit(state);
-
-    if (scene_surface_created_callbacks.size())
-    {
-        if (auto const surface = scene_surface(); surface && surface.value())
+    auto const [acquire_syncpoint, release_syncpoint] = [&]() -> std::pair<std::optional<SyncPoint>, std::optional<SyncPoint>>
         {
-            for (auto const& callback : scene_surface_created_callbacks)
+            if (sync_timeline && sync_timeline.value().timeline_set())
+            {
+                auto [acquire, release] = sync_timeline.value().claim_timeline();
+                return std::make_pair(acquire, release);
+            }
+            return std::make_pair(std::nullopt, std::nullopt);
+        }();
+
+    /* Any previously committed, but not yet ready, buffer is now superceded
+     */
+    if (buffer_ready_source)
+    {
+        // We don't need to handle the buffer becoming ready anymore...
+        wl_event_source_remove(buffer_ready_source);
+        // ...and the client is now free to reuse it
+        pending_context->release.signal();
+        // Now clean up our context handling.
+        pending_context.reset();
+        buffer_ready_source = nullptr;
+    }
+
+    if (acquire_syncpoint && release_syncpoint)
+    {
+        /* If we have an acquire syncpoint then we need to wait for the buffer to be ready
+         * before we actually commit.
+         *
+         * In future we might want to push this further into the pipeline, but for now,
+         * waiting before doing any of the commit is sufficient.
+         */
+
+        if (!pending.buffer || !(*pending.buffer))
+        {
+            throw wayland::ProtocolError{
+                sync_timeline.value().resource,
+                SyncTimeline::Error::no_buffer,
+                "Timeline acquire sync point set, but no buffer committed"};
+        }
+
+        pending_context = std::make_unique<PendingBufferState>(PendingBufferState{
+            this,
+            acquire_syncpoint->to_eventfd(),
+            *release_syncpoint});
+
+        wl_event_loop_fd_func_t handle_buffer_ready =
+            [](int /*fd*/, uint32_t /*mask*/, void* data)
+            {
+                /* Because we are dispatched from the Wayland event loop we do not
+                 * need locking here; either data is valid, or we should have been
+                 * removed from the run queue.
+                 */
+                auto& state = *static_cast<PendingBufferState*>(data);
+
+                state.surf->pending.release_fence = state.release;
+
+                try
+                {
+                    complete_commit(state.surf);
+                }
+                catch (wayland::ProtocolError const& err)
+                {
+                    wl_resource_post_error(err.resource(), err.code(), "%s", err.message());
+                }
+                catch (...)
+                {
+                    wayland::internal_error_processing_request(state.surf->client->raw_client(), "Surface::commit()");
+                }
+
+                wl_event_source_remove(state.surf->buffer_ready_source);
+                state.surf->buffer_ready_source = nullptr;
+                state.surf->pending_context.reset();
+
+                return 0;
+            };
+
+        auto client = wl_resource_get_client(resource);
+        auto display = wl_client_get_display(client);
+        auto event_loop = wl_display_get_event_loop(display);
+
+        buffer_ready_source = wl_event_loop_add_fd(
+            event_loop,
+            pending_context->eventfd,
+            WL_EVENT_READABLE,
+            handle_buffer_ready,
+            pending_context.get());
+    }
+    else
+    {
+        complete_commit(this);
+    }
+}
+
+void mf::WlSurface::complete_commit(WlSurface* surf)
+{
+    // Apply pending subsurface z-order changes BEFORE role->commit()
+    // Per Wayland spec, subsurface state changes (z-order, position) are applied
+    // immediately on parent commit, even if the parent is a synchronized subsurface
+    if (surf->pending_surface_order)
+    {
+        // Convert list back to vector
+        surf->children.assign(surf->pending_surface_order->begin(), surf->pending_surface_order->end());
+
+        // Update parent_z_index and clear the parent marker
+        auto const parent_marker = std::find(surf->children.begin(), surf->children.end(), nullptr);
+        surf->parent_z_index = parent_marker - surf->children.begin();
+        surf->children.erase(parent_marker);
+
+        surf->pending_surface_order = std::nullopt;
+    }
+
+    // order is important
+    auto const state = std::move(surf->pending);
+    surf->pending = WlSurfaceState();
+    surf->role->commit(state);
+
+    if (surf->scene_surface_created_callbacks.size())
+    {
+        if (auto const surface = surf->scene_surface(); surface && surface.value())
+        {
+            for (auto const& callback : surf->scene_surface_created_callbacks)
             {
                 callback(surface.value());
             }
-            scene_surface_created_callbacks.clear();
+            surf->scene_surface_created_callbacks.clear();
         }
     }
 }
 
 void mf::WlSurface::set_buffer_transform(int32_t transform)
 {
-    (void)transform;
-    // TODO
+    try
+    {
+        auto const result = OutputManager::from_output_transform(transform);
+        pending.orientation = std::get<0>(result);
+        pending.mirror_mode = std::get<1>(result);
+    }
+    catch (std::out_of_range const&)
+    {
+        throw wayland::ProtocolError{
+            resource,
+            Error::invalid_transform,
+            "Invalid transform"};
+    }
+
 }
 
 void mf::WlSurface::set_buffer_scale(int32_t scale)
@@ -538,6 +799,14 @@ void mf::WlSurface::set_buffer_scale(int32_t scale)
     pending.scale = scale;
 }
 
+void mir::frontend::WlSurface::offset(int32_t x, int32_t y)
+{
+    if (x != 0 || y != 0)
+    {
+        mir::log_warning("Client requested unimplemented non-zero offset. Rendering will be incorrect.");
+    }
+}
+
 auto mf::WlSurface::confine_pointer_state() const -> MirPointerConfinementState
 {
     if (auto const maybe_scene_surface = scene_surface())
@@ -560,6 +829,15 @@ void mf::WlSurface::associate_viewport(wayland::Weak<Viewport> viewport)
     pending.viewport = viewport;
 }
 
+void mf::WlSurface::associate_sync_timeline(wayland::Weak<SyncTimeline> timeline)
+{
+    if (this->sync_timeline)
+    {
+        BOOST_THROW_EXCEPTION(TimelineAlreadyAssociated{});
+    }
+    sync_timeline = timeline;
+}
+
 void mir::frontend::WlSurface::update_surface_spec(shell::SurfaceSpecification const& spec)
 {
     pending.surface_spec.update_from(spec);
