@@ -18,19 +18,23 @@
 #define MIR_FRONTEND_WL_SURFACE_H
 
 #include "fractional_scale_v1.h"
-#include "mir/geometry/forward.h"
+#include <mir/geometry/forward.h>
 #include "wayland_wrapper.h"
-#include "mir/wayland/weak.h"
+#include <mir/wayland/weak.h>
 
 #include "wl_surface_role.h"
 
-#include "mir/geometry/displacement.h"
-#include "mir/geometry/size.h"
-#include "mir/geometry/point.h"
-#include "mir/geometry/rectangle.h"
-#include "mir/shell/surface_specification.h"
+#include <mir/geometry/displacement.h>
+#include <mir/geometry/size.h>
+#include <mir/geometry/point.h>
+#include <mir/geometry/rectangle.h>
+#include <mir/geometry/rectangles.h>
+#include <mir/shell/surface_specification.h>
+#include "linux_drm_syncobj.h"
 
+#include <atomic>
 #include <vector>
+#include <list>
 #include <map>
 
 namespace mir
@@ -60,6 +64,7 @@ class WlSurface;
 class WlSubsurface;
 class ResourceLifetimeTracker;
 class Viewport;
+class SyncTimeline;
 
 struct WlSurfaceState
 {
@@ -85,9 +90,14 @@ struct WlSurfaceState
     std::optional<float> scale;
     std::optional<geometry::Displacement> offset;
     std::optional<std::optional<std::vector<geometry::Rectangle>>> input_shape;
+    std::optional<geometry::Rectangles> opaque_region;
+    std::optional<MirOrientation> orientation;
+    std::optional<MirMirrorMode> mirror_mode;
     std::vector<wayland::Weak<Callback>> frame_callbacks;
     wayland::Weak<Viewport> viewport;
 
+    std::optional<SyncPoint> release_fence;
+
 private:
     // only set to true if invalidate_surface_data() is called
     // surface_data_needs_refresh() returns true if this is true, or if other things are changed which mandate a refresh
@@ -138,6 +148,10 @@ public:
     void set_pending_offset(std::optional<geometry::Displacement> const& offset);
     void add_subsurface(WlSubsurface* child);
     void remove_subsurface(WlSubsurface* child);
+    bool has_subsurface_with_surface(WlSurface* surface) const;
+    enum class SubsurfacePlacement { above, below };
+
+    void reorder_subsurface(WlSubsurface* child, WlSurface* sibling, SubsurfacePlacement placement);
     void refresh_surface_data_now();
     void pending_invalidate_surface_data() { pending.invalidate_surface_data(); }
     void populate_surface_data(std::vector<shell::StreamSpecification>& buffer_streams,
@@ -156,6 +170,26 @@ public:
      */
     void associate_viewport(wayland::Weak<Viewport> viewport);
 
+    /**
+     * Associate a DRM Syncobj timeline with this surface
+     *
+     * This associates explicit synchronisation fences with the surface's
+     * buffer submissions.
+     * See linux-drm-syncobj-v1 protocol for more details
+     *
+     * \throws A TimelineAlreadyAssociated if the surface already has a timeline associated
+     */
+    void associate_sync_timeline(wayland::Weak<SyncTimeline> timeline);
+
+    class TimelineAlreadyAssociated : public std::logic_error
+    {
+    public:
+        TimelineAlreadyAssociated()
+            : std::logic_error("Surface already has a sync timeline associated")
+        {
+        }
+    };
+
     std::shared_ptr<scene::Session> const session;
     std::shared_ptr<compositor::BufferStream> const stream;
 
@@ -169,6 +203,7 @@ private:
     NullWlSurfaceRole null_role;
     WlSurfaceRole* role;
     std::vector<WlSubsurface*> children; // ordering is from bottom to top
+    ptrdiff_t parent_z_index{0}; // index in children where parent surface renders (subsurfaces before this are below parent)
     /* We might need to resubmit the current buffer, but with different metadata
      * For example: if a client commits a wl_surface.buffer_scale() without attaching
      * a new buffer, we need to generate a new frame with the same content, but at the
@@ -179,7 +214,19 @@ private:
      */
     std::shared_ptr<graphics::Buffer> current_buffer;
 
+    /* State for when a buffer update is waiting for a client fence to signal
+     */
+    struct PendingBufferState;
+    std::unique_ptr<PendingBufferState> pending_context;
+    struct wl_event_source* buffer_ready_source{nullptr};
+
+    static void complete_commit(WlSurface* surf);
+
     WlSurfaceState pending;
+    // Subsurface z-order state (plus a nullptr representing the parent surface)
+    // This is separate from WlSurfaceState because it must be applied immediately on commit,
+    // even if the parent surface is a synchronized subsurface (per Wayland spec)
+    std::optional<std::list<WlSubsurface*>> pending_surface_order;
     geometry::Displacement offset_;
     float scale{1};
     std::optional<geometry::Size> buffer_size_;
@@ -191,6 +238,7 @@ private:
     std::vector<SceneSurfaceCreatedCallback> scene_surface_created_callbacks;
     wayland::Weak<Viewport> viewport;
     wayland::Weak<FractionalScaleV1> fractional_scale;
+    wayland::Weak<SyncTimeline> sync_timeline;
 
     void send_frame_callbacks(CallbackList& list);
 
@@ -203,6 +251,9 @@ private:
     void damage_buffer(int32_t x, int32_t y, int32_t width, int32_t height) override;
     void set_buffer_transform(int32_t transform) override;
     void set_buffer_scale(int32_t scale) override;
+    void offset(int32_t x, int32_t y) override;
+
+    std::optional<geometry::Rectangles> opaque_region_;
 };
 }
 }
