@@ -20,19 +20,19 @@
 #include "wl_surface.h"
 #include "wl_seat.h"
 
-#include "mir/executor.h"
-#include "mir_toolkit/events/event.h"
-#include "mir/events/touch_event.h"
-#include "mir/log.h"
-#include "mir/time/clock.h"
-#include "mir/wayland/client.h"
+#include <mir/executor.h>
+#include <mir_toolkit/events/event.h>
+#include <mir/events/touch_event.h>
+#include <mir/log.h>
+#include <mir/time/clock.h>
+#include <mir/wayland/client.h>
 
 namespace mf = mir::frontend;
 namespace mw = mir::wayland;
 namespace geom = mir::geometry;
 
 mf::WlTouch::WlTouch(wl_resource* new_resource, std::shared_ptr<time::Clock> const& clock)
-    : Touch(new_resource, Version<8>()),
+    : Touch(new_resource, Version<9>()),
       clock{clock}
 {
 }
