@@ -16,16 +16,18 @@
 
 #include "wlr_screencopy_v1.h"
 
-#include "mir/compositor/screen_shooter.h"
-#include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/renderer/sw/pixel_source.h"
-#include "mir/graphics/buffer.h"
-#include "mir/scene/scene_change_notification.h"
-#include "mir/frontend/surface_stack.h"
-#include "mir/geometry/rectangles.h"
-#include "mir/wayland/weak.h"
-#include "mir/wayland/protocol_error.h"
-#include "mir/executor.h"
+#include <mir/log.h>
+#include <mir/compositor/screen_shooter.h>
+#include <mir/compositor/screen_shooter_factory.h>
+#include <mir/graphics/graphic_buffer_allocator.h>
+#include <mir/renderer/sw/pixel_source.h>
+#include <mir/graphics/buffer.h>
+#include <mir/scene/scene_change_notification.h>
+#include <mir/frontend/surface_stack.h>
+#include <mir/geometry/rectangles.h>
+#include <mir/wayland/weak.h>
+#include <mir/wayland/protocol_error.h>
+#include <mir/executor.h>
 #include "wayland_wrapper.h"
 #include "wayland_timespec.h"
 #include "output_manager.h"
@@ -94,7 +96,7 @@ struct WlrScreencopyV1Ctx
 {
     std::shared_ptr<Executor> const wayland_executor;
     std::shared_ptr<graphics::GraphicBufferAllocator> const allocator;
-    std::shared_ptr<compositor::ScreenShooter> const screen_shooter;
+    std::shared_ptr<compositor::ScreenShooterFactory> const screen_shooter_factory;
     std::shared_ptr<SurfaceStack> const surface_stack;
 };
 
@@ -120,6 +122,7 @@ public:
 
     void capture_on_damage(WlrScreencopyV1DamageTracker::Frame* frame);
 
+    std::unique_ptr<compositor::ScreenShooter> const screen_shooter;
 private:
     /// From wayland::WlrScreencopyManagerV1
     /// @{
@@ -173,7 +176,7 @@ private:
     /// @{
     bool copy_has_been_called{false};
     bool should_send_damage{false};
-    std::shared_ptr<renderer::software::WriteMappableBuffer> target;
+    std::shared_ptr<renderer::software::WriteMappable> target;
     /// @}
 };
 }
@@ -183,14 +186,14 @@ auto mf::create_wlr_screencopy_manager_unstable_v1(
     wl_display* display,
     std::shared_ptr<Executor> const& wayland_executor,
     std::shared_ptr<graphics::GraphicBufferAllocator> const& allocator,
-    std::shared_ptr<compositor::ScreenShooter> const& screen_shooter,
+    std::shared_ptr<compositor::ScreenShooterFactory> const& screen_shooter_factory,
     std::shared_ptr<SurfaceStack> const& surface_stack)
 -> std::shared_ptr<wayland::WlrScreencopyManagerV1::Global>
 {
     auto ctx = std::shared_ptr<WlrScreencopyV1Ctx>{new WlrScreencopyV1Ctx{
         wayland_executor,
         allocator,
-        screen_shooter,
+        screen_shooter_factory,
         surface_stack}};
     return std::make_shared<WlrScreencopyManagerV1Global>(display, std::move(ctx));
 }
@@ -360,6 +363,7 @@ mf::WlrScreencopyManagerV1::WlrScreencopyManagerV1(
     wl_resource* resource,
     std::shared_ptr<WlrScreencopyV1Ctx> const& ctx)
     : wayland::WlrScreencopyManagerV1{resource, Version<3>()},
+      screen_shooter(ctx->screen_shooter_factory->create(thread_pool_executor)),
       ctx{ctx},
       damage_tracker{*ctx->wayland_executor, *ctx->surface_stack}
 {
@@ -375,11 +379,10 @@ void mf::WlrScreencopyManagerV1::capture_output(
     int32_t overlay_cursor,
     wl_resource* output)
 {
-    (void)overlay_cursor;
     auto const& output_config = OutputGlobal::from_or_throw(output).current_config();
     auto const output_area = output_config.extents();
     auto const buffer_size = output_config.modes[output_config.current_mode_index].size;
-    new WlrScreencopyFrameV1{frame, this, ctx, {output, output_area, buffer_size}};
+    new WlrScreencopyFrameV1{frame, this, ctx, {output, output_area, buffer_size, output_config.transformation(), overlay_cursor == 1}};
 }
 
 void mf::WlrScreencopyManagerV1::capture_output_region(
@@ -389,12 +392,11 @@ void mf::WlrScreencopyManagerV1::capture_output_region(
     int32_t x, int32_t y,
     int32_t width, int32_t height)
 {
-    (void)overlay_cursor;
     auto const& output_config = OutputGlobal::from_or_throw(output).current_config();
     auto const extents = output_config.extents();
     auto const intersection = intersection_of({{x, y}, {width, height}}, extents);
     auto const buffer_size = translate_and_scale(intersection, extents, {{}, extents.size}).size;
-    new WlrScreencopyFrameV1{frame, this, ctx, {output, intersection, buffer_size}};
+    new WlrScreencopyFrameV1{frame, this, ctx, {output, intersection, buffer_size, output_config.transformation(), overlay_cursor == 1}};
 }
 
 mf::WlrScreencopyFrameV1::WlrScreencopyFrameV1(
@@ -420,11 +422,20 @@ void mf::WlrScreencopyFrameV1::capture(geom::Rectangle buffer_space_damage)
 {
     if (!target)
     {
-        fatal_error(
-            "WlrScreencopyFrameV1::capture() called without a target, copy %s been called",
+        log_error("WlrScreencopyFrameV1::capture() called without a target, copy %s been called",
             copy_has_been_called ? "has" : "has not");
+        report_result(std::nullopt, buffer_space_damage);
+        return;
     }
-    ctx->screen_shooter->capture(std::move(target), params.output_space_area,
+
+    if (!manager)
+    {
+        log_error("WlrScreencopyFrameV1::capture() called without a manager");
+        report_result(std::nullopt, buffer_space_damage);
+        return;
+    }
+
+    manager.value().screen_shooter->capture(std::move(target), params.output_space_area, params.transform, params.overlay_cursor,
         [wayland_executor=ctx->wayland_executor, buffer_space_damage, self=mw::make_weak(this)]
             (std::optional<time::Timestamp> captured_time)
         {
@@ -486,7 +497,7 @@ void mf::WlrScreencopyFrameV1::prepare_target(wl_resource* buffer)
             stride.as_int()));
     }
 
-    target = std::shared_ptr<mir::renderer::software::WriteMappableBuffer>{
+    target = std::shared_ptr<mir::renderer::software::WriteMappable>{
         shm_data.get(),
         [shm_data, weak_buffer = mw::make_weak(shm_buffer), executor = ctx->wayland_executor](auto*)
         {
@@ -509,8 +520,8 @@ void mf::WlrScreencopyFrameV1::report_result(
 {
     if (captured_time)
     {
-        send_flags_event(Flags::y_invert);
-
+        // Note that we never send the inverted flag. The reason for this is that our
+        // renderer applies the inversion itself during set_output_transform.
         if (should_send_damage)
         {
             send_damage_event(
@@ -520,6 +531,7 @@ void mf::WlrScreencopyFrameV1::report_result(
                 buffer_space_damage.size.height.as_uint32_t());
         }
 
+        send_flags_event(0);
         WaylandTimespec const timespec{captured_time.value()};
         send_ready_event(
             timespec.tv_sec_hi,
