@@ -1,5 +1,5 @@
 /*
- * Copyright © 2022 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3,
@@ -18,16 +18,17 @@
 #define MIR_FRONTEND_WLR_SCREENCOPY_V1_H
 
 #include "wlr-screencopy-unstable-v1_wrapper.h"
-#include "mir/geometry/rectangle.h"
+#include <mir/geometry/rectangle.h>
 
 #include <memory>
+#include <glm/glm.hpp>
 
 namespace mir
 {
 class Executor;
 namespace compositor
 {
-class ScreenShooter;
+class ScreenShooterFactory;
 }
 namespace graphics
 {
@@ -46,7 +47,7 @@ auto create_wlr_screencopy_manager_unstable_v1(
     wl_display* display,
     std::shared_ptr<Executor> const& wayland_executor,
     std::shared_ptr<graphics::GraphicBufferAllocator> const& allocator,
-    std::shared_ptr<compositor::ScreenShooter> const& screen_shooter,
+    std::shared_ptr<compositor::ScreenShooterFactory> const& screen_shooter_factory,
     std::shared_ptr<SurfaceStack> const& surface_stack)
 -> std::shared_ptr<wayland::WlrScreencopyManagerV1::Global>;
 
@@ -59,12 +60,15 @@ public:
         wl_resource* output;
         geometry::Rectangle output_space_area;
         geometry::Size buffer_size;
+        glm::mat2 transform;
+        bool overlay_cursor;
 
         auto operator==(FrameParams const& other) const -> bool
         {
             return output == other.output &&
                    output_space_area == other.output_space_area &&
-                   buffer_size == other.buffer_size;
+                   buffer_size == other.buffer_size &&
+                   transform == other.transform;
         }
 
         auto full_buffer_space_damage() const -> geometry::Rectangle
