@@ -16,18 +16,18 @@
 
 #include "xdg_activation_v1.h"
 
-#include "mir/events/keyboard_event.h"
-#include "mir/input/keyboard_observer.h"
-#include "mir/main_loop.h"
-#include "mir/scene/null_session_listener.h"
-#include "mir/scene/session.h"
-#include "mir/scene/session_coordinator.h"
-#include "mir/scene/session_listener.h"
-#include "mir/shell/shell.h"
-#include "mir/shell/token_authority.h"
-#include "mir/wayland/client.h"
-#include "mir/wayland/protocol_error.h"
-#include "mir/log.h"
+#include <mir/events/keyboard_event.h>
+#include <mir/input/keyboard_observer.h>
+#include <mir/main_loop.h>
+#include <mir/scene/null_session_listener.h>
+#include <mir/scene/session.h>
+#include <mir/scene/session_coordinator.h>
+#include <mir/scene/session_listener.h>
+#include <mir/shell/shell.h>
+#include <mir/shell/token_authority.h>
+#include <mir/wayland/client.h>
+#include <mir/wayland/protocol_error.h>
+#include <mir/log.h>
 #include "wl_seat.h"
 #include "wl_surface.h"
 
@@ -256,12 +256,11 @@ void mf::XdgActivationV1::remove_token(Token const& token)
 {
     std::lock_guard guard(pending_tokens_mutex);
 
-    pending_tokens.erase(std::remove_if(pending_tokens.begin(), pending_tokens.end(),
+    std::erase_if(pending_tokens,
         [&](auto const& pending_token)
         {
             return pending_token->token == token;
-        }),
-        pending_tokens.end());
+        });
 }
 
 void mf::XdgActivationV1::invalidate_all()
