@@ -19,13 +19,13 @@
 #include "wl_surface.h"
 #include "wayland_utils.h"
 
-#include "mir/wayland/protocol_error.h"
-#include "mir/wayland/client.h"
-#include "mir/frontend/wayland.h"
-#include "mir/shell/surface_specification.h"
-#include "mir/shell/shell.h"
-#include "mir/scene/surface.h"
-#include "mir/log.h"
+#include <mir/wayland/protocol_error.h>
+#include <mir/wayland/client.h>
+#include <mir/frontend/wayland.h>
+#include <mir/shell/surface_specification.h>
+#include <mir/shell/shell.h>
+#include <mir/scene/surface.h>
+#include <mir/log.h>
 
 #include <boost/throw_exception.hpp>
 
@@ -116,14 +116,16 @@ private:
 mf::XdgShellStable::XdgShellStable(
     struct wl_display* display,
     Executor& wayland_executor,
-    std::shared_ptr<msh::Shell> shell,
+    std::shared_ptr<msh::Shell> const& shell,
     WlSeat& seat,
-    OutputManager* output_manager)
+    OutputManager* output_manager,
+    std::shared_ptr<SurfaceRegistry> const& surface_registry)
     : Global(display, Version<5>()),
       wayland_executor{wayland_executor},
       shell{shell},
       seat{seat},
-      output_manager{output_manager}
+      output_manager{output_manager},
+      surface_registry{surface_registry}
 {
 }
 
@@ -277,7 +279,8 @@ mf::XdgPopupStable::XdgPopupStable(
           mw::XdgPopup::client,
           surface,
           xdg_surface->xdg_shell.shell,
-          xdg_surface->xdg_shell.output_manager),
+          xdg_surface->xdg_shell.output_manager,
+          xdg_surface->xdg_shell.surface_registry),
       reactive{positioner.reactive},
       aux_rect{positioner.aux_rect ? positioner.aux_rect.value() : geom::Rectangle{}},
       shell{xdg_surface->xdg_shell.shell},
@@ -426,7 +429,8 @@ mf::XdgToplevelStable::XdgToplevelStable(wl_resource* new_resource, XdgSurfaceSt
           mw::XdgToplevel::client,
           surface,
           xdg_surface->xdg_shell.shell,
-          xdg_surface->xdg_shell.output_manager),
+          xdg_surface->xdg_shell.output_manager,
+          xdg_surface->xdg_shell.surface_registry),
       xdg_surface{xdg_surface}
 {
     if (version_supports_wm_capabilities())
@@ -436,7 +440,7 @@ mf::XdgToplevelStable::XdgToplevelStable(wl_resource* new_resource, XdgSurfaceSt
             WmCapabilities::minimize,
             WmCapabilities::fullscreen,
         };
-        wl_array capability_array;
+        wl_array capability_array{};
         wl_array_init(&capability_array);
         for (auto& capability : capabilities)
         {
@@ -449,7 +453,7 @@ mf::XdgToplevelStable::XdgToplevelStable(wl_resource* new_resource, XdgSurfaceSt
         wl_array_release(&capability_array);
     }
 
-    wl_array states;
+    wl_array states{};
     wl_array_init(&states);
     send_configure_event(0, 0, &states);
     wl_array_release(&states);
@@ -598,6 +602,11 @@ void mf::XdgToplevelStable::handle_resize(
     send_toplevel_configure();
 }
 
+void mf::XdgToplevelStable::handle_tiled_edges(Flags<MirTiledEdge> /*tiled_edges*/)
+{
+    send_toplevel_configure();
+}
+
 void mf::XdgToplevelStable::handle_close_request()
 {
     send_close_event();
@@ -605,7 +614,7 @@ void mf::XdgToplevelStable::handle_close_request()
 
 void mf::XdgToplevelStable::send_toplevel_configure()
 {
-    wl_array states;
+    wl_array states{};
     wl_array_init(&states);
 
     if (is_active())
@@ -632,6 +641,28 @@ void mf::XdgToplevelStable::send_toplevel_configure()
                 *state = State::fullscreen;
         }
 
+        auto tiled_edges = surface.value()->tiled_edges();
+        if (tiled_edges & mir_tiled_edge_north)
+        {
+            if (uint32_t *state = static_cast<decltype(state)>(wl_array_add(&states, sizeof *state)))
+                *state = State::tiled_top;
+        }
+        if (tiled_edges & mir_tiled_edge_east)
+        {
+            if (uint32_t *state = static_cast<decltype(state)>(wl_array_add(&states, sizeof *state)))
+                *state = State::tiled_right;
+        }
+        if (tiled_edges & mir_tiled_edge_south)
+        {
+            if (uint32_t *state = static_cast<decltype(state)>(wl_array_add(&states, sizeof *state)))
+                *state = State::tiled_bottom;
+        }
+        if (tiled_edges & mir_tiled_edge_west)
+        {
+            if (uint32_t *state = static_cast<decltype(state)>(wl_array_add(&states, sizeof *state)))
+                *state = State::tiled_left;
+        }
+
         // TODO: plumb resizing state through Mir?
     }
 
