@@ -41,9 +41,10 @@ public:
     XdgShellStable(
         wl_display* display,
         Executor& wayland_executor,
-        std::shared_ptr<shell::Shell> shell,
+        std::shared_ptr<shell::Shell> const& shell,
         WlSeat& seat,
-        OutputManager* output_manager);
+        OutputManager* output_manager,
+        std::shared_ptr<SurfaceRegistry> const& surface_registry);
 
     static auto get_window(wl_resource* surface) -> std::shared_ptr<scene::Surface>;
 
@@ -51,6 +52,7 @@ public:
     std::shared_ptr<shell::Shell> const shell;
     WlSeat& seat;
     OutputManager* const output_manager;
+    std::shared_ptr<SurfaceRegistry> const surface_registry;
 
 private:
     class Instance;
@@ -81,6 +83,7 @@ public:
         std::optional<geometry::Point> const& new_top_left,
         geometry::Size const& new_size) override;
     void handle_close_request() override;
+    void handle_tiled_edges(Flags<MirTiledEdge> /*tiled_edges*/) override {}
 
     static auto from(wl_resource* resource) -> XdgPopupStable*;
 
@@ -128,6 +131,7 @@ public:
     void handle_active_change(bool /*is_now_active*/) override;
     void handle_resize(std::optional<geometry::Point> const& new_top_left, geometry::Size const& new_size) override;
     void handle_close_request() override;
+    void handle_tiled_edges(Flags<MirTiledEdge> tiled_edges) override;
 
     static XdgToplevelStable* from(wl_resource* surface);
 
