@@ -20,12 +20,12 @@
 #include "window_wl_surface_role.h"
 #include "wayland_utils.h"
 
-#include "mir/wayland/protocol_error.h"
-#include "mir/wayland/client.h"
-#include "mir/frontend/wayland.h"
-#include "mir/shell/surface_specification.h"
-#include "mir/scene/surface.h"
-#include "mir/log.h"
+#include <mir/wayland/protocol_error.h>
+#include <mir/wayland/client.h>
+#include <mir/frontend/wayland.h>
+#include <mir/shell/surface_specification.h>
+#include <mir/scene/surface.h>
+#include <mir/log.h>
 
 namespace mf = mir::frontend;
 namespace ms = mir::scene;
@@ -87,6 +87,7 @@ public:
         std::optional<geometry::Point> const& new_top_left,
         geometry::Size const& new_size) override;
     void handle_close_request() override;
+    void handle_tiled_edges(Flags<MirTiledEdge> /*tiled_edges*/) override {}
 
 private:
     std::optional<geom::Point> cached_top_left;
@@ -123,6 +124,7 @@ public:
         std::optional<geometry::Point> const& new_top_left,
         geometry::Size const& new_size) override;
     void handle_close_request() override;
+    void handle_tiled_edges(Flags<MirTiledEdge> /*tiled_edges*/) override;
 
 private:
     static XdgToplevelV6* from(wl_resource* surface);
@@ -190,14 +192,16 @@ void mf::XdgShellV6::Instance::pong(uint32_t serial)
 mf::XdgShellV6::XdgShellV6(
     struct wl_display* display,
     Executor& wayland_executor,
-    std::shared_ptr<msh::Shell> shell,
+    std::shared_ptr<msh::Shell> const& shell,
     WlSeat& seat,
-    OutputManager* output_manager) :
+    OutputManager* output_manager,
+    std::shared_ptr<SurfaceRegistry> const& surface_registry) :
     Global(display, Version<1>()),
     wayland_executor{wayland_executor},
     shell{shell},
     seat{seat},
-    output_manager{output_manager}
+    output_manager{output_manager},
+    surface_registry{surface_registry}
 {
 }
 
@@ -307,7 +311,8 @@ mf::XdgPopupV6::XdgPopupV6(
           mw::XdgPopupV6::client,
           surface,
           xdg_surface->xdg_shell.shell,
-          xdg_surface->xdg_shell.output_manager),
+          xdg_surface->xdg_shell.output_manager,
+          xdg_surface->xdg_shell.surface_registry),
       xdg_surface{xdg_surface}
 {
     auto specification = static_cast<mir::shell::SurfaceSpecification*>(
@@ -374,10 +379,11 @@ mf::XdgToplevelV6::XdgToplevelV6(struct wl_resource* new_resource, XdgSurfaceV6*
           mw::XdgToplevelV6::client,
           surface,
           xdg_surface->xdg_shell.shell,
-          xdg_surface->xdg_shell.output_manager),
+          xdg_surface->xdg_shell.output_manager,
+          xdg_surface->xdg_shell.surface_registry),
       xdg_surface{xdg_surface}
 {
-    wl_array states;
+    wl_array states{};
     wl_array_init(&states);
     send_configure_event(0, 0, &states);
     wl_array_release(&states);
@@ -517,6 +523,11 @@ void mf::XdgToplevelV6::handle_resize(
     send_toplevel_configure();
 }
 
+void mf::XdgToplevelV6::handle_tiled_edges(Flags<MirTiledEdge> /*tiled_edges*/)
+{
+    // Tiled edges are not supported
+}
+
 void mf::XdgToplevelV6::handle_close_request()
 {
     send_close_event();
@@ -524,7 +535,7 @@ void mf::XdgToplevelV6::handle_close_request()
 
 void mf::XdgToplevelV6::send_toplevel_configure()
 {
-    wl_array states;
+    wl_array states{};
     wl_array_init(&states);
 
     if (is_active())
