@@ -1,5 +1,5 @@
 /*
- * Copyright © 2018 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3,
@@ -34,6 +34,7 @@ namespace frontend
 {
 class WlSeat;
 class OutputManager;
+class SurfaceRegistry;
 
 class XdgShellV6 : public wayland::XdgShellV6::Global
 {
@@ -41,14 +42,16 @@ public:
     XdgShellV6(
         wl_display* display,
         Executor& wayland_executor,
-        std::shared_ptr<shell::Shell> shell,
+        std::shared_ptr<shell::Shell> const& shell,
         WlSeat& seat,
-        OutputManager* output_manager);
+        OutputManager* output_manager,
+        std::shared_ptr<SurfaceRegistry> const& surface_registry);
 
     Executor& wayland_executor;
     std::shared_ptr<shell::Shell> const shell;
     WlSeat& seat;
     OutputManager* const output_manager;
+    std::shared_ptr<SurfaceRegistry> const surface_registry;
 
     // Returns the Mir surface if the window is recognised by XdgShellV6
     static auto get_window(wl_resource* surface) -> std::shared_ptr<scene::Surface>;
