@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2018 Marius Gripsgard <marius@ubports.com>
- * Copyright (C) 2019-2020 Canonical Ltd.
+ * Copyright (C) Marius Gripsgard <marius@ubports.com>
+ * Copyright (C) Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -18,13 +18,13 @@
 
 #include "xwayland_spawner.h"
 
-#include "mir/dispatch/multiplexing_dispatchable.h"
-#include "mir/dispatch/threaded_dispatcher.h"
-#include "mir/dispatch/readable_fd.h"
-#include "mir/fd.h"
-#include "mir/log.h"
-#include "mir/fatal.h"
-#include "mir/thread_name.h"
+#include <mir/dispatch/multiplexing_dispatchable.h>
+#include <mir/dispatch/threaded_dispatcher.h>
+#include <mir/dispatch/readable_fd.h>
+#include <mir/fd.h>
+#include <mir/log.h>
+#include <mir/fatal.h>
+#include <mir/thread_name.h>
 
 #include <fcntl.h>
 #include <sys/socket.h>
@@ -138,11 +138,9 @@ auto create_socket(std::vector<mir::Fd>& fds, struct sockaddr_un *addr, size_t p
 auto create_sockets(int xdisplay) -> std::vector<mir::Fd>
 {
     std::vector<mir::Fd> result;
-    struct sockaddr_un addr;
+    struct sockaddr_un addr{ .sun_family = AF_UNIX, .sun_path = { 0 } };
     size_t path_size;
 
-    addr.sun_family = AF_UNIX;
-    addr.sun_path[0] = 0;
     path_size = snprintf(addr.sun_path + 1, sizeof(addr.sun_path) - 1, x11_socket_fmt, xdisplay);
     create_socket(result, &addr, path_size);
 
