@@ -22,12 +22,14 @@
 #include "xwayland_client_manager.h"
 #include "xwayland_wm_shell.h"
 #include "xwayland_surface_role.h"
+#include "surface_registry.h"
 
-#include "mir/frontend/wayland.h"
-#include "mir/scene/surface.h"
-#include "mir/shell/shell.h"
-#include "mir/shell/surface_specification.h"
-#include "mir/events/input_event.h"
+#include <mir/frontend/wayland.h>
+#include <mir/scene/surface.h>
+#include <mir/shell/shell.h>
+#include <mir/shell/surface_specification.h>
+#include <mir/events/input_event.h>
+#include <mir/wayland/weak.h>
 
 #include "boost/throw_exception.hpp"
 
@@ -518,6 +520,7 @@ void mf::XWaylandSurface::close()
     if (scene_surface)
     {
         shell->destroy_surface(scene_surface->session().lock(), scene_surface);
+        wm_shell.surface_registry->remove_surface(scene_surface);
         scene_surface.reset();
         // Someone may still be holding on to the surface somewhere, and that's fine
     }
@@ -719,6 +722,7 @@ void mf::XWaylandSurface::attach_wl_surface(WlSurface* wl_surface)
         XWaylandSurfaceRole::populate_surface_data_scaled(wl_surface, scale, spec, keep_alive_until_spec_is_used);
 
         // May be overridden by anything in the pending spec
+        spec.top_left = cached.geometry.top_left;
         spec.width = cached.geometry.size.width;
         spec.height = cached.geometry.size.height;
         spec.type = mir_window_type_freestyle;
@@ -736,8 +740,8 @@ void mf::XWaylandSurface::attach_wl_surface(WlSurface* wl_surface)
     std::shared_ptr<XWaylandClientManager::Session> local_client_session;
     std::shared_ptr<ms::Session> session;
     bool rejected = false;
-    reply_functions.push_back(connection->read_property(
-        window, connection->_NET_WM_PID,
+    reply_functions.push_back(connection->query_client_pid(
+        window,
         XCBConnection::Handler<uint32_t>{
             [&](uint32_t pid)
             {
@@ -751,7 +755,7 @@ void mf::XWaylandSurface::attach_wl_surface(WlSurface* wl_surface)
             },
             [&](std::string const&)
             {
-                log_warning("X11 app did not set _NET_WM_PID, grouping it under the default XWayland application");
+                log_warning("X11 app is not local, grouping it under the default XWayland application");
                 session = get_session(wl_surface->resource);
             }
         }));
@@ -787,7 +791,8 @@ void mf::XWaylandSurface::attach_wl_surface(WlSurface* wl_surface)
         prep_surface_spec(lock, spec);
     }
 
-    auto const surface = shell->create_surface(session, mw::make_weak(wl_surface), spec, observer, nullptr);
+    auto const surface = shell->create_surface(session, spec, observer, nullptr);
+    wm_shell.surface_registry->add_surface(surface, mw::Weak<WlSurface>(wl_surface));
     XWaylandSurfaceObserverManager local_surface_observer_manager{surface, std::move(observer)};
     inform_client_of_window_state(std::unique_lock{mutex}, state);
     auto const top_left = scaled_top_left_of(*surface) + scaled_content_offset_of(*surface);
