@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2018 Marius Gripsgard <marius@ubports.com>
- * Copyright (C) 2020 Canonical Ltd.
+ * Copyright (C) Marius Gripsgard <marius@ubports.com>
+ * Copyright (C) Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -19,8 +19,8 @@
 #ifndef MIR_FRONTEND_XWAYLAND_WM_H
 #define MIR_FRONTEND_XWAYLAND_WM_H
 
-#include "mir/dispatch/threaded_dispatcher.h"
-#include "mir/geometry/rectangle.h"
+#include <mir/dispatch/threaded_dispatcher.h>
+#include <mir/geometry/rectangle.h>
 #include "wayland_connector.h"
 #include "xcb_connection.h"
 
