@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014-2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -14,9 +14,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/glib_main_loop_sources.h"
-#include "mir/lockable_callback.h"
-#include "mir/raii.h"
+#include <mir/glib_main_loop_sources.h>
+#include <mir/lockable_callback.h>
+#include <mir/raii.h>
 #include <mir/log.h>
 
 #include <algorithm>
@@ -451,14 +451,12 @@ void md::FdSources::remove_all_owned_by(void const* owner)
 {
     std::lock_guard lock{sources_mutex};
 
-    auto const new_end = std::remove_if(
-        sources.begin(), sources.end(),
+    std::erase_if(
+        sources,
         [&] (std::unique_ptr<FdSource> const& fd_source)
         {
             return fd_source->owner == owner;
         });
-
-    sources.erase(new_end, sources.end());
 }
 
 /*****************
@@ -622,8 +620,8 @@ void md::SignalSources::ensure_signal_is_handled(int sig)
     if (handled_signals.find(sig) != handled_signals.end())
         return;
 
-    struct sigaction old_action;
-    struct sigaction new_action;
+    struct sigaction old_action{};
+    struct sigaction new_action{};
 
     new_action.sa_sigaction = SourceRegistration::notify_sources_of_signal;
     sigfillset(&new_action.sa_mask);
