@@ -14,30 +14,32 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/default_server_configuration.h"
-#include "mir/options/configuration.h"
+#include <mir/default_server_configuration.h>
+#include <mir/options/configuration.h>
 
-#include "mir/graphics/default_display_configuration_policy.h"
-#include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/graphics/display.h"
+#include <mir/graphics/default_display_configuration_policy.h>
+#include <mir/graphics/graphic_buffer_allocator.h>
+#include <mir/graphics/display.h>
 #include "multiplexing_display.h"
 #include "null_cursor.h"
 #include "software_cursor.h"
 #include "platform_probe.h"
+#include <mir/shell/accessibility_manager.h>
 
-#include "mir/graphics/gl_config.h"
-#include "mir/graphics/platform.h"
-#include "mir/graphics/cursor.h"
+#include <mir/graphics/gl_config.h>
+#include <mir/graphics/platform.h>
+#include <mir/graphics/cursor.h>
 #include "display_configuration_observer_multiplexer.h"
+#include "default_output_filter.h"
 
-#include "mir/shared_library.h"
-#include "mir/shared_library_prober.h"
-#include "mir/abnormal_exit.h"
-#include "mir/emergency_cleanup.h"
-#include "mir/log.h"
-#include "mir/report_exception.h"
-#include "mir/main_loop.h"
-#include "mir/udev/wrapper.h"
+#include <mir/shared_library.h>
+#include <mir/shared_library_prober.h>
+#include <mir/abnormal_exit.h>
+#include <mir/emergency_cleanup.h>
+#include <mir/log.h>
+#include <mir/report_exception.h>
+#include <mir/main_loop.h>
+#include <mir/udev/wrapper.h>
 
 #include <boost/throw_exception.hpp>
 
@@ -235,7 +237,7 @@ auto mir::DefaultServerConfiguration::the_rendering_platforms() ->
                         graphics::probe_rendering_module(
                             display_targets,
                             *platform,
-                            *the_options(),
+                            *the_options_provider()->options_for(*platform),
                             the_console_services());
 
                     bool found_supported_device{false};
@@ -413,11 +415,10 @@ mir::DefaultServerConfiguration::the_cursor()
                 mir::log_info("Using software cursor");
                 primary_cursor = std::make_shared<mg::SoftwareCursor>(
                     the_buffer_allocator(),
-                    the_main_loop(),
                     the_input_scene());
             }
 
-            primary_cursor->show(*the_default_cursor_image());
+            primary_cursor->show(the_default_cursor_image());
             return wrap_cursor(primary_cursor);
         });
 }
@@ -462,3 +463,13 @@ mir::DefaultServerConfiguration::the_display_configuration_observer()
             return std::make_shared<mg::DisplayConfigurationObserverMultiplexer>(default_executor);
         });
 }
+
+std::shared_ptr<mg::OutputFilter>
+mir::DefaultServerConfiguration::the_output_filter()
+{
+    return output_filter(
+        [this]() -> std::shared_ptr<mg::OutputFilter>
+        {
+	   return std::make_shared<mg::DefaultOutputFilter>(the_input_scene());
+        });
+}
