@@ -17,7 +17,7 @@
 #include <vector>
 #include <span>
 
-#include "mir/graphics/cursor.h"
+#include <mir/graphics/cursor.h>
 
 namespace mir::graphics
 {
@@ -28,10 +28,16 @@ class MultiplexingCursor : public Cursor
 public:
     explicit MultiplexingCursor(std::span<Display*> platform_displays);
 
-    void show(CursorImage const& image) override;
+    void show(std::shared_ptr<CursorImage> const& image) override;
     void hide() override;
     void move_to(geometry::Point position) override;
 
+    void scale(float) override;
+
+    auto renderable() -> std::shared_ptr<Renderable> override;
+
+    auto needs_compositing() const -> bool override;
+
 private:
     std::vector<std::shared_ptr<Cursor>> const platform_cursors;
 };
