@@ -17,7 +17,7 @@
 #ifndef MIR_GRAPHICS_NULL_CURSOR_H_
 #define MIR_GRAPHICS_NULL_CURSOR_H_
 
-#include "mir/graphics/cursor.h"
+#include <mir/graphics/cursor.h>
 
 namespace mir
 {
@@ -27,9 +27,12 @@ namespace graphics
 class NullCursor : public Cursor
 {
 public:
-    void show(CursorImage const&) override {}
+    void show(std::shared_ptr<CursorImage> const&) override {}
     void hide() override {}
     void move_to(geometry::Point) override {}
+    void scale(float) override {}
+    auto renderable() -> std::shared_ptr<Renderable> override { return nullptr; }
+    auto needs_compositing() const -> bool override { return false; }
 };
 
 }
