@@ -16,14 +16,14 @@
 
  #include "platform_probe.h"
 
-#include "mir/graphics/display.h"
-#include "mir/log.h"
-#include "mir/graphics/platform.h"
-#include "mir/options/configuration.h"
-#include "mir/shared_library.h"
-#include "mir/shared_library_prober.h"
-#include "mir/shared_library_prober_report.h"
-#include "mir/udev/wrapper.h"
+#include <mir/graphics/display.h>
+#include <mir/log.h>
+#include <mir/graphics/platform.h>
+#include <mir/options/configuration.h>
+#include <mir/shared_library.h>
+#include <mir/shared_library_prober.h>
+#include <mir/shared_library_prober_report.h>
+#include <mir/udev/wrapper.h>
 
 #include <algorithm>
 #include <boost/throw_exception.hpp>
@@ -413,15 +413,12 @@ auto mg::select_display_modules(
      * This lets us assume, from here on in, that everything in platforms is
      * a graphics module (and hence contains a `describe_graphics_module` symbol, etc)
      */
-    platforms.erase(
-        std::remove_if(
-            platforms.begin(),
-            platforms.end(),
-            [](auto const& module)
-            {
-                return !is_graphics_module(*module);
-            }),
-        platforms.end());
+    std::erase_if(
+        platforms,
+        [](auto const& module)
+        {
+            return !is_graphics_module(*module);
+        });
 
     /* Sort the platform modules by DSO filename.
      *
