@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,9 +17,11 @@
 #ifndef MIR_GRAPHICS_SOFTWARE_CURSOR_H_
 #define MIR_GRAPHICS_SOFTWARE_CURSOR_H_
 
-#include "mir/graphics/cursor.h"
-#include "mir_toolkit/client_types.h"
-#include "mir/geometry/displacement.h"
+#include <mir/graphics/cursor.h>
+#include <mir/graphics/cursor_image.h>
+#include <mir_toolkit/client_types.h>
+#include <mir/geometry/displacement.h>
+
 #include <mutex>
 
 namespace mir
@@ -41,30 +43,31 @@ class SoftwareCursor : public Cursor
 public:
     SoftwareCursor(
         std::shared_ptr<GraphicBufferAllocator> const& allocator,
-        std::shared_ptr<Executor> const& scene_executor,
         std::shared_ptr<input::Scene> const& scene);
     ~SoftwareCursor();
 
-    void show(CursorImage const& cursor_image) override;
+    void show(std::shared_ptr<CursorImage> const& cursor_image) override;
     void hide() override;
     void move_to(geometry::Point position) override;
+    void scale(float) override;
+    auto renderable() -> std::shared_ptr<Renderable> override;
+    auto needs_compositing() const -> bool override;
 
 private:
-    std::shared_ptr<detail::CursorRenderable> create_renderable_for(
+    std::shared_ptr<detail::CursorRenderable> create_scaled_renderable_for(
         CursorImage const& cursor_image, geometry::Point position);
 
     std::shared_ptr<GraphicBufferAllocator> const allocator;
     std::shared_ptr<input::Scene> const scene;
     MirPixelFormat const format;
 
-    /// If input visualisations are removed from the scene before they are added, the scene throws and Mir crashes
-    /// We don't want to call into the scene under lock, so we make these calls on with an executor
-    std::shared_ptr<Executor> const scene_executor;
-
-    std::mutex guard;
-    std::shared_ptr<detail::CursorRenderable> renderable;
+    std::mutex mutable guard;
+    std::shared_ptr<detail::CursorRenderable> renderable_;
     bool visible;
     geometry::Displacement hotspot;
+
+    float current_scale{1.0};
+    std::shared_ptr<graphics::CursorImage> current_cursor_image;
 };
 
 }
