@@ -15,12 +15,12 @@
  */
 
 #include "basic_seat.h"
-#include "mir/input/device.h"
-#include "mir/input/input_sink.h"
-#include "mir/graphics/display_configuration_observer.h"
-#include "mir/graphics/display_configuration.h"
-#include "mir/geometry/rectangle.h"
-#include "mir_toolkit/common.h"
+#include <mir/input/device.h>
+#include <mir/input/input_sink.h>
+#include <mir/graphics/display_configuration_observer.h>
+#include <mir/graphics/display_configuration.h>
+#include <mir/geometry/rectangle.h>
+#include <mir_toolkit/common.h>
 
 #include <algorithm>
 #include <array>
@@ -150,7 +150,7 @@ struct mi::BasicSeat::OutputTracker : mg::DisplayConfigurationObserver
         {
             // Output has not been populated sensibly, that's expected as there's no way to do that (yet).
             // FIXME: We just guess (which works with a single touchscreen output). {alan_g}
-            // https://github.com/MirServer/mir/issues/611
+            // https://github.com/canonical/mir/issues/611
             auto const pos = begin(outputs);
             if (pos != end(outputs))
                 return pos->second;
@@ -167,14 +167,16 @@ private:
 
 mi::BasicSeat::BasicSeat(std::shared_ptr<mi::InputDispatcher> const& dispatcher,
                          std::shared_ptr<mi::TouchVisualizer> const& touch_visualizer,
-                         std::shared_ptr<mi::CursorListener> const& cursor_listener,
+                         std::shared_ptr<mi::CursorObserver> const& cursor_observer,
+                         std::shared_ptr<mi::CursorObserverMultiplexer> const& cursor_observer_multiplexer,
                          std::shared_ptr<Registrar> const& registrar,
                          std::shared_ptr<mi::KeyMapper> const& key_mapper,
                          std::shared_ptr<time::Clock> const& clock,
                          std::shared_ptr<mi::SeatObserver> const& observer) :
       input_state_tracker{dispatcher,
                           touch_visualizer,
-                          cursor_listener,
+                          cursor_observer,
+                          cursor_observer_multiplexer,
                           key_mapper,
                           clock,
                           observer},
