@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015-2016 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -18,9 +18,9 @@
 #define MIR_BASIC_SEAT_H_
 
 #include "seat_input_device_tracker.h"
-#include "mir/input/seat.h"
-#include "mir/frontend/event_sink.h"
-#include "mir/observer_registrar.h"
+#include <mir/input/seat.h>
+#include <mir/frontend/event_sink.h>
+#include <mir/observer_registrar.h>
 
 #include <mutex>
 
@@ -37,7 +37,8 @@ class DisplayConfigurationObserver;
 namespace input
 {
 class TouchVisualizer;
-class CursorListener;
+class CursorObserver;
+class CursorObserverMultiplexer;
 class InputDispatcher;
 class KeyMapper;
 class SeatObserver;
@@ -48,7 +49,8 @@ public:
     using Registrar = ObserverRegistrar<graphics::DisplayConfigurationObserver>;
     BasicSeat(std::shared_ptr<InputDispatcher> const& dispatcher,
               std::shared_ptr<TouchVisualizer> const& touch_visualizer,
-              std::shared_ptr<CursorListener> const& cursor_listener,
+              std::shared_ptr<CursorObserver> const& cursor_observer,
+              std::shared_ptr<CursorObserverMultiplexer> const& cursor_observer_multiplexer,
               std::shared_ptr<Registrar> const& registrar,
               std::shared_ptr<KeyMapper> const& key_mapper,
               std::shared_ptr<time::Clock> const& clock,
@@ -60,6 +62,7 @@ public:
     geometry::Rectangle bounding_rectangle() const override;
     input::OutputInfo output_info(uint32_t output_id) const override;
     EventUPtr create_device_state() override;
+    auto xkb_modifiers() const -> MirXkbModifiers override;
     void set_confinement_regions(geometry::Rectangles const& regions) override;
     void reset_confinement_regions() override;
 
