@@ -14,15 +14,15 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "cursor_controller.h"
+#include <mir/input/cursor_controller.h>
 
-#include "mir/input/scene.h"
-#include "mir/input/surface.h"
-#include "mir/graphics/cursor.h"
-#include "mir/graphics/cursor_image.h"
-#include "mir/scene/observer.h"
-#include "mir/scene/null_surface_observer.h"
-#include "mir/scene/surface.h"
+#include <mir/input/scene.h>
+#include <mir/input/surface.h>
+#include <mir/graphics/cursor.h>
+#include <mir/graphics/cursor_image.h>
+#include <mir/scene/observer.h>
+#include <mir/scene/null_surface_observer.h>
+#include <mir/scene/surface.h>
 
 #include <exception>
 #include <mutex>
@@ -202,7 +202,7 @@ mi::CursorController::CursorController(std::shared_ptr<mi::Scene> const& input_t
 
 mi::CursorController::~CursorController()
 {
-    try 
+    try
     {
         input_targets->remove_observer(observer);
     }
@@ -228,7 +228,7 @@ void mi::CursorController::set_cursor_image_locked(std::unique_lock<std::mutex>&
     if (image && !is_empty(image))
     {
         if (usable)
-            cursor->show(*image);
+            cursor->show(image);
     }
     else
         cursor->hide();
@@ -291,7 +291,7 @@ void mir::input::CursorController::pointer_usable()
     if (became_usable)
     {
         if (image && !is_empty(image))
-            cursor->show(*image);
+            cursor->show(image);
         if (di)
         {
             di->show();
