@@ -14,14 +14,11 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/default_server_configuration.h"
+#include <mir/default_server_configuration.h>
 
 #include "key_repeat_dispatcher.h"
 #include "keyboard_resync_dispatcher.h"
 #include "event_filter_chain_dispatcher.h"
-#include "config_changer.h"
-#include "cursor_controller.h"
-#include "mir/input/input_event_transformer.h"
 #include "touchspot_controller.h"
 #include "null_input_manager.h"
 #include "null_input_dispatcher.h"
@@ -34,26 +31,29 @@
 #include "seat_observer_multiplexer.h"
 #include "idle_poking_dispatcher.h"
 
-#include "mir/input/touch_visualizer.h"
-#include "mir/input/input_probe.h"
-#include "mir/input/platform.h"
-#include "mir/input/xkb_mapper_registrar.h"
-#include "mir/input/vt_filter.h"
-#include "mir/input/device.h"
-#include "mir/options/configuration.h"
-#include "mir/options/option.h"
-#include "mir/dispatch/multiplexing_dispatchable.h"
-#include "mir/compositor/scene.h"
-#include "mir/emergency_cleanup.h"
-#include "mir/main_loop.h"
-#include "mir/abnormal_exit.h"
-#include "mir/glib_main_loop.h"
-#include "mir/log.h"
-#include "mir/shared_library.h"
-#include "mir/dispatch/action_queue.h"
-#include "mir/console_services.h"
+#include <mir/input/touch_visualizer.h>
+#include <mir/input/input_probe.h>
+#include <mir/input/platform.h>
+#include <mir/input/xkb_mapper_registrar.h>
+#include <mir/input/vt_filter.h>
+#include <mir/input/device.h>
+#include <mir/input/input_event_transformer.h>
+#include <mir/input/cursor_observer_multiplexer.h>
+#include <mir/input/cursor_controller.h>
+#include <mir/options/configuration.h>
+#include <mir/options/option.h>
+#include <mir/dispatch/multiplexing_dispatchable.h>
+#include <mir/compositor/scene.h>
+#include <mir/emergency_cleanup.h>
+#include <mir/main_loop.h>
+#include <mir/abnormal_exit.h>
+#include <mir/glib_main_loop.h>
+#include <mir/log.h>
+#include <mir/shared_library.h>
+#include <mir/dispatch/action_queue.h>
+#include <mir/console_services.h>
 
-#include "mir_toolkit/cursors.h"
+#include <mir_toolkit/cursors.h>
 
 namespace mi = mir::input;
 namespace mr = mir::report;
@@ -81,6 +81,12 @@ mir::DefaultServerConfiguration::the_event_filter_chain_dispatcher()
             auto const make_default_filter_list =
                 [this]() -> std::vector<std::weak_ptr<mi::EventFilter>>
                 {
+                    auto const options = the_options();
+                    if (!options->get<bool>(options::vt_switching_option_name))
+                    {
+                        return {};
+                    }
+
                     try
                     {
                         default_filter = std::make_shared<mi::VTFilter>(
@@ -108,10 +114,7 @@ std::shared_ptr<mi::InputEventTransformer> mir::DefaultServerConfiguration::the_
     return input_event_transformer(
         [this]
         {
-            auto event_transformer =
-                std::make_shared<input::InputEventTransformer>(the_input_device_registry(), the_main_loop());
-            the_composite_event_filter()->prepend(event_transformer);
-            return event_transformer;
+            return std::make_shared<input::InputEventTransformer>(the_seat(), the_clock());
         });
 }
 
@@ -177,23 +180,28 @@ mir::DefaultServerConfiguration::the_input_dispatcher()
         });
 }
 
-std::shared_ptr<mi::CursorListener>
-mir::DefaultServerConfiguration::the_cursor_listener()
+std::shared_ptr<mi::CursorController> mir::DefaultServerConfiguration::the_cursor_controller()
 {
-    return cursor_listener(
-        [this]() -> std::shared_ptr<mi::CursorListener>
+    return cursor_controller(
+        [this]()
         {
-            return wrap_cursor_listener(std::make_shared<mi::CursorController>(
-                    the_input_scene(),
-                    the_cursor(),
-                    the_default_cursor_image()));
+            return std::make_shared<mi::CursorController>(the_input_scene(), the_cursor(), the_default_cursor_image());
         });
-
 }
 
-std::shared_ptr<mi::CursorListener>
-mir::DefaultServerConfiguration::wrap_cursor_listener(
-    std::shared_ptr<mi::CursorListener> const& wrapped)
+std::shared_ptr<mi::CursorObserverMultiplexer>
+mir::DefaultServerConfiguration::the_cursor_observer_multiplexer()
+{
+    return cursor_observer_multiplexer(
+        [this]() -> std::shared_ptr<mi::CursorObserverMultiplexer>
+        {
+            return wrap_cursor_observer_multiplexer(std::make_shared<mi::CursorObserverMultiplexer>(*the_main_loop()));
+        });
+}
+
+std::shared_ptr<mi::CursorObserverMultiplexer>
+mir::DefaultServerConfiguration::wrap_cursor_observer_multiplexer(
+    std::shared_ptr<mi::CursorObserverMultiplexer> const& wrapped)
 {
     return wrapped;
 }
@@ -214,7 +222,7 @@ mir::DefaultServerConfiguration::the_touch_visualizer()
             {
                 visualizer->enable();
             }
-            
+
             return visualizer;
         });
 }
@@ -242,35 +250,36 @@ mir::DefaultServerConfiguration::the_cursor_images()
 std::shared_ptr<mi::InputManager>
 mir::DefaultServerConfiguration::the_input_manager()
 {
-    return input_manager(
-        [this]() -> std::shared_ptr<mi::InputManager>
+    if (input_manager)
+        return input_manager;
+
+    return input_manager = [this]() -> std::shared_ptr<mi::InputManager>
+    {
+        auto const options = the_options();
+        bool input_opt = options->get<bool>(options::enable_input_opt);
+
+        if (!input_opt)
         {
-            auto const options = the_options();
-            bool input_opt = options->get<bool>(options::enable_input_opt);
-
-            if (!input_opt)
-            {
-                return std::make_shared<mi::NullInputManager>();
-            }
-            else
-            {
-                auto const emergency_cleanup = the_emergency_cleanup();
-                auto const device_registry = the_input_device_registry();
-                auto const input_report = the_input_report();
-
-                auto platform = probe_input_platforms(
-                    *options,
-                    emergency_cleanup,
-                    device_registry,
-                    the_console_services(),
-                    input_report,
-                    the_platform_libaries(),
-                    *the_shared_library_prober_report());
-
-                return std::make_shared<mi::DefaultInputManager>(the_input_reading_multiplexer(), std::move(platform));
-            }
+            return std::make_shared<mi::NullInputManager>();
         }
-    );
+        else
+        {
+            auto const emergency_cleanup = the_emergency_cleanup();
+            auto const device_registry = the_input_device_registry();
+            auto const input_report = the_input_report();
+
+            auto platform = probe_input_platforms(
+                *options,
+                emergency_cleanup,
+                device_registry,
+                the_console_services(),
+                input_report,
+                the_platform_libaries(),
+                *the_shared_library_prober_report());
+
+            return std::make_shared<mi::DefaultInputManager>(the_input_reading_multiplexer(), std::move(platform));
+        }
+    }();
 }
 
 std::shared_ptr<mir::dispatch::MultiplexingDispatchable>
@@ -292,7 +301,8 @@ std::shared_ptr<mi::Seat> mir::DefaultServerConfiguration::the_seat()
             return std::make_shared<mi::BasicSeat>(
                     the_input_dispatcher(),
                     the_touch_visualizer(),
-                    the_cursor_listener(),
+                    the_cursor_controller(),
+                    the_cursor_observer_multiplexer(),
                     the_display_configuration_observer_registrar(),
                     the_key_mapper(),
                     the_clock(),
@@ -323,7 +333,7 @@ std::shared_ptr<mi::DefaultInputDeviceHub> mir::DefaultServerConfiguration::the_
            auto input_dispatcher = the_input_dispatcher();
            auto key_repeater = std::dynamic_pointer_cast<mi::KeyRepeatDispatcher>(input_dispatcher);
            auto hub = std::make_shared<mi::DefaultInputDeviceHub>(
-               the_seat(),
+               the_input_event_transformer(),
                the_input_reading_multiplexer(),
                the_clock(),
                the_key_mapper(),
