@@ -17,8 +17,8 @@
 #ifndef MIR_INPUT_EVENT_FILTER_CHAIN_DISPATCHER_H_
 #define MIR_INPUT_EVENT_FILTER_CHAIN_DISPATCHER_H_
 
-#include "mir/input/composite_event_filter.h"
-#include "mir/input/input_dispatcher.h"
+#include <mir/input/composite_event_filter.h>
+#include <mir/input/input_dispatcher.h>
 
 #include <vector>
 #include <mutex>
@@ -44,10 +44,10 @@ public:
     bool dispatch(std::shared_ptr<MirEvent const> const& event) override;
     void start() override;
     void stop() override;
-    
+
 private:
     std::mutex filter_guard;
-    
+
     std::vector<std::weak_ptr<EventFilter>> filters;
     std::shared_ptr<InputDispatcher> const next_dispatcher;
 };
