@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -16,7 +16,7 @@
 
 #include "input_modifier_utils.h"
 
-#include "mir_toolkit/events/input/input_event.h"
+#include <mir_toolkit/events/input/input_event.h>
 
 namespace mi = mir::input;
 
@@ -39,4 +39,3 @@ MirInputEventModifiers mi::expand_modifiers(MirInputEventModifiers modifiers)
 
     return modifiers;
 }
-
