@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,7 +17,7 @@
 #ifndef MIR_INPUT_NULL_INPUT_DISPATCHER_H_
 #define MIR_INPUT_NULL_INPUT_DISPATCHER_H_
 
-#include "mir/input/input_dispatcher.h"
+#include <mir/input/input_dispatcher.h>
 
 namespace mir
 {
