@@ -17,7 +17,7 @@
 #ifndef MIR_INPUT_NULL_INPUT_TARGETER_H_
 #define MIR_INPUT_NULL_INPUT_TARGETER_H_
 
-#include "mir/shell/input_targeter.h"
+#include <mir/shell/input_targeter.h>
 
 namespace mir
 {
@@ -36,9 +36,6 @@ struct NullInputTargeter : public shell::InputTargeter
     void clear_focus() override
     {
     }
-
-    void set_drag_and_drop_handle(std::vector<uint8_t> const&) override {}
-    void clear_drag_and_drop_handle() override {}
 };
 
 }
