@@ -1,5 +1,5 @@
 /*
- * Copyright © 2016 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -18,8 +18,8 @@
 #ifndef MIR_INPUT_SEAT_OBSERVER_MULTIPLEXER_H_
 #define MIR_INPUT_SEAT_OBSERVER_MULTIPLEXER_H_
 
-#include "mir/input/seat_observer.h"
-#include "mir/observer_multiplexer.h"
+#include <mir/input/seat_observer.h>
+#include <mir/observer_multiplexer.h>
 
 namespace mir
 {
