@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -14,15 +14,15 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/default_server_configuration.h"
-#include "mir/options/configuration.h"
+#include <mir/default_server_configuration.h>
+#include <mir/options/configuration.h>
 
 #include "reports.h"
 #include "lttng_report_factory.h"
 #include "logging_report_factory.h"
 #include "null_report_factory.h"
 
-#include "mir/abnormal_exit.h"
+#include <mir/abnormal_exit.h>
 
 namespace mg = mir::graphics;
 namespace mf = mir::frontend;
@@ -112,4 +112,3 @@ auto mir::DefaultServerConfiguration::the_shell_report() -> std::shared_ptr<shel
             return report_factory(options::shell_report_opt)->create_shell_report();
         });
 }
-
