@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -15,11 +15,10 @@
  */
 
 #include "display_configuration_report.h"
-#include "mir/graphics/display_configuration.h"
-#include "mir/output_type_names.h"
-#include "mir/logging/logger.h"
-#include "mir/graphics/edid.h"
-#include "mir/scene/session.h"
+#include <mir/graphics/display_configuration.h>
+#include <mir/output_type_names.h>
+#include <mir/logging/logger.h>
+#include <mir/scene/session.h>
 
 #include <boost/exception/diagnostic_information.hpp>
 #include <cmath>
@@ -107,20 +106,25 @@ void mrl::DisplayConfigurationReport::log_configuration(
                     );
         if (out.connected)
         {
-            using mir::graphics::Edid;
-            if (out.edid.size() >= Edid::minimum_size)
+            if (out.display_info.model)
             {
-                auto edid = reinterpret_cast<Edid const*>(out.edid.data());
-                Edid::MonitorName name;
-                if (edid->get_monitor_name(name))
-                    logger->log(component, severity,
-                                "%sEDID monitor name: %s", indent, name);
-                Edid::Manufacturer man;
-                edid->get_manufacturer(man);
                 logger->log(component, severity,
-                            "%sEDID manufacturer: %s", indent, man);
+                            "%sEDID monitor name: %s", indent, out.display_info.model->c_str());
+            }
+            if (out.display_info.vendor)
+            {
                 logger->log(component, severity,
-                            "%sEDID product code: %hu", indent, edid->product_code());
+                            "%sEDID manufacturer: %s", indent, out.display_info.vendor->c_str());
+            }
+            if (out.display_info.product_code)
+            {
+                logger->log(component, severity,
+                            "%sEDID product code: %hu", indent, *out.display_info.product_code);
+            }
+            if (out.display_info.serial)
+            {
+                logger->log(component, severity,
+                            "%sEDID serial number: %s", indent, out.display_info.serial->c_str());
             }
 
             int width_mm = out.physical_size_mm.width.as_int();
