@@ -16,8 +16,8 @@
 
 #include "input_report.h"
 
-#include "mir/logging/logger.h"
-#include "mir/logging/input_timestamp.h"
+#include <mir/logging/logger.h>
+#include <mir/logging/input_timestamp.h>
 
 #include <linux/input.h>
 
@@ -122,4 +122,4 @@ void mrl::InputReport::received_event_from_kernel(int64_t when, int type, int co
        << " value=" << value;
 
     logger->log(ml::Severity::informational, ss.str(), component());
-}
\ No newline at end of file
+}
