@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -16,7 +16,7 @@
 
 #include "scene_report.h"
 
-#include "mir/logging/logger.h"
+#include <mir/logging/logger.h>
 
 #include <sstream>
 
