@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -18,7 +18,7 @@
 #ifndef MIR_REPORT_LOGGING_SCENE_REPORT_H_
 #define MIR_REPORT_LOGGING_SCENE_REPORT_H_
 
-#include "mir/scene/scene_report.h"
+#include <mir/scene/scene_report.h>
 
 #include <map>
 #include <memory>
