@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -16,8 +16,8 @@
 
 #include "compositor_report.h"
 
-#include "mir/graphics/buffer.h"
-#include "mir/report/lttng/mir_tracepoint.h"
+#include <mir/graphics/buffer.h>
+#include <mir/report/lttng/mir_tracepoint.h>
 
 #define TRACEPOINT_DEFINE
 #define TRACEPOINT_PROBE_DYNAMIC_LINKAGE
