@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -19,7 +19,7 @@
 
 #include "server_tracepoint_provider.h"
 
-#include "mir/compositor/compositor_report.h"
+#include <mir/compositor/compositor_report.h>
 
 namespace mir
 {
