@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/report/lttng/mir_tracepoint.h"
+#include <mir/report/lttng/mir_tracepoint.h>
 
 #include "input_report.h"
 
@@ -25,4 +25,4 @@
 void mir::report::lttng::InputReport::received_event_from_kernel(int64_t when, int type, int code, int value)
 {
     mir_tracepoint(mir_server_input, received_event_from_kernel, when, type, code, value);
-}
\ No newline at end of file
+}
