@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -16,34 +16,33 @@
 
 #include "shared_library_prober_report.h"
 
-#include "mir/report/lttng/mir_tracepoint.h"
+#include <mir/report/lttng/mir_tracepoint.h>
 
 #define TRACEPOINT_DEFINE
 #define TRACEPOINT_PROBE_DYNAMIC_LINKAGE
 #include "shared_library_prober_report_tp.h"
 
 namespace mrl = mir::report::lttng;
-namespace bf = boost::filesystem;
 
-void mrl::SharedLibraryProberReport::probing_path(bf::path const& path)
+void mrl::SharedLibraryProberReport::probing_path(std::filesystem::path const& path)
 {
     mir_tracepoint(mir_server_shared_library_prober, probing_path,
                    path.string().c_str());
 }
 
-void mrl::SharedLibraryProberReport::probing_failed(bf::path const& path, std::exception const& error)
+void mrl::SharedLibraryProberReport::probing_failed(std::filesystem::path const& path, std::exception const& error)
 {
     mir_tracepoint(mir_server_shared_library_prober, probing_failed,
                    path.string().c_str(), error.what());
 }
 
-void mrl::SharedLibraryProberReport::loading_library(bf::path const& filename)
+void mrl::SharedLibraryProberReport::loading_library(std::filesystem::path const& filename)
 {
     mir_tracepoint(mir_server_shared_library_prober, loading_library,
                    filename.string().c_str());
 }
 
-void mrl::SharedLibraryProberReport::loading_failed(bf::path const& filename, std::exception const& error)
+void mrl::SharedLibraryProberReport::loading_failed(std::filesystem::path const& filename, std::exception const& error)
 {
     mir_tracepoint(mir_server_shared_library_prober, loading_failed,
                    filename.string().c_str(), error.what());
