@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -18,7 +18,7 @@
 #define MIR_REPORT_LTTNG_SHARED_LIBRARY_PROBER_REPORT_H_
 
 #include "server_tracepoint_provider.h"
-#include "mir/shared_library_prober_report.h"
+#include <mir/shared_library_prober_report.h>
 
 namespace mir
 {
@@ -30,10 +30,10 @@ namespace lttng
 class SharedLibraryProberReport : public mir::SharedLibraryProberReport
 {
 public:
-    void probing_path(boost::filesystem::path const& path) override;
-    void probing_failed(boost::filesystem::path const& path, std::exception const& error) override;
-    void loading_library(boost::filesystem::path const& filename) override;
-    void loading_failed(boost::filesystem::path const& filename, std::exception const& error) override;
+    void probing_path(std::filesystem::path const& path) override;
+    void probing_failed(std::filesystem::path const& path, std::exception const& error) override;
+    void loading_library(std::filesystem::path const& filename) override;
+    void loading_failed(std::filesystem::path const& filename, std::exception const& error) override;
 
 private:
     ServerTracepointProvider tp_provider;
