@@ -18,7 +18,7 @@
 #ifndef MIR_REPORT_NULL_INPUT_REPORT_H_
 #define MIR_REPORT_NULL_INPUT_REPORT_H_
 
-#include "mir/input/input_report.h"
+#include <mir/input/input_report.h>
 
 namespace mir
 {
