@@ -14,23 +14,23 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/run_mir.h"
-#include "mir/terminate_with_current_exception.h"
-#include "mir/display_server.h"
-#include "mir/fatal.h"
-#include "mir/main_loop.h"
-#include "mir/server_configuration.h"
-#include "mir/frontend/connector.h"
-#include "mir/raii.h"
-#include "mir/emergency_cleanup.h"
-#include "mir/executor.h"
+#include <mir/run_mir.h>
+#include <mir/terminate_with_current_exception.h>
+#include <mir/display_server.h>
+#include <mir/fatal.h>
+#include <mir/main_loop.h>
+#include <mir/server_configuration.h>
+#include <mir/frontend/connector.h>
+#include <mir/raii.h>
+#include <mir/emergency_cleanup.h>
+#include <mir/executor.h>
 
 #include <atomic>
 #include <mutex>
 #include <csignal>
-#include <cassert>
 #include <unistd.h>
 #include <boost/throw_exception.hpp>
+#include <errno.h>
 
 namespace
 {
@@ -162,6 +162,26 @@ extern "C" [[noreturn]] void fatal_signal_cleanup(int sig, siginfo_t* info, void
         constexpr size_t len = std::char_traits<char>::length(warning);
         [[maybe_unused]]auto n = write(STDERR_FILENO, warning, len);
     }
+
+    // Log a security event
+    char security_head[] = "{\"datetime\": \"YYYY-MM-DDThh:mm:ssZ";
+    char security_mid[]  = "\", \"appid\": \"";
+    char security_tail[] = "\", \"event\": \"crash\", \"description\": \"Fatal signal received\"}\n";
+    std::time_t time = std::time(nullptr);
+    // strftime isn't listed as async-signal-safe, but neither "%F" or "%T" use locale information
+    [[maybe_unused]]auto n = std::strftime(security_head + 14, 21, "%FT%TZ", std::gmtime(&time));
+    n = write(STDERR_FILENO, security_head, sizeof(security_head) - 1);
+    n = write(STDERR_FILENO, security_mid, sizeof(security_mid) - 1);
+    if (program_invocation_short_name)
+    {
+        n = write(STDERR_FILENO, program_invocation_short_name, std::strlen(program_invocation_short_name));
+    }
+    else
+    {
+        n = write(STDERR_FILENO, "<unknown>", 9);
+    }
+    n = write(STDERR_FILENO, security_tail, sizeof(security_tail) - 1);
+
     perform_emergency_cleanup();
 
     auto const old_handler = old_handlers.at(sig);
@@ -206,11 +226,12 @@ void mir::run_mir(
         terminator_ :
         [&server_ptr](int)
         {
-          assert(server_ptr);
-          server_ptr->stop();
+            if (!server_ptr)
+                fatal_error_abort("Logic error in mir::run_mir() server_ptr is nullptr");
+            server_ptr->stop();
         };
 
-    struct sigaction old_action;
+    struct sigaction old_action{};
     if ((sigaction(SIGHUP, nullptr, &old_action) == 0) && (old_action.sa_handler == SIG_IGN))
     {
         // If our parent process is ignoring SIGHUP (e.g. is nohup) then we do the same
@@ -237,7 +258,7 @@ void mir::run_mir(
             {
                 for (auto sig : fatal_error_signals)
                 {
-                    struct sigaction sig_handler_desc;
+                    struct sigaction sig_handler_desc{};
                     sigfillset(&sig_handler_desc.sa_mask);
                     sig_handler_desc.sa_flags = SA_SIGINFO;
                     sig_handler_desc.sa_sigaction = &fatal_signal_cleanup;
