@@ -16,33 +16,26 @@
 
 #include "application_session.h"
 
-#include "mir/scene/surface.h"
-#include "mir/scene/session_container.h"
-#include "mir/scene/session_listener.h"
-#include "mir/scene/surface_factory.h"
-#include "mir/shell/surface_stack.h"
-#include "mir/shell/surface_specification.h"
-#include "mir/compositor/stream.h"
-#include "mir/events/event_builders.h"
-#include "mir/frontend/event_sink.h"
-#include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/scene/surface_observer.h"
+#include <mir/scene/surface.h>
+#include <mir/scene/session_container.h>
+#include <mir/scene/session_listener.h>
+#include <mir/scene/surface_factory.h>
+#include <mir/shell/surface_stack.h>
+#include <mir/shell/surface_specification.h>
+#include <mir/compositor/stream.h>
+#include <mir/graphics/graphic_buffer_allocator.h>
+#include <mir/scene/surface_observer.h>
 
 #include <boost/throw_exception.hpp>
 
 #include <stdexcept>
 #include <memory>
-#include <cassert>
 #include <algorithm>
-#include <cstring>
 
-namespace mf = mir::frontend;
 namespace ms = mir::scene;
 namespace msh = mir::shell;
 namespace mg = mir::graphics;
-namespace mev = mir::events;
 namespace mc = mir::compositor;
-namespace geom = mir::geometry;
 
 ms::ApplicationSession::ApplicationSession(
     std::shared_ptr<msh::SurfaceStack> const& surface_stack,
@@ -51,7 +44,6 @@ ms::ApplicationSession::ApplicationSession(
     Fd socket_fd,
     std::string const& session_name,
     std::shared_ptr<SessionListener> const& session_listener,
-    std::shared_ptr<mf::EventSink> const& sink,
     std::shared_ptr<graphics::GraphicBufferAllocator> const& gralloc) :
     surface_stack(surface_stack),
     surface_factory(surface_factory),
@@ -59,7 +51,6 @@ ms::ApplicationSession::ApplicationSession(
     socket_fd_(socket_fd),
     session_name(session_name),
     session_listener(session_listener),
-    event_sink(sink),
     gralloc(gralloc)
 {
     assert(surface_stack);
@@ -77,7 +68,6 @@ ms::ApplicationSession::~ApplicationSession()
 
 auto ms::ApplicationSession::create_surface(
     std::shared_ptr<Session> const& session,
-    wayland::Weak<frontend::WlSurface> const& wayland_surface,
     shell::SurfaceSpecification const& the_params,
     std::shared_ptr<ms::SurfaceObserver> const& observer,
     Executor* observer_executor) -> std::shared_ptr<Surface>
@@ -97,13 +87,13 @@ auto ms::ApplicationSession::create_surface(
     std::shared_ptr<mc::BufferStream> const buffer_stream =
         std::dynamic_pointer_cast<mc::BufferStream>(params.streams.value()[0].stream.lock());
 
-    std::list<StreamInfo> streams;
+    std::list<StreamInfo> stream_list;
     for (auto& stream : params.streams.value())
     {
-        streams.push_back({std::dynamic_pointer_cast<mc::BufferStream>(stream.stream.lock()), stream.displacement});
+        stream_list.push_back({std::dynamic_pointer_cast<mc::BufferStream>(stream.stream.lock()), stream.displacement});
     }
 
-    auto surface = surface_factory->create_surface(session, wayland_surface, streams, params);
+    auto surface = surface_factory->create_surface(session, stream_list, params);
 
     auto const input_mode = params.input_mode.is_set() ? params.input_mode.value() : input::InputReceptionMode::normal;
     surface_stack->add_surface(surface, input_mode);
@@ -144,6 +134,8 @@ auto ms::ApplicationSession::create_surface(
         surface->set_focus_mode(params.focus_mode.value());
     if (params.visible_on_lock_screen.is_set())
         surface->set_visible_on_lock_screen(params.visible_on_lock_screen.value());
+    if (params.tiled_edges.is_set())
+        surface->set_tiled_edges(params.tiled_edges.value());
 
     return surface;
 }
@@ -256,30 +248,16 @@ void ms::ApplicationSession::show()
     }
 }
 
-void ms::ApplicationSession::send_input_config(MirInputConfig const& config)
-{
-    event_sink->handle_input_config_change(config);
-}
-
-void ms::ApplicationSession::set_lifecycle_state(MirLifecycleState state)
-{
-    event_sink->handle_lifecycle_event(state);
-}
-
 void ms::ApplicationSession::start_prompt_session()
 {
-    // All sessions which are part of the prompt session get this event.
-    event_sink->handle_event(mev::make_prompt_session_state_event(mir_prompt_session_state_started));
 }
 
 void ms::ApplicationSession::stop_prompt_session()
 {
-    event_sink->handle_event(mev::make_prompt_session_state_event(mir_prompt_session_state_stopped));
 }
 
 void ms::ApplicationSession::suspend_prompt_session()
 {
-    event_sink->handle_event(mev::make_prompt_session_state_event(mir_prompt_session_state_suspended));
 }
 
 void ms::ApplicationSession::resume_prompt_session()
@@ -310,15 +288,15 @@ void ms::ApplicationSession::destroy_buffer_stream(std::shared_ptr<frontend::Buf
 }
 
 void ms::ApplicationSession::configure_streams(
-    ms::Surface& surface, std::vector<shell::StreamSpecification> const& streams)
+    ms::Surface& surface, std::vector<shell::StreamSpecification> const& stream_specs)
 {
     std::list<ms::StreamInfo> list;
-    for (auto& stream : streams)
+    for (auto& stream : stream_specs)
     {
         if (auto const s = std::dynamic_pointer_cast<mc::BufferStream>(stream.stream.lock()))
             list.emplace_back(ms::StreamInfo{s, stream.displacement});
     }
-    surface.set_streams(list); 
+    surface.set_streams(list);
 }
 
 auto ms::ApplicationSession::has_buffer_stream(
@@ -326,8 +304,3 @@ auto ms::ApplicationSession::has_buffer_stream(
 {
     return streams.find(stream) != streams.end();
 }
-
-void ms::ApplicationSession::send_error(mir::ClientVisibleError const& error)
-{
-    event_sink->handle_error(error);
-}
