@@ -15,12 +15,12 @@
  */
 
 #include "basic_idle_hub.h"
-#include "mir/time/alarm.h"
-#include "mir/time/alarm_factory.h"
-#include "mir/time/clock.h"
-#include "mir/lockable_callback.h"
-#include "mir/executor.h"
-#include "mir/fatal.h"
+#include <mir/time/alarm.h>
+#include <mir/time/alarm_factory.h>
+#include <mir/time/clock.h>
+#include <mir/lockable_callback.h>
+#include <mir/executor.h>
+#include <mir/fatal.h>
 
 #include <set>
 
