@@ -14,18 +14,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "basic_surface.h"
-#include "mir/compositor/buffer_stream.h"
-#include "mir/frontend/event_sink.h"
-#include "mir/graphics/buffer.h"
-#include "mir/graphics/cursor_image.h"
-#include "mir/graphics/null_display_configuration_observer.h"
-#include "mir/geometry/displacement.h"
-#include "mir/renderer/sw/pixel_source.h"
-#include "mir/observer_multiplexer.h"
-#include "mir/scene/surface_observer.h"
+#include <mir/scene/basic_surface.h>
+#include <mir/compositor/buffer_stream.h>
+#include <mir/frontend/event_sink.h>
+#include <mir/graphics/buffer.h>
+#include <mir/graphics/cursor_image.h>
+#include <mir/graphics/null_display_configuration_observer.h>
+#include <mir/geometry/displacement.h>
+#include <mir/renderer/sw/pixel_source.h>
+#include <mir/observer_multiplexer.h>
+#include <mir/scene/surface_observer.h>
 
-#include "mir/scene/scene_report.h"
+#include <mir/scene/scene_report.h>
 
 #include <boost/throw_exception.hpp>
 
@@ -110,6 +110,11 @@ public:
         for_each_observer(&SurfaceObserver::orientation_set_to, surf, orientation);
     }
 
+    void mirror_mode_set_to(Surface const* surf, MirMirrorMode mirror_mode) override
+    {
+        for_each_observer(&SurfaceObserver::mirror_mode_set_to, surf, mirror_mode);
+    }
+
     void transformation_set_to(Surface const* surf, glm::mat4 const& t) override
     {
         for_each_observer(&SurfaceObserver::transformation_set_to, surf, t);
@@ -174,25 +179,14 @@ public:
     {
         for_each_observer(&SurfaceObserver::rescale_output, surf, id);
     }
+
+    void tiled_edges(Surface const* surf, Flags<MirTiledEdge> edges) override
+    {
+        for_each_observer(&SurfaceObserver::tiled_edges, surf, edges);
+    }
 };
 
-namespace
-{
-//TODO: the concept of default stream is going away very soon.
-std::shared_ptr<mc::BufferStream> default_stream(std::list<ms::StreamInfo> const& layers)
-{
-    //There's not a good reason, other than soon-to-be-deprecated api to disallow contentless surfaces
-    if (layers.empty())
-        BOOST_THROW_EXCEPTION(std::logic_error("Surface must have content"));
-    else
-        return layers.front().stream;
-}
-
-}
-
 ms::BasicSurface::BasicSurface(
-    std::shared_ptr<Session> const& session,
-    mw::Weak<frontend::WlSurface> wayland_surface,
     std::string const& name,
     geometry::Rectangle rect,
     std::weak_ptr<Surface> const& parent,
@@ -215,11 +209,8 @@ ms::BasicSurface::BasicSurface(
         }
     },
     observers(std::make_shared<Multiplexer>()),
-    session_{session},
-    surface_buffer_stream(default_stream(layers)),
     report(report),
     parent_(parent),
-    wayland_surface_{wayland_surface},
     display_config_registrar{display_config_registrar},
     display_config_monitor{std::make_shared<DisplayConfigurationEarlyListener>(this)}
 {
@@ -230,8 +221,6 @@ ms::BasicSurface::BasicSurface(
 }
 
 ms::BasicSurface::BasicSurface(
-    std::shared_ptr<Session> const& session,
-    mw::Weak<frontend::WlSurface> wayland_surface,
     std::string const& name,
     geometry::Rectangle rect,
     MirPointerConfinementState state,
@@ -240,8 +229,6 @@ ms::BasicSurface::BasicSurface(
     std::shared_ptr<SceneReport> const& report,
     std::shared_ptr<ObserverRegistrar<graphics::DisplayConfigurationObserver>> const& display_config_registrar) :
     BasicSurface(
-        session,
-        wayland_surface,
         name,
         rect,
         std::shared_ptr<Surface>{nullptr},
@@ -320,12 +307,6 @@ mir::geometry::Size ms::BasicSurface::content_size() const
     return content_size(*synchronised_state.lock());
 }
 
-std::shared_ptr<mf::BufferStream> ms::BasicSurface::primary_buffer_stream() const
-{
-    // Doesn't lock the mutex because surface_buffer_stream is const
-    return surface_buffer_stream;
-}
-
 void ms::BasicSurface::set_input_region(std::vector<geom::Rectangle> const& input_rectangles)
 {
     synchronised_state.lock()->custom_input_rectangles = input_rectangles;
@@ -337,6 +318,11 @@ std::vector<geom::Rectangle> ms::BasicSurface::get_input_region() const
     return state->custom_input_rectangles;
 }
 
+void ms::BasicSurface::set_opaque_region(geom::Rectangles const& region)
+{
+    synchronised_state.lock()->opaque_region = region;
+}
+
 void ms::BasicSurface::resize(geom::Size const& desired_size)
 {
     geom::Size new_size = desired_size;
@@ -384,17 +370,63 @@ bool ms::BasicSurface::input_area_contains(geom::Point const& point) const
 
     if (state->custom_input_rectangles.empty())
     {
-        // no custom input, restrict to bounding rectangle
+        // The surface has no custom input, so it is restricted to its bounding rectangle.
+        // Note that the "content_size" returned here is already oriented properly, so the
+        // width and height do NOT need to be swapped, unlike the custom input rectangles
+        // case.
         auto const input_rect = geom::Rectangle{content_top_left(*state), content_size(*state)};
         return input_rect.contains(point);
     }
     else
     {
-        auto local_point = as_point(point - content_top_left(*state));
+        auto const local_point = as_point(point - content_top_left(*state));
         for (auto const& rectangle : state->custom_input_rectangles)
         {
-            if (rectangle.contains(local_point))
-                return true;
+            // Note that this size is already rotated according to the orientation, so the
+            // width and height do not need to be swapped.
+            auto const& surface_size = state->surface_rect.size;
+
+            // When a surface is rendered with an orientation, it is unrotated so that it appears
+            // upright. The input region that the surface provides is given in surface-local coordinates
+            // meaning that it will need to be rotated to match up with the surface.
+            switch (state->orientation)
+            {
+            case mir_orientation_left:
+            {
+                auto rotated_rect = rectangle;
+                rotated_rect.top_left.x = geom::X(rectangle.top_left.y.as_value());
+                rotated_rect.top_left.y = geom::Y(surface_size.height.as_value() - rectangle.top_left.x.as_value() - rectangle.size.width.as_value());
+                rotated_rect.size.width = geom::Width(rectangle.size.height.as_value());
+                rotated_rect.size.height = geom::Height(rectangle.size.width.as_value());
+                if (rotated_rect.contains(local_point))
+                    return true;
+                break;
+            }
+            case mir_orientation_right:
+            {
+                auto rotated_rect = rectangle;
+                rotated_rect.top_left.x = geom::X(surface_size.width.as_value() - rectangle.top_left.y.as_value() - rectangle.size.height.as_value());
+                rotated_rect.top_left.y = geom::Y(rectangle.top_left.x.as_value());
+                rotated_rect.size.width = geom::Width(rectangle.size.height.as_value());
+                rotated_rect.size.height = geom::Height(rectangle.size.width.as_value());
+                if (rotated_rect.contains(local_point))
+                    return true;
+                break;
+            }
+            case mir_orientation_inverted:
+            {
+                auto rotated_rect = rectangle;
+                rotated_rect.top_left.x = geom::X(surface_size.width.as_value() - rectangle.top_left.x.as_value() - rectangle.size.width.as_value());
+                rotated_rect.top_left.y = geom::Y(surface_size.height.as_value() - rectangle.top_left.y.as_value() - rectangle.size.height.as_value());
+                if (rotated_rect.contains(local_point))
+                    return true;
+                break;
+            }
+            default:
+                if (rectangle.contains(local_point))
+                    return true;
+                break;
+            }
         }
     }
     return false;
@@ -408,9 +440,16 @@ void ms::BasicSurface::set_alpha(float alpha)
 
 void ms::BasicSurface::set_orientation(MirOrientation orientation)
 {
+    synchronised_state.lock()->orientation = orientation;
     observers->orientation_set_to(this, orientation);
 }
 
+void ms::BasicSurface::set_mirror_mode(MirMirrorMode mirror_mode)
+{
+    synchronised_state.lock()->mirror_mode = mirror_mode;
+    observers->mirror_mode_set_to(this, mirror_mode);
+}
+
 void ms::BasicSurface::set_transformation(glm::mat4 const& t)
 {
     synchronised_state.lock()->transformation_matrix = t;
@@ -598,7 +637,7 @@ struct CursorImageFromBuffer : public mg::CursorImage
     CursorImageFromBuffer(
         std::shared_ptr<mg::Buffer> buffer,
         geom::Displacement const& hotspot)
-        : buffer{mrs::as_read_mappable_buffer(std::move(buffer))},
+        : buffer{std::move(buffer)},
           mapping{this->buffer->map_readable()},
           hotspot_(hotspot)
     {
@@ -618,8 +657,8 @@ struct CursorImageFromBuffer : public mg::CursorImage
         return hotspot_;
     }
 
-    std::shared_ptr<mrs::ReadMappableBuffer> const buffer;
-    std::unique_ptr<mrs::Mapping<unsigned char const>> const mapping;
+    std::shared_ptr<mg::Buffer> const buffer;
+    std::unique_ptr<mrs::Mapping<std::byte const>> mapping;
     geom::Displacement const hotspot_;
 };
 }
@@ -633,11 +672,6 @@ void ms::BasicSurface::set_cursor_from_buffer(
     observers->cursor_image_set_to(this, image);
 }
 
-auto ms::BasicSurface::wayland_surface() -> mw::Weak<mf::WlSurface> const&
-{
-    return wayland_surface_;
-}
-
 void ms::BasicSurface::request_client_surface_close()
 {
     observers->client_surface_close_requested(this);
@@ -695,6 +729,26 @@ std::shared_ptr<ms::Surface> ms::BasicSurface::parent() const
 
 namespace
 {
+auto translate_opaque_region(
+    std::optional<mir::geometry::Rectangles> const& opaque_region, geom::Displacement translation)
+    -> std::optional<mir::geometry::Rectangles>
+{
+    return opaque_region.transform(
+        [&translation](auto const r)
+        {
+            auto region = geom::Rectangles{};
+            for (auto const& subregion : r)
+            {
+                auto const translated_top_left = geom::Point{
+                    subregion.top_left.x + translation.dx,
+                    subregion.top_left.y + translation.dy,
+                };
+                region.add(geom::Rectangle{translated_top_left, subregion.size});
+            }
+
+            return region;
+        });
+}
 //This class avoids locking for long periods of time by copying (or lazy-copying)
 class SurfaceSnapshot : public mg::Renderable
 {
@@ -704,16 +758,23 @@ public:
         geom::Point top_left,
         std::optional<geom::Rectangle> const& clip_area,
         glm::mat4 const& transform,
+        MirOrientation orientation,
+        MirMirrorMode mirror_mode,
         float alpha,
         mg::Renderable::ID id,
-        ms::Surface const* surface)
-    : entry{std::move(buffer)},
-      alpha_{alpha},
-      screen_position_{top_left, entry->size()},
-      clip_area_{clip_area},
-      transformation_{transform},
-      id_{id},
-      surface{surface}
+        ms::Surface const* surface,
+        std::optional<geom::Rectangles> opaque_region) :
+        entry{std::move(buffer)},
+        alpha_{alpha},
+        screen_position_{top_left, entry->size()},
+        clip_area_{clip_area},
+        transformation_{transform},
+        orientation_{orientation},
+        mirror_mode_{mirror_mode},
+        id_{id},
+        surface{surface},
+        opaque_region_{translate_opaque_region(
+            opaque_region, mir::geometry::generic::as_displacement(screen_position_.top_left))}
     {
     }
 
@@ -741,6 +802,12 @@ public:
     glm::mat4 transformation() const override
     { return transformation_; }
 
+    MirOrientation orientation() const override
+    { return orientation_; }
+
+    MirMirrorMode mirror_mode() const override
+    { return mirror_mode_; }
+
     bool shaped() const override
     {
         return entry->pixel_format().info().transform([](auto info) { return info.has_alpha();}).value_or(true);
@@ -753,14 +820,23 @@ public:
     {
         return surface;
     }
+
+    std::optional<geom::Rectangles> opaque_region() const override
+    {
+        return opaque_region_;
+    }
+
 private:
     std::shared_ptr<mc::BufferStream::Submission> const entry;
     float const alpha_;
     geom::Rectangle const screen_position_;
     std::optional<geom::Rectangle> const clip_area_;
     glm::mat4 const transformation_;
+    MirOrientation orientation_;
+    MirMirrorMode mirror_mode_;
     mg::Renderable::ID const id_;
     ms::Surface const* surface;
+    std::optional<geom::Rectangles> const opaque_region_;
 };
 }
 
@@ -782,7 +858,12 @@ void ms::BasicSurface::rename(std::string const& title)
     }
 }
 
-void ms::BasicSurface::set_streams(std::list<scene::StreamInfo> const& s)
+std::list<ms::StreamInfo> ms::BasicSurface::get_streams() const
+{
+    return synchronised_state.lock()->layers;
+}
+
+void ms::BasicSurface::set_streams(std::list<StreamInfo> const& s)
 {
     geom::Point surface_top_left;
     {
@@ -817,9 +898,12 @@ mg::RenderableList ms::BasicSurface::generate_renderables(mc::CompositorID id) c
                 content_top_left_ + info.displacement,
                 state->clip_area,
                 state->transformation_matrix,
+                state->orientation,
+                state->mirror_mode,
                 state->surface_alpha,
                 info.stream.get(),
-                this));
+                this,
+                state->opaque_region));
         }
     }
     return list;
@@ -914,7 +998,7 @@ void mir::scene::BasicSurface::set_application_id(std::string const& application
 
 auto mir::scene::BasicSurface::session() const -> std::weak_ptr<Session>
 {
-    return session_;
+    return {};
 }
 
 void mir::scene::BasicSurface::set_window_margins(
@@ -959,6 +1043,95 @@ void mir::scene::BasicSurface::set_focus_mode(MirFocusMode focus_mode)
     synchronised_state.lock()->focus_mode = focus_mode;
 }
 
+auto mir::scene::BasicSurface::tiled_edges() const -> Flags<MirTiledEdge>
+{
+    return synchronised_state.lock()->tiled_edges;
+}
+
+void mir::scene::BasicSurface::set_tiled_edges(Flags<MirTiledEdge> edges)
+{
+    synchronised_state.lock()->tiled_edges = edges;
+    observers->tiled_edges(this, edges);
+}
+
+auto mir::scene::BasicSurface::min_width() const -> geometry::Width
+{
+    auto state = synchronised_state.lock();
+    return state->min_width + state->margins.left + state->margins.right;
+}
+
+auto mir::scene::BasicSurface::max_width() const -> geometry::Width
+{
+    auto state = synchronised_state.lock();
+    if (state->max_width < geom::Width{std::numeric_limits<int>::max()} - state->margins.left - state->margins.right)
+    {
+        return state->max_width + state->margins.left + state->margins.right;
+    }
+    else
+    {
+        return geom::Width{std::numeric_limits<int>::max()};
+    }
+}
+
+auto mir::scene::BasicSurface::min_height() const -> geometry::Height
+{
+    auto state = synchronised_state.lock();
+    return state->min_height + state->margins.top + state->margins.bottom;
+}
+
+auto mir::scene::BasicSurface::max_height() const -> geometry::Height
+{
+    auto state = synchronised_state.lock();
+    if (state->max_height < geom::Height{std::numeric_limits<int>::max()} - state->margins.top - state->margins.bottom)
+    {
+        return state->max_height + state->margins.top + state->margins.bottom;
+    }
+    else
+    {
+        return geom::Height{std::numeric_limits<int>::max()};
+    }
+}
+
+void mir::scene::BasicSurface::set_min_width(geometry::Width width)
+{
+    auto state = synchronised_state.lock();
+    state->min_width = std::max(geom::Width{0}, width - state->margins.left - state->margins.right);
+}
+
+void mir::scene::BasicSurface::set_max_width(geometry::Width width)
+{
+    auto state = synchronised_state.lock();
+
+    if (width < geom::Width{std::numeric_limits<int>::max()} - state->margins.left - state->margins.right)
+    {
+        state->max_width = width - state->margins.left - state->margins.right;
+    }
+    else
+    {
+        state->max_width = geom::Width{std::numeric_limits<int>::max()};
+    }
+}
+
+void mir::scene::BasicSurface::set_min_height(geometry::Height height)
+{
+    auto state = synchronised_state.lock();
+    state->min_height = std::max(geom::Height{0}, height - state->margins.top - state->margins.bottom);
+}
+
+void mir::scene::BasicSurface::set_max_height(geometry::Height height)
+{
+    auto state = synchronised_state.lock();
+
+    if (height < geom::Height{std::numeric_limits<int>::max()} - state->margins.top - state->margins.bottom)
+    {
+        state->max_height = height - state->margins.top - state->margins.bottom;
+    }
+    else
+    {
+        state->max_height = geom::Height{std::numeric_limits<int>::max()};
+    }
+}
+
 void mir::scene::BasicSurface::clear_frame_posted_callbacks(State& state)
 {
     for (auto& layer : state.layers)
