@@ -14,17 +14,18 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/default_server_configuration.h"
+#include <mir/default_server_configuration.h>
 
-#include "mir/frontend/drag_icon_controller.h"
-#include "mir/graphics/display.h"
-#include "mir/input/cursor_listener.h"
-#include "mir/input/scene.h"
-#include "mir/main_loop.h"
-#include "mir/renderer/gl/context.h"
-#include "mir/scene/session.h"
-#include "mir/scene/session_container.h"
-#include "mir/shell/display_configuration_controller.h"
+#include <mir/frontend/drag_icon_controller.h>
+#include <mir/graphics/display.h>
+#include <mir/input/cursor_observer.h>
+#include <mir/input/scene.h>
+#include <mir/input/cursor_controller.h>
+#include <mir/main_loop.h>
+#include <mir/renderer/gl/context.h>
+#include <mir/scene/session.h>
+#include <mir/scene/session_container.h>
+#include <mir/shell/display_configuration_controller.h>
 
 #include "broadcasting_session_event_sink.h"
 #include "mediating_display_changer.h"
@@ -32,12 +33,11 @@
 #include "surface_allocator.h"
 #include "surface_stack.h"
 #include "prompt_session_manager_impl.h"
-#include "timeout_application_not_responding_detector.h"
 #include "basic_clipboard.h"
 #include "basic_text_input_hub.h"
 #include "basic_idle_hub.h"
-#include "mir/options/default_configuration.h"
-#include "mir/frontend/display_changer.h"
+#include <mir/options/default_configuration.h>
+#include <mir/frontend/display_changer.h>
 
 namespace mc = mir::compositor;
 namespace mf = mir::frontend;
@@ -157,7 +157,7 @@ mir::DefaultServerConfiguration::the_frontend_display_changer()
 std::shared_ptr<mf::DragIconController> mir::DefaultServerConfiguration::the_drag_icon_controller()
 {
     return drag_icon_controller(
-        [this] { return std::dynamic_pointer_cast<mf::DragIconController>(the_cursor_listener()); });
+        [this] { return std::dynamic_pointer_cast<mf::DragIconController>(the_cursor_controller()); });
 }
 
 std::shared_ptr<mir::DisplayChanger>
@@ -179,7 +179,6 @@ mir::DefaultServerConfiguration::the_session_coordinator()
                 the_session_event_sink(),
                 the_session_listener(),
                 the_display(),
-                the_application_not_responding_detector(),
                 the_buffer_allocator(),
                 the_display_configuration_observer_registrar());
         });
@@ -237,26 +236,6 @@ auto mir::DefaultServerConfiguration::the_idle_hub()
         });
 }
 
-auto mir::DefaultServerConfiguration::the_application_not_responding_detector()
--> std::shared_ptr<scene::ApplicationNotRespondingDetector>
-{
-    return application_not_responding_detector(
-        [this]() -> std::shared_ptr<scene::ApplicationNotRespondingDetector>
-        {
-            using namespace std::literals::chrono_literals;
-            return wrap_application_not_responding_detector(
-                std::make_shared<ms::TimeoutApplicationNotRespondingDetector>(
-                    *the_main_loop(), 1s));
-        });
-}
-
-auto mir::DefaultServerConfiguration::wrap_application_not_responding_detector(
-    std::shared_ptr<scene::ApplicationNotRespondingDetector> const& wrapped)
-        -> std::shared_ptr<scene::ApplicationNotRespondingDetector>
-{
-    return wrapped;
-}
-
 std::shared_ptr<msh::DisplayConfigurationController>
 mir::DefaultServerConfiguration::the_display_configuration_controller()
 {
