@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/scene/null_surface_observer.h"
+#include <mir/scene/null_surface_observer.h>
 
 namespace ms = mir::scene;
 namespace mg = mir::graphics;
@@ -27,6 +27,7 @@ void ms::NullSurfaceObserver::hidden_set_to(Surface const*, bool) {}
 void ms::NullSurfaceObserver::frame_posted(Surface const*, geometry::Rectangle const&) {}
 void ms::NullSurfaceObserver::alpha_set_to(Surface const*, float) {}
 void ms::NullSurfaceObserver::orientation_set_to(Surface const*, MirOrientation) {}
+void ms::NullSurfaceObserver::mirror_mode_set_to(Surface const*, MirMirrorMode) {}
 void ms::NullSurfaceObserver::transformation_set_to(Surface const*, glm::mat4 const&) {}
 void ms::NullSurfaceObserver::reception_mode_set_to(Surface const*, input::InputReceptionMode) {}
 void ms::NullSurfaceObserver::cursor_image_set_to(Surface const*, std::weak_ptr<mg::CursorImage> const&) {}
@@ -40,3 +41,4 @@ void ms::NullSurfaceObserver::application_id_set_to(Surface const*, std::string
 void ms::NullSurfaceObserver::entered_output(Surface const*, graphics::DisplayConfigurationOutputId const&) {}
 void ms::NullSurfaceObserver::left_output(Surface const*, graphics::DisplayConfigurationOutputId const&) {}
 void ms::NullSurfaceObserver::rescale_output(Surface const*, graphics::DisplayConfigurationOutputId const&){}
+void ms::NullSurfaceObserver::tiled_edges(Surface const*, Flags<MirTiledEdge>) {}
