@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -16,10 +16,10 @@
 
 #include "prompt_session_manager_impl.h"
 
-#include "mir/scene/prompt_session_creation_parameters.h"
-#include "mir/scene/prompt_session_listener.h"
-#include "mir/scene/session.h"
-#include "mir/scene/session_container.h"
+#include <mir/scene/prompt_session_creation_parameters.h>
+#include <mir/scene/prompt_session_listener.h>
+#include <mir/scene/session.h>
+#include <mir/scene/session_container.h>
 #include "prompt_session_container.h"
 #include "prompt_session_impl.h"
 
