@@ -16,9 +16,9 @@
 
 #include "surface_change_notification.h"
 
-#include "mir/scene/scene_change_notification.h"
-#include "mir/scene/surface.h"
-#include "mir/geometry/displacement.h"
+#include <mir/scene/scene_change_notification.h>
+#include <mir/scene/surface.h>
+#include <mir/geometry/displacement.h>
 
 #include <boost/throw_exception.hpp>
 
@@ -67,7 +67,7 @@ void ms::SceneChangeNotification::surface_exists(std::shared_ptr<ms::Surface> co
 {
     add_surface_observer(surface.get());
 }
-    
+
 void ms::SceneChangeNotification::surface_removed(std::shared_ptr<ms::Surface> const& surface)
 {
     {
