@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/scene/session_container.h"
+#include <mir/scene/session_container.h>
 
 #include <boost/throw_exception.hpp>
 
@@ -104,4 +104,4 @@ auto mir::scene::SessionContainer::predecessor_of(std::shared_ptr<Session> const
     }
 
     BOOST_THROW_EXCEPTION(std::logic_error("Invalid session"));
-}
\ No newline at end of file
+}
