@@ -16,17 +16,16 @@
 
 #include "session_manager.h"
 #include "application_session.h"
-#include "mir/scene/session_container.h"
-#include "mir/scene/surface.h"
-#include "mir/scene/session.h"
-#include "mir/scene/session_listener.h"
-#include "mir/scene/application_not_responding_detector.h"
-#include "mir/shell/surface_stack.h"
-#include "mir/scene/session_event_sink.h"
-#include "mir/frontend/event_sink.h"
-#include "mir/graphics/display.h"
-#include "mir/graphics/display_configuration.h"
-#include "mir/observer_multiplexer.h"
+#include <mir/scene/session_container.h>
+#include <mir/scene/surface.h>
+#include <mir/scene/session.h>
+#include <mir/scene/session_listener.h>
+#include <mir/scene/application_not_responding_detector.h>
+#include <mir/shell/surface_stack.h>
+#include <mir/scene/session_event_sink.h>
+#include <mir/graphics/display.h>
+#include <mir/graphics/display_configuration.h>
+#include <mir/observer_multiplexer.h>
 
 #include <boost/throw_exception.hpp>
 
@@ -87,7 +86,6 @@ ms::SessionManager::SessionManager(
     std::shared_ptr<SessionEventSink> const& session_event_sink,
     std::shared_ptr<SessionListener> const& session_listener,
     std::shared_ptr<graphics::Display const> const& display,
-    std::shared_ptr<ApplicationNotRespondingDetector> const& anr_detector,
     std::shared_ptr<graphics::GraphicBufferAllocator> const& allocator,
     std::shared_ptr<ObserverRegistrar<graphics::DisplayConfigurationObserver>> const& display_config_registrar) :
     observers(std::make_shared<SessionObservers>()),
@@ -97,7 +95,6 @@ ms::SessionManager::SessionManager(
     session_event_sink(session_event_sink),
     session_listener(session_listener),
     display{display},
-    anr_detector{anr_detector},
     allocator{allocator},
     display_config_registrar{display_config_registrar}
 {
@@ -127,8 +124,7 @@ ms::SessionManager::~SessionManager() noexcept
 std::shared_ptr<ms::Session> ms::SessionManager::open_session(
     pid_t client_pid,
     Fd socket_fd,
-    std::string const& name,
-    std::shared_ptr<mf::EventSink> const& sender)
+    std::string const& name)
 {
     std::shared_ptr<Session> new_session = std::make_shared<ApplicationSession>(
         surface_stack,
@@ -137,18 +133,12 @@ std::shared_ptr<ms::Session> ms::SessionManager::open_session(
         socket_fd,
         name,
         observers,
-        sender,
         allocator);
 
     app_container->insert_session(new_session);
 
     observers->starting(new_session);
 
-    anr_detector->register_session(new_session.get(), [sender]()
-    {
-        sender->send_ping(0);
-    });
-
     return new_session;
 }
 
@@ -166,8 +156,6 @@ void ms::SessionManager::unset_focus()
 
 void ms::SessionManager::close_session(std::shared_ptr<Session> const& session)
 {
-    anr_detector->unregister_session(session.get());
-
     session_event_sink->handle_session_stopping(session);
 
     observers->stopping(session);
