@@ -17,18 +17,18 @@
 #ifndef MIR_SCENE_SURFACE_STACK_H_
 #define MIR_SCENE_SURFACE_STACK_H_
 
-#include "mir/shell/surface_stack.h"
-#include "mir/frontend/surface_stack.h"
+#include <mir/shell/surface_stack.h>
+#include <mir/frontend/surface_stack.h>
 
-#include "mir/compositor/scene.h"
-#include "mir/scene/observer.h"
-#include "mir/input/scene.h"
-#include "mir/recursive_read_write_mutex.h"
-#include "mir/scene/session_lock.h"
+#include <mir/compositor/scene.h>
+#include <mir/scene/observer.h>
+#include <mir/input/scene.h>
+#include <mir/recursive_read_write_mutex.h>
+#include <mir/scene/session_lock.h>
 
-#include "mir/basic_observers.h"
-#include "mir/scene/surface_observer.h"
-#include "mir/observer_multiplexer.h"
+#include <mir/basic_observers.h>
+#include <mir/scene/surface_observer.h>
+#include <mir/observer_multiplexer.h>
 
 #include <atomic>
 #include <map>
@@ -154,6 +154,13 @@ private:
      * The inner vectors contain the list of surfaces on each layer (bottom to top)
      */
     std::vector<std::vector<std::shared_ptr<Surface>>> surface_layers;
+
+    /// Surface focus order that's maintained parallel to [surface_layers]. Whereas [surface_layers]
+    /// provides a model of how the surface will be rendered into a scene, this list provides
+    /// the relative focus order of surfaces, with the most-recently focused surfaces appearing at
+    /// the front of the list, and the least-recently focused surfaces appearing at the back of the
+    /// list.
+    std::vector<std::weak_ptr<Surface>> focus_order;
     std::map<Surface*,std::shared_ptr<RenderingTracker>> rendering_trackers;
     std::set<compositor::CompositorID> registered_compositors;
 
