@@ -14,27 +14,28 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/server.h"
+#include <mir/server.h>
 
-#include "mir/emergency_cleanup.h"
-#include "mir/fd.h"
-#include "mir/frontend/connector.h"
-#include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/graphics/display_sink.h"
-#include "mir/input/composite_event_filter.h"
-#include "mir/input/event_filter.h"
-#include "mir/options/default_configuration.h"
-#include "mir/default_server_configuration.h"
-#include "mir/logging/logger.h"
-#include "mir/log.h"
-#include "mir/main_loop.h"
-#include "mir/report_exception.h"
-#include "mir/run_mir.h"
+#include <mir/emergency_cleanup.h>
+#include <mir/fd.h>
+#include <mir/frontend/connector.h>
+#include <mir/frontend/wayland.h>
+#include <mir/graphics/graphic_buffer_allocator.h>
+#include <mir/graphics/display_sink.h>
+#include <mir/input/composite_event_filter.h>
+#include <mir/input/event_filter.h>
+#include <mir/options/default_configuration.h>
+#include <mir/default_server_configuration.h>
+#include <mir/logging/logger.h>
+#include <mir/log.h>
+#include <mir/main_loop.h>
+#include <mir/report_exception.h>
+#include <mir/run_mir.h>
 
 // TODO these are used to frig a stub renderer when running headless
-#include "mir/renderer/renderer.h"
-#include "mir/graphics/renderable.h"
-#include "mir/renderer/renderer_factory.h"
+#include <mir/renderer/renderer.h>
+#include <mir/graphics/renderable.h>
+#include <mir/renderer/renderer_factory.h>
 
 #include "frontend_wayland/wayland_connector.h"
 #include <iostream>
@@ -75,12 +76,11 @@ struct TemporaryCompositeEventFilter : public mi::CompositeEventFilter
 
 #define FOREACH_WRAPPER(MACRO)\
     MACRO(cursor)\
-    MACRO(cursor_listener)\
+    MACRO(cursor_observer_multiplexer)\
     MACRO(display_buffer_compositor_factory)\
     MACRO(display_configuration_policy)\
     MACRO(shell)\
-    MACRO(surface_stack)\
-    MACRO(application_not_responding_detector)
+    MACRO(surface_stack)
 
 #define FOREACH_OVERRIDE(MACRO)\
     MACRO(compositor)\
@@ -97,14 +97,15 @@ struct TemporaryCompositeEventFilter : public mi::CompositeEventFilter
     MACRO(session_authorizer)\
     MACRO(session_listener)\
     MACRO(shell)\
-    MACRO(application_not_responding_detector)\
     MACRO(persistent_surface_store)\
-    MACRO(renderer_factory)
+    MACRO(renderer_factory)\
+    MACRO(accessibility_manager)\
+    MACRO(clock)
 
 #define FOREACH_ACCESSOR(MACRO)\
     MACRO(the_compositor)\
     MACRO(the_compositor_report)\
-    MACRO(the_cursor_listener)\
+    MACRO(the_cursor_observer_multiplexer)\
     MACRO(the_cursor)\
     MACRO(the_display)\
     MACRO(the_display_configuration_controller)\
@@ -115,6 +116,7 @@ struct TemporaryCompositeEventFilter : public mi::CompositeEventFilter
     MACRO(the_input_targeter)  \
     MACRO(the_logger)\
     MACRO(the_main_loop)\
+    MACRO(the_output_filter)\
     MACRO(the_prompt_session_listener)\
     MACRO(the_session_authorizer)\
     MACRO(the_session_coordinator)\
@@ -127,7 +129,6 @@ struct TemporaryCompositeEventFilter : public mi::CompositeEventFilter
     MACRO(the_surface_stack)\
     MACRO(the_touch_visualizer)\
     MACRO(the_input_device_hub)\
-    MACRO(the_application_not_responding_detector)\
     MACRO(the_persistent_surface_store)\
     MACRO(the_display_configuration_observer_registrar)\
     MACRO(the_seat_observer_registrar)\
@@ -137,7 +138,13 @@ struct TemporaryCompositeEventFilter : public mi::CompositeEventFilter
     MACRO(the_input_device_registry)\
     MACRO(the_idle_handler)\
     MACRO(the_token_authority)\
-    MACRO(the_accessibility_manager)
+    MACRO(the_accessibility_manager)\
+    MACRO(the_display_configuration_observer)\
+    MACRO(the_buffer_allocator)\
+    MACRO(the_default_cursor_image)\
+    MACRO(the_scene_report)\
+    MACRO(the_scene)\
+    MACRO(the_screen_shooter_factory)
 
 #define MIR_SERVER_BUILDER(name)\
     std::function<std::invoke_result_t<decltype(&mir::DefaultServerConfiguration::the_##name),mir::DefaultServerConfiguration*>()> name##_builder;
@@ -394,6 +401,11 @@ void mir::Server::run()
     try
     {
         mir::log_info("Starting");
+        mir::security_log(
+            logging::Severity::warning,
+            "sys_startup",
+            "Mir is starting up");
+
         verify_accessing_allowed(self->server_config);
 
         auto const emergency_cleanup = self->server_config->the_emergency_cleanup();
@@ -415,6 +427,11 @@ void mir::Server::run()
                 { self->init_callback(); self->init_callback = []{}; },
             self->terminator);
 
+        mir::security_log(
+            logging::Severity::warning,
+            "sys_shutdown",
+            "Mir is shutting down");
+
         self->exit_status = true;
     }
     catch (...)
@@ -512,20 +529,13 @@ void mir::Server::add_wayland_extension(
     }
 }
 
-void mir::Server::set_wayland_extension_filter(
-    std::function<bool(std::shared_ptr<scene::Session> const&, char const*)> const& extension_filter)
+void mir::Server::set_wayland_extension_policy(
+    std::string const& interface_name,
+    std::function<bool(std::shared_ptr<scene::Session> const&, char const*)> const& policy)
 {
     if (auto const config = self->server_config)
     {
-        config->set_wayland_extension_filter(extension_filter);
-    }
-}
-
-void mir::Server::set_enabled_wayland_extensions(std::vector<std::string> const& extensions)
-{
-    if (auto const config = self->server_config)
-    {
-        config->set_enabled_wayland_extensions(extensions);
+        config->set_wayland_extension_policy(interface_name, policy);
     }
 }
 
@@ -779,3 +789,12 @@ void mir::Server::set_the_decoration_strategy(std::shared_ptr<DecorationStrategy
 {
     self->server_config->set_the_decoration_strategy(strategy);
 }
+
+void mir::Server::for_each_output_binding(wayland::Client* client, graphics::DisplayConfigurationOutputId output,
+    std::function<void(wl_resource* output)> const& callback)
+{
+    if (auto const wc = dynamic_pointer_cast<frontend::WaylandTools>(self->server_config->the_wayland_connector()))
+    {
+        wc ->for_each_output_binding(client, output, callback);
+    }
+}
