@@ -15,21 +15,20 @@
  */
 
 #include "basic_decoration.h"
-#include "mir/graphics/buffer.h"
+#include <mir/graphics/buffer.h>
 #include "window.h"
 #include "input.h"
-#include "renderer.h"
 #include "threadsafe_access.h"
 
-#include "mir/executor.h"
-#include "mir/shell/shell.h"
-#include "mir/shell/surface_specification.h"
-#include "mir/scene/surface.h"
-#include "mir/scene/session.h"
-#include "mir/graphics/buffer_properties.h"
-#include "mir/compositor/buffer_stream.h"
-#include "mir/input/cursor_images.h"
-#include "mir/wayland/weak.h"
+#include <mir/executor.h>
+#include <mir/shell/shell.h>
+#include <mir/shell/surface_specification.h>
+#include <mir/scene/surface.h>
+#include <mir/scene/session.h>
+#include <mir/graphics/buffer_properties.h>
+#include <mir/compositor/buffer_stream.h>
+#include <mir/input/cursor_images.h>
+#include <mir/wayland/weak.h>
 
 #include <boost/throw_exception.hpp>
 #include <functional>
@@ -140,19 +139,17 @@ msd::BasicDecoration::BufferStreams::~BufferStreams()
 
 msd::BasicDecoration::BasicDecoration(
     std::shared_ptr<msh::Shell> const& shell,
-    std::shared_ptr<mg::GraphicBufferAllocator> const& buffer_allocator,
     std::shared_ptr<Executor> const& executor,
     std::shared_ptr<input::CursorImages> const& cursor_images,
     std::shared_ptr<ms::Surface> const& window_surface,
     std::shared_ptr<DecorationStrategy> decoration_strategy)
     : threadsafe_self{std::make_shared<ThreadsafeAccess<BasicDecoration>>(executor)},
       decoration_strategy{decoration_strategy},
+      renderer_strategy{decoration_strategy->render_strategy()},
       shell{shell},
-      buffer_allocator{buffer_allocator},
       cursor_images{cursor_images},
       session{window_surface->session().lock()},
       buffer_streams{std::make_unique<BufferStreams>(session, decoration_strategy->buffer_format())},
-      renderer{std::make_unique<Renderer>(buffer_allocator, decoration_strategy->render_strategy())},
       window_surface{window_surface},
       decoration_surface{create_surface()},
       window_state{decoration_strategy->new_window_state(window_surface, scale)},
@@ -287,7 +284,7 @@ auto msd::BasicDecoration::create_surface() const -> std::shared_ptr<scene::Surf
             mg::BufferUsage::software}),
         {},
         }};
-    return shell->create_surface(session, {}, params, nullptr, nullptr);
+    return shell->create_surface(session, params, nullptr, nullptr);
 }
 
 void msd::BasicDecoration::update(
@@ -370,7 +367,7 @@ void msd::BasicDecoration::update(
         input_updated({
             &InputState::buttons}))
     {
-        renderer->update_state(*window_state, *input_state);
+        renderer_strategy->update_state(*window_state, *input_state);
     }
 
     std::vector<std::pair<
@@ -385,10 +382,10 @@ void msd::BasicDecoration::update(
     {
         new_buffers.emplace_back(
             buffer_streams->left_border,
-            renderer->render_left_border());
+            renderer_strategy->render_left_border());
         new_buffers.emplace_back(
             buffer_streams->right_border,
-            renderer->render_right_border());
+            renderer_strategy->render_right_border());
     }
 
     if (window_updated({
@@ -399,7 +396,7 @@ void msd::BasicDecoration::update(
     {
         new_buffers.emplace_back(
             buffer_streams->bottom_border,
-            renderer->render_bottom_border());
+            renderer_strategy->render_bottom_border());
     }
 
     if (window_updated({
@@ -412,7 +409,7 @@ void msd::BasicDecoration::update(
     {
         new_buffers.emplace_back(
             buffer_streams->titlebar,
-            renderer->render_titlebar());
+            renderer_strategy->render_titlebar());
     }
 
     float inv_scale = 1.0f / window_state->scale();
