@@ -19,11 +19,11 @@
 #include "threadsafe_access.h"
 #include "basic_decoration.h"
 
-#include "mir/scene/surface.h"
-#include "mir/scene/null_surface_observer.h"
-#include "mir/events/pointer_event.h"
-#include "mir/events/touch_event.h"
-#include "mir_toolkit/cursors.h"
+#include <mir/scene/surface.h>
+#include <mir/scene/null_surface_observer.h>
+#include <mir/events/pointer_event.h>
+#include <mir/events/touch_event.h>
+#include <mir_toolkit/cursors.h>
 
 namespace ms = mir::scene;
 namespace mi = mir::input;
