@@ -14,22 +14,28 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/default_server_configuration.h"
+#include <mir/default_server_configuration.h>
 
+#include "basic_accessibility_manager.h"
 #include "basic_idle_handler.h"
 #include "decoration/basic_decoration.h"
 #include "decoration/basic_manager.h"
 #include "default_persistent_surface_store.h"
 #include "graphics_display_layout.h"
+#include "basic_mousekeys_transformer.h"
+#include "basic_simulated_secondary_click_transformer.h"
+#include "basic_hover_click_transformer.h"
+#include "basic_slow_keys_transformer.h"
+#include "basic_sticky_keys_transformer.h"
 
-#include "mir/abnormal_exit.h"
-#include "mir/input/composite_event_filter.h"
-#include "mir/main_loop.h"
-#include "mir/options/configuration.h"
-#include "mir/shell/abstract_shell.h"
-#include "mir/shell/accessibility_manager.h"
-#include "mir/shell/system_compositor_window_manager.h"
-#include "mir/shell/token_authority.h"
+#include <mir/abnormal_exit.h>
+#include <mir/input/composite_event_filter.h>
+#include <mir/main_loop.h>
+#include <mir/options/configuration.h>
+#include <mir/options/option.h>
+#include <mir/shell/abstract_shell.h>
+#include <mir/shell/system_compositor_window_manager.h>
+#include <mir/shell/token_authority.h>
 
 namespace ms = mir::scene;
 namespace msh = mir::shell;
@@ -72,7 +78,7 @@ auto mir::DefaultServerConfiguration::the_decoration_manager() -> std::shared_pt
         [this]()->std::shared_ptr<msd::Manager>
         {
             return std::make_shared<msd::BasicManager>(
-                msd::DecorationStrategy::default_decoration_strategy(),
+                msd::DecorationStrategy::default_decoration_strategy(the_buffer_allocator()),
                 *the_display_configuration_observer_registrar(),
                 [buffer_allocator = the_buffer_allocator(),
                  executor = the_main_loop(),
@@ -83,7 +89,6 @@ auto mir::DefaultServerConfiguration::the_decoration_manager() -> std::shared_pt
                 {
                     return std::make_unique<msd::BasicDecoration>(
                         shell,
-                        buffer_allocator,
                         executor,
                         cursor_images,
                         surface,
@@ -189,7 +194,14 @@ auto mir::DefaultServerConfiguration::the_accessibility_manager() -> std::shared
     return accessibility_manager(
         [this]
         {
-            return std::make_shared<shell::AccessibilityManager>(the_options(), the_input_event_transformer());
+            return std::make_shared<shell::BasicAccessibilityManager>(
+                the_input_event_transformer(),
+                the_options()->get<bool>(mir::options::enable_key_repeat_opt),
+                the_cursor(),
+                std::make_shared<shell::BasicMouseKeysTransformer>(the_main_loop(), the_clock()),
+                std::make_shared<shell::BasicSimulatedSecondaryClickTransformer>(the_main_loop()),
+                std::make_shared<shell::BasicHoverClickTransformer>(the_main_loop(), the_cursor_observer_multiplexer()),
+                std::make_shared<shell::BasicSlowKeysTransformer>(the_main_loop()),
+                std::make_shared<shell::BasicStickyKeysTransformer>());
         });
 }
-
