@@ -14,9 +14,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/shell/surface_stack_wrapper.h"
+#include <mir/shell/surface_stack_wrapper.h>
 
-#include "mir/geometry/point.h"
+#include <mir/geometry/point.h>
 
 namespace msh = mir::shell;
 
@@ -69,4 +69,4 @@ auto msh::SurfaceStackWrapper::is_above(
     std::weak_ptr<scene::Surface> const& b) const -> bool
 {
     return wrapped->is_above(a, b);
-}
\ No newline at end of file
+}
