@@ -15,8 +15,8 @@
  */
 
 #include "shm_backing.h"
-#include "mir/raii.h"
-#include "mir/synchronised.h"
+#include <mir/raii.h>
+#include <mir/synchronised.h>
 
 #include <sys/mman.h>
 #include <fcntl.h>
@@ -143,7 +143,7 @@ private:
 
     static void install_sigbus_handler()
     {
-        struct sigaction sig_handler_desc;
+        struct sigaction sig_handler_desc{};
         sigfillset(&sig_handler_desc.sa_mask);
         sig_handler_desc.sa_flags = SA_SIGINFO;
         sig_handler_desc.sa_sigaction = &sigbus_handler;
@@ -290,7 +290,7 @@ private:
         size_t size;
         bool size_is_trustworthy;
     };
-    
+
     template<typename T>
     class Mapping : public mir::shm::Mapping<T>
     {
@@ -353,7 +353,7 @@ auto backing_size_is_guaranteed_at_least(mir::Fd const& backing_store, size_t si
          * usefully check to see if it's big enough now, and if so, we don't have to do the SIGBUS
          * dance
          */
-        struct stat file_info;
+        struct stat file_info{};
         if (fstat(backing_store, &file_info) >= 0)
         {
             return static_cast<size_t>(file_info.st_size) >= size;
@@ -411,7 +411,7 @@ void ShmBacking::resize(size_t new_size)
             std::system_category(),
             "Failed to map client-provided SHM pool"}));
     }
-    
+
     *current_mapping.lock() = std::make_shared<CurrentMapping>(
         mapped_address,
         new_size,
@@ -527,7 +527,7 @@ public:
         backing_store.resize(new_size);
     }
 private:
-    ShmBacking backing_store; 
+    ShmBacking backing_store;
 };
 }
 
