@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/wayland/lifetime_tracker.h"
+#include <mir/wayland/lifetime_tracker.h>
 
 #include <map>
 
