@@ -17,7 +17,7 @@
 #include "test_rendering_platform.h"
 #include "test_display_platform.h"
 
-#include "mir_test_framework/executable_path.h"
+#include <mir_test_framework/executable_path.h>
 
 namespace mtf = mir_test_framework;
 
@@ -44,4 +44,3 @@ GbmKmsPlatformEnv platform_harness;
 }
 
 INSTANTIATE_TEST_SUITE_P(GbmKms, DisplayPlatformTest, testing::Values(&platform_harness));
-
