@@ -1,5 +1,5 @@
 /*
- * Copyright © 2021 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -20,7 +20,7 @@
 #include <gmock/gmock.h>
 #include <boost/throw_exception.hpp>
 
-#include "mir/graphics/platform.h"
+#include <mir/graphics/platform.h>
 
 namespace mg = mir::graphics;
 
