@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir_test_framework/headless_test.h"
+#include <mir_test_framework/headless_test.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
@@ -23,7 +23,7 @@ using namespace testing;
 
 struct CommandLineHandling : mir_test_framework::HeadlessTest
 {
-    MOCK_METHOD1(callback, void(std::vector<char const*> const&));
+    MOCK_METHOD(void, callback, (std::vector<char const*> const&), ());
 
     std::function<void(int argc, char const* const* argv)> callback_functor =
         [this](int argc, char const* const* argv)
