@@ -14,15 +14,15 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/input/input_device_info.h"
-#include "mir/input/input_device_observer.h"
-#include "mir/input/input_device_hub.h"
+#include <mir/input/input_device_info.h>
+#include <mir/input/input_device_observer.h>
+#include <mir/input/input_device_hub.h>
 
-#include "mir_test_framework/headless_in_process_server.h"
-#include "mir_test_framework/fake_input_device.h"
-#include "mir_test_framework/stub_server_platform_factory.h"
-#include "mir/test/signal_actions.h"
-#include "mir/test/fake_shared.h"
+#include <mir_test_framework/headless_in_process_server.h>
+#include <mir_test_framework/fake_input_device.h>
+#include <mir_test_framework/stub_server_platform_factory.h>
+#include <mir/test/signal_actions.h>
+#include <mir/test/fake_shared.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
@@ -36,10 +36,10 @@ namespace
 
 struct MockInputDeviceObserver : public mi::InputDeviceObserver
 {
-    MOCK_METHOD1(device_added, void(std::shared_ptr<mi::Device> const& device));
-    MOCK_METHOD1(device_changed, void(std::shared_ptr<mi::Device> const& device));
-    MOCK_METHOD1(device_removed, void(std::shared_ptr<mi::Device> const& device));
-    MOCK_METHOD0(changes_complete, void());
+    MOCK_METHOD(void, device_added, (std::shared_ptr<mi::Device> const& device), (override));
+    MOCK_METHOD(void, device_changed, (std::shared_ptr<mi::Device> const& device), (override));
+    MOCK_METHOD(void, device_removed, (std::shared_ptr<mi::Device> const& device), (override));
+    MOCK_METHOD(void, changes_complete, (), (override));
 };
 
 struct TestInputDeviceHub : mtf::HeadlessInProcessServer
@@ -67,8 +67,6 @@ TEST_F(TestInputDeviceHub, notifies_input_device_observer_about_available_device
 {
     using namespace testing;
     InSequence seq;
-    EXPECT_CALL(observer, device_added(_)); // Account for "mousekey-pointer"
-
     EXPECT_CALL(observer, changes_complete())
         .WillOnce(mt::WakeUp(&observer_registered));
 
