@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -17,10 +17,10 @@
 #ifndef MIR_TEST_DOUBLES_FAKE_ALARM_FACTORY_H_
 #define MIR_TEST_DOUBLES_FAKE_ALARM_FACTORY_H_
 
-#include "mir/time/alarm_factory.h"
-#include "mir/time/alarm.h"
-#include "mir/time/clock.h"
-#include "mir/test/doubles/advanceable_clock.h"
+#include <mir/time/alarm_factory.h>
+#include <mir/time/alarm.h>
+#include <mir/time/clock.h>
+#include <mir/test/doubles/advanceable_clock.h>
 
 #include <vector>
 
