@@ -17,7 +17,7 @@
 #ifndef MIR_TEST_DOUBLES_MOCK_COMPOSITOR_H_
 #define MIR_TEST_DOUBLES_MOCK_COMPOSITOR_H_
 
-#include "mir/compositor/compositor.h"
+#include <mir/compositor/compositor.h>
 
 #include <gmock/gmock.h>
 
@@ -40,4 +40,3 @@ public:
 }
 
 #endif /* MIR_TEST_DOUBLES_MOCK_COMPOSITOR_H_ */
-
