@@ -18,7 +18,7 @@
 #ifndef MIR_TEST_DOUBLES_MOCK_SURFACE_STACK_H_
 #define MIR_TEST_DOUBLES_MOCK_SURFACE_STACK_H_
 
-#include "mir/frontend/surface_stack.h"
+#include <mir/frontend/surface_stack.h>
 
 #include <gmock/gmock.h>
 
