@@ -17,7 +17,7 @@
 #ifndef MIR_TEST_DOUBLES_MOCK_INPUT_DEVICE_HUB_H_
 #define MIR_TEST_DOUBLES_MOCK_INPUT_DEVICE_HUB_H_
 
-#include "mir/input/input_device_hub.h"
+#include <mir/input/input_device_hub.h>
 #include <gmock/gmock.h>
 
 namespace mir
@@ -29,10 +29,10 @@ namespace doubles
 
 struct MockInputDeviceHub : input::InputDeviceHub
 {
-    MOCK_METHOD1(add_observer, void(std::shared_ptr<input::InputDeviceObserver> const&));
-    MOCK_METHOD1(remove_observer, void(std::weak_ptr<input::InputDeviceObserver> const&));
-    MOCK_METHOD1(for_each_input_device, void(std::function<void(input::Device const&)> const&));
-    MOCK_METHOD1(for_each_mutable_input_device, void(std::function<void(input::Device&)> const&));
+    MOCK_METHOD(void, add_observer, (std::shared_ptr<input::InputDeviceObserver> const&), (override));
+    MOCK_METHOD(void, remove_observer, (std::weak_ptr<input::InputDeviceObserver> const&), (override));
+    MOCK_METHOD(void, for_each_input_device, (std::function<void(input::Device const&)> const&), (override));
+    MOCK_METHOD(void, for_each_mutable_input_device, (std::function<void(input::Device&)> const&), (override));
 };
 
 }
