@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,7 +17,7 @@
 #ifndef MIR_TEST_DOUBLES_MOCK_INPUT_SINK_H_
 #define MIR_TEST_DOUBLES_MOCK_INPUT_SINK_H_
 
-#include "mir/input/input_sink.h"
+#include <mir/input/input_sink.h>
 
 #include <gmock/gmock.h>
 
@@ -30,12 +30,11 @@ namespace doubles
 
 struct MockInputSink : mir::input::InputSink
 {
-    MOCK_METHOD1(handle_input, void(std::shared_ptr<MirEvent> const&));
-    MOCK_METHOD1(confine_pointer, void(mir::geometry::Point&));
-    MOCK_CONST_METHOD0(bounding_rectangle, mir::geometry::Rectangle());
-    MOCK_CONST_METHOD1(output_info, mir::input::OutputInfo(uint32_t));
-    MOCK_METHOD1(key_state, void(std::vector<uint32_t> const&));
-    MOCK_METHOD1(pointer_state, void(MirPointerButtons));
+    MOCK_METHOD(void, handle_input, (std::shared_ptr<MirEvent> const&), (override));
+    MOCK_METHOD(mir::geometry::Rectangle, bounding_rectangle, (), (const, override));
+    MOCK_METHOD(mir::input::OutputInfo, output_info, (uint32_t), (const, override));
+    MOCK_METHOD(void, key_state, (std::vector<uint32_t> const&), (override));
+    MOCK_METHOD(void, pointer_state, (MirPointerButtons), (override));
 };
 
 }
