@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,7 +17,7 @@
 #ifndef MIR_TEST_DOUBLES_NULL_EMERGENCY_CLEANUP_H_
 #define MIR_TEST_DOUBLES_NULL_EMERGENCY_CLEANUP_H_
 
-#include "mir/emergency_cleanup.h"
+#include <mir/emergency_cleanup.h>
 
 namespace mir
 {
