@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,7 +17,7 @@
 #ifndef MIR_SCENE_NULL_PROMPT_SESSION_MANAGER_H_
 #define MIR_SCENE_NULL_PROMPT_SESSION_MANAGER_H_
 
-#include "mir/scene/prompt_session_manager.h"
+#include <mir/scene/prompt_session_manager.h>
 
 namespace mir
 {
