@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014-2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,7 +17,7 @@
 #ifndef MIR_TEST_DOUBLES_STUB_ALARM_H_
 #define MIR_TEST_DOUBLES_STUB_ALARM_H_
 
-#include "mir/time/alarm.h"
+#include <mir/time/alarm.h>
 
 namespace mir
 {
