@@ -17,11 +17,11 @@
 #ifndef MIR_TEST_DOUBLES_STUB_BUFFER_H_
 #define MIR_TEST_DOUBLES_STUB_BUFFER_H_
 
-#include "mir/graphics/buffer_basic.h"
-#include "mir/graphics/buffer_properties.h"
-#include "mir/geometry/size.h"
-#include "mir/graphics/buffer_id.h"
-#include "mir/renderer/sw/pixel_source.h"
+#include <mir/graphics/buffer_basic.h>
+#include <mir/graphics/buffer_properties.h>
+#include <mir/geometry/size.h>
+#include <mir/graphics/buffer_id.h>
+#include <mir/renderer/sw/pixel_source.h>
 #include <vector>
 #include <string.h>
 
@@ -35,7 +35,7 @@ namespace doubles
 class StubBuffer :
     public graphics::BufferBasic,
     public graphics::NativeBufferBase,
-    public renderer::software::RWMappableBuffer
+    public renderer::software::RWMappable
 {
 public:
     StubBuffer()
@@ -55,7 +55,7 @@ public:
                   size,
                   mir_pixel_format_abgr_8888,
                   graphics::BufferUsage::hardware},
-              geometry::Stride{}}
+              geometry::Stride{size.width.as_uint32_t() * MIR_BYTES_PER_PIXEL(mir_pixel_format_abgr_8888)}}
 
     {
     }
@@ -66,8 +66,7 @@ public:
                   size,
                   pixel_format,
                   graphics::BufferUsage::hardware},
-                  geometry::Stride{}}
-
+                  geometry::Stride{size.width.as_uint32_t() * MIR_BYTES_PER_PIXEL(pixel_format)}}
     {
     }
 
@@ -119,7 +118,7 @@ public:
     class Mapping : public mir::renderer::software::Mapping<T>
     {
     public:
-        Mapping(StubBuffer* buffer)
+        Mapping(std::conditional_t<std::is_const_v<T>, StubBuffer const*, StubBuffer*> buffer)
             : buffer{buffer}
         {
         }
@@ -139,7 +138,7 @@ public:
             return buffer->buf_size;
         }
 
-        auto data() -> T* override
+        auto data() const -> T* override
         {
             return buffer->written_pixels.data();
         }
@@ -149,25 +148,25 @@ public:
             return buffer->written_pixels.size();
         }
     private:
-        StubBuffer* const buffer;
+        std::conditional_t<std::is_const_v<T>, StubBuffer const*, StubBuffer*> const buffer;
     };
 
     template<typename T>
     friend class Mapping;
 
-    auto map_writeable() -> std::unique_ptr<renderer::software::Mapping<unsigned char>> override
+    auto map_writeable() -> std::unique_ptr<renderer::software::Mapping<std::byte>> override
     {
-        return std::make_unique<Mapping<unsigned char>>(this);
+        return std::make_unique<Mapping<std::byte>>(this);
     }
 
-    auto map_readable() -> std::unique_ptr<renderer::software::Mapping<unsigned char const>> override
+    auto map_readable() const -> std::unique_ptr<renderer::software::Mapping<std::byte const>> override
     {
-        return std::make_unique<Mapping<unsigned char const>>(this);
+        return std::make_unique<Mapping<std::byte const>>(this);
     }
 
-    auto map_rw() -> std::unique_ptr<renderer::software::Mapping<unsigned char>> override
+    auto map_rw() -> std::unique_ptr<renderer::software::Mapping<std::byte>> override
     {
-        return std::make_unique<Mapping<unsigned char>>(this);
+        return std::make_unique<Mapping<std::byte>>(this);
     }
 
     NativeBufferBase* native_buffer_base() override
@@ -179,7 +178,7 @@ public:
     MirPixelFormat const buf_pixel_format;
     geometry::Stride const buf_stride;
     graphics::BufferID const buf_id;
-    std::vector<unsigned char> written_pixels;
+    std::vector<std::byte> written_pixels;
 };
 }
 }
