@@ -17,8 +17,8 @@
 #ifndef MIR_TEST_DOUBLES_NULL_BUFFER_STREAM_H_
 #define MIR_TEST_DOUBLES_NULL_BUFFER_STREAM_H_
 
-#include "mir/geometry/forward.h"
-#include "mir_toolkit/common.h"
+#include <mir/geometry/forward.h>
+#include <mir_toolkit/common.h>
 #include <mir/compositor/buffer_stream.h>
 #include <mir/test/doubles/stub_buffer.h>
 
