@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,7 +17,7 @@
 #ifndef MIR_TEST_DOUBLES_STUB_CLIENT_BUFFER_FACTORY_H_
 #define MIR_TEST_DOUBLES_STUB_CLIENT_BUFFER_FACTORY_H_
 
-#include "mir/client/client_buffer_factory.h"
+#include <mir/client/client_buffer_factory.h>
 #include "stub_client_buffer.h"
 
 namespace mir
