@@ -17,9 +17,9 @@
 #ifndef MIR_TEST_DOUBLES_STUB_RENDERER_H_
 #define MIR_TEST_DOUBLES_STUB_RENDERER_H_
 
-#include "mir/renderer/renderer.h"
-#include "mir/graphics/renderable.h"
-#include "mir/graphics/buffer.h"
+#include <mir/renderer/renderer.h>
+#include <mir/graphics/renderable.h>
+#include <mir/graphics/buffer.h>
 #include <thread>
 
 namespace mir
@@ -34,6 +34,7 @@ class StubRenderer : public renderer::Renderer
 public:
     void set_viewport(geometry::Rectangle const&) override {}
     void set_output_transform(glm::mat2 const&) override {}
+    void set_output_filter(MirOutputFilter) override {};
     void suspend() override {}
 
     auto render(graphics::RenderableList const& renderables) const -> std::unique_ptr<graphics::Framebuffer> override
