@@ -17,10 +17,10 @@
 #ifndef MIR_TEST_DOUBLES_STUB_SHELL_H_
 #define MIR_TEST_DOUBLES_STUB_SHELL_H_
 
-#include "mir/shell/shell.h"
-#include "mir/test/doubles/stub_session.h"
-#include "mir/test/doubles/null_prompt_session.h"
-#include "mir/test/doubles/stub_surface.h"
+#include <mir/shell/shell.h>
+#include <mir/test/doubles/stub_session.h>
+#include <mir/test/doubles/null_prompt_session.h>
+#include <mir/test/doubles/stub_surface.h>
 
 namespace mir
 {
@@ -107,8 +107,7 @@ struct StubShell : public shell::Shell
     auto open_session(
         pid_t client_pid,
         Fd /*socket_fd*/,
-        std::string const& /*name*/,
-        std::shared_ptr<frontend::EventSink> const& /*sink*/) -> std::shared_ptr<scene::Session> override
+        std::string const& /*name*/) -> std::shared_ptr<scene::Session> override
     {
         return std::make_shared<StubSession>(client_pid);
     }
@@ -136,7 +135,6 @@ struct StubShell : public shell::Shell
 
     auto create_surface(
         std::shared_ptr<scene::Session> const& /*session*/,
-        wayland::Weak<frontend::WlSurface> const& /*wayland_surface*/,
         shell::SurfaceSpecification const& /*params*/,
         std::shared_ptr<scene::SurfaceObserver> const& /*observer*/,
         Executor* /*observer_executor*/) -> std::shared_ptr<scene::Surface> override
