@@ -34,12 +34,13 @@ struct StubSurface : scene::Surface
     geometry::Size window_size() const override { return {}; }
     geometry::Displacement content_offset() const override { return {}; }
     geometry::Size content_size() const override { return {}; }
-    std::shared_ptr<frontend::BufferStream> primary_buffer_stream() const override { return nullptr; }
+    std::list<scene::StreamInfo> get_streams() const override { return {}; }
     void set_streams(std::list<scene::StreamInfo> const&) override {}
     input::InputReceptionMode reception_mode() const override { return input::InputReceptionMode::normal; }
     void set_reception_mode(input::InputReceptionMode) override {}
     void set_input_region(std::vector<geometry::Rectangle> const&) override {}
     std::vector<geometry::Rectangle> get_input_region() const override { return {}; }
+    virtual void set_opaque_region(geometry::Rectangles const& ) override {}
     void resize(geometry::Size const&) override {}
     geometry::Point top_left() const override { return {}; }
     geometry::Rectangle input_bounds() const override { return {}; }
@@ -47,6 +48,7 @@ struct StubSurface : scene::Surface
     void consume(std::shared_ptr<MirEvent const> const&) override {}
     void set_alpha(float) override {}
     void set_orientation(MirOrientation) override {}
+    void set_mirror_mode(MirMirrorMode) override {}
     void set_transformation(glm::mat4 const&) override {}
     bool visible() const override { return false; }
     graphics::RenderableList generate_renderables(compositor::CompositorID) const override { return {}; }
@@ -62,7 +64,6 @@ struct StubSurface : scene::Surface
     void show() override {}
     void set_cursor_image(std::shared_ptr<graphics::CursorImage> const&) override {}
     std::shared_ptr<graphics::CursorImage> cursor_image() const override { return nullptr; }
-    auto wayland_surface() -> wayland::Weak<frontend::WlSurface> const& override { abort(); }
     void request_client_surface_close() override {}
     std::shared_ptr<Surface> parent() const override { return nullptr; }
     void register_interest(std::weak_ptr<scene::SurfaceObserver> const&) override {}
@@ -91,6 +92,22 @@ struct StubSurface : scene::Surface
         geometry::DeltaX) override {}
     auto focus_mode() const -> MirFocusMode override { return mir_focus_mode_focusable; }
     void set_focus_mode(MirFocusMode) override {}
+    auto tiled_edges() const -> Flags<MirTiledEdge> { return Flags(mir_tiled_edge_none); }
+    void set_tiled_edges(Flags<MirTiledEdge>) {}
+    auto min_width() const -> geometry::Width { return min_width_; }
+    auto max_width() const -> geometry::Width { return max_width_; }
+    auto min_height() const -> geometry::Height { return min_height_; }
+    auto max_height() const -> geometry::Height { return max_height_; }
+    void set_min_width(geometry::Width w) { min_width_ = w; }
+    void set_max_width(geometry::Width w) { max_width_ = w; }
+    void set_min_height(geometry::Height h) { min_height_ = h; }
+    void set_max_height(geometry::Height h) { max_height_ = h; }
+
+private:
+    mir::geometry::Width min_width_{0};
+    mir::geometry::Height min_height_{0};
+    mir::geometry::Width max_width_{std::numeric_limits<int>::max()};
+    mir::geometry::Height max_height_{std::numeric_limits<int>::max()};
 };
 }
 }
