@@ -17,7 +17,7 @@
 #ifndef MIR_TEST_DOUBLES_STUB_TOUCH_VISUALIZER_H_
 #define MIR_TEST_DOUBLES_STUB_TOUCH_VISUALIZER_H_
 
-#include "mir/input/touch_visualizer.h"
+#include <mir/input/touch_visualizer.h>
 
 namespace mir
 {
@@ -44,4 +44,3 @@ struct StubTouchVisualizer : public input::TouchVisualizer
 } // namespace mir
 
 #endif // MIR_TEST_DOUBLES_STUB_TOUCH_VISUALIZER_H_
-
