@@ -1,5 +1,5 @@
 /*
- * Copyright © 2016 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -17,7 +17,7 @@
 #ifndef MIR_TEST_INPUT_DEVICES_MATCHER_H_
 #define MIR_TEST_INPUT_DEVICES_MATCHER_H_
 
-#include "mir/input/device.h"
+#include <mir/input/device.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
