@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -18,8 +18,8 @@
 #ifndef MIR_TEST_TEST_DISPATCHABLE_H_
 #define MIR_TEST_TEST_DISPATCHABLE_H_
 
-#include "mir/test/pipe.h"
-#include "mir/dispatch/dispatchable.h"
+#include <mir/test/pipe.h>
+#include <mir/dispatch/dispatchable.h>
 
 #include <functional>
 
