@@ -1,5 +1,5 @@
 /*
- * Copyright © 2012-2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -14,9 +14,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir_test_framework/deferred_in_process_server.h"
-#include "mir_test_framework/testing_server_configuration.h"
-#include "mir/test/doubles/mock_input_manager.h"
+#include <mir_test_framework/deferred_in_process_server.h>
+#include <mir_test_framework/testing_server_configuration.h>
+#include <mir/test/doubles/mock_input_manager.h>
 
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
