@@ -16,41 +16,36 @@
 
 #include "src/server/input/default_input_device_hub.h"
 #include "src/server/input/basic_seat.h"
-#include "src/server/input/config_changer.h"
 #include "src/server/scene/broadcasting_session_event_sink.h"
 
-#include "mir/test/doubles/fake_display_configuration_observer_registrar.h"
-#include "mir/test/doubles/mock_input_device.h"
-#include "mir/test/doubles/mock_input_device_observer.h"
-#include "mir/test/doubles/mock_input_dispatcher.h"
-#include "mir/test/doubles/mock_touch_visualizer.h"
-#include "mir/test/doubles/mock_cursor_listener.h"
-#include "mir/test/doubles/mock_input_manager.h"
-#include "mir/test/doubles/mock_led_observer_registrar.h"
-#include "mir/test/doubles/mock_seat_report.h"
-#include "mir/test/doubles/mock_server_status_listener.h"
-#include "mir/test/doubles/mock_scene_session.h"
-#include "mir/test/doubles/triggered_main_loop.h"
-#include "mir/test/event_matchers.h"
-#include "mir/test/doubles/advanceable_clock.h"
-#include "mir/test/fake_shared.h"
-#include "mir/test/doubles/stub_display_configuration.h"
+#include <mir/test/doubles/advanceable_clock.h>
+#include <mir/test/doubles/fake_display_configuration_observer_registrar.h>
+#include <mir/test/doubles/mock_cursor_observer.h>
+#include <mir/test/doubles/mock_input_device.h>
+#include <mir/test/doubles/mock_input_device_observer.h>
+#include <mir/test/doubles/mock_input_dispatcher.h>
+#include <mir/test/doubles/mock_input_manager.h>
+#include <mir/test/doubles/mock_led_observer_registrar.h>
+#include <mir/test/doubles/mock_scene_session.h>
+#include <mir/test/doubles/mock_seat_report.h>
+#include <mir/test/doubles/mock_server_status_listener.h>
+#include <mir/test/doubles/mock_touch_visualizer.h>
+#include <mir/test/event_matchers.h>
+#include <mir/test/fake_shared.h>
+#include <mir/test/fd_utils.h>
+#include <mir/test/input_config_matchers.h>
 
-#include "mir/dispatch/multiplexing_dispatchable.h"
-#include "mir/graphics/buffer.h"
-#include "mir/graphics/display_configuration_observer.h"
-#include "mir/scene/session_container.h"
+#include <mir/dispatch/multiplexing_dispatchable.h>
+#include <mir/scene/session_container.h>
 
-#include "mir/input/device.h"
-#include "mir/input/xkb_mapper_registrar.h"
-#include "mir/input/device_capability.h"
-#include "mir/input/mir_pointer_config.h"
-#include "mir/input/mir_touchpad_config.h"
-#include "mir/input/touch_visualizer.h"
-#include "mir/input/input_device_info.h"
-#include "mir/geometry/rectangles.h"
-#include "mir/test/input_config_matchers.h"
-#include "mir/test/fd_utils.h"
+#include <mir/input/cursor_observer_multiplexer.h>
+#include <mir/input/device.h>
+#include <mir/input/device_capability.h>
+#include <mir/input/input_device_info.h>
+#include <mir/input/mir_pointer_config.h>
+#include <mir/input/mir_touchpad_config.h>
+#include <mir/input/touch_visualizer.h>
+#include <mir/input/xkb_mapper_registrar.h>
 
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
@@ -85,9 +80,8 @@ MATCHER_P(DeviceMatches, device_info, "")
 
 struct SingleSeatInputDeviceHubSetup : ::testing::Test
 {
-    mtd::TriggeredMainLoop observer_loop;
     NiceMock<mtd::MockInputDispatcher> mock_dispatcher;
-    NiceMock<mtd::MockCursorListener> mock_cursor_listener;
+    NiceMock<mtd::MockCursorObserver> mock_cursor_observer;
     NiceMock<mtd::MockTouchVisualizer> mock_visualizer;
     NiceMock<mtd::MockSeatObserver> mock_seat_observer;
     NiceMock<mtd::MockServerStatusListener> mock_status_listener;
@@ -99,10 +93,11 @@ struct SingleSeatInputDeviceHubSetup : ::testing::Test
     ms::BroadcastingSessionEventSink session_event_sink;
     mtd::FakeDisplayConfigurationObserverRegistrar display_config;
     NiceMock<mtd::MockLedObserverRegistrar> led_observer_registrar;
+    mi::CursorObserverMultiplexer cursor_observer_multiplexer{mir::immediate_executor};
     mi::BasicSeat seat{mt::fake_shared(mock_dispatcher),      mt::fake_shared(mock_visualizer),
-                       mt::fake_shared(mock_cursor_listener), mt::fake_shared(display_config),
-                       mt::fake_shared(key_mapper),           mt::fake_shared(clock),
-                       mt::fake_shared(mock_seat_observer)};
+                       mt::fake_shared(mock_cursor_observer), mt::fake_shared(cursor_observer_multiplexer),
+                       mt::fake_shared(display_config),       mt::fake_shared(key_mapper),
+                       mt::fake_shared(clock),                mt::fake_shared(mock_seat_observer)};
     mi::DefaultInputDeviceHub hub{
         mt::fake_shared(seat),
         mt::fake_shared(multiplexer),
@@ -111,13 +106,6 @@ struct SingleSeatInputDeviceHubSetup : ::testing::Test
         mt::fake_shared(mock_status_listener),
         mt::fake_shared(led_observer_registrar)};
     NiceMock<mtd::MockInputDeviceObserver> mock_observer;
-    mi::ConfigChanger changer{
-        mt::fake_shared(mock_input_manager),
-            mt::fake_shared(hub),
-            mt::fake_shared(session_container),
-            mt::fake_shared(session_event_sink),
-            mt::fake_shared(hub)
-    };
 
     mi::DeviceCapabilities const keyboard_caps = mi::DeviceCapability::keyboard | mi::DeviceCapability::alpha_numeric;
     mi::DeviceCapabilities const touchpad_caps = mi::DeviceCapability::touchpad | mi::DeviceCapability::pointer;
@@ -138,7 +126,7 @@ struct SingleSeatInputDeviceHubSetup : ::testing::Test
     {
         for (int i = 0; i != count; ++i)
         {
-            mt::fd_becomes_readable(multiplexer.watch_fd(), 5s);
+            (void)mt::fd_becomes_readable(multiplexer.watch_fd(), 5s);
             multiplexer.dispatch(mir::dispatch::FdEvent::readable);
         }
     }
@@ -251,9 +239,9 @@ TEST_F(SingleSeatInputDeviceHubSetup, forwards_touch_spots_to_visualizer)
 TEST_F(SingleSeatInputDeviceHubSetup, tracks_pointer_position)
 {
     geom::Point first{10,10}, second{20,20}, third{10,30};
-    EXPECT_CALL(mock_cursor_listener, cursor_moved_to(first.x.as_int(), first.y.as_int()));
-    EXPECT_CALL(mock_cursor_listener, cursor_moved_to(second.x.as_int(), second.y.as_int()));
-    EXPECT_CALL(mock_cursor_listener, cursor_moved_to(third.x.as_int(), third.y.as_int()));
+    EXPECT_CALL(mock_cursor_observer, cursor_moved_to(first.x.as_int(), first.y.as_int()));
+    EXPECT_CALL(mock_cursor_observer, cursor_moved_to(second.x.as_int(), second.y.as_int()));
+    EXPECT_CALL(mock_cursor_observer, cursor_moved_to(third.x.as_int(), third.y.as_int()));
 
     mi::InputSink* sink;
     mi::EventBuilder* builder;
@@ -270,7 +258,7 @@ TEST_F(SingleSeatInputDeviceHubSetup, confines_pointer_movement)
     geom::Point confined_pos{10, 18};
     display_config.resize_output(0, geom::Size{confined_pos.x.as_int() + 1, confined_pos.y.as_int() + 1});
 
-    EXPECT_CALL(mock_cursor_listener, cursor_moved_to(confined_pos.x.as_int(), confined_pos.y.as_int())).Times(2);
+    EXPECT_CALL(mock_cursor_observer, cursor_moved_to(confined_pos.x.as_int(), confined_pos.y.as_int())).Times(2);
 
     mi::InputSink* sink;
     mi::EventBuilder* builder;
@@ -281,7 +269,7 @@ TEST_F(SingleSeatInputDeviceHubSetup, confines_pointer_movement)
     sink->handle_input(motion_event(*builder, 10.0f, 10.0f));
 }
 
-TEST_F(SingleSeatInputDeviceHubSetup, forwards_pointer_updates_to_cursor_listener)
+TEST_F(SingleSeatInputDeviceHubSetup, forwards_pointer_updates_to_cursor_observer)
 {
     auto move_x = 12.0f, move_y = 14.0f;
 
@@ -292,7 +280,7 @@ TEST_F(SingleSeatInputDeviceHubSetup, forwards_pointer_updates_to_cursor_listene
 
     auto event = motion_event(*builder, move_x, move_y);
 
-    EXPECT_CALL(mock_cursor_listener, cursor_moved_to(move_x, move_y)).Times(1);
+    EXPECT_CALL(mock_cursor_observer, cursor_moved_to(move_x, move_y)).Times(1);
 
     sink->handle_input(std::move(event));
 }
@@ -469,9 +457,9 @@ TEST_F(SingleSeatInputDeviceHubSetup, tracks_a_single_cursor_position_from_multi
     auto motion_2 = motion_event(*mouse_event_builder_2, 18, -10);
     auto motion_3 = motion_event(*mouse_event_builder_2, 2, 10);
 
-    EXPECT_CALL(mock_cursor_listener, cursor_moved_to(23, 20));
-    EXPECT_CALL(mock_cursor_listener, cursor_moved_to(41, 10));
-    EXPECT_CALL(mock_cursor_listener, cursor_moved_to(43, 20));
+    EXPECT_CALL(mock_cursor_observer, cursor_moved_to(23, 20));
+    EXPECT_CALL(mock_cursor_observer, cursor_moved_to(41, 10));
+    EXPECT_CALL(mock_cursor_observer, cursor_moved_to(43, 20));
 
     mouse_sink_1->handle_input(std::move(motion_1));
     mouse_sink_2->handle_input(std::move(motion_2));
@@ -509,37 +497,3 @@ TEST_F(SingleSeatInputDeviceHubSetup, tracks_a_single_button_state_from_multiple
     mouse_sink_1->handle_input(std::move(motion_3));
     mouse_sink_1->handle_input(std::move(motion_4));
 }
-
-TEST_F(SingleSeatInputDeviceHubSetup, input_device_changes_sent_to_session)
-{
-    NiceMock<mtd::MockSceneSession> session;
-    session_container.insert_session(mt::fake_shared(session));
-
-    EXPECT_CALL(session, send_input_config(UnorderedElementsAre(DeviceMatches(device.get_device_info()))));
-    hub.add_device(mt::fake_shared(device));
-}
-
-TEST_F(SingleSeatInputDeviceHubSetup, input_device_changes_sent_to_session_multiple_devices)
-{
-    NiceMock<mtd::MockSceneSession> session;
-    session_container.insert_session(mt::fake_shared(session));
-
-    hub.add_device(mt::fake_shared(device));
-
-    EXPECT_CALL(session,
-                send_input_config(UnorderedElementsAre(DeviceMatches(device.get_device_info()),
-                                                       DeviceMatches(another_device.get_device_info()))));
-    hub.add_device(mt::fake_shared(another_device));
-}
-
-TEST_F(SingleSeatInputDeviceHubSetup, input_device_changes_sent_to_sink_removal)
-{
-    hub.add_device(mt::fake_shared(device));
-    hub.add_device(mt::fake_shared(another_device));
-
-    NiceMock<mtd::MockSceneSession> session;
-    session_container.insert_session(mt::fake_shared(session));
-    EXPECT_CALL(session,
-                send_input_config(UnorderedElementsAre(DeviceMatches(another_device.get_device_info()))));
-    hub.remove_device(mt::fake_shared(device));
-}
