@@ -14,8 +14,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir_toolkit/client_types.h"
-#include "mir/graphics/display_configuration.h"
+#include <mir_toolkit/client_types.h>
+#include <mir/graphics/display_configuration.h>
 
 #include <gtest/gtest.h>
 
