@@ -14,31 +14,33 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/compositor/display_listener.h"
-#include "mir/graphics/platform.h"
-#include "mir/renderer/renderer_factory.h"
+#include <mir/compositor/display_listener.h>
+#include <mir/graphics/platform.h>
+#include <mir/renderer/renderer_factory.h>
 #include "src/server/report/null_report_factory.h"
 #include "src/server/scene/surface_stack.h"
-#include "src/server/scene/basic_surface.h"
+#include <mir/scene/basic_surface.h>
 #include "src/server/compositor/default_display_buffer_compositor_factory.h"
 #include "src/server/compositor/multi_threaded_compositor.h"
-#include "mir/compositor/stream.h"
-#include "mir/test/fake_shared.h"
-#include "mir/test/doubles/fake_display_configuration_observer_registrar.h"
-#include "mir/test/doubles/mock_buffer_stream.h"
-#include "mir/test/doubles/null_display.h"
-#include "mir/test/doubles/stub_renderer.h"
-#include "mir/test/doubles/stub_display_sink.h"
-#include "mir/test/doubles/stub_buffer.h"
-#include "mir/test/doubles/null_display_sync_group.h"
-#include "mir/test/doubles/mock_event_sink.h"
-#include "mir/test/doubles/stub_buffer_allocator.h"
-#include "mir/test/doubles/mock_gl_buffer.h"
-#include "mir/test/doubles/mock_output_surface.h"
-#include "mir/test/doubles/stub_gl_rendering_provider.h"
-#include "mir/test/doubles/null_gl_config.h"
-#include "mir/test/doubles/stub_buffer_allocator.h"
-#include "mir/test/doubles/stub_main_loop.h"
+#include <mir/compositor/stream.h>
+#include <mir/test/fake_shared.h>
+#include <mir/test/doubles/fake_display_configuration_observer_registrar.h>
+#include <mir/test/doubles/mock_buffer_stream.h>
+#include <mir/test/doubles/null_display.h>
+#include <mir/test/doubles/stub_renderer.h>
+#include <mir/test/doubles/stub_display_sink.h>
+#include <mir/test/doubles/stub_buffer.h>
+#include <mir/test/doubles/null_display_sync_group.h>
+#include <mir/test/doubles/mock_event_sink.h>
+#include <mir/test/doubles/stub_buffer_allocator.h>
+#include <mir/test/doubles/mock_gl_buffer.h>
+#include <mir/test/doubles/mock_output_surface.h>
+#include <mir/test/doubles/stub_gl_rendering_provider.h>
+#include <mir/test/doubles/null_gl_config.h>
+#include <mir/test/doubles/stub_buffer_allocator.h>
+#include <mir/test/doubles/stub_main_loop.h>
+#include <mir/test/doubles/stub_output_filter.h>
+#include <mir/test/doubles/stub_cursor.h>
 
 #include <condition_variable>
 #include <mutex>
@@ -159,8 +161,6 @@ struct SurfaceStackCompositor : public Test
         streams({ { stream, {0,0}} }),
         display_config_registrar{std::make_shared<mtd::FakeDisplayConfigurationObserverRegistrar>()},
         stub_surface{std::make_shared<ms::BasicSurface>(
-            nullptr /* session */,
-            mw::Weak<mf::WlSurface>{},
             std::string("stub"),
             geom::Rectangle{{0,0},{1,1}},
             mir_pointer_unconfined,
@@ -172,8 +172,6 @@ struct SurfaceStackCompositor : public Test
         other_stream(std::make_shared<mc::Stream>()),
         other_streams({ { other_stream, {0,0}} }),
         other_stub_surface{std::make_shared<ms::BasicSurface>(
-            nullptr /* session */,
-            mw::Weak<mf::WlSurface>{},
             std::string("other_stub"),
             geom::Rectangle{{10,0},{1,1}},
             mir_pointer_unconfined,
@@ -203,13 +201,15 @@ struct SurfaceStackCompositor : public Test
     CountingDisplaySyncGroup stub_secondary_db;
     StubDisplay stub_display{stub_primary_db, stub_secondary_db};
     StubDisplayListener stub_display_listener;
+    std::shared_ptr<mtd::StubCursor> stub_cursor{std::make_shared<mtd::StubCursor>()};
 
     mc::DefaultDisplayBufferCompositorFactory dbc_factory{
         std::vector<std::shared_ptr<mg::GLRenderingProvider>>{std::make_shared<mtd::StubGlRenderingProvider>()},
         std::make_shared<mtd::NullGLConfig>(),
         mt::fake_shared(renderer_factory),
         std::make_shared<mtd::StubBufferAllocator>(),
-        null_comp_report};
+        null_comp_report,
+        std::make_shared<mtd::StubOutputFilter>()};
 };
 
 std::chrono::milliseconds const default_delay{-1};
@@ -226,7 +226,7 @@ TEST_F(SurfaceStackCompositor, composes_on_start_if_told_to_in_constructor_when_
         mt::fake_shared(dbc_factory),
         mt::fake_shared(stack),
         mt::fake_shared(stub_display_listener),
-        null_comp_report, default_delay, true);
+        null_comp_report, stub_cursor, default_delay, true);
     mt_compositor.start();
 
     EXPECT_TRUE(stub_primary_db.has_posted_at_least(1, timeout));
@@ -240,7 +240,7 @@ TEST_F(SurfaceStackCompositor, does_not_compose_on_start_if_told_to_in_construct
         mt::fake_shared(dbc_factory),
         mt::fake_shared(stack),
         mt::fake_shared(stub_display_listener),
-        null_comp_report, default_delay, true);
+        null_comp_report, stub_cursor, default_delay, true);
     mt_compositor.start();
 
     EXPECT_TRUE(stub_primary_db.has_posted_at_least(0, timeout));
@@ -254,7 +254,7 @@ TEST_F(SurfaceStackCompositor, does_not_composes_on_start_if_told_not_to_in_cons
         mt::fake_shared(dbc_factory),
         mt::fake_shared(stack),
         mt::fake_shared(stub_display_listener),
-        null_comp_report, default_delay, false);
+        null_comp_report, stub_cursor, default_delay, false);
     mt_compositor.start();
 
     EXPECT_TRUE(stub_primary_db.has_posted_at_least(0, timeout));
@@ -268,7 +268,7 @@ TEST_F(SurfaceStackCompositor, swapping_a_surface_that_has_been_added_triggers_a
         mt::fake_shared(dbc_factory),
         mt::fake_shared(stack),
         mt::fake_shared(stub_display_listener),
-        null_comp_report, default_delay, false);
+        null_comp_report, stub_cursor, default_delay, false);
     mt_compositor.start();
 
     stack.add_surface(stub_surface, mi::InputReceptionMode::normal);
@@ -285,7 +285,7 @@ TEST_F(SurfaceStackCompositor, an_empty_scene_retriggers)
         mt::fake_shared(dbc_factory),
         mt::fake_shared(stack),
         mt::fake_shared(stub_display_listener),
-        null_comp_report, default_delay, false);
+        null_comp_report, stub_cursor, default_delay, false);
     mt_compositor.start();
 
     stack.add_surface(stub_surface, mi::InputReceptionMode::normal);
@@ -310,7 +310,7 @@ TEST_F(SurfaceStackCompositor, moving_a_surface_triggers_composition)
         mt::fake_shared(dbc_factory),
         mt::fake_shared(stack),
         mt::fake_shared(stub_display_listener),
-        null_comp_report, default_delay, false);
+        null_comp_report, stub_cursor, default_delay, false);
 
     mt_compositor.start();
     stub_surface->move_to(geom::Point{1,1});
@@ -332,7 +332,7 @@ TEST_F(SurfaceStackCompositor, removing_a_surface_triggers_composition)
         mt::fake_shared(dbc_factory),
         mt::fake_shared(stack),
         mt::fake_shared(stub_display_listener),
-        null_comp_report, default_delay, false);
+        null_comp_report, stub_cursor, default_delay, false);
 
     mt_compositor.start();
     stack.remove_surface(stub_surface);
@@ -351,7 +351,7 @@ TEST_F(SurfaceStackCompositor, buffer_updates_trigger_composition)
         mt::fake_shared(dbc_factory),
         mt::fake_shared(stack),
         mt::fake_shared(stub_display_listener),
-        null_comp_report, default_delay, false);
+        null_comp_report, stub_cursor, default_delay, false);
 
     mt_compositor.start();
     streams.front().stream->submit_buffer(stub_buffer, stub_buffer->size(), {{0, 0}, geom::SizeD{stub_buffer->size()}});
