@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/test/spin_wait.h"
+#include <mir/test/spin_wait.h>
 
 #include <thread>
 
@@ -24,11 +24,11 @@ bool mir::test::spin_wait_for_condition_or_timeout(
     std::chrono::milliseconds spin_period)
 {
     auto const end = std::chrono::steady_clock::now() + timeout;
-    
+
     while (std::chrono::steady_clock::now() < end && !condition())
     {
         std::this_thread::sleep_for(spin_period);
-    }   
+    }
 
     return condition();
 }
