@@ -14,9 +14,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/test/doubles/fake_alarm_factory.h"
-#include "mir/lockable_callback.h"
-#include "mir/basic_callback.h"
+#include <mir/test/doubles/fake_alarm_factory.h>
+#include <mir/lockable_callback.h>
+#include <mir/basic_callback.h>
 
 #include <numeric>
 #include <algorithm>
