@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/test/doubles/mock_egl.h"
+#include <mir/test/doubles/mock_egl.h>
 #include <gtest/gtest.h>
 
 namespace mtd = mir::test::doubles;
@@ -147,7 +147,7 @@ mtd::MockEGL::MockEGL()
         }));
 
     ON_CALL(*this, eglSwapBuffers(_,_))
-        .WillByDefault(Return(EGL_TRUE));                              
+        .WillByDefault(Return(EGL_TRUE));
 
     ON_CALL(*this, eglGetCurrentDisplay())
     .WillByDefault(Return(fake_egl_display));
@@ -195,7 +195,8 @@ void mtd::MockEGL::provide_egl_extensions()
         "GL_OES_EGL_image "
         "EGL_EXT_image_dma_buf_import "
         "EGL_WL_bind_wayland_display "
-        "EGL_EXT_platform_base";
+        "EGL_EXT_platform_base "
+        "EGL_EXT_device_query";
     ON_CALL(*this, eglQueryString(_,EGL_EXTENSIONS))
         .WillByDefault(Return(egl_exts));
 }
