@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/test/doubles/null_logger.h"
+#include <mir/test/doubles/null_logger.h>
 
 namespace mtd = mir::test::doubles;
 
