@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/test/doubles/stub_display_configuration.h"
+#include <mir/test/doubles/stub_display_configuration.h>
 
 #include <limits>
 #include <boost/throw_exception.hpp>
@@ -94,7 +94,6 @@ mtd::StubDisplayConfigurationOutput::StubDisplayConfigurationOutput(
             subpixel_arrangement,
             {},
             mir_output_gamma_unsupported,
-            {},
             {}
         }
 {
@@ -125,7 +124,6 @@ mtd::StubDisplayConfigurationOutput::StubDisplayConfigurationOutput(
         mir_subpixel_arrangement_unknown,
         {},
         mir_output_gamma_unsupported,
-        {},
         {}
     }
 {
@@ -229,7 +227,6 @@ mtd::StubDisplayConfig::StubDisplayConfig(unsigned int num_displays, std::vector
             mir_subpixel_arrangement_unknown,
             {},
             mir_output_gamma_unsupported,
-            {},
             {}
         };
 
@@ -258,7 +255,6 @@ mtd::StubDisplayConfig::StubDisplayConfig(std::vector<geometry::Rectangle> const
                 mir_subpixel_arrangement_unknown,
                 {},
                 mir_output_gamma_unsupported,
-                {},
                 {}
             };
 
