@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -14,8 +14,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/test/doubles/triggered_main_loop.h"
-#include "mir/test/doubles/stub_alarm.h"
+#include <mir/test/doubles/triggered_main_loop.h>
+#include <mir/test/doubles/stub_alarm.h>
 
 #include <algorithm>
 #include <sys/select.h>
@@ -35,16 +35,12 @@ void mtd::TriggeredMainLoop::register_fd_handler(std::initializer_list<int> fds,
 void mtd::TriggeredMainLoop::unregister_fd_handler(void const* owner)
 {
     base::unregister_fd_handler(owner);
-    fd_callbacks.erase(
-        remove_if(
-            begin(fd_callbacks),
-            end(fd_callbacks),
-            [owner](Item const& item)
-            {
-                return item.owner == owner;
-            }),
-        end(fd_callbacks)
-        );
+    std::erase_if(
+        fd_callbacks,
+        [owner](Item const& item)
+        {
+            return item.owner == owner;
+        });
 }
 
 void mtd::TriggeredMainLoop::trigger_pending_fds()
