@@ -14,16 +14,18 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir_test_framework/executable_path.h"
+#include <mir_test_framework/executable_path.h>
 #include <mir/fatal.h>
 
 #include <libgen.h>
-#include <stdexcept>
 #include <boost/throw_exception.hpp>
 #include <boost/exception/errinfo_errno.hpp>
-#include <boost/filesystem.hpp>
 #include <dlfcn.h>
 
+#include <filesystem>
+#include <format>
+#include <stdexcept>
+
 std::string mir_test_framework::executable_path()
 {
     char buf[1024];
@@ -60,7 +62,7 @@ std::string mir_test_framework::server_platform_path()
     for (auto const& option : {library_path() + "/server-modules/",
                                library_path() + "/mir/server-platform/",
                                std::string(MIR_SERVER_PLATFORM_PATH) + '/'})
-        if (boost::filesystem::exists(option))
+        if (std::filesystem::exists(option))
             return option;
     BOOST_THROW_EXCEPTION(std::runtime_error("Failed to find server platform directory in standard search locations"));
 }
@@ -70,9 +72,9 @@ std::string mir_test_framework::test_data_path()
     std::string run_path     = executable_path() + "/test-data";
     std::string install_path = MIR_INSTALL_PREFIX"/share/mir-test-data";
 
-    if (boost::filesystem::exists(run_path))
+    if (std::filesystem::exists(run_path))
         return run_path;
-    else if (boost::filesystem::exists(install_path))
+    else if (std::filesystem::exists(install_path))
         return install_path;
 
     BOOST_THROW_EXCEPTION(std::runtime_error("Failed to find test data in standard search locations"));
@@ -89,11 +91,11 @@ std::string mir_test_framework::server_platform(std::string const& name)
          {library_path() + "/server-modules/", library_path() + "/mir/server-platform/", std::string(MIR_SERVER_PLATFORM_PATH) + '/'})
     {
         auto path_to_test = option + libname;
-        if (boost::filesystem::exists(path_to_test))
+        if (std::filesystem::exists(path_to_test))
             return path_to_test;
     }
 
-    BOOST_THROW_EXCEPTION(std::runtime_error("Failed to find server platform in standard search locations"));
+    BOOST_THROW_EXCEPTION(std::runtime_error(std::format("Failed to find graphics platform '{}' in standard search locations", name)));
 }
 
 std::string mir_test_framework::server_input_platform(std::string const& name)
@@ -107,9 +109,9 @@ std::string mir_test_framework::server_input_platform(std::string const& name)
          {library_path() + "/server-modules/", library_path() + "/mir/server-platform/", std::string(MIR_SERVER_PLATFORM_PATH) + '/'})
     {
         auto path_to_test = option + libname;
-        if (boost::filesystem::exists(path_to_test))
+        if (std::filesystem::exists(path_to_test))
             return path_to_test;
     }
 
-    BOOST_THROW_EXCEPTION(std::runtime_error("Failed to find server input platform in standard search locations"));
+    BOOST_THROW_EXCEPTION(std::runtime_error(std::format("Failed to find input platform '{}' in standard search locations", name)));
 }
