@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -14,9 +14,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/graphics/display.h"
-#include "mir_test_framework/headless_in_process_server.h"
-#include "mir_test_framework/stub_server_platform_factory.h"
+#include <mir/graphics/display.h>
+#include <mir_test_framework/headless_in_process_server.h>
+#include <mir_test_framework/stub_server_platform_factory.h>
 
 namespace mtf = mir_test_framework;
 namespace msh = mir::shell;
