@@ -1,5 +1,5 @@
 /*
- * Copyright © 2012 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -14,8 +14,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir_test_framework/process.h"
-#include "mir/log.h"
+#include <mir_test_framework/process.h>
+#include <mir/log.h>
 
 #include <errno.h>
 #include <signal.h>
@@ -81,7 +81,6 @@ mtf::Process::Process(pid_t pid)
     , terminated(false)
     , detached(false)
 {
-    assert(pid > 0);
 }
 
 mtf::Process::~Process()
