@@ -1,6 +1,6 @@
 
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -15,14 +15,14 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/shared_library.h"
+#include <mir/shared_library.h>
 
-#include "mir/geometry/rectangle.h"
-#include "mir/graphics/display.h"
+#include <mir/geometry/rectangle.h>
+#include <mir/graphics/display.h>
 
-#include "mir_test_framework/executable_path.h"
-#include "mir_test_framework/stub_server_platform_factory.h"
-#include "mir_test_framework/fake_input_device.h"
+#include <mir_test_framework/executable_path.h>
+#include <mir_test_framework/stub_server_platform_factory.h>
+#include <mir_test_framework/fake_input_device.h>
 
 #include <vector>
 
@@ -41,11 +41,11 @@ void ensure_platform_library()
 {
     if (!platform_graphics_lib)
     {
-        platform_graphics_lib = new mir::SharedLibrary{mtf::server_platform("graphics-dummy.so")};
+        platform_graphics_lib = new mir::SharedLibrary{mtf::server_platform("graphics-dummy")};
     }
     if (!platform_input_lib)
     {
-        platform_input_lib = new mir::SharedLibrary{mtf::server_platform("input-stub.so")};
+        platform_input_lib = new mir::SharedLibrary{mtf::server_input_platform("input-stub")};
     }
 }
 }
