@@ -16,13 +16,13 @@
 
 #include "stubbed_graphics_platform.h"
 
-#include "mir/graphics/platform.h"
+#include <mir/graphics/platform.h>
 
-#include "mir_toolkit/common.h"
-#include "mir/test/doubles/stub_buffer_allocator.h"
-#include "mir/test/doubles/stub_gl_rendering_provider.h"
-#include "mir/test/doubles/fake_display.h"
-#include "mir/assert_module_entry_point.h"
+#include <mir_toolkit/common.h>
+#include <mir/test/doubles/stub_buffer_allocator.h>
+#include <mir/test/doubles/stub_gl_rendering_provider.h>
+#include <mir/test/doubles/fake_display.h>
+#include <mir/assert_module_entry_point.h>
 
 #include <boost/exception/errinfo_errno.hpp>
 #include <boost/throw_exception.hpp>
@@ -100,9 +100,16 @@ auto mtf::StubGraphicPlatform::maybe_create_provider(
     return nullptr;
 }
 
-auto mtf::StubGraphicPlatform::maybe_create_provider(mg::DisplayProvider::Tag const&)
+auto mtf::StubGraphicPlatform::maybe_create_provider(mg::DisplayProvider::Tag const& tag)
     -> std::shared_ptr<mg::DisplayProvider>
 {
+    class NullCPUAddressableDisplayProvider : public mg::CPUAddressableDisplayProvider
+    {
+    };
+    if (dynamic_cast<mg::CPUAddressableDisplayProvider::Tag const*>(&tag))
+    {
+        return std::make_shared<NullCPUAddressableDisplayProvider>();
+    }
     return nullptr;
 }
 
