@@ -14,11 +14,12 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <mir/test/doubles/stub_gl_rendering_provider.h>
 #include "src/server/compositor/default_display_buffer_compositor_factory.h"
 #include <miral/test_display_server.h>
 
 #include <miral/command_line_option.h>
-#include <miral/minimal_window_manager.h>
+#include <miral/floating_window_manager.h>
 #include <miral/set_window_management_policy.h>
 
 #include <mir_test_framework/executable_path.h>
@@ -60,7 +61,6 @@ miral::TestDisplayServer::TestDisplayServer(int argc, char const** argv) :
     unsetenv("WAYLAND_DISPLAY");    // We don't want to conflict with any existing server
     add_to_environment("MIR_SERVER_PLATFORM_PATH", mtf::server_platform_path().c_str());
     add_to_environment("MIR_SERVER_PLATFORM_DISPLAY_LIBS", "mir:stub-graphics");
-    add_to_environment("MIR_SERVER_PLATFORM_RENDERING_LIBS", "mir:stub-graphics");
     add_to_environment("MIR_SERVER_PLATFORM_INPUT_LIB", "mir:stub-input");
     add_to_environment("MIR_SERVER_CONSOLE_PROVIDER", "none");
 }
@@ -70,7 +70,7 @@ miral::TestDisplayServer::~TestDisplayServer() = default;
 auto miral::TestDisplayServer::build_window_manager_policy(WindowManagerTools const& tools)
 -> std::unique_ptr<WindowManagementPolicy>
 {
-    return std::make_unique<MinimalWindowManager>(tools);
+    return std::make_unique<FloatingWindowManager>(tools);
 }
 
 void miral::TestDisplayServer::start_server()
@@ -104,24 +104,30 @@ void miral::TestDisplayServer::start_server()
                                 });
                         });
 
-
-                    server.override_the_display_buffer_compositor_factory(
-                        [&server]() -> std::shared_ptr<mir::compositor::DisplayBufferCompositorFactory>
+                    // We want to use the native RenderingPlatform if available, but if not we
+                    // need to stub out the DisplayBufferCompositorFactory. While it would be
+                    // possible to set up a full set of MockGL/MockEGL dummies, doing so across
+                    // the DSO loader is sufficiently annoying that we should just use a dummy,
+                    // non-GL DisplayBufferCompositor.
+                    server.wrap_display_buffer_compositor_factory(
+                        [&server](auto default_impl) -> std::shared_ptr<mir::compositor::DisplayBufferCompositorFactory>
                         {
                             auto first_rendering_platform = server.the_rendering_platforms().front();
                             auto gl_provider =
                                 mg::RenderingPlatform::acquire_provider<mg::GLRenderingProvider>(
                                     std::move(first_rendering_platform));
-                            if (gl_provider)
+                            if (gl_provider && std::dynamic_pointer_cast<mtd::StubGlRenderingProvider>(gl_provider))
                             {
                                 return std::make_shared<mtf::HeadlessDisplayBufferCompositorFactory>(
                                     std::move(gl_provider),
                                     server.the_gl_config());
                             }
-                            BOOST_THROW_EXCEPTION((std::runtime_error{"Platform does not support GL interface"}));
+                            else
+                            {
+                                return default_impl;
+                            }
                         });
 
-
                     server.override_the_logger([&]()
                         {
                             std::shared_ptr<ml::Logger> result{};
