@@ -1,5 +1,5 @@
 /*
- * Copyright © 2019 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3 as
@@ -15,7 +15,7 @@
  */
 
 #include "test_window_manager_tools.h"
-#include "miral/output.h"
+#include <miral/output.h>
 
 #include <optional>
 
