@@ -15,13 +15,15 @@
  */
 
 #include "static_display_config.h"
-#include "mir/logging/dumb_console_logger.h"
-#include "mir/logging/logger.h"
+#include <mir/logging/dumb_console_logger.h>
+#include <mir/logging/logger.h>
 
 #include <mir/test/doubles/mock_display_configuration.h>
 
+#include <filesystem>
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
+#include "yaml-cpp/yaml.h"
 
 using namespace testing;
 using namespace mir::geometry;
@@ -35,10 +37,20 @@ namespace
 static constexpr Point default_top_left{0, 0};
 static constexpr mg::DisplayConfigurationMode default_mode{{648, 480}, 60.0};
 static constexpr mg::DisplayConfigurationMode another_mode{{1280, 1024}, 75.0};
+static const std::vector<uint8_t> basic_edid{
+    0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x59, 0x96, 0x01, 0x30, 0x01, 0x00, 0x00, 0x00,
+    0x1e, 0x1c, 0x01, 0x04, 0xa5, 0x0a, 0x0f, 0x78, 0x16, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x01, 0x00, 0x01, 0x00, 0x01, 0x00, 0x01, 0x00,
+    0x01, 0x00, 0x01, 0x00, 0x01, 0x00, 0x0f, 0x1b, 0x20, 0x48, 0x30, 0x00, 0x2c, 0x50, 0x20, 0x14,
+    0x02, 0x04, 0x3c, 0x3c, 0x00, 0x00, 0x00, 0x1e, 0x00, 0x00, 0x00, 0xfc, 0x00, 0x41, 0x4e, 0x58,
+    0x37, 0x35, 0x33, 0x30, 0x20, 0x55, 0x0a, 0x20, 0x20, 0x20, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x93,
+};
 
 struct MockLogger : ml::Logger
 {
-    MOCK_METHOD3(log, void (ml::Severity severity, const std::string& message, const std::string& component));
+    MOCK_METHOD(void, log, (ml::Severity severity, const std::string& message, const std::string& component), (override));
 };
 
 struct StaticDisplayConfig : Test
@@ -81,6 +93,7 @@ struct StaticDisplayConfig : Test
         hdmi1.power_mode = mir_power_mode_on;
         hdmi1.orientation = mir_orientation_normal;
         hdmi1.name = "HDMI-A-1";
+        hdmi1.display_info = mg::DisplayInfo{basic_edid};
 
         EXPECT_CALL(dc, for_each_output(_)).WillRepeatedly(DoAll(
             InvokeArgument<0>(mg::UserDisplayConfigurationOutput{vga1}),
@@ -151,7 +164,10 @@ public:
 
 TEST_F(StaticDisplayConfig, nonexistent_config_file_is_no_error)
 {
-    miral::StaticDisplayConfig{tmpnam(nullptr)};
+    char tmp_dir_path[] = "/tmp/mir-XXXXXX";
+    ASSERT_THAT(mkdtemp(tmp_dir_path), NotNull());
+    miral::StaticDisplayConfig{std::string(tmp_dir_path) + "/display.conf"};
+    std::filesystem::remove_all(tmp_dir_path);
 }
 
 TEST_F(StaticDisplayConfig, empty_config_input_causes_AbnormalExit)
@@ -175,6 +191,47 @@ TEST_F(StaticDisplayConfig, well_formed_non_config_input_causes_AbnormalExit)
     EXPECT_THROW((sdc.load_config(well_formed, "")), mir::AbnormalExit);
 }
 
+TEST_F(StaticDisplayConfig, empty_layout_is_error)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"};
+
+    EXPECT_THROW((sdc.load_config(stream, "")), mir::AbnormalExit);
+}
+
+TEST_F(StaticDisplayConfig, empty_cards_is_error)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    cards:\n"};
+
+    EXPECT_THROW((sdc.load_config(stream, "")), mir::AbnormalExit);
+}
+
+TEST_F(StaticDisplayConfig, empty_card_is_no_error)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    cards:\n"
+        "    - \n"};
+
+    sdc.load_config(stream, "");
+}
+
+TEST_F(StaticDisplayConfig, empty_output_is_no_error)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    cards:\n"
+        "    - VGA-1:\n"};
+
+    sdc.load_config(stream, "");
+}
+
 TEST_F(StaticDisplayConfig, valid_config_input_is_no_error)
 {
     std::istringstream valid_config_stream{valid_input};
@@ -539,3 +596,300 @@ TEST_F(StaticDisplayConfig, given_no_custom_attributes_when_they_are_added_exist
 
     EXPECT_THAT(hdmi1.custom_attribute, ElementsAre());
 }
+
+TEST_F(StaticDisplayConfig, can_set_and_retrieve_custom_data_on_layouts)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  another:\n"
+        "    cards:\n"
+        "    - VGA-1:\n"
+        "        state: disabled\n"
+        "    - HDMI-A-1:\n"
+        "        state: disabled\n"
+        "    custom_data: value\n"
+        "  expected:\n"
+        "    cards:\n"
+        "    - VGA-1:\n"
+        "        orientation: inverted\n"
+        "    - HDMI-A-1:\n"
+        "        position: [1280, 0]\n"};
+
+    sdc.layout_userdata_builder("custom_data",  [](YAML::Node const& node) -> std::any
+    {
+        EXPECT_THAT(node.Scalar(), Eq("value"));
+        return node.Scalar();
+    });
+
+    sdc.load_config(stream, "");
+    EXPECT_THAT(sdc.layout_userdata("custom_data"), Eq(std::nullopt));
+    sdc.select_layout("another");
+    auto const other_data = sdc.layout_userdata("custom_data");
+    EXPECT_THAT(other_data, Ne(std::nullopt));
+    EXPECT_THAT(std::any_cast<std::string>(other_data.value()), Eq("value"));
+}
+
+TEST_F(StaticDisplayConfig, empty_displays_is_error)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"};
+
+    EXPECT_THROW((sdc.load_config(stream, "")), mir::AbnormalExit);
+}
+
+TEST_F(StaticDisplayConfig, null_display_is_error)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"
+        "    - \n"};
+
+    EXPECT_THROW((sdc.load_config(stream, "")), mir::AbnormalExit);
+}
+
+TEST_F(StaticDisplayConfig, empty_display_is_error)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"
+        "    - {}\n"};
+
+    EXPECT_THROW((sdc.load_config(stream, "")), mir::AbnormalExit);
+}
+
+struct PropertyValueTest : public StaticDisplayConfig, public WithParamInterface<std::pair<std::string, std::string>>
+{
+};
+
+TEST_P(PropertyValueTest, invalid_display_property_value_is_error)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"
+        "    - " + GetParam().first + ": null\n"};
+
+    EXPECT_THROW((sdc.load_config(stream, "")), mir::AbnormalExit);
+}
+
+TEST_P(PropertyValueTest, empty_display_property_value_is_error)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"
+        "    - " + GetParam().first + ": ""\n"};
+
+    EXPECT_THROW((sdc.load_config(stream, "")), mir::AbnormalExit);
+}
+
+TEST_F(StaticDisplayConfig, no_matcher_matches_all)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"
+        "    - state: disabled\n"};
+
+    sdc.load_config(stream, "");
+
+    sdc.apply_to(dc);
+
+    EXPECT_THAT(vga1.used, Eq(false));
+    EXPECT_THAT(vga1.power_mode, Eq(mir_power_mode_off));
+    EXPECT_THAT(hdmi1.used, Eq(false));
+    EXPECT_THAT(hdmi1.power_mode, Eq(mir_power_mode_off));
+}
+
+TEST_F(StaticDisplayConfig, unmatched_displays_dont_change)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"
+        "    - vendor: unmatched\n"
+        "      state: disabled\n"};
+
+    sdc.load_config(stream, "");
+
+    sdc.apply_to(dc);
+
+    EXPECT_THAT(vga1.used, Eq(true));
+    EXPECT_THAT(vga1.power_mode, Eq(mir_power_mode_on));
+    EXPECT_THAT(hdmi1.used, Eq(true));
+    EXPECT_THAT(hdmi1.power_mode, Eq(mir_power_mode_on));
+}
+
+TEST_F(StaticDisplayConfig, displays_are_matched_by_vendor)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"
+        "    - vendor: Valve Corporation\n"
+        "      group: 1\n"};
+
+    sdc.load_config(stream, "");
+
+    sdc.apply_to(dc);
+
+    EXPECT_THAT(hdmi1.logical_group_id, Eq(mg::DisplayConfigurationLogicalGroupId{1}));
+    EXPECT_THAT(vga1.logical_group_id, Eq(mg::DisplayConfigurationLogicalGroupId{0}));
+}
+
+TEST_F(StaticDisplayConfig, displays_are_matched_by_model)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"
+        "    - model: ANX7530 U\n"
+        "      orientation: left\n"};
+
+    sdc.load_config(stream, "");
+
+    sdc.apply_to(dc);
+
+    EXPECT_THAT(hdmi1.orientation, Eq(mir_orientation_left));
+    EXPECT_THAT(vga1.orientation, Eq(mir_orientation_normal));
+}
+
+TEST_F(StaticDisplayConfig, displays_are_matched_by_product)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"
+        "    - product: 12289\n"
+        "      position: [100, 100]\n"};
+
+    sdc.load_config(stream, "");
+
+    sdc.apply_to(dc);
+
+    EXPECT_THAT(hdmi1.top_left, Eq(Point{100, 100}));
+    EXPECT_THAT(vga1.top_left, Eq(Point{0, 0}));
+}
+
+TEST_F(StaticDisplayConfig, displays_are_matched_by_serial)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"
+        "    - serial: 0x00000001\n"
+        "      state: disabled\n"};
+
+    sdc.load_config(stream, "");
+
+    sdc.apply_to(dc);
+
+    EXPECT_THAT(vga1.used, Eq(true));
+    EXPECT_THAT(vga1.power_mode, Eq(mir_power_mode_on));
+    EXPECT_THAT(hdmi1.used, Eq(false));
+    EXPECT_THAT(hdmi1.power_mode, Eq(mir_power_mode_off));
+}
+
+TEST_F(StaticDisplayConfig, displays_are_matched_by_multiple_properties)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"
+        "    - vendor: Valve Corporation\n"
+        "      model: ANX7530 U\n"
+        "      product: 12289\n"
+        "      serial: 0x00000001\n"
+        "      orientation: left\n"};
+
+    sdc.load_config(stream, "");
+
+    sdc.apply_to(dc);
+
+    EXPECT_THAT(hdmi1.orientation, Eq(mir_orientation_left));
+    EXPECT_THAT(vga1.orientation, Eq(mir_orientation_normal));
+}
+
+TEST_F(StaticDisplayConfig, displays_need_full_match)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    displays:\n"
+        "    - vendor: Valve Corporation\n"
+        "      model: ANX7530 U\n"
+        "      product: 12289\n"
+        "      serial: 1\n"  // incorrect serial
+        "      orientation: left\n"};
+
+    sdc.load_config(stream, "");
+
+    sdc.apply_to(dc);
+
+    EXPECT_THAT(hdmi1.orientation, Eq(mir_orientation_normal));
+    EXPECT_THAT(vga1.orientation, Eq(mir_orientation_normal));
+}
+
+TEST_F(StaticDisplayConfig, displays_precede_cards)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    cards:\n"
+        "    - HDMI-A-1:\n"
+        "        orientation: right\n"
+        "    displays:\n"
+        "    - vendor: Valve Corporation\n"
+        "      orientation: left\n"};
+
+    sdc.load_config(stream, "");
+
+    sdc.apply_to(dc);
+
+    EXPECT_THAT(hdmi1.orientation, Eq(mir_orientation_left));
+    EXPECT_THAT(vga1.orientation, Eq(mir_orientation_normal));
+}
+
+TEST_F(StaticDisplayConfig, cards_apply_on_unmatched_displays)
+{
+    std::istringstream stream{
+        "layouts:\n"
+        "  default:\n"
+        "    cards:\n"
+        "    - VGA-1:\n"
+        "        orientation: right\n"
+        "    displays:\n"
+        "    - vendor: Valve Corporation\n"
+        "      orientation: left\n"};
+
+    sdc.load_config(stream, "");
+
+    sdc.apply_to(dc);
+
+    EXPECT_THAT(hdmi1.orientation, Eq(mir_orientation_left));
+    EXPECT_THAT(vga1.orientation, Eq(mir_orientation_right));
+}
+
+TEST_P(PropertyValueTest, serialize_properties_for_outputs)
+{
+    std::ostringstream out;
+
+    miral::YamlFileDisplayConfig::serialize_configuration(out, dc);
+
+    ASSERT_THAT(out.str(), ContainsRegex("# [ -] " + GetParam().first + ": " + GetParam().second));
+}
+
+INSTANTIATE_TEST_SUITE_P(
+    EDIDValues,
+    PropertyValueTest,
+    Values(
+        std::make_pair("vendor", "Valve Corporation"),
+        std::make_pair("model", "ANX7530 U"),
+        std::make_pair("product", "12289"),
+        std::make_pair("serial", "0x00000001")
+    )
+);
