@@ -16,13 +16,16 @@
 
 #include <miral/window_info.h>
 
-#include "mir_test_framework/process.h"
+#include <mir_test_framework/process.h>
+
+#include <mir/test/doubles/stub_surface.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
 
 using namespace miral;
 namespace mtf = mir_test_framework;
+using namespace testing;
 
 namespace
 {
@@ -37,7 +40,8 @@ TEST(WindowInfo, negative_window_size_does_not_divide_by_zero)
 {
     auto p = mtf::fork_and_run_in_a_different_process(
         [] {
-            Window window;
+            auto const surface = std::make_shared<mir::test::doubles::StubSurface>();
+            Window window{Application{}, surface};
             WindowSpecification params;
 
             Point p{0, 0};
@@ -57,3 +61,14 @@ TEST(WindowInfo, negative_window_size_does_not_divide_by_zero)
 
     EXPECT_TRUE(p->wait_for_termination().succeeded());
 }
+
+// Test for crash https://github.com/canonical/mir/issues/4281
+TEST(WindowInfo, stub_values_are_returned)
+{
+    WindowInfo info{};
+
+    EXPECT_THAT(info.min_width(), Eq(Width{0}));
+    EXPECT_THAT(info.min_height(), Eq(Height{0}));
+    EXPECT_THAT(info.max_width(), Eq(Width{std::numeric_limits<int>::max()}));
+    EXPECT_THAT(info.max_height(), Eq(Height{std::numeric_limits<int>::max()}));
+}
