@@ -17,22 +17,25 @@
 #include "src/server/compositor/multi_threaded_compositor.h"
 #include "src/server/report/null_report_factory.h"
 
-#include "mir/compositor/display_listener.h"
-#include "mir/compositor/display_buffer_compositor.h"
-#include "mir/compositor/scene.h"
-#include "mir/compositor/display_buffer_compositor_factory.h"
-#include "mir/scene/observer.h"
-#include "mir/raii.h"
+#include <mir/compositor/display_listener.h>
+#include <mir/compositor/display_buffer_compositor.h>
+#include <mir/compositor/scene.h>
+#include <mir/compositor/display_buffer_compositor_factory.h>
+#include <mir/scene/observer.h>
+#include <mir/raii.h>
 
-#include "mir/test/current_thread_name.h"
-#include "mir/test/doubles/null_display.h"
-#include "mir/test/doubles/null_display_sink.h"
-#include "mir/test/doubles/mock_display_sink.h"
-#include "mir/test/doubles/mock_compositor_report.h"
-#include "mir/test/doubles/mock_scene.h"
-#include "mir/test/doubles/stub_scene.h"
-#include "mir/test/doubles/stub_display.h"
-#include "mir/test/doubles/null_display_buffer_compositor_factory.h"
+#include <mir/test/current_thread_name.h>
+#include <mir/test/doubles/null_display.h>
+#include <mir/test/doubles/null_display_sink.h>
+#include <mir/test/doubles/mock_cursor.h>
+#include <mir/test/doubles/mock_display_sink.h>
+#include <mir/test/doubles/mock_compositor_report.h>
+#include <mir/test/doubles/mock_scene.h>
+#include <mir/test/doubles/stub_scene.h>
+#include <mir/test/doubles/stub_display.h>
+#include <mir/test/doubles/stub_renderable.h>
+#include <mir/test/doubles/null_display_buffer_compositor_factory.h>
+#include <mir/test/doubles/stub_cursor.h>
 
 #include <boost/throw_exception.hpp>
 
@@ -77,7 +80,7 @@ private:
     {
         void for_each_display_sink(std::function<void(mg::DisplaySink&)> const& f) override
         {
-            f(buffer);            
+            f(buffer);
         }
         void post() override {}
         std::chrono::milliseconds recommended_sleep() const override
@@ -342,11 +345,12 @@ struct StubDisplayListener : mc::DisplayListener
 
 struct MockDisplayListener : mc::DisplayListener
 {
-    MOCK_METHOD1(add_display, void(geom::Rectangle const& /*area*/));
-    MOCK_METHOD1(remove_display, void(geom::Rectangle const& /*area*/));
+    MOCK_METHOD(void, add_display, (geom::Rectangle const& /*area*/), (override));
+    MOCK_METHOD(void, remove_display, (geom::Rectangle const& /*area*/), (override));
 };
 
 auto const null_report = mr::null_compositor_report();
+auto const stub_cursor = std::make_shared<mtd::StubCursor>();
 unsigned int const composites_per_update{1};
 auto const null_display_listener = std::make_shared<StubDisplayListener>();
 std::chrono::milliseconds const default_delay{-1};
@@ -362,7 +366,7 @@ TEST(MultiThreadedCompositor, compositing_happens_in_different_threads)
     auto display = std::make_shared<mtd::StubDisplay>(nbuffers);
     auto scene = std::make_shared<StubScene>();
     auto db_compositor_factory = std::make_shared<RecordingDisplayBufferCompositorFactory>();
-    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, default_delay, true};
+    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, stub_cursor, default_delay, true};
 
     compositor.start();
 
@@ -403,6 +407,7 @@ TEST(MultiThreadedCompositor, does_not_deadlock_itself)
         scene,
         std::make_shared<ReentrantDisplayListener>(scene),
         null_report,
+        stub_cursor,
         default_delay,
         true
     };
@@ -429,6 +434,7 @@ TEST(MultiThreadedCompositor, reports_in_the_right_places)
                                            scene,
                                            null_display_listener,
                                            mock_report,
+                                           stub_cursor,
                                            default_delay,
                                            true};
 
@@ -474,7 +480,7 @@ TEST(MultiThreadedCompositor, composites_only_on_demand)
     auto display = std::make_shared<mtd::StubDisplay>(nbuffers);
     auto scene = std::make_shared<StubScene>();
     auto db_compositor_factory = std::make_shared<RecordingDisplayBufferCompositorFactory>();
-    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, default_delay, true};
+    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, stub_cursor, default_delay, true};
 
     // Verify we're actually starting at zero frames
     EXPECT_TRUE(db_compositor_factory->check_record_count_for_each_buffer(nbuffers, 0, 0));
@@ -537,7 +543,7 @@ TEST(MultiThreadedCompositor, recommended_sleep_throttles_compositor_loop)
     auto scene = std::make_shared<StubScene>();
     auto factory = std::make_shared<RecordingDisplayBufferCompositorFactory>();
     mc::MultiThreadedCompositor compositor{display, factory, scene,
-                                           null_display_listener, null_report,
+                                           null_display_listener, null_report, stub_cursor,
                                            recommendation, false};
 
     EXPECT_TRUE(factory->check_record_count_for_each_buffer(nbuffers, 0, 0));
@@ -586,7 +592,7 @@ TEST(MultiThreadedCompositor, when_no_initial_composite_is_needed_there_is_none)
     auto display = std::make_shared<mtd::StubDisplay>(nbuffers);
     auto scene = std::make_shared<StubScene>();
     auto db_compositor_factory = std::make_shared<RecordingDisplayBufferCompositorFactory>();
-    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, default_delay, false};
+    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, stub_cursor, default_delay, false};
 
     // Verify we're actually starting at zero frames
     ASSERT_TRUE(db_compositor_factory->check_record_count_for_each_buffer(nbuffers, 0, 0));
@@ -610,7 +616,7 @@ TEST(MultiThreadedCompositor, initial_composite_is_requested_we_composite_exactl
     auto display = std::make_shared<mtd::StubDisplay>(nbuffers);
     auto scene = std::make_shared<StubScene>();
     auto db_compositor_factory = std::make_shared<RecordingDisplayBufferCompositorFactory>();
-    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, default_delay, true};
+    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, stub_cursor, default_delay, true};
 
     // Verify we're actually starting at zero frames
     ASSERT_TRUE(db_compositor_factory->check_record_count_for_each_buffer(nbuffers, 0, 0));
@@ -633,7 +639,7 @@ TEST(MultiThreadedCompositor, when_no_initial_composite_is_needed_we_still_compo
     auto display = std::make_shared<mtd::StubDisplay>(nbuffers);
     auto scene = std::make_shared<StubScene>();
     auto db_compositor_factory = std::make_shared<RecordingDisplayBufferCompositorFactory>();
-    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, default_delay, false};
+    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, stub_cursor, default_delay, false};
 
     compositor.start();
 
@@ -668,7 +674,7 @@ TEST(MultiThreadedCompositor, surface_update_from_render_doesnt_deadlock)
     auto display = std::make_shared<mtd::StubDisplay>(nbuffers);
     auto scene = std::make_shared<StubScene>();
     auto db_compositor_factory = std::make_shared<SurfaceUpdatingDisplayBufferCompositorFactory>(scene);
-    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, default_delay, true};
+    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, stub_cursor, default_delay, true};
 
     compositor.start();
 
@@ -700,7 +706,7 @@ TEST(MultiThreadedCompositor, double_start_or_stop_ignored)
         .Times(AtLeast(0))
         .WillRepeatedly(Return(mc::SceneElementSequence{}));
 
-    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, mock_scene, null_display_listener, mock_report, default_delay, true};
+    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, mock_scene, null_display_listener, mock_report, stub_cursor, default_delay, true};
 
     compositor.start();
     compositor.start();
@@ -715,7 +721,7 @@ TEST(MultiThreadedCompositor, cleans_up_after_throw_in_start)
     auto display = std::make_shared<StubDisplayWithMockBuffers>(nbuffers);
     auto scene = std::make_shared<StubScene>();
     auto db_compositor_factory = std::make_shared<RecordingDisplayBufferCompositorFactory>();
-    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, default_delay, true};
+    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, stub_cursor, default_delay, true};
 
     scene->throw_on_add_observer(true);
 
@@ -769,7 +775,7 @@ TEST(MultiThreadedCompositor, DISABLED_names_compositor_threads)
     auto display = std::make_shared<StubDisplayWithMockBuffers>(nbuffers);
     auto scene = std::make_shared<StubScene>();
     auto db_compositor_factory = std::make_shared<ThreadNameDisplayBufferCompositorFactory>();
-    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, default_delay, true};
+    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, stub_cursor, default_delay, true};
 
     compositor.start();
 
@@ -798,7 +804,7 @@ TEST(MultiThreadedCompositor, registers_and_unregisters_with_scene)
     EXPECT_CALL(*mock_scene, register_compositor(_))
         .Times(nbuffers);
     mc::MultiThreadedCompositor compositor{
-        display, db_compositor_factory, mock_scene, null_display_listener, mock_report, default_delay, true};
+        display, db_compositor_factory, mock_scene, null_display_listener, mock_report, stub_cursor, default_delay, true};
 
     compositor.start();
 
@@ -821,7 +827,7 @@ TEST(MultiThreadedCompositor, notifies_about_display_additions_and_removals)
     auto mock_report = std::make_shared<testing::NiceMock<mtd::MockCompositorReport>>();
 
     mc::MultiThreadedCompositor compositor{
-        display, db_compositor_factory, stub_scene, mock_display_listener, mock_report, default_delay, true};
+        display, db_compositor_factory, stub_scene, mock_display_listener, mock_report, stub_cursor, default_delay, true};
 
     EXPECT_CALL(*mock_display_listener, add_display(_)).Times(nbuffers);
 
@@ -843,7 +849,7 @@ TEST(MultiThreadedCompositor, when_compositor_thread_fails_start_reports_error)
     auto mock_report = std::make_shared<testing::NiceMock<mtd::MockCompositorReport>>();
 
     mc::MultiThreadedCompositor compositor{
-        display, db_compositor_factory, stub_scene, mock_display_listener, mock_report, default_delay, true};
+        display, db_compositor_factory, stub_scene, mock_display_listener, mock_report, stub_cursor, default_delay, true};
 
     EXPECT_CALL(*mock_display_listener, add_display(_))
         .WillRepeatedly(Throw(std::runtime_error("Failed to add display")));
@@ -866,7 +872,7 @@ TEST(MultiThreadedCompositor, can_schedule_from_display_observer_when_adding_dis
         .WillByDefault(InvokeWithoutArgs([&]{ stub_scene->emit_change_event(); }));
 
     mc::MultiThreadedCompositor compositor{
-        display, db_compositor_factory, stub_scene, mock_display_listener, mock_report, default_delay, true};
+        display, db_compositor_factory, stub_scene, mock_display_listener, mock_report, stub_cursor, default_delay, true};
     compositor.start();
 }
 
@@ -884,6 +890,47 @@ TEST(MultiThreadedCompositor, can_schedule_from_display_observer_when_removing_d
         .WillByDefault(InvokeWithoutArgs([&]{ stub_scene->emit_change_event(); }));
 
     mc::MultiThreadedCompositor compositor{
-        display, db_compositor_factory, stub_scene, mock_display_listener, mock_report, default_delay, true};
+        display, db_compositor_factory, stub_scene, mock_display_listener, mock_report, stub_cursor, default_delay, true};
     compositor.start();
 }
+
+TEST(MultiThreadedCompositor, checks_if_cursor_needs_compositing)
+{
+    using namespace testing;
+    using namespace std::literals::chrono_literals;
+
+    unsigned int const nbuffers = 1;
+
+    auto display = std::make_shared<mtd::StubDisplay>(nbuffers);
+    auto scene = std::make_shared<StubScene>();
+    auto db_compositor_factory = std::make_shared<RecordingDisplayBufferCompositorFactory>();
+    auto const mock_cursor = std::make_shared<mtd::MockCursor>();
+    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, mock_cursor, default_delay, true};
+
+    EXPECT_CALL(*mock_cursor, needs_compositing()).Times(1).WillOnce(Return(false));
+    compositor.start();
+    std::this_thread::sleep_for(100ms);
+
+    compositor.stop();
+}
+
+TEST(MultiThreadedCompositor, gets_renderable_if_cursor_needs_compositing)
+{
+    using namespace testing;
+    using namespace std::literals::chrono_literals;
+
+    unsigned int const nbuffers = 1;
+
+    auto display = std::make_shared<mtd::StubDisplay>(nbuffers);
+    auto scene = std::make_shared<StubScene>();
+    auto db_compositor_factory = std::make_shared<RecordingDisplayBufferCompositorFactory>();
+    auto const mock_cursor = std::make_shared<mtd::MockCursor>();
+    mc::MultiThreadedCompositor compositor{display, db_compositor_factory, scene, null_display_listener, null_report, mock_cursor, default_delay, true};
+
+    EXPECT_CALL(*mock_cursor, needs_compositing()).Times(1).WillOnce(Return(true));
+    EXPECT_CALL(*mock_cursor, renderable()).Times(1).WillOnce(Return(std::make_shared<mtd::StubRenderable>()));
+    compositor.start();
+    std::this_thread::sleep_for(100ms);
+
+    compositor.stop();
+}
