@@ -15,11 +15,11 @@
  */
 
 #include "src/server/console/minimal_console_services.h"
-#include "mir_test_framework/open_wrapper.h"
-#include "mir/test/doubles/mock_drm.h"
-#include "mir/test/doubles/simple_device_observer.h"
+#include <mir_test_framework/open_wrapper.h>
+#include <mir/test/doubles/mock_drm.h>
+#include <mir/test/doubles/simple_device_observer.h>
 
-#include "mir/anonymous_shm_file.h"
+#include <mir/anonymous_shm_file.h>
 
 #include <fcntl.h>
 
