@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -14,9 +14,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/dispatch/action_queue.h"
+#include <mir/dispatch/action_queue.h>
 
-#include "mir/test/fd_utils.h"
+#include <mir/test/fd_utils.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
@@ -75,5 +75,3 @@ TEST(ActionQueue, executes_action_only_once)
     // Even so, we expect our action to be executed only once.
     EXPECT_THAT(count_executed, Eq(1));
 }
-
-
