@@ -14,13 +14,13 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/dispatch/multiplexing_dispatchable.h"
-#include "mir/dispatch/threaded_dispatcher.h"
-#include "mir/test/pipe.h"
-#include "mir/test/signal.h"
-#include "mir/test/fd_utils.h"
-#include "mir/test/test_dispatchable.h"
-#include "mir/test/auto_unblock_thread.h"
+#include <mir/dispatch/multiplexing_dispatchable.h>
+#include <mir/dispatch/threaded_dispatcher.h>
+#include <mir/test/pipe.h>
+#include <mir/test/signal.h>
+#include <mir/test/fd_utils.h>
+#include <mir/test/test_dispatchable.h>
+#include <mir/test/auto_unblock_thread.h>
 
 #include <atomic>
 #include <thread>
@@ -482,6 +482,6 @@ TEST(MultiplexingDispatchableTest, automatic_removals_are_threadsafe)
     eventloop.add_thread();
     eventloop.add_thread();
     eventloop.add_thread();
-    
+
     dispatchee->trigger();
 }
