@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/dispatch/readable_fd.h"
+#include <mir/dispatch/readable_fd.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
