@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -14,16 +14,16 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/dispatch/threaded_dispatcher.h"
-#include "mir/dispatch/dispatchable.h"
-#include "mir/fd.h"
-#include "mir/test/current_thread_name.h"
-#include "mir/test/death.h"
-#include "mir/test/pipe.h"
-#include "mir/test/signal.h"
-#include "mir/test/test_dispatchable.h"
-#include "mir_test_framework/process.h"
-#include "mir/test/cross_process_action.h"
+#include <mir/dispatch/threaded_dispatcher.h>
+#include <mir/dispatch/dispatchable.h>
+#include <mir/fd.h>
+#include <mir/test/current_thread_name.h>
+#include <mir/test/death.h>
+#include <mir/test/pipe.h>
+#include <mir/test/signal.h>
+#include <mir/test/test_dispatchable.h>
+#include <mir_test_framework/process.h>
+#include <mir/test/cross_process_action.h>
 
 #include <fcntl.h>
 
@@ -55,9 +55,9 @@ public:
 class MockDispatchable : public md::Dispatchable
 {
 public:
-    MOCK_CONST_METHOD0(watch_fd, mir::Fd());
-    MOCK_METHOD1(dispatch, bool(md::FdEvents));
-    MOCK_CONST_METHOD0(relevant_events, md::FdEvents());
+    MOCK_METHOD(mir::Fd, watch_fd, (), (const, override));
+    MOCK_METHOD(bool, dispatch, (md::FdEvents), (override));
+    MOCK_METHOD(md::FdEvents, relevant_events, (), (const, override));
 };
 
 }
@@ -342,7 +342,7 @@ TEST(ThreadedDispatcherSignalTest, keeps_dispatching_after_signal_interruption)
                  * When there's a signal handler for SIGCONT installed then
                  * any blocked syscall will (correctly) return EINTR, so install one.
                  */
-                struct sigaction sig_handler_new;
+                struct sigaction sig_handler_new{};
                 sigfillset(&sig_handler_new.sa_mask);
                 sig_handler_new.sa_flags = 0;
                 sig_handler_new.sa_handler = [](auto) {};
