@@ -15,12 +15,12 @@
  */
 
 #include "src/server/frontend_wayland/wlr_screencopy_v1.h"
-#include "mir/scene/observer.h"
-#include "mir/scene/surface_observer.h"
-#include "mir/test/doubles/mock_frontend_surface_stack.h"
-#include "mir/test/doubles/mock_surface.h"
-#include "mir/test/doubles/explicit_executor.h"
-#include "mir/test/fake_shared.h"
+#include <mir/scene/observer.h>
+#include <mir/scene/surface_observer.h>
+#include <mir/test/doubles/mock_frontend_surface_stack.h>
+#include <mir/test/doubles/mock_surface.h>
+#include <mir/test/doubles/explicit_executor.h>
+#include <mir/test/fake_shared.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
@@ -40,12 +40,12 @@ struct MockFrame : mf::WlrScreencopyV1DamageTracker::Frame, mw::LifetimeTracker
 {
 public:
     MockFrame(geom::Rectangle output_space_area)
-        : params{nullptr, output_space_area, output_space_area.size}
+        : params{nullptr, output_space_area, output_space_area.size, glm::mat2(1.f), false}
     {
     }
 
     MockFrame(geom::Rectangle output_space_area, geom::Size buffer_size)
-        : params{nullptr, output_space_area, buffer_size}
+        : params{nullptr, output_space_area, buffer_size, glm::mat2(1.f), false}
     {
     }
 
