@@ -1,5 +1,5 @@
 /*
- * Copyright © 2016 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/graphics/gamma_curves.h"
+#include <mir/graphics/gamma_curves.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
@@ -91,4 +91,3 @@ TEST(LinearGammaLUTs, is_monotonically_increasing)
     EXPECT_THAT(luts.green, IsMonotonicallyIncreasing());
     EXPECT_THAT(luts.blue, IsMonotonicallyIncreasing());
 }
-
