@@ -23,36 +23,37 @@
 #include <ranges>
 #include <string>
 
-#include "mir/console_services.h"
-#include "mir/graphics/platform.h"
-#include "mir/options/configuration.h"
-#include "mir/options/default_configuration.h"
-#include "mir/options/option.h"
-#include "mir/shared_library.h"
-#include "mir/shared_library_prober_report.h"
-#include "mir/test/doubles/fake_display.h"
-#include "mir/test/doubles/mock_gl_rendering_provider.h"
-#include "mir/test/doubles/mock_udev_device.h"
-#include "mir/test/doubles/mock_x11.h"
-#include "mir/test/doubles/null_platform.h"
-#include "mir/test/doubles/stub_console_services.h"
-#include "mir_test_framework/temporary_environment_value.h"
+#include <mir/console_services.h>
+#include <mir/graphics/platform.h>
+#include "quirk_common.h"
+#include <mir/options/configuration.h>
+#include <mir/options/default_configuration.h>
+#include <mir/options/option.h>
+#include <mir/shared_library.h>
+#include <mir/shared_library_prober_report.h>
+#include <mir/test/doubles/fake_display.h>
+#include <mir/test/doubles/mock_gl_rendering_provider.h>
+#include <mir/test/doubles/mock_udev_device.h>
+#include <mir/test/doubles/mock_x11.h>
+#include <mir/test/doubles/null_platform.h>
+#include <mir/test/doubles/stub_console_services.h>
+#include <mir_test_framework/temporary_environment_value.h>
 #include "src/server/graphics/platform_probe.h"
-#include "src/include/common/mir/logging/null_shared_library_prober_report.h"
-#include "mir/options/program_option.h"
-#include "mir/udev/wrapper.h"
-#include "mir/test/doubles/null_logger.h"
+#include "mir/logging/null_shared_library_prober_report.h"
+#include <mir/options/program_option.h>
+#include <mir/udev/wrapper.h>
+#include <mir/test/doubles/null_logger.h>
 
-#include "mir/test/doubles/mock_egl.h"
+#include <mir/test/doubles/mock_egl.h>
 #if defined(MIR_BUILD_PLATFORM_GBM_KMS) || defined(MIR_BUILD_PLATFORM_ATOMIC_KMS)
-#include "mir/test/doubles/mock_drm.h"
-#include "mir/test/doubles/mock_gbm.h"
-#include "mir/test/doubles/mock_gl.h"
+#include <mir/test/doubles/mock_drm.h>
+#include <mir/test/doubles/mock_gbm.h>
+#include <mir/test/doubles/mock_gl.h>
 #endif
-#include "mir/test/doubles/null_console_services.h"
+#include <mir/test/doubles/null_console_services.h>
 
-#include "mir_test_framework/udev_environment.h"
-#include "mir_test_framework/executable_path.h"
+#include <mir_test_framework/udev_environment.h>
+#include <mir_test_framework/executable_path.h>
 
 namespace mtd = mir::test::doubles;
 namespace mtf = mir_test_framework;
@@ -79,7 +80,7 @@ std::vector<std::shared_ptr<mir::SharedLibrary>> available_platforms()
 
 void add_dummy_platform(std::vector<std::shared_ptr<mir::SharedLibrary>>& modules)
 {
-    modules.insert(modules.begin(), std::make_shared<mir::SharedLibrary>(mtf::server_platform("graphics-dummy.so")));
+    modules.insert(modules.begin(), std::make_shared<mir::SharedLibrary>(mtf::server_platform("graphics-dummy")));
 }
 
 void add_broken_platform(std::vector<std::shared_ptr<mir::SharedLibrary>>& modules)
@@ -1097,13 +1098,19 @@ TEST_F(FullProbeStack, gbm_kms_is_not_selected_for_nvidia_driver_by_default)
 
     auto devices = mg::select_display_modules(the_options_provider(), the_console_services(), *the_library_prober_report());
 
-    EXPECT_THAT(devices, UnorderedElementsAre(
+    // Make sure other devices have the proper platform
+    EXPECT_THAT(devices, IsSupersetOf({
         Pair(IsPlatformForDevice(nouveau_device.get()), ModuleNameMatches(StrEq("mir:gbm-kms"))),
         Pair(IsPlatformForDevice(amd_device.get()), ModuleNameMatches(StrEq("mir:gbm-kms")))
-        ));
+        }));
+
+
+    // If we have an nvidia device, then it must not use gbm-kms (for display at least)
+    auto GbmForNvidia = Pair(IsPlatformForDevice(nvidia_device.get()), ModuleNameMatches(StrEq("mir:gbm-kms")));
+    EXPECT_THAT(devices, Each(Not(GbmForNvidia)));
 }
 
-TEST_F(FullProbeStack, gbm_kms_is_selected_for_nvidia_driver_when_quirk_is_allowed)
+TEST_F(FullProbeStack, gbm_kms_is_not_selected_for_nvidia_driver_when_quirk_is_allowed)
 {
     using namespace testing;
 
@@ -1124,11 +1131,13 @@ TEST_F(FullProbeStack, gbm_kms_is_selected_for_nvidia_driver_when_quirk_is_allow
 
     auto devices = mg::select_display_modules(the_options_provider(), the_console_services(), *the_library_prober_report());
 
-    EXPECT_THAT(devices, UnorderedElementsAre(
-        Pair(IsPlatformForDevice(nvidia_device.get()), ModuleNameMatches(StrEq("mir:gbm-kms"))),
+    EXPECT_THAT(devices, IsSupersetOf({
         Pair(IsPlatformForDevice(nouveau_device.get()), ModuleNameMatches(StrEq("mir:gbm-kms"))),
-        Pair(IsPlatformForDevice(amd_device.get()), ModuleNameMatches(StrEq("mir:gbm-kms")))
-        ));
+        Pair(IsPlatformForDevice(amd_device.get()), ModuleNameMatches(StrEq("mir:gbm-kms"))),
+        }));
+
+    auto GbmForNvidia = Pair(IsPlatformForDevice(nvidia_device.get()), ModuleNameMatches(StrEq("mir:gbm-kms")));
+    EXPECT_THAT(devices, Each(Not(GbmForNvidia)));
 }
 
 namespace
