@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015-2016 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -16,12 +16,12 @@
 
 #include "src/server/input/default_input_manager.h"
 
-#include "mir/test/signal_actions.h"
-#include "mir/test/fake_shared.h"
-#include "mir/test/doubles/mock_input_platform.h"
+#include <mir/test/signal_actions.h>
+#include <mir/test/fake_shared.h>
+#include <mir/test/doubles/mock_input_platform.h>
 
-#include "mir/dispatch/multiplexing_dispatchable.h"
-#include "mir/dispatch/action_queue.h"
+#include <mir/dispatch/multiplexing_dispatchable.h>
+#include <mir/dispatch/action_queue.h>
 
 #include <sys/eventfd.h>
 
