@@ -14,8 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/events/event_builders.h"
-#include "mir/events/event_private.h" // only needed to validate motion_up/down mapping
+#include <mir/events/event_builders.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
@@ -97,7 +96,7 @@ TEST_F(InputEventBuilder, makes_valid_touch_event)
        EXPECT_EQ(touch_major_values[i], mir_touch_event_axis_value(tev, i, mir_touch_axis_touch_major));
        EXPECT_EQ(touch_minor_values[i], mir_touch_event_axis_value(tev, i, mir_touch_axis_touch_minor));
        EXPECT_EQ(size_values[i], mir_touch_event_axis_value(tev, i, mir_touch_axis_size));
-   }   
+   }
 }
 
 TEST_F(InputEventBuilder, makes_valid_pointer_event)
