@@ -1,5 +1,5 @@
 /*
- * Copyright © 2017 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -15,11 +15,11 @@
  */
 
 #include "src/server/input/default_input_device_hub.h"
-#include "mir/test/doubles/mock_input_device_hub.h"
-#include "mir/test/doubles/mock_device.h"
-#include "mir/test/doubles/mock_input_device_observer.h"
-#include "mir/test/doubles/triggered_main_loop.h"
-#include "mir/test/fake_shared.h"
+#include <mir/test/doubles/mock_input_device_hub.h>
+#include <mir/test/doubles/mock_device.h>
+#include <mir/test/doubles/mock_input_device_observer.h>
+#include <mir/test/doubles/triggered_main_loop.h>
+#include <mir/test/fake_shared.h>
 
 namespace mt = mir::test;
 namespace mtd = mt::doubles;
