@@ -16,17 +16,16 @@
 
 #include "src/server/input/surface_input_dispatcher.h"
 
-#include "mir/events/event_builders.h"
-#include "mir/events/event_private.h"
-#include "mir/scene/observer.h"
-#include "mir/scene/surface_observer.h"
-#include "mir/thread_safe_list.h"
+#include <mir/events/event_builders.h>
+#include <mir/scene/observer.h>
+#include <mir/scene/surface_observer.h>
+#include <mir/thread_safe_list.h>
 
-#include "mir/test/event_matchers.h"
-#include "mir/test/fake_shared.h"
-#include "mir/test/doubles/stub_input_scene.h"
-#include "mir/test/doubles/mock_surface.h"
-#include "mir/test/doubles/explicit_executor.h"
+#include <mir/test/event_matchers.h>
+#include <mir/test/fake_shared.h>
+#include <mir/test/doubles/stub_input_scene.h>
+#include <mir/test/doubles/mock_surface.h>
+#include <mir/test/doubles/explicit_executor.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
@@ -62,7 +61,7 @@ struct MockSurfaceWithGeometry : public mtd::MockSurface
     {
         return geom;
     }
-    
+
     geom::Rectangle const geom;
 };
 
@@ -74,7 +73,7 @@ struct StubInputScene : public mtd::StubInputScene
         surfaces.add(surface);
 
         observer->surface_added(surface);
-        
+
         return surface;
     }
 
@@ -110,7 +109,7 @@ struct StubInputScene : public mtd::StubInputScene
 		observer->surface_exists(surface);
         });
     }
-    
+
     void remove_observer(std::weak_ptr<ms::Observer> const& /* remove_observer */) override
     {
         assert(observer != nullptr);
@@ -122,7 +121,7 @@ struct StubInputScene : public mtd::StubInputScene
     {
         return is_locked;
     }
-    
+
     mir::ThreadSafeList<std::shared_ptr<ms::Surface>> mutable surfaces;
 
     std::shared_ptr<ms::Observer> observer;
@@ -192,7 +191,7 @@ struct FakePointer
     mir::EventUPtr press_button(geom::Point const& location, MirPointerButton button = mir_pointer_button_primary)
     {
         buttons |= button;
-        
+
         return mev::make_pointer_event(
             id, std::chrono::nanoseconds(0),
             0, mir_pointer_action_button_down, buttons,
@@ -210,7 +209,7 @@ struct FakeToucher
         : id(id)
     {
     }
-    
+
     mir::EventUPtr move_to(geom::Point const& point)
     {
         auto ev = mev::make_touch_event(id, std::chrono::nanoseconds(0), 0);
@@ -225,7 +224,7 @@ struct FakeToucher
     mir::EventUPtr touch_at(geom::Point const& point)
     {
         touched = true;
-        
+
         auto ev = mev::make_touch_event(id, std::chrono::nanoseconds(0), 0);
         mev::add_touch(*ev, 0, mir_touch_action_down,
                        mir_touch_tooltype_finger, point.x.as_int(), point.y.as_int(),
@@ -248,7 +247,7 @@ struct FakeToucher
     mir::EventUPtr release_at(geom::Point const& point)
     {
         touched = false;
-        
+
         auto ev = mev::make_touch_event(id, std::chrono::nanoseconds(0), 0);
         mev::add_touch(*ev, 0, mir_touch_action_up,
                        mir_touch_tooltype_finger, point.x.as_int(), point.y.as_int(),
@@ -274,8 +273,8 @@ struct FakeToucher
 
 struct MockKeyboardObserver: mi::KeyboardObserver
 {
-    MOCK_METHOD1(keyboard_event, void(std::shared_ptr<MirEvent const> const& event));
-    MOCK_METHOD1(keyboard_focus_set, void(std::shared_ptr<mi::Surface> const& surface));
+    MOCK_METHOD(void, keyboard_event, (std::shared_ptr<MirEvent const> const& event), (override));
+    MOCK_METHOD(void, keyboard_focus_set, (std::shared_ptr<mi::Surface> const& surface), (override));
 };
 
 }
@@ -482,7 +481,7 @@ TEST_F(SurfaceInputDispatcher, gestures_persist_over_button_down)
     EXPECT_CALL(*surface, consume(mt::ButtonUpEvent(6,6))).Times(1);
     EXPECT_CALL(*surface, consume(mt::PointerLeaveEvent())).Times(1);
     EXPECT_CALL(*another_surface, consume(mt::PointerEnterEvent())).Times(1);
-    
+
     dispatcher.start();
 
     EXPECT_TRUE(dispatcher.dispatch(std::move(ev_1)));
@@ -589,7 +588,7 @@ TEST_F(SurfaceInputDispatcher, gestures_persist_over_touch_down)
     EXPECT_CALL(*right_surface, consume(_)).Times(0);
 
     dispatcher.start();
-    
+
     FakeToucher toucher;
     EXPECT_TRUE(dispatcher.dispatch(toucher.touch_at({0, 0})));
     EXPECT_TRUE(dispatcher.dispatch(toucher.move_to({2, 2})));
@@ -609,7 +608,7 @@ TEST_F(SurfaceInputDispatcher, touch_target_switches_on_finger_down)
     EXPECT_CALL(*right_surface, consume(_)).Times(1);
 
     dispatcher.start();
-    
+
     FakeToucher toucher;
     EXPECT_TRUE(dispatcher.dispatch(toucher.touch_at({0, 0})));
     // Note: No touch release event produced
@@ -661,7 +660,7 @@ TEST_F(SurfaceInputDispatcher, touch_gesture_target_may_vanish_but_things_contin
     EXPECT_CALL(*surface_1, consume(mt::TouchEvent(0, 0))).Times(1);
 
     dispatcher.start();
-    
+
     FakeToucher toucher;
     EXPECT_TRUE(dispatcher.dispatch(toucher.touch_at({0, 0})));
     scene.remove_surface(surface_2);
