@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -15,9 +15,9 @@
  */
 
 #include "src/server/report/logging/display_report.h"
-#include "mir/graphics/frame.h"
-#include "mir/logging/logger.h"
-#include "mir/test/doubles/mock_egl.h"
+#include <mir/graphics/frame.h>
+#include <mir/logging/logger.h>
+#include <mir/test/doubles/mock_egl.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
@@ -33,7 +33,7 @@ namespace
 class MockLogger : public ml::Logger
 {
 public:
-    MOCK_METHOD3(log, void(ml::Severity severity, const std::string& message, const std::string& component));
+    MOCK_METHOD(void, log, (ml::Severity severity, const std::string& message, const std::string& component), (override));
     ~MockLogger() noexcept(true) {}
 };
 
