@@ -15,7 +15,7 @@
  */
 
 #include "src/platforms/gbm-kms/server/kms/bypass.h"
-#include "mir/test/doubles/fake_renderable.h"
+#include <mir/test/doubles/fake_renderable.h>
 
 #include <gtest/gtest.h>
 #include <memory>
@@ -75,7 +75,7 @@ TEST_F(BypassMatchTest, shaped_fullscreen_window_not_bypassed)
     mgg::BypassMatch matcher(primary_monitor);
 
     mg::RenderableList list{
-        std::make_shared<mtd::FakeRenderable>(geom::Rectangle{{0, 0}, {1920, 1200}}, 1.0f, false)
+        std::make_shared<mtd::FakeRenderable>(geom::Rectangle{{0, 0}, {1920, 1200}}, 1.0f, false, std::nullopt)
     };
 
     EXPECT_EQ(list.rend(), std::find_if(list.rbegin(), list.rend(), matcher));
@@ -185,13 +185,13 @@ TEST_F(BypassMatchTest, many_fullscreen_windows_only_bypass_top_rectangular)
 
     auto bypassed = std::make_shared<mtd::FakeRenderable>(0, 0, 1920, 1200);
     mg::RenderableList list{
-        std::make_shared<mtd::FakeRenderable>(primary_monitor, 0.5f, false),
+        std::make_shared<mtd::FakeRenderable>(primary_monitor, 0.5f, false, std::nullopt),
         std::make_shared<mtd::FakeRenderable>(geom::Rectangle{{9, 10}, {11, 12}}),
-        std::make_shared<mtd::FakeRenderable>(primary_monitor, 1.0f, true),
+        std::make_shared<mtd::FakeRenderable>(primary_monitor, 1.0f, true, std::nullopt),
         std::make_shared<mtd::FakeRenderable>(geom::Rectangle{{5, 6}, {7, 8}}),
         std::make_shared<mtd::FakeRenderable>(primary_monitor),
         std::make_shared<mtd::FakeRenderable>(geom::Rectangle{{1, 2}, {3, 4}}),
-        std::make_shared<mtd::FakeRenderable>(primary_monitor, 1.0f, false),
+        std::make_shared<mtd::FakeRenderable>(primary_monitor, 1.0f, false, std::nullopt),
         bypassed
     };
 
@@ -208,7 +208,7 @@ TEST_F(BypassMatchTest, nonrectangular_not_bypassable)
     auto fullscreen_not_bypassed = std::make_shared<mtd::FakeRenderable>(0, 0, 1920, 1200);
     mg::RenderableList list{
         std::make_shared<mtd::FakeRenderable>(1, 2, 3, 4),
-        std::make_shared<mtd::FakeRenderable>(primary_monitor, 1.0f, false)
+        std::make_shared<mtd::FakeRenderable>(primary_monitor, 1.0f, false, std::nullopt)
     };
 
     EXPECT_EQ(list.rend(), std::find_if(list.rbegin(), list.rend(), matcher));
