@@ -19,15 +19,16 @@
 #include "src/platforms/gbm-kms/server/kms/kms_output_container.h"
 #include "src/platforms/gbm-kms/server/kms/kms_display_configuration.h"
 
-#include "mir/graphics/cursor_image.h"
+#include <mir/graphics/cursor_image.h>
 
+#include <memory>
 #include <xf86drm.h>
 
-#include "mir/test/doubles/mock_gbm.h"
-#include "mir/test/doubles/mock_drm.h"
-#include "mir/test/doubles/stub_display_configuration.h"
-#include "mir/test/fake_shared.h"
-#include "mir_test_framework/temporary_environment_value.h"
+#include <mir/test/doubles/mock_gbm.h>
+#include <mir/test/doubles/mock_drm.h>
+#include <mir/test/doubles/stub_display_configuration.h>
+#include <mir/test/fake_shared.h>
+#include <mir_test_framework/temporary_environment_value.h>
 #include "mock_kms_output.h"
 
 #include <gtest/gtest.h>
@@ -301,8 +302,7 @@ struct MesaCursorTest : ::testing::Test
 
     size_t const cursor_side{64};
     MesaCursorTest()
-        : cursor{output_container,
-            mt::fake_shared(current_configuration)}
+        : cursor{output_container,current_configuration}
     {
         using namespace ::testing;
         ON_CALL(mock_drm, drmGetCap(_, DRM_CAP_CURSOR_WIDTH, _))
@@ -321,9 +321,9 @@ struct MesaCursorTest : ::testing::Test
     }
 
     testing::NiceMock<mtd::MockDRM> mock_drm;
-    StubCursorImage stub_image;
-    StubKMSOutputContainer output_container;
-    StubCurrentConfiguration current_configuration{output_container};
+    std::shared_ptr<StubCursorImage> const stub_image = std::make_shared<StubCursorImage>();
+    std::shared_ptr<StubKMSOutputContainer> output_container = std::make_shared<StubKMSOutputContainer>();
+    std::shared_ptr<StubCurrentConfiguration> current_configuration = std::make_shared<StubCurrentConfiguration>(*output_container);
     mgg::Cursor cursor;
 };
 
@@ -352,8 +352,7 @@ TEST_F(MesaCursorTest, creates_cursor_bo_image)
                                         GBM_FORMAT_ARGB8888,
                                         GBM_BO_USE_CURSOR | GBM_BO_USE_WRITE));
 
-    mgg::Cursor cursor_tmp{output_container,
-        std::make_shared<StubCurrentConfiguration>(output_container)};
+    mgg::Cursor cursor_tmp{output_container, current_configuration};
 }
 
 TEST_F(MesaCursorTest, queries_received_cursor_size)
@@ -364,8 +363,7 @@ TEST_F(MesaCursorTest, queries_received_cursor_size)
     EXPECT_CALL(mock_gbm, gbm_bo_get_width(_)).Times(2);
     EXPECT_CALL(mock_gbm, gbm_bo_get_height(_)).Times(2);
 
-    mgg::Cursor cursor_tmp{output_container,
-        std::make_shared<StubCurrentConfiguration>(output_container)};
+    mgg::Cursor cursor_tmp{output_container, current_configuration};
 }
 
 TEST_F(MesaCursorTest, respects_drm_cap_cursor)
@@ -379,15 +377,14 @@ TEST_F(MesaCursorTest, respects_drm_cap_cursor)
 
     EXPECT_CALL(mock_gbm, gbm_bo_create(_, drm_buffer_size, drm_buffer_size, _, _));
 
-    mgg::Cursor cursor_tmp{output_container,
-                           std::make_shared<StubCurrentConfiguration>(output_container)};
+    mgg::Cursor cursor_tmp{output_container, current_configuration};
 }
 
 TEST_F(MesaCursorTest, show_cursor_writes_to_bo)
 {
     using namespace testing;
 
-    StubCursorImage image;
+    auto image = std::make_shared<StubCursorImage>();
     geom::Size const cursor_size{cursor_side, cursor_side};
     size_t const cursor_size_bytes{cursor_side * cursor_side * sizeof(uint32_t)};
 
@@ -422,7 +419,7 @@ TEST_F(MesaCursorTest, show_cursor_pads_missing_data)
         .WillByDefault(Return(stride));
     EXPECT_CALL(mock_gbm, gbm_bo_write(mock_gbm.fake_gbm.bo, ContainsASingleWhitePixel(width*height), buffer_size_bytes));
 
-    cursor.show(SinglePixelCursorImage());
+    cursor.show(std::make_shared<SinglePixelCursorImage>());
 }
 
 TEST_F(MesaCursorTest, pads_missing_data_when_buffer_size_differs)
@@ -443,9 +440,8 @@ TEST_F(MesaCursorTest, pads_missing_data_when_buffer_size_differs)
 
     EXPECT_CALL(mock_gbm, gbm_bo_write(mock_gbm.fake_gbm.bo, ContainsASingleWhitePixel(width*height), buffer_size_bytes));
 
-    mgg::Cursor cursor_tmp{output_container,
-        std::make_shared<StubCurrentConfiguration>(output_container)};
-    cursor_tmp.show(SinglePixelCursorImage());
+    mgg::Cursor cursor_tmp{output_container, current_configuration};
+    cursor_tmp.show(std::make_shared<SinglePixelCursorImage>());
 }
 
 TEST_F(MesaCursorTest, does_not_throw_when_images_are_too_large)
@@ -462,42 +458,40 @@ TEST_F(MesaCursorTest, does_not_throw_when_images_are_too_large)
         geom::Size const large_cursor_size{cursor_side, cursor_side};
     };
 
-    cursor.show(LargeCursorImage());
+    cursor.show(std::make_shared<LargeCursorImage>());
 }
 
 TEST_F(MesaCursorTest, clears_cursor_state_on_construction)
 {
     using namespace testing;
 
-    EXPECT_CALL(*output_container.outputs[0], clear_cursor());
-    EXPECT_CALL(*output_container.outputs[1], clear_cursor());
-    EXPECT_CALL(*output_container.outputs[2], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[0], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[1], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[2], clear_cursor());
 
     /* No checking of existing cursor state */
-    EXPECT_CALL(*output_container.outputs[0], has_cursor_image()).Times(0);
-    EXPECT_CALL(*output_container.outputs[1], has_cursor_image()).Times(0);
-    EXPECT_CALL(*output_container.outputs[2], has_cursor_image()).Times(0);
+    EXPECT_CALL(*output_container->outputs[0], has_cursor_image()).Times(0);
+    EXPECT_CALL(*output_container->outputs[1], has_cursor_image()).Times(0);
+    EXPECT_CALL(*output_container->outputs[2], has_cursor_image()).Times(0);
 
-    mgg::Cursor cursor_tmp{output_container,
-       std::make_shared<StubCurrentConfiguration>(output_container)};
+    mgg::Cursor cursor_tmp{output_container, current_configuration};
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 }
 
 TEST_F(MesaCursorTest, construction_fails_if_initial_set_fails)
 {
     using namespace testing;
 
-    ON_CALL(*output_container.outputs[0], clear_cursor())
+    ON_CALL(*output_container->outputs[0], clear_cursor())
         .WillByDefault(Return(false));
-    ON_CALL(*output_container.outputs[0], set_cursor_image(_))
+    ON_CALL(*output_container->outputs[0], set_cursor_image(_))
         .WillByDefault(Return(false));
-    ON_CALL(*output_container.outputs[0], has_cursor_image())
+    ON_CALL(*output_container->outputs[0], has_cursor_image())
         .WillByDefault(Return(false));
 
     EXPECT_THROW(
-        mgg::Cursor cursor_tmp(output_container,
-           std::make_shared<StubCurrentConfiguration>(output_container));
+        mgg::Cursor cursor_tmp(output_container, current_configuration);
     , std::runtime_error);
 }
 
@@ -507,18 +501,18 @@ TEST_F(MesaCursorTest, move_to_sets_clears_cursor_if_needed)
 
     cursor.show(stub_image);
 
-    EXPECT_CALL(*output_container.outputs[0], has_cursor_image())
+    EXPECT_CALL(*output_container->outputs[0], has_cursor_image())
         .WillOnce(Return(false))
         .WillOnce(Return(true));
-    EXPECT_CALL(*output_container.outputs[0], set_cursor_image(_));
+    EXPECT_CALL(*output_container->outputs[0], set_cursor_image(_));
 
-    EXPECT_CALL(*output_container.outputs[1], has_cursor_image())
+    EXPECT_CALL(*output_container->outputs[1], has_cursor_image())
         .WillOnce(Return(true));
-    EXPECT_CALL(*output_container.outputs[1], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[1], clear_cursor());
 
     cursor.move_to({10, 10});
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 }
 
 TEST_F(MesaCursorTest, move_to_doesnt_set_clear_cursor_if_not_needed)
@@ -527,19 +521,19 @@ TEST_F(MesaCursorTest, move_to_doesnt_set_clear_cursor_if_not_needed)
 
     cursor.show(stub_image);
 
-    EXPECT_CALL(*output_container.outputs[0], has_cursor_image())
+    EXPECT_CALL(*output_container->outputs[0], has_cursor_image())
         .WillOnce(Return(true));
-    EXPECT_CALL(*output_container.outputs[0], set_cursor_image(_))
+    EXPECT_CALL(*output_container->outputs[0], set_cursor_image(_))
         .Times(0);
 
-    EXPECT_CALL(*output_container.outputs[1], has_cursor_image())
+    EXPECT_CALL(*output_container->outputs[1], has_cursor_image())
         .WillOnce(Return(false));
-    EXPECT_CALL(*output_container.outputs[1], clear_cursor())
+    EXPECT_CALL(*output_container->outputs[1], clear_cursor())
         .Times(0);
 
     cursor.move_to({10, 10});
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 }
 
 TEST_F(MesaCursorTest, move_to_moves_cursor_to_right_output)
@@ -548,37 +542,37 @@ TEST_F(MesaCursorTest, move_to_moves_cursor_to_right_output)
 
     cursor.show(stub_image);
 
-    EXPECT_CALL(*output_container.outputs[0], move_cursor(geom::Point{10,-4}));
-    EXPECT_CALL(*output_container.outputs[1], move_cursor(_))
+    EXPECT_CALL(*output_container->outputs[0], move_cursor(geom::Point{10,-4}));
+    EXPECT_CALL(*output_container->outputs[1], move_cursor(_))
         .Times(0);
 
     cursor.move_to({10, -4});
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 
-    EXPECT_CALL(*output_container.outputs[0], move_cursor(_))
+    EXPECT_CALL(*output_container->outputs[0], move_cursor(_))
         .Times(0);
-    EXPECT_CALL(*output_container.outputs[1], move_cursor(geom::Point{50,100}));
+    EXPECT_CALL(*output_container->outputs[1], move_cursor(geom::Point{50,100}));
 
     cursor.move_to({150, 150});
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 
-    EXPECT_CALL(*output_container.outputs[0], move_cursor(geom::Point{150,75}));
-    EXPECT_CALL(*output_container.outputs[1], move_cursor(geom::Point{50,25}));
+    EXPECT_CALL(*output_container->outputs[0], move_cursor(geom::Point{150,75}));
+    EXPECT_CALL(*output_container->outputs[1], move_cursor(geom::Point{50,25}));
 
     cursor.move_to({150, 75});
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 
-    EXPECT_CALL(*output_container.outputs[0], move_cursor(_))
+    EXPECT_CALL(*output_container->outputs[0], move_cursor(_))
         .Times(0);
-    EXPECT_CALL(*output_container.outputs[1], move_cursor(_))
+    EXPECT_CALL(*output_container->outputs[1], move_cursor(_))
         .Times(0);
 
     cursor.move_to({-64, -64});
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 }
 
 TEST_F(MesaCursorTest, moves_properly_to_and_inside_left_rotated_output)
@@ -587,16 +581,16 @@ TEST_F(MesaCursorTest, moves_properly_to_and_inside_left_rotated_output)
 
     cursor.show(stub_image);
 
-    current_configuration.conf.set_orentation_of_output(mg::DisplayConfigurationOutputId{2}, mir_orientation_left);
+    current_configuration->conf.set_orentation_of_output(mg::DisplayConfigurationOutputId{2}, mir_orientation_left);
 
     InSequence seq;
-    EXPECT_CALL(*output_container.outputs[2], move_cursor(geom::Point{112, 36}));
-    EXPECT_CALL(*output_container.outputs[2], move_cursor(geom::Point{150, 32}));
+    EXPECT_CALL(*output_container->outputs[2], move_cursor(geom::Point{112, 36}));
+    EXPECT_CALL(*output_container->outputs[2], move_cursor(geom::Point{150, 32}));
 
     cursor.move_to({766, 112});
     cursor.move_to({770, 150});
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 }
 
 
@@ -606,16 +600,16 @@ TEST_F(MesaCursorTest, moves_properly_to_and_inside_right_rotated_output)
 
     cursor.show(stub_image);
 
-    current_configuration.conf.set_orentation_of_output(mg::DisplayConfigurationOutputId{2}, mir_orientation_right);
+    current_configuration->conf.set_orentation_of_output(mg::DisplayConfigurationOutputId{2}, mir_orientation_right);
 
     InSequence seq;
-    EXPECT_CALL(*output_container.outputs[2], move_cursor(geom::Point{624, 100}));
-    EXPECT_CALL(*output_container.outputs[2], move_cursor(geom::Point{586, 104}));
+    EXPECT_CALL(*output_container->outputs[2], move_cursor(geom::Point{624, 100}));
+    EXPECT_CALL(*output_container->outputs[2], move_cursor(geom::Point{586, 104}));
 
     cursor.move_to({766, 112});
     cursor.move_to({770, 150});
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 }
 
 TEST_F(MesaCursorTest, moves_properly_to_and_inside_inverted_output)
@@ -624,55 +618,55 @@ TEST_F(MesaCursorTest, moves_properly_to_and_inside_inverted_output)
 
     cursor.show(stub_image);
 
-    current_configuration.conf.set_orentation_of_output(mg::DisplayConfigurationOutputId{2}, mir_orientation_inverted);
+    current_configuration->conf.set_orentation_of_output(mg::DisplayConfigurationOutputId{2}, mir_orientation_inverted);
 
     InSequence seq;
-    EXPECT_CALL(*output_container.outputs[2], move_cursor(geom::Point{636, 24}));
-    EXPECT_CALL(*output_container.outputs[2], move_cursor(geom::Point{632,-14}));
+    EXPECT_CALL(*output_container->outputs[2], move_cursor(geom::Point{636, 24}));
+    EXPECT_CALL(*output_container->outputs[2], move_cursor(geom::Point{632,-14}));
 
     cursor.move_to({766, 112});
     cursor.move_to({770, 150});
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 }
 
 TEST_F(MesaCursorTest, hides_cursor_in_all_outputs)
 {
     using namespace testing;
 
-    EXPECT_CALL(*output_container.outputs[0], clear_cursor());
-    EXPECT_CALL(*output_container.outputs[1], clear_cursor());
-    EXPECT_CALL(*output_container.outputs[2], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[0], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[1], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[2], clear_cursor());
 
     cursor.hide();
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 }
 
 TEST_F(MesaCursorTest, hidden_cursor_is_not_shown_on_display_when_moved)
 {
     using namespace testing;
 
-    EXPECT_CALL(*output_container.outputs[0], clear_cursor());
-    EXPECT_CALL(*output_container.outputs[1], clear_cursor());
-    EXPECT_CALL(*output_container.outputs[2], clear_cursor());
-    EXPECT_CALL(*output_container.outputs[0], move_cursor(_)).Times(0);
-    EXPECT_CALL(*output_container.outputs[1], move_cursor(_)).Times(0);
-    EXPECT_CALL(*output_container.outputs[2], move_cursor(_)).Times(0);
+    EXPECT_CALL(*output_container->outputs[0], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[1], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[2], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[0], move_cursor(_)).Times(0);
+    EXPECT_CALL(*output_container->outputs[1], move_cursor(_)).Times(0);
+    EXPECT_CALL(*output_container->outputs[2], move_cursor(_)).Times(0);
 
     cursor.hide();
     cursor.move_to({17, 29});
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 }
 
 TEST_F(MesaCursorTest, clears_cursor_on_exit)
 {
     using namespace testing;
 
-    EXPECT_CALL(*output_container.outputs[0], clear_cursor());
-    EXPECT_CALL(*output_container.outputs[1], clear_cursor());
-    EXPECT_CALL(*output_container.outputs[2], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[0], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[1], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[2], clear_cursor());
 }
 
 TEST_F(MesaCursorTest, cursor_is_shown_at_correct_location_after_suspend_resume)
@@ -681,57 +675,57 @@ TEST_F(MesaCursorTest, cursor_is_shown_at_correct_location_after_suspend_resume)
 
     cursor.show(stub_image);
 
-    EXPECT_CALL(*output_container.outputs[0], move_cursor(geom::Point{150,75}));
-    EXPECT_CALL(*output_container.outputs[1], move_cursor(geom::Point{50,25}));
-    EXPECT_CALL(*output_container.outputs[0], clear_cursor());
-    EXPECT_CALL(*output_container.outputs[1], clear_cursor());
-    EXPECT_CALL(*output_container.outputs[2], has_cursor_image())
+    EXPECT_CALL(*output_container->outputs[0], move_cursor(geom::Point{150,75}));
+    EXPECT_CALL(*output_container->outputs[1], move_cursor(geom::Point{50,25}));
+    EXPECT_CALL(*output_container->outputs[0], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[1], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[2], has_cursor_image())
         .WillRepeatedly(Return(false));
-    EXPECT_CALL(*output_container.outputs[2], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[2], clear_cursor());
 
     cursor.move_to({150, 75});
     cursor.suspend();
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 
-    EXPECT_CALL(*output_container.outputs[0], set_cursor_image(_));
-    EXPECT_CALL(*output_container.outputs[1], set_cursor_image(_));
-    EXPECT_CALL(*output_container.outputs[0], move_cursor(geom::Point{150,75}));
-    EXPECT_CALL(*output_container.outputs[1], move_cursor(geom::Point{50,25}));
+    EXPECT_CALL(*output_container->outputs[0], set_cursor_image(_));
+    EXPECT_CALL(*output_container->outputs[1], set_cursor_image(_));
+    EXPECT_CALL(*output_container->outputs[0], move_cursor(geom::Point{150,75}));
+    EXPECT_CALL(*output_container->outputs[1], move_cursor(geom::Point{50,25}));
 
     cursor.resume();
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 }
 
 TEST_F(MesaCursorTest, hidden_cursor_is_not_shown_after_suspend_resume)
 {
     using namespace testing;
 
-    EXPECT_CALL(*output_container.outputs[0], clear_cursor()).Times(AnyNumber());
-    EXPECT_CALL(*output_container.outputs[1], clear_cursor()).Times(AnyNumber());
-    EXPECT_CALL(*output_container.outputs[2], clear_cursor()).Times(AnyNumber());
+    EXPECT_CALL(*output_container->outputs[0], clear_cursor()).Times(AnyNumber());
+    EXPECT_CALL(*output_container->outputs[1], clear_cursor()).Times(AnyNumber());
+    EXPECT_CALL(*output_container->outputs[2], clear_cursor()).Times(AnyNumber());
 
     cursor.hide();
     cursor.suspend();
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 
-    EXPECT_CALL(*output_container.outputs[0], set_cursor_image(_)).Times(0);
-    EXPECT_CALL(*output_container.outputs[1], set_cursor_image(_)).Times(0);
-    EXPECT_CALL(*output_container.outputs[2], set_cursor_image(_)).Times(0);
+    EXPECT_CALL(*output_container->outputs[0], set_cursor_image(_)).Times(0);
+    EXPECT_CALL(*output_container->outputs[1], set_cursor_image(_)).Times(0);
+    EXPECT_CALL(*output_container->outputs[2], set_cursor_image(_)).Times(0);
 
     cursor.resume();
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 }
 
 TEST_F(MesaCursorTest, show_with_param_places_cursor_on_output)
 {
-    EXPECT_CALL(*output_container.outputs[0], clear_cursor());
+    EXPECT_CALL(*output_container->outputs[0], clear_cursor());
     cursor.hide();
 
-    output_container.verify_and_clear_expectations();
+    output_container->verify_and_clear_expectations();
 
-    EXPECT_CALL(*output_container.outputs[0], set_cursor_image(_));
+    EXPECT_CALL(*output_container->outputs[0], set_cursor_image(_));
     cursor.show(stub_image);
 }
 
@@ -761,19 +755,138 @@ TEST_F(MesaCursorTest, show_cursor_sets_cursor_with_hotspot)
 
 
     EXPECT_CALL(mock_gbm, gbm_bo_write(_, _, _)).Times(AnyNumber());
-    EXPECT_CALL(*output_container.outputs[0], set_cursor_image(_)).Times(AnyNumber());
+    EXPECT_CALL(*output_container->outputs[0], set_cursor_image(_)).Times(AnyNumber());
 
     // When we set the image with the hotspot, first we should see the cursor move from its initial
     // location, to account for the displacement. Further movement should be offset by the hotspot.
     {
         InSequence seq;
-        EXPECT_CALL(*output_container.outputs[0], move_cursor(initial_buffer_location));
-        EXPECT_CALL(*output_container.outputs[0], move_cursor(expected_buffer_location_1));
-        EXPECT_CALL(*output_container.outputs[0], move_cursor(expected_buffer_location_2));
+        EXPECT_CALL(*output_container->outputs[0], move_cursor(initial_buffer_location));
+        EXPECT_CALL(*output_container->outputs[0], move_cursor(expected_buffer_location_1));
+        EXPECT_CALL(*output_container->outputs[0], move_cursor(expected_buffer_location_2));
     }
 
-    cursor.show(HotspotCursor());
+    cursor.show(std::make_shared<HotspotCursor>());
     cursor.move_to(cursor_location_1);
     cursor.move_to(cursor_location_2);
 }
 
+TEST_F(MesaCursorTest, does_not_need_compositing)
+{
+    EXPECT_THAT(cursor.needs_compositing(), Eq(false));
+}
+
+TEST_F(MesaCursorTest, if_shown_cursor_renderable_is_not_null)
+{
+    using namespace testing;
+
+    auto image = std::make_shared<StubCursorImage>();
+    cursor.show(image);
+
+    EXPECT_THAT(cursor.renderable(), NotNull());
+}
+
+TEST_F(MesaCursorTest, cursor_renderable_buffer_is_not_null)
+{
+    using namespace testing;
+
+    auto image = std::make_shared<StubCursorImage>();
+    cursor.show(image);
+
+    EXPECT_THAT(cursor.renderable()->buffer(), NotNull());
+}
+
+TEST_F(MesaCursorTest, cursor_renderable_id_is_not_null)
+{
+    using namespace testing;
+
+    auto image = std::make_shared<StubCursorImage>();
+    cursor.show(image);
+
+    EXPECT_THAT(cursor.renderable()->id(), NotNull());
+}
+
+TEST_F(MesaCursorTest, cursor_renderable_screen_position_is_expected)
+{
+    using namespace testing;
+
+    auto image = std::make_shared<StubCursorImage>();
+    cursor.move_to(geom::Point{50, 50});
+    cursor.show(image);
+
+    EXPECT_THAT(cursor.renderable()->screen_position(), Eq(
+        geom::Rectangle({50, 50}, {image->size()})));
+}
+
+TEST_F(MesaCursorTest, cursor_renderable_src_bounds_is_expected)
+{
+    using namespace testing;
+
+    auto image = std::make_shared<StubCursorImage>();
+    cursor.move_to(geom::Point{50, 50});
+    cursor.show(image);
+
+    EXPECT_THAT(cursor.renderable()->src_bounds(), Eq(
+        geom::RectangleD({0, 0}, image->size())));
+}
+
+TEST_F(MesaCursorTest, cursor_renderable_clip_area_is_unset)
+{
+    using namespace testing;
+
+    auto image = std::make_shared<StubCursorImage>();
+    cursor.show(image);
+
+    EXPECT_THAT(cursor.renderable()->clip_area(), Eq(std::nullopt));
+}
+
+TEST_F(MesaCursorTest, cursor_renderable_alpha_is_one)
+{
+    using namespace testing;
+
+    auto image = std::make_shared<StubCursorImage>();
+    cursor.show(image);
+
+    EXPECT_THAT(cursor.renderable()->alpha(), Eq(1));
+}
+
+TEST_F(MesaCursorTest, cursor_renderable_transformation_is_identity)
+{
+    using namespace testing;
+
+    auto image = std::make_shared<StubCursorImage>();
+    cursor.show(image);
+
+    EXPECT_THAT(cursor.renderable()->transformation(), Eq(glm::mat4(1.f)));
+}
+
+TEST_F(MesaCursorTest, cursor_renderable_shaped_is_true)
+{
+    using namespace testing;
+
+    auto image = std::make_shared<StubCursorImage>();
+    cursor.show(image);
+
+    EXPECT_THAT(cursor.renderable()->shaped(), Eq(true));
+}
+
+TEST_F(MesaCursorTest, cursor_renderable_surface_is_nullopt)
+{
+    using namespace testing;
+
+    auto image = std::make_shared<StubCursorImage>();
+    cursor.show(image);
+
+    EXPECT_THAT(cursor.renderable()->surface_if_any(), Eq(std::nullopt));
+}
+
+TEST_F(MesaCursorTest, if_hidden_cursor_renderable_is_null)
+{
+    using namespace testing;
+
+    auto image = std::make_shared<StubCursorImage>();
+    cursor.show(image);
+    cursor.hide();
+
+    EXPECT_THAT(cursor.renderable(), IsNull());
+}
