@@ -14,20 +14,20 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/graphics/display.h"
-#include "mir/graphics/display_configuration.h"
-#include "mir/options/program_option.h"
+#include <mir/graphics/display.h>
+#include <mir/graphics/display_configuration.h>
+#include <mir/options/program_option.h>
 
-#include "mir/test/doubles/mock_egl.h"
-#include "mir/test/doubles/mock_gl.h"
-#include "mir/test/doubles/stub_gl_config.h"
-#include "mir/test/doubles/null_emergency_cleanup.h"
-#include "mir/test/doubles/stub_console_services.h"
+#include <mir/test/doubles/mock_egl.h>
+#include <mir/test/doubles/mock_gl.h>
+#include <mir/test/doubles/stub_gl_config.h>
+#include <mir/test/doubles/null_emergency_cleanup.h>
+#include <mir/test/doubles/stub_console_services.h>
 #include "src/server/report/null_report_factory.h"
-#include "mir/graphics/default_display_configuration_policy.h"
-#include "mir/test/doubles/mock_drm.h"
-#include "mir/test/doubles/mock_gbm.h"
-#include "mir_test_framework/udev_environment.h"
+#include <mir/graphics/default_display_configuration_policy.h>
+#include <mir/test/doubles/mock_drm.h>
+#include <mir/test/doubles/mock_gbm.h>
+#include <mir_test_framework/udev_environment.h>
 #include "src/platforms/gbm-kms/server/kms/platform.h"
 #include "src/platforms/gbm-kms/server/kms/quirks.h"
 
@@ -87,7 +87,7 @@ public:
         // Caution: non-local state!
         // This works because standard-drm-devices contains a udev device with 226:0 and devnode /dev/dri/card0
         auto device = ctx.char_device_from_devnum(makedev(226, 0));
-       
+
         auto platform = std::make_shared<mgg::Platform>(
             *device,
             mir::report::null_display_report(),
