@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -16,12 +16,12 @@
 
 #include "src/platforms/gbm-kms/server/display_helpers.h"
 #include "src/platforms/gbm-kms/server/kms/quirks.h"
-#include "mir/udev/wrapper.h"
+#include <mir/udev/wrapper.h>
 
-#include "mir_test_framework/udev_environment.h"
-#include "mir/test/doubles/mock_drm.h"
-#include "mir/test/doubles/stub_console_services.h"
-#include "mir/test/doubles/mock_option.h"
+#include <mir_test_framework/udev_environment.h>
+#include <mir/test/doubles/mock_drm.h>
+#include <mir/test/doubles/stub_console_services.h>
+#include <mir/test/doubles/mock_option.h>
 
 #include <fcntl.h>
 
@@ -31,7 +31,7 @@
 namespace mgg = mir::graphics::gbm;
 namespace mtf = mir_test_framework;
 namespace mtd = mir::test::doubles;
-                          
+
 namespace
 {
 
@@ -41,7 +41,7 @@ MATCHER_P(FlagSet, flag, "")
 }
 
 class DRMHelperTest : public ::testing::Test
-{              
+{
 protected:
     ::testing::NiceMock<mtd::MockDRM> mock_drm;
     mtf::UdevEnvironment fake_devices;
@@ -50,7 +50,7 @@ protected:
 }
 
 TEST_F(DRMHelperTest, closes_drm_fd_on_exec)
-{   
+{
     using namespace testing;
 
     fake_devices.add_standard_device("standard-drm-render-nodes");
@@ -59,4 +59,4 @@ TEST_F(DRMHelperTest, closes_drm_fd_on_exec)
 
     auto helper = mgg::helpers::DRMHelper::open_any_render_node(
         std::make_shared<mir::udev::Context>());
-}   
+}
