@@ -1,5 +1,5 @@
 /*
- * Copyright © 2021 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -19,11 +19,11 @@
 
 #include <boost/program_options/options_description.hpp>
 
-#include "mir/options/program_option.h"
-#include "mir/udev/wrapper.h"
-#include "mir_test_framework/udev_environment.h"
+#include <mir/options/program_option.h>
+#include <mir/udev/wrapper.h>
+#include <mir_test_framework/udev_environment.h>
 #include "src/platforms/gbm-kms/server/kms/quirks.h"
-#include "mir_test_framework/temporary_environment_value.h"
+#include <mir_test_framework/temporary_environment_value.h>
 
 namespace mtf = mir_test_framework;
 namespace mgg = mir::graphics::gbm;
@@ -288,7 +288,7 @@ TEST_F(Quirks, default_requires_modesetting_support)
 TEST_F(Quirks, disable_kms_probe_selectively_disables_modesetting_support)
 {
     mgg::Quirks::add_quirks_option(description);
-    mgg::Quirks quirks{*parsed_options_from_args({"--driver-quirks=disable-kms-probe:amdgpu"})};
+    mgg::Quirks quirks{*parsed_options_from_args({"--driver-quirks=disable-kms-probe:driver:amdgpu"})};
 
     auto const enumerator = make_drm_device_enumerator();
 
