@@ -17,19 +17,19 @@
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
 
-#include "mir/graphics/platform.h"
+#include <mir/graphics/platform.h>
 #include "src/platforms/x11/graphics/display.h"
 #include "src/platforms/x11/graphics/platform.h"
 #include "src/server/report/null/display_report.h"
 
-#include "mir/graphics/display_configuration.h"
+#include <mir/graphics/display_configuration.h>
 
-#include "mir/test/doubles/null_display_configuration_policy.h"
-#include "mir/test/doubles/mock_egl.h"
-#include "mir/test/doubles/mock_x11.h"
-#include "mir/test/doubles/mock_x11_resources.h"
-#include "mir/test/doubles/mock_gl_config.h"
-#include "mir/test/fake_shared.h"
+#include <mir/test/doubles/null_display_configuration_policy.h>
+#include <mir/test/doubles/mock_egl.h>
+#include <mir/test/doubles/mock_x11.h>
+#include <mir/test/doubles/mock_x11_resources.h>
+#include <mir/test/doubles/mock_gl_config.h>
+#include <mir/test/fake_shared.h>
 
 
 namespace mg=mir::graphics;
@@ -56,7 +56,7 @@ public:
 
         ON_CALL(mock_egl, eglQueryString(_, EGL_EXTENSIONS))
             .WillByDefault(Return("other stuff and EGL_CHROMIUM_sync_control"));
-                    
+
         ON_CALL(mock_egl, eglQueryContext(mock_egl.fake_egl_display,
                                           mock_egl.fake_egl_context,
                                           EGL_CONTEXT_CLIENT_VERSION,
