@@ -14,7 +14,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <EGL/egl.h>
 #include <stdexcept>
+#include <glm/ext/matrix_transform.hpp>
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
 #include <mir/geometry/rectangle.h>
@@ -24,10 +26,12 @@
 #include <mir/compositor/buffer_stream.h>
 #include <mir/test/doubles/mock_gl.h>
 #include <mir/test/doubles/mock_egl.h>
-#include <src/renderers/gl/renderer.h>
+#include <mir/renderers/gl/renderer.h>
 #include <mir/test/doubles/stub_gl_rendering_provider.h>
 #include <mir/test/doubles/mock_output_surface.h>
 
+#include <mir/graphics/transformation.h>
+
 using testing::SetArgPointee;
 using testing::InSequence;
 using testing::Return;
@@ -120,6 +124,8 @@ public:
         mock_buffer = std::make_shared<testing::NiceMock<mtd::MockTextureBuffer>>();
         EXPECT_CALL(*mock_buffer, id())
             .WillRepeatedly(Return(mir::graphics::BufferID(789)));
+        EXPECT_CALL(*mock_buffer, layout())
+            .WillRepeatedly(Return(mir::graphics::gl::Texture::Layout::GL));
         EXPECT_CALL(*mock_buffer, size())
             .WillRepeatedly(Return(mir::geometry::Size{123, 456}));
         ON_CALL(*mock_buffer, shader(_))
@@ -136,6 +142,8 @@ public:
         EXPECT_CALL(*renderable, shaped()).WillRepeatedly(Return(false));
         EXPECT_CALL(*renderable, alpha()).WillRepeatedly(Return(1.0f));
         EXPECT_CALL(*renderable, transformation()).WillRepeatedly(Return(trans));
+        EXPECT_CALL(*renderable, orientation()).WillRepeatedly(Return(mir_orientation_normal));
+        EXPECT_CALL(*renderable, mirror_mode()).WillRepeatedly(Return(mir_mirror_mode_none));
         EXPECT_CALL(*renderable, screen_position())
             .WillRepeatedly(Return(mir::geometry::Rectangle{{1,2},{3,4}}));
         EXPECT_CALL(*renderable, clip_area())
@@ -156,7 +164,7 @@ public:
     std::shared_ptr<mtd::MockTextureBuffer> mock_buffer;
     std::shared_ptr<testing::NiceMock<mtd::MockRenderable>> renderable;
     mg::RenderableList renderable_list;
-    glm::mat4 trans;
+    glm::mat4 trans{1.f};
     std::shared_ptr<mtd::StubGlRenderingProvider> const gl_platform{std::make_shared<mtd::StubGlRenderingProvider>()};
 
     class StubProgram : public mg::gl::Program
@@ -230,6 +238,58 @@ TEST_F(GLRenderer, avoids_src_alpha_for_rgbx_blending)  // LP: #1423462
     renderer.render(renderable_list);
 }
 
+TEST_F(GLRenderer, applies_inverse_orientation_matrix)
+{
+    InSequence seq;
+    EXPECT_CALL(mock_gl, glUniformMatrix4fv(_, _, _, _))
+        .Times(2); // Display transform
+    EXPECT_CALL(*renderable, orientation())
+        .WillOnce(Return(mir_orientation_left));
+    EXPECT_CALL(mock_gl, glUniformMatrix4fv(
+        _, _, _, testing::Truly([](float const* ptr)
+        {
+            glm::mat4 mat;
+            for (size_t i = 0; i < 4; i++)
+            {
+                for (size_t j = 0; j < 4; j++)
+                {
+                    mat[i][j] = ptr[i * 4 + j];
+                }
+            }
+            return mat * glm::mat4(mir::graphics::transformation(mir_orientation_left)) == glm::mat4(1.f);
+        }))).Times(1);
+
+    mrg::Renderer renderer(gl_platform, make_output_surface());
+    renderer.render(renderable_list);
+}
+
+TEST_F(GLRenderer, applies_mirror_mode)
+{
+    InSequence seq;
+    EXPECT_CALL(mock_gl, glUniformMatrix4fv(_, _, _, _))
+        .Times(3); // Display transform + orientation transform
+    EXPECT_CALL(*renderable, mirror_mode())
+        .WillOnce(Return(mir_mirror_mode_vertical));
+    EXPECT_CALL(mock_gl, glUniformMatrix4fv(
+        _, _, _, testing::Truly([](float const* ptr)
+        {
+            glm::mat4 mat;
+            for (size_t i = 0; i < 4; i++)
+            {
+                for (size_t j = 0; j < 4; j++)
+                {
+                    mat[i][j] = ptr[i * 4 + j];
+                }
+            }
+            glm::mat4 expected(1.f);
+            expected[1][1] = -1;
+            return mat == expected;
+        }))).Times(1);
+
+    mrg::Renderer renderer(gl_platform, make_output_surface());
+    renderer.render(renderable_list);
+}
+
 TEST_F(GLRenderer, clears_to_opaque_black)
 {
     InSequence seq;
@@ -245,15 +305,24 @@ TEST_F(GLRenderer, clears_to_opaque_black)
 TEST_F(GLRenderer, makes_display_buffer_current_when_created)
 {
     auto mock_output_surface = make_output_surface();
+    // We move the output_surface into the Renderer on construction, but want to validate the
+    // expectations before destruction; we need to hold a non-owning ptr to it.
+    auto raw_surface = mock_output_surface.get();
 
     EXPECT_CALL(*mock_output_surface, make_current());
 
     mrg::Renderer renderer(gl_platform, std::move(mock_output_surface));
+
+    // Teardown might make further GL calls; we don't care about them here.
+    testing::Mock::VerifyAndClearExpectations(raw_surface);
 }
 
 TEST_F(GLRenderer, makes_display_buffer_current_before_rendering)
 {
     auto mock_output_surface = make_output_surface();
+    // We move the output_surface into the Renderer on construction, but want to validate the
+    // expectations before destruction; we need to hold a non-owning ptr to it.
+    auto raw_surface = mock_output_surface.get();
 
     InSequence seq;
     EXPECT_CALL(*mock_output_surface, make_current()).Times(AnyNumber());
@@ -262,6 +331,9 @@ TEST_F(GLRenderer, makes_display_buffer_current_before_rendering)
     mrg::Renderer renderer(gl_platform, std::move(mock_output_surface));
 
     renderer.render(renderable_list);
+
+    // Teardown might make further GL calls; we don't care about them here.
+    testing::Mock::VerifyAndClearExpectations(raw_surface);
 }
 
 TEST_F(GLRenderer, swaps_buffers_after_rendering)
@@ -303,6 +375,37 @@ TEST_F(GLRenderer, dont_set_scissor_test_when_unnecessary)
     renderer.render(renderable_list);
 }
 
+TEST_F(GLRenderer, scales_scissor_test_with_output_scale)
+{
+    // Regression test for: WindowInfo::clip_area is incorrect if the output is scaled
+    // When display has scale=2, viewport is in logical coordinates (960x540)
+    // but physical output is 1920x1080. glScissor needs physical coordinates.
+
+    int const physical_width = 1920;
+    int const physical_height = 1080;
+    int const logical_width = 960;   // physical / scale(2.0)
+    int const logical_height = 540;  // physical / scale(2.0)
+
+    auto output_surface = make_output_surface();
+    ON_CALL(*output_surface, size())
+        .WillByDefault(Return(mir::geometry::Size{physical_width, physical_height}));
+
+    // clip_area is in logical coordinates
+    EXPECT_CALL(*renderable, clip_area())
+        .WillRepeatedly(Return(std::optional<mir::geometry::Rectangle>({{0, 0}, {100, 100}})));
+
+    EXPECT_CALL(mock_gl, glEnable(GL_SCISSOR_TEST));
+    EXPECT_CALL(mock_gl, glDisable(GL_SCISSOR_TEST));
+    // Width and height should be scaled by 2.0 (200, 200 instead of 100, 100)
+    int const scaled_clip_size = 100 * 2;  // logical size * scale factor
+    EXPECT_CALL(mock_gl, glScissor(0, physical_height - scaled_clip_size, scaled_clip_size, scaled_clip_size));
+
+    mrg::Renderer renderer(gl_platform, std::move(output_surface));
+    renderer.set_viewport(mir::geometry::Rectangle{{0, 0}, {logical_width, logical_height}});
+
+    renderer.render(renderable_list);
+}
+
 
 TEST_F(GLRenderer, unchanged_viewport_avoids_gl_calls)
 {
@@ -436,3 +539,57 @@ TEST_F(GLRenderer, sets_viewport_downscaled_wide)
     mrg::Renderer renderer(gl_platform, std::move(output_surface));
     renderer.set_viewport(view_area);
 }
+
+TEST_F(GLRenderer, binds_surface_on_set_viewport)
+{
+    auto output_surface = make_output_surface();
+    // We move the output_surface into the Renderer on construction, but want to validate the
+    // expectations before destruction; we need to hold a non-owning ptr to it.
+    auto raw_surface = output_surface.get();
+
+    InSequence seq;
+    EXPECT_CALL(*output_surface, make_current())
+        .Times(2);  // Once during construction, and once when we update the viewport
+    EXPECT_CALL(*output_surface, bind())
+        .Times(1);  // Once when we update the viewport
+
+    mir::geometry::Rectangle constexpr view_area{{0,0}, {1920,1080}};
+    mrg::Renderer renderer(gl_platform, std::move(output_surface));
+    renderer.set_viewport(view_area);
+
+    // Teardown might make further GL calls; we don't care about them here.
+    testing::Mock::VerifyAndClearExpectations(raw_surface);
+}
+
+TEST_F(GLRenderer, destroys_gl_resources_with_current_context)
+{
+    auto mock_output_surface = make_output_surface();
+
+    auto const dummy_dpy = reinterpret_cast<EGLDisplay>(0x0000110011);
+    auto const dummy_ctx = reinterpret_cast<EGLContext>(0x00ffaa1122);
+
+    ON_CALL(*mock_output_surface, make_current())
+        .WillByDefault(
+            [dummy_dpy, dummy_ctx]()
+            {
+               eglMakeCurrent(dummy_dpy, EGL_NO_SURFACE, EGL_NO_SURFACE, dummy_ctx);
+            });
+
+    mrg::Renderer renderer(gl_platform, std::move(mock_output_surface));
+
+    eglMakeCurrent(dummy_dpy, EGL_NO_SURFACE, EGL_NO_SURFACE, EGL_NO_CONTEXT);
+
+    // All cleanup should be done with a current context
+    EXPECT_CALL(mock_gl, glDeleteShader(_))
+        .WillRepeatedly(
+            [dummy_ctx](auto)
+            {
+               EXPECT_THAT(eglGetCurrentContext(), testing::Eq(dummy_ctx));
+            });
+    EXPECT_CALL(mock_gl, glDeleteProgram(_))
+        .WillRepeatedly(
+            [dummy_ctx](auto)
+            {
+               EXPECT_THAT(eglGetCurrentContext(), testing::Eq(dummy_ctx));
+            });
+}
