@@ -14,43 +14,41 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/shell/abstract_shell.h"
+#include <mir/shell/abstract_shell.h>
 
-#include "mir/events/event_builders.h"
-#include "mir/scene/session.h"
-#include "mir/scene/null_session_listener.h"
-#include "mir/scene/session_container.h"
-#include "mir/scene/surface_factory.h"
-#include "mir/graphics/display_configuration_observer.h"
-#include "mir/wayland/weak.h"
+#include <mir/events/event_builders.h>
+#include <mir/scene/session.h>
+#include <mir/scene/null_session_listener.h>
+#include <mir/scene/session_container.h>
+#include <mir/scene/surface_factory.h>
+#include <mir/graphics/display_configuration_observer.h>
+#include <mir/wayland/weak.h>
 
 #include "src/server/report/null/shell_report.h"
 #include "src/include/server/mir/scene/session_event_sink.h"
 #include "src/server/scene/session_manager.h"
 #include "src/server/shell/decoration/null_manager.h"
 
-#include "mir/test/doubles/mock_window_manager.h"
-#include "mir/test/doubles/mock_surface_stack.h"
-#include "mir/test/doubles/mock_surface.h"
-#include "mir/test/doubles/stub_surface.h"
-#include "mir/test/doubles/null_event_sink.h"
-#include "mir/test/doubles/null_prompt_session_manager.h"
-#include "mir/test/doubles/stub_input_targeter.h"
-#include "mir/test/doubles/stub_buffer_allocator.h"
-#include "mir/test/doubles/null_application_not_responding_detector.h"
-#include "mir/test/doubles/stub_display.h"
-#include "mir/test/doubles/mock_input_seat.h"
-#include "mir/test/doubles/stub_observer_registrar.h"
+#include <mir/test/doubles/mock_window_manager.h>
+#include <mir/test/doubles/mock_surface_stack.h>
+#include <mir/test/doubles/mock_surface.h>
+#include <mir/test/doubles/stub_surface.h>
+#include <mir/test/doubles/null_event_sink.h>
+#include <mir/test/doubles/null_prompt_session_manager.h>
+#include <mir/test/doubles/stub_input_targeter.h>
+#include <mir/test/doubles/stub_buffer_allocator.h>
+#include <mir/test/doubles/stub_display.h>
+#include <mir/test/doubles/mock_input_seat.h>
+#include <mir/test/doubles/stub_observer_registrar.h>
 
-#include "mir/test/fake_shared.h"
-#include "mir/test/event_matchers.h"
-#include "mir/test/make_surface_spec.h"
+#include <mir/test/fake_shared.h>
+#include <mir/test/event_matchers.h>
+#include <mir/test/make_surface_spec.h>
 
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
 
 namespace mf = mir::frontend;
-namespace mw = mir::wayland;
 namespace mi = mir::input;
 namespace ms = mir::scene;
 namespace msh = mir::shell;
@@ -72,20 +70,20 @@ MATCHER_P(WeakPtrTo, p, "")
 
 struct MockSessionContainer : public ms::SessionContainer
 {
-    MOCK_METHOD1(insert_session, void(std::shared_ptr<ms::Session> const&));
-    MOCK_METHOD1(remove_session, void(std::shared_ptr<ms::Session> const&));
-    MOCK_CONST_METHOD1(successor_of, std::shared_ptr<ms::Session>(std::shared_ptr<ms::Session> const&));
-    MOCK_CONST_METHOD1(for_each, void(std::function<void(std::shared_ptr<ms::Session> const&)>));
-    MOCK_METHOD0(lock, void());
-    MOCK_METHOD0(unlock, void());
+    MOCK_METHOD(void, insert_session, (std::shared_ptr<ms::Session> const&));
+    MOCK_METHOD(void, remove_session, (std::shared_ptr<ms::Session> const&));
+    MOCK_METHOD(std::shared_ptr<ms::Session>, successor_of, (std::shared_ptr<ms::Session> const&), (const));
+    MOCK_METHOD(void, for_each, (std::function<void(std::shared_ptr<ms::Session> const&)>), (const));
+    MOCK_METHOD(void, lock, ());
+    MOCK_METHOD(void, unlock, ());
     ~MockSessionContainer() noexcept {}
 };
 
 struct MockSessionEventSink : public ms::SessionEventSink
 {
-    MOCK_METHOD1(handle_focus_change, void(std::shared_ptr<ms::Session> const& session));
-    MOCK_METHOD0(handle_no_focus, void());
-    MOCK_METHOD1(handle_session_stopping, void(std::shared_ptr<ms::Session> const& session));
+    MOCK_METHOD(void, handle_focus_change, (std::shared_ptr<ms::Session> const& session));
+    MOCK_METHOD(void, handle_no_focus, ());
+    MOCK_METHOD(void, handle_session_stopping, (std::shared_ptr<ms::Session> const& session));
 };
 
 struct MockSessionManager : ms::SessionManager
@@ -106,13 +104,12 @@ struct MockSessionManager : ms::SessionManager
               session_event_sink,
               std::make_shared<ms::NullSessionListener>(),
               display,
-              std::make_shared<mtd::NullANRDetector>(),
               std::make_shared<mtd::StubBufferAllocator>(),
               std::make_shared<mtd::StubObserverRegistrar<mir::graphics::DisplayConfigurationObserver>>()}
     {
     }
 
-    MOCK_METHOD1(set_focus_to, void (std::shared_ptr<ms::Session> const& focus));
+    MOCK_METHOD(void, set_focus_to, (std::shared_ptr<ms::Session> const& focus));
 
     void unmocked_set_focus_to(std::shared_ptr<ms::Session> const& focus)
     { ms::SessionManager::set_focus_to(focus); }
@@ -120,16 +117,19 @@ struct MockSessionManager : ms::SessionManager
 
 struct MockSurfaceFactory : public ms::SurfaceFactory
 {
-    MOCK_METHOD4(create_surface, std::shared_ptr<ms::Surface>(
-        std::shared_ptr<ms::Session> const&,
-        mw::Weak<mf::WlSurface> const&,
-        std::list<ms::StreamInfo> const&,
-        msh::SurfaceSpecification const&));
+    MOCK_METHOD(
+        std::shared_ptr<ms::Surface>,
+        create_surface,
+        (std::shared_ptr<ms::Session> const&,
+         std::list<ms::StreamInfo> const&,
+         msh::SurfaceSpecification const&));
 };
 
 struct MockDecorationManager : public msh::decoration::NullManager
 {
-    MOCK_METHOD1(decorate, void(std::shared_ptr<ms::Surface> const&));
+    MOCK_METHOD(void, decorate, (std::shared_ptr<ms::Surface> const&));
+    MOCK_METHOD(
+        geom::Size, compute_size_with_decorations, (geom::Size content_size, MirWindowType type, MirWindowState state));
 };
 
 using NiceMockWindowManager = NiceMock<mtd::MockWindowManager>;
@@ -174,7 +174,7 @@ struct AbstractShell : Test
             WillByDefault(Invoke(&session_manager, &MockSessionManager::unmocked_set_focus_to));
         ON_CALL(mock_surface, size())
             .WillByDefault(Return(geom::Size{}));
-        ON_CALL(surface_factory, create_surface(_, _, _, _))
+        ON_CALL(surface_factory, create_surface(_, _, _))
             .WillByDefault(Return(mt::fake_shared(mock_surface)));
         ON_CALL(seat, create_device_state())
             .WillByDefault(Invoke(
@@ -191,13 +191,11 @@ struct AbstractShell : Test
         auto const session = shell.open_session(
             __LINE__,
             mir::Fd{mir::Fd::invalid},
-            "Foo",
-            std::shared_ptr<mf::EventSink>());
-        EXPECT_CALL(surface_factory, create_surface(_, _, _, _))
+            "Foo");
+        EXPECT_CALL(surface_factory, create_surface(_, _, _))
             .WillOnce(Return(mt::fake_shared(surface)));
         return shell.create_surface(
             session,
-            {},
             mt::make_surface_spec(session->create_buffer_stream(properties)),
             nullptr,
             nullptr);
@@ -215,7 +213,7 @@ TEST_F(AbstractShell, open_session_adds_session_to_window_manager)
     InSequence s;
     EXPECT_CALL(*wm, add_session(_)).WillOnce(SaveArg<0>(&new_session));
 
-    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Visual Basic Studio", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Visual Basic Studio");
     EXPECT_EQ(session, new_session);
 }
 
@@ -226,15 +224,15 @@ TEST_F(AbstractShell, close_session_removes_session_from_window_manager)
     InSequence s;
     EXPECT_CALL(*wm, remove_session(_)).WillOnce(SaveArg<0>(&old_session));
 
-    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
     shell.close_session(session);
     EXPECT_EQ(session, old_session);
 }
 
 TEST_F(AbstractShell, close_session_notifies_session_event_sink)
 {
-    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla");
 
     InSequence s;
     EXPECT_CALL(session_event_sink, handle_session_stopping(session1));
@@ -249,17 +247,17 @@ TEST_F(AbstractShell, close_session_removes_existing_session_surfaces_from_windo
     mtd::StubSurface surface1;
     mtd::StubSurface surface2;
     mtd::StubSurface surface3;
-    EXPECT_CALL(surface_factory, create_surface(_, _, _, _)).
+    EXPECT_CALL(surface_factory, create_surface(_, _, _)).
         WillOnce(Return(mt::fake_shared(surface1))).
         WillOnce(Return(mt::fake_shared(surface2))).
         WillOnce(Return(mt::fake_shared(surface3)));
 
-    auto const session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto const created_surface1 = shell.create_surface(session, {},
+    auto const session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
+    auto const created_surface1 = shell.create_surface(session,
         mt::make_surface_spec(session->create_buffer_stream(properties)), nullptr, nullptr);
-    auto const created_surface2 = shell.create_surface(session, {},
+    auto const created_surface2 = shell.create_surface(session,
         mt::make_surface_spec(session->create_buffer_stream(properties)), nullptr, nullptr);
-    auto const created_surface3 = shell.create_surface(session, {},
+    auto const created_surface3 = shell.create_surface(session,
         mt::make_surface_spec(session->create_buffer_stream(properties)), nullptr, nullptr);
 
     session->destroy_surface(created_surface2);
@@ -276,18 +274,18 @@ TEST_F(AbstractShell, close_session_removes_existing_session_surfaces_from_windo
 TEST_F(AbstractShell, create_surface_provides_create_parameters_to_window_manager)
 {
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
 
     auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
     EXPECT_CALL(*wm, add_surface(session, params, _));
 
-    shell.create_surface(session, {}, params, nullptr, nullptr);
+    shell.create_surface(session, params, nullptr, nullptr);
 }
 
 TEST_F(AbstractShell, create_surface_allows_window_manager_to_set_create_parameters)
 {
     std::shared_ptr<ms::Session> const session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
 
     auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
     params.width = geom::Width{100};
@@ -301,13 +299,13 @@ TEST_F(AbstractShell, create_surface_allows_window_manager_to_set_create_paramet
             std::function<std::shared_ptr<ms::Surface>(std::shared_ptr<ms::Session> const& session, msh::SurfaceSpecification const&)> const& build)
             { return build(session, params); }));
 
-    shell.create_surface(session, {}, params, nullptr, nullptr);
+    shell.create_surface(session, params, nullptr, nullptr);
 }
 
 TEST_F(AbstractShell, create_surface_allows_window_manager_to_enable_ssd)
 {
     std::shared_ptr<ms::Session> const session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
 
     auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
 
@@ -326,13 +324,13 @@ TEST_F(AbstractShell, create_surface_allows_window_manager_to_enable_ssd)
                 return build(session, modified_params);
             }));
 
-    shell.create_surface(session, {}, params, nullptr, nullptr);
+    shell.create_surface(session, params, nullptr, nullptr);
 }
 
 TEST_F(AbstractShell, create_surface_allows_window_manager_to_disable_ssd)
 {
     std::shared_ptr<ms::Session> const session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
 
     auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
     params.server_side_decorated = true;
@@ -352,7 +350,7 @@ TEST_F(AbstractShell, create_surface_allows_window_manager_to_disable_ssd)
                 return build(session, modified_params);
             }));
 
-    shell.create_surface(session, {}, params, nullptr, nullptr);
+    shell.create_surface(session, params, nullptr, nullptr);
 }
 
 TEST_F(AbstractShell, create_surface_sets_surfaces_session)
@@ -360,23 +358,23 @@ TEST_F(AbstractShell, create_surface_sets_surfaces_session)
     auto const mock_surface = std::make_shared<mtd::MockSurface>();
 
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
 
-    EXPECT_CALL(surface_factory, create_surface(session, _, _, _)).
+    EXPECT_CALL(surface_factory, create_surface(session, _, _)).
         WillOnce(Return(mock_surface));
 
     auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
 
-    shell.create_surface(session, {}, params, nullptr, nullptr);
+    shell.create_surface(session, params, nullptr, nullptr);
 }
 
 TEST_F(AbstractShell, destroy_surface_removes_surface_from_window_manager)
 {
     std::shared_ptr<ms::Session> const session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
 
-    auto const surface = shell.create_surface(session, {}, params, nullptr, nullptr);
+    auto const surface = shell.create_surface(session, params, nullptr, nullptr);
 
     EXPECT_CALL(*wm, remove_surface(session, WeakPtrTo(surface)));
 
@@ -473,8 +471,8 @@ TEST_F(AbstractShell, pointer_input_events_are_handled_by_window_manager)
 
 TEST_F(AbstractShell, as_focus_controller_set_focus_to_notifies_session_event_sink)
 {
-    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla");
 
     InSequence s;
     EXPECT_CALL(session_event_sink, handle_focus_change(session1));
@@ -490,12 +488,12 @@ TEST_F(AbstractShell, as_focus_controller_set_focus_to_notifies_session_event_si
 TEST_F(AbstractShell, as_focus_controller_focus_next_session_notifies_session_event_sink)
 {
     msh::FocusController& focus_controller = shell;
-    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla");
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto const params2 = mt::make_surface_spec(session->create_buffer_stream(properties));
-    shell.create_surface(session, {}, params, nullptr, nullptr);
-    shell.create_surface(session1, {}, params2, nullptr, nullptr);
+    shell.create_surface(session, params, nullptr, nullptr);
+    shell.create_surface(session1, params2, nullptr, nullptr);
 
     focus_controller.set_focus_to(session, {});
 
@@ -506,12 +504,12 @@ TEST_F(AbstractShell, as_focus_controller_focus_next_session_notifies_session_ev
 
 TEST_F(AbstractShell, as_focus_controller_focused_session_follows_focus)
 {
-    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla");
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto const params2 = mt::make_surface_spec(session->create_buffer_stream(properties));
-    shell.create_surface(session, {}, params, nullptr, nullptr);
-    shell.create_surface(session1, {}, params2, nullptr, nullptr);
+    shell.create_surface(session, params, nullptr, nullptr);
+    shell.create_surface(session1, params2, nullptr, nullptr);
 
     msh::FocusController& focus_controller = shell;
 
@@ -525,17 +523,17 @@ TEST_F(AbstractShell, as_focus_controller_focused_session_follows_focus)
 
 TEST_F(AbstractShell, as_focus_controller_focused_surface_follows_focus)
 {
-    auto const session0 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto const session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
+    auto const session0 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
+    auto const session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla");
     ON_CALL(mock_surface1, size()).WillByDefault(Return(geom::Size{}));
-    EXPECT_CALL(surface_factory, create_surface(_, _, _, _)).Times(AnyNumber())
+    EXPECT_CALL(surface_factory, create_surface(_, _, _)).Times(AnyNumber())
         .WillOnce(Return(mt::fake_shared(mock_surface1)))
         .WillOnce(Return(mt::fake_shared(mock_surface)));
 
     auto const params0 = mt::make_surface_spec(session0->create_buffer_stream(properties));
     auto const params1 = mt::make_surface_spec(session1->create_buffer_stream(properties));
-    auto const surface0 = shell.create_surface(session0, {}, params0, nullptr, nullptr);
-    auto const surface1 = shell.create_surface(session1, {}, params1, nullptr, nullptr);
+    auto const surface0 = shell.create_surface(session0, params0, nullptr, nullptr);
+    auto const surface1 = shell.create_surface(session1, params1, nullptr, nullptr);
 
     msh::FocusController& focus_controller = shell;
 
@@ -568,13 +566,13 @@ TEST_F(AbstractShell, as_focus_controller_delegates_surface_at_to_surface_stack)
 TEST_F(AbstractShell, as_focus_controller_focus_next_session_skips_surfaceless_sessions)
 {
     msh::FocusController& focus_controller = shell;
-    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Surfaceless", std::shared_ptr<mf::EventSink>());
-    auto session2 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Surfaceless");
+    auto session2 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla");
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto created_surface = shell.create_surface(session, {}, params, nullptr, nullptr);
+    auto created_surface = shell.create_surface(session, params, nullptr, nullptr);
     auto const params2 = mt::make_surface_spec(session2->create_buffer_stream(properties));
-    shell.create_surface(session2, {}, params2, nullptr, nullptr);
+    shell.create_surface(session2, params2, nullptr, nullptr);
 
     focus_controller.set_focus_to(session, created_surface);
 
@@ -587,10 +585,10 @@ TEST_F(AbstractShell,
        as_focus_controller_focus_next_session_does_not_focus_any_session_if_no_session_has_surfaces)
 {
     msh::FocusController& focus_controller = shell;
-    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Surfaceless", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Surfaceless");
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
+    auto surface = shell.create_surface(session, creation_params, nullptr, nullptr);
 
     focus_controller.set_focus_to(session, surface);
 
@@ -604,10 +602,10 @@ TEST_F(AbstractShell,
 TEST_F(AbstractShell, modify_surface_with_only_streams_doesnt_call_into_wm)
 {
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
 
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
+    auto surface = shell.create_surface(session, creation_params, nullptr, nullptr);
 
     msh::SurfaceSpecification stream_modification;
     stream_modification.streams = std::vector<msh::StreamSpecification>{};
@@ -620,11 +618,11 @@ TEST_F(AbstractShell, modify_surface_with_only_streams_doesnt_call_into_wm)
 TEST_F(AbstractShell, modify_surface_does_not_call_wm_for_empty_changes)
 {
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
 
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
 
-    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
+    auto surface = shell.create_surface(session, creation_params, nullptr, nullptr);
 
     msh::SurfaceSpecification stream_modification;
 
@@ -644,10 +642,10 @@ TEST_F(AbstractShell, size_gets_adjusted_for_windows_with_margins)
         content_size.width + left + right,
         content_size.height + top + bottom};
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
 
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
+    auto surface = shell.create_surface(session, creation_params, nullptr, nullptr);
     surface->resize({50, 50});
     surface->set_window_margins(top, left, bottom, right);
 
@@ -675,10 +673,10 @@ TEST_F(AbstractShell, max_size_gets_adjusted_for_windows_with_margins)
         content_size.width + left + right,
         content_size.height + top + bottom};
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
 
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
+    auto surface = shell.create_surface(session, creation_params, nullptr, nullptr);
     surface->resize({50, 50});
     surface->set_window_margins(top, left, bottom, right);
 
@@ -706,10 +704,10 @@ TEST_F(AbstractShell, min_size_gets_adjusted_for_windows_with_margins)
         content_size.width + left + right,
         content_size.height + top + bottom};
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
 
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
+    auto surface = shell.create_surface(session, creation_params, nullptr, nullptr);
     surface->resize({50, 50});
     surface->set_window_margins(top, left, bottom, right);
 
@@ -738,10 +736,10 @@ TEST_F(AbstractShell, aux_rect_gets_adjusted_for_windows_with_margins)
         frontend_aux_rect.top_left + geom::Displacement{left, top},
         frontend_aux_rect.size};
     std::shared_ptr<ms::Session> session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
 
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
+    auto surface = shell.create_surface(session, creation_params, nullptr, nullptr);
     surface->resize(content_size);
     surface->set_window_margins(top, left, bottom, right);
 
@@ -760,14 +758,14 @@ TEST_F(AbstractShell, aux_rect_gets_adjusted_for_windows_with_margins)
 TEST_F(AbstractShell, when_remaining_session_has_no_surface_focus_next_session_doesnt_loop_endlessly)
 {
     std::shared_ptr<ms::Session> empty_session =
-        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "empty_session", std::shared_ptr<mf::EventSink>());
+        shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "empty_session");
 
     {
         std::shared_ptr<ms::Session> another_session =
-            shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "another_session", std::shared_ptr<mf::EventSink>());
+            shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "another_session");
 
         auto creation_params = mt::make_surface_spec(another_session->create_buffer_stream(properties));
-        auto surface = shell.create_surface(another_session, {}, creation_params, nullptr, nullptr);
+        auto surface = shell.create_surface(another_session, creation_params, nullptr, nullptr);
 
         shell.set_focus_to(another_session, surface);
 
@@ -779,15 +777,15 @@ TEST_F(AbstractShell, when_remaining_session_has_no_surface_focus_next_session_d
 
 TEST_F(AbstractShell, focus_can_be_set)
 {
-    EXPECT_CALL(surface_factory, create_surface(_, _, _, _)).Times(AnyNumber())
+    EXPECT_CALL(surface_factory, create_surface(_, _, _)).Times(AnyNumber())
         .WillOnce(Return(mt::fake_shared(mock_surface1)))
         .WillOnce(Return(mt::fake_shared(mock_surface)));
 
     msh::FocusController& focus_controller = shell;
-    auto const session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto const session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto const created_surface1 = shell.create_surface(session, {}, params, nullptr, nullptr);
-    auto const created_surface2 = shell.create_surface(session, {}, params, nullptr, nullptr);
+    auto const created_surface1 = shell.create_surface(session, params, nullptr, nullptr);
+    auto const created_surface2 = shell.create_surface(session, params, nullptr, nullptr);
 
     focus_controller.set_focus_to(session, created_surface2);
     EXPECT_THAT(created_surface1->focus_state(), Eq(mir_window_focus_state_unfocused));
@@ -802,17 +800,17 @@ TEST_F(AbstractShell, setting_focus_to_child_makes_parent_active)
 {
     ON_CALL(mock_surface1, parent())
         .WillByDefault(Return(mt::fake_shared(mock_surface)));
-    EXPECT_CALL(surface_factory, create_surface(_, _, _, _)).Times(AnyNumber())
+    EXPECT_CALL(surface_factory, create_surface(_, _, _)).Times(AnyNumber())
         .WillOnce(Return(mt::fake_shared(mock_surface)))
         .WillOnce(Return(mt::fake_shared(mock_surface1)))
         .WillOnce(Return(mt::fake_shared(mock_surface2)));
 
     msh::FocusController& focus_controller = shell;
-    auto const session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto const session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto const parent_surface = shell.create_surface(session, {}, params, nullptr, nullptr);
-    auto const child_surface = shell.create_surface(session, {}, params, nullptr, nullptr);
-    auto const other_surface = shell.create_surface(session, {}, params, nullptr, nullptr);
+    auto const parent_surface = shell.create_surface(session, params, nullptr, nullptr);
+    auto const child_surface = shell.create_surface(session, params, nullptr, nullptr);
+    auto const other_surface = shell.create_surface(session, params, nullptr, nullptr);
 
     ASSERT_THAT(child_surface->parent(), Eq(parent_surface));
 
@@ -890,7 +888,7 @@ TEST_F(AbstractShell, makes_parent_active_when_switching_to_child)
     focus_controller.set_focus_to(surface_parent->session().lock(), surface_parent);
     /* window         | expected focus state
      * -----------------------------------------------
-     * surface_parent | mir_window_focus_state_focused 
+     * surface_parent | mir_window_focus_state_focused
      * surface_child  | <don't care>
     */
 
@@ -1035,20 +1033,20 @@ TEST_F(AbstractShell, popup_grab_tree_can_be_set_based_on_child)
     focus_controller.set_popup_grab_tree(surface_tip);
 }
 
-// Regression test for https://github.com/MirServer/mir/issues/2279
+// Regression test for https://github.com/canonical/mir/issues/2279
 TEST_F(AbstractShell, focus_next_session_allows_later_focusing_same_window)
 {
-    EXPECT_CALL(surface_factory, create_surface(_, _, _, _)).Times(AnyNumber())
+    EXPECT_CALL(surface_factory, create_surface(_, _, _)).Times(AnyNumber())
         .WillOnce(Return(mt::fake_shared(mock_surface1)))
         .WillOnce(Return(mt::fake_shared(mock_surface)));
 
     msh::FocusController& focus_controller = shell;
-    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session2 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
+    auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
+    auto session2 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla");
     auto const params1 = mt::make_surface_spec(session1->create_buffer_stream(properties));
-    auto created_surface1 = shell.create_surface(session1, {}, params1, nullptr, nullptr);
+    auto created_surface1 = shell.create_surface(session1, params1, nullptr, nullptr);
     auto const params2 = mt::make_surface_spec(session2->create_buffer_stream(properties));
-    auto created_surface2 = shell.create_surface(session2, {}, params2, nullptr, nullptr);
+    auto created_surface2 = shell.create_surface(session2, params2, nullptr, nullptr);
 
     focus_controller.set_focus_to(session1, created_surface1);
     focus_controller.focus_next_session();
@@ -1087,10 +1085,208 @@ TEST_F(AbstractShell, as_focus_controller_emits_input_device_state_event_on_focu
 {
     EXPECT_CALL(mock_surface, consume(mt::InputDeviceStateEvent())).Times(1);
 
-    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "some", std::shared_ptr<mf::EventSink>());
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "some");
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
+    auto surface = shell.create_surface(session, creation_params, nullptr, nullptr);
 
     msh::FocusController& focus_controller = shell;
     focus_controller.set_focus_to(session, surface);
 }
+struct SsdConstraintsParams
+{
+    bool set_width;
+    bool set_height;
+    bool set_min_size;
+    bool set_max_size;
+};
+
+class SsdSizeConstraintsTest : public AbstractShell, public WithParamInterface<SsdConstraintsParams>
+{
+};
+
+TEST_P(SsdSizeConstraintsTest, adjusts_size_constraints_when_ssd_enabled)
+{
+    auto const& p = GetParam();
+
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "TestSession");
+    auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
+
+    params.server_side_decorated = true;
+
+    int const w_val = 800;
+    int const h_val = 600;
+    int const min_w = 100;
+    int const min_h = 100;
+    int const max_w = 2000;
+    int const max_h = 2000;
+
+    if (p.set_width)
+        params.width = geom::Width{w_val};
+
+    if (p.set_height)
+        params.height = geom::Height{h_val};
+
+    if (p.set_min_size)
+    {
+        params.min_width = geom::Width{min_w};
+        params.min_height = geom::Height{min_h};
+    }
+
+    if (p.set_max_size)
+    {
+        params.max_width = geom::Width{max_w};
+        params.max_height = geom::Height{max_h};
+    }
+
+    geom::Size const padding{20, 30};
+
+    EXPECT_CALL(decoration_manager, compute_size_with_decorations(_, _, _))
+
+        .WillRepeatedly(
+            Invoke([padding](geom::Size const& content, MirWindowType, MirWindowState)
+                   { return geom::Size{content.width + padding.width, content.height + padding.height}; }));
+
+    msh::SurfaceSpecification captured_spec;
+    EXPECT_CALL(*wm, add_surface(session, _, _))
+        .WillOnce(Invoke(
+            [&](auto, auto spec, auto)
+            {
+                captured_spec = spec;
+                return std::make_shared<NiceMock<mtd::MockSurface>>();
+            }));
+
+    shell.create_surface(session, params, nullptr, nullptr);
+
+    if (p.set_width)
+        EXPECT_THAT(captured_spec.width.value(), Eq(geom::Width{w_val} + padding.width));
+    else
+        EXPECT_FALSE(captured_spec.width.is_set());
+
+    if (p.set_height)
+        EXPECT_THAT(captured_spec.height.value(), Eq(geom::Height{h_val} + padding.height));
+    else
+        EXPECT_FALSE(captured_spec.height.is_set());
+
+    if (p.set_min_size)
+    {
+        EXPECT_THAT(captured_spec.min_width.value(), Eq(geom::Width{min_w} + padding.width));
+        EXPECT_THAT(captured_spec.min_height.value(), Eq(geom::Height{min_h} + padding.height));
+    }
+    else
+    {
+        EXPECT_FALSE(captured_spec.min_width.is_set());
+        EXPECT_FALSE(captured_spec.min_height.is_set());
+    }
+
+    if (p.set_max_size)
+    {
+        EXPECT_THAT(captured_spec.max_width.value(), Eq(geom::Width{max_w} + padding.width));
+        EXPECT_THAT(captured_spec.max_height.value(), Eq(geom::Height{max_h} + padding.height));
+    }
+    else
+    {
+        EXPECT_FALSE(captured_spec.max_width.is_set());
+        EXPECT_FALSE(captured_spec.max_height.is_set());
+    }
+
+}
+
+TEST_P(SsdSizeConstraintsTest, does_not_adjust_size_constraints_when_ssd_disabled)
+{
+    auto const& p = GetParam();
+
+    auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "TestSession");
+    auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
+
+    params.server_side_decorated = false;
+
+    int const w_val = 800;
+    int const h_val = 600;
+    int const min_w = 100;
+    int const min_h = 100;
+    int const max_w = 2000;
+    int const max_h = 2000;
+
+    if (p.set_width)
+        params.width = geom::Width{w_val};
+
+    if (p.set_height)
+        params.height = geom::Height{h_val};
+
+    if (p.set_min_size)
+    {
+        params.min_width = geom::Width{min_w};
+        params.min_height = geom::Height{min_h};
+    }
+
+    if (p.set_max_size)
+    {
+        params.max_width = geom::Width{max_w};
+        params.max_height = geom::Height{max_h};
+    }
+
+    EXPECT_CALL(decoration_manager, compute_size_with_decorations(_, _, _)).Times(0);
+
+    msh::SurfaceSpecification captured_spec;
+    EXPECT_CALL(*wm, add_surface(session, _, _))
+        .WillOnce(Invoke(
+            [&](auto, auto spec, auto)
+            {
+                captured_spec = spec;
+                return std::make_shared<NiceMock<mtd::MockSurface>>();
+            }));
+
+    shell.create_surface(session, params, nullptr, nullptr);
+
+    if (p.set_width)
+        EXPECT_THAT(captured_spec.width.value(), Eq(geom::Width{w_val}));
+    else
+        EXPECT_FALSE(captured_spec.width.is_set());
+
+    if (p.set_height)
+        EXPECT_THAT(captured_spec.height.value(), Eq(geom::Height{h_val}));
+    else
+        EXPECT_FALSE(captured_spec.height.is_set());
+
+    if (p.set_min_size)
+    {
+        EXPECT_THAT(captured_spec.min_width.value(), Eq(geom::Width{min_w}));
+        EXPECT_THAT(captured_spec.min_height.value(), Eq(geom::Height{min_h}));
+    }
+    else
+    {
+        EXPECT_FALSE(captured_spec.min_width.is_set());
+        EXPECT_FALSE(captured_spec.min_height.is_set());
+    }
+
+    if (p.set_max_size)
+    {
+        EXPECT_THAT(captured_spec.max_width.value(), Eq(geom::Width{max_w}));
+        EXPECT_THAT(captured_spec.max_height.value(), Eq(geom::Height{max_h}));
+    }
+    else
+    {
+        EXPECT_FALSE(captured_spec.max_width.is_set());
+        EXPECT_FALSE(captured_spec.max_height.is_set());
+    }
+}
+
+INSTANTIATE_TEST_SUITE_P(
+    SsdSizeConstraints,
+    SsdSizeConstraintsTest,
+    testing::Values(
+        SsdConstraintsParams{.set_width = false, .set_height = false, .set_min_size = false, .set_max_size = false},
+        SsdConstraintsParams{.set_width = true, .set_height = true, .set_min_size = true, .set_max_size = true},
+        SsdConstraintsParams{.set_width = true, .set_height = false, .set_min_size = false, .set_max_size = false},
+        SsdConstraintsParams{.set_width = false, .set_height = true, .set_min_size = false, .set_max_size = false},
+        SsdConstraintsParams{.set_width = false, .set_height = false, .set_min_size = true, .set_max_size = false},
+        SsdConstraintsParams{.set_width = false, .set_height = false, .set_min_size = false, .set_max_size = true}),
+    [](TestParamInfo<SsdConstraintsParams> const& info)
+    {
+        return std::format(
+            "width_{}_height_{}_min_size_{}_max_size_{}",
+            info.param.set_width ? "set" : "unset",
+            info.param.set_height ? "set" : "unset",
+            info.param.set_min_size ? "set" : "unset",
+            info.param.set_max_size ? "set" : "unset");
+    });
