@@ -1,5 +1,5 @@
 /*
- * Copyright © 2021 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -15,7 +15,7 @@
  */
 
 #include "src/server/scene/basic_clipboard.h"
-#include "mir/test/fake_shared.h"
+#include <mir/test/fake_shared.h>
 
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
@@ -25,7 +25,7 @@ using namespace testing;
 namespace ms = mir::scene;
 namespace mt = mir::test;
 
-struct MockClipboardSource : ms::ClipboardSource
+struct MockClipboardSource : ms::DataExchangeSource
 {
     auto mime_types() const -> std::vector<std::string> const& override
     {
@@ -36,12 +36,23 @@ struct MockClipboardSource : ms::ClipboardSource
     {
     }
 
+    void cancelled() override {}
+    void dnd_drop_performed() override {}
+    auto actions() -> uint32_t override { return 0; }
+    void offer_accepted(const std::optional<std::string>&) override {}
+    uint32_t offer_set_actions(uint32_t, uint32_t) override { return 0; }
+    void dnd_finished() override {}
+
     std::vector<std::string> types;
 };
 
 struct MockClipboardObserver : ms::ClipboardObserver
 {
-    MOCK_METHOD1(paste_source_set, void(std::shared_ptr<ms::ClipboardSource> const&));
+    MOCK_METHOD(void, paste_source_set, (std::shared_ptr<ms::DataExchangeSource> const&));
+
+    void drag_n_drop_source_set(const std::shared_ptr<ms::DataExchangeSource>&) override {}
+    void drag_n_drop_source_cleared(const std::shared_ptr<ms::DataExchangeSource>&) override {}
+    void end_of_dnd_gesture() override {}
 };
 
 struct BasicClipboardTest : Test
@@ -92,8 +103,11 @@ TEST_F(BasicClipboardTest, clearing_old_paste_source_does_nothing)
 
 TEST_F(BasicClipboardTest, observer_notified_of_paste_source_set)
 {
-    clipboard.register_interest(observer_ptr);
+    Sequence seq;
+    EXPECT_CALL(observer, paste_source_set(Eq(nullptr)));
     EXPECT_CALL(observer, paste_source_set(Eq(source_a)));
+
+    clipboard.register_interest(observer_ptr);
     clipboard.set_paste_source(source_a);
 }
 
@@ -101,8 +115,11 @@ TEST_F(BasicClipboardTest, observer_notified_of_paste_source_change)
 {
     clipboard.set_paste_source(source_a);
 
-    clipboard.register_interest(observer_ptr);
+    Sequence seq;
+    EXPECT_CALL(observer, paste_source_set(Eq(source_a)));
     EXPECT_CALL(observer, paste_source_set(Eq(source_b)));
+
+    clipboard.register_interest(observer_ptr);
     clipboard.set_paste_source(source_b);
 }
 
@@ -110,8 +127,11 @@ TEST_F(BasicClipboardTest, observer_notified_of_paste_source_cleared)
 {
     clipboard.set_paste_source(source_a);
 
-    clipboard.register_interest(observer_ptr);
+    Sequence seq;
     EXPECT_CALL(observer, paste_source_set(Eq(nullptr)));
+    EXPECT_CALL(observer, paste_source_set(Eq(source_a)));
+
+    clipboard.register_interest(observer_ptr);
     clipboard.clear_paste_source();
 }
 
@@ -119,8 +139,11 @@ TEST_F(BasicClipboardTest, observer_notified_of_paste_source_cleared_with_value)
 {
     clipboard.set_paste_source(source_a);
 
-    clipboard.register_interest(observer_ptr);
+    Sequence seq;
+    EXPECT_CALL(observer, paste_source_set(Eq(source_a)));
     EXPECT_CALL(observer, paste_source_set(Eq(nullptr)));
+
+    clipboard.register_interest(observer_ptr);
     clipboard.clear_paste_source(*source_a);
 }
 
@@ -129,16 +152,20 @@ TEST_F(BasicClipboardTest, observer_not_notified_when_old_paste_source_cleared)
     clipboard.set_paste_source(source_a);
     clipboard.set_paste_source(source_b);
 
+    EXPECT_CALL(observer, paste_source_set(Eq(source_b)));
+
     clipboard.register_interest(observer_ptr);
-    EXPECT_CALL(observer, paste_source_set(_)).Times(0);
     // a is not longer the current paste source, so nothing should happen
     clipboard.clear_paste_source(*source_a);
 }
 
 TEST_F(BasicClipboardTest, can_set_paste_source_from_paste_source_observer_callback)
 {
-    clipboard.register_interest(observer_ptr);
     EXPECT_CALL(observer, paste_source_set(_))
+        .WillOnce([&](auto source)
+        {
+            EXPECT_THAT(source, Eq(nullptr));
+        })
         .WillOnce([&](auto)
         {
             clipboard.set_paste_source(source_b);
@@ -147,5 +174,6 @@ TEST_F(BasicClipboardTest, can_set_paste_source_from_paste_source_observer_callb
         {
             EXPECT_THAT(source, Eq(source_b));
         });
+    clipboard.register_interest(observer_ptr);
     clipboard.set_paste_source(source_a);
 }
