@@ -15,10 +15,10 @@
  */
 
 #include "src/server/scene/basic_idle_hub.h"
-#include "mir/test/doubles/advanceable_clock.h"
-#include "mir/test/doubles/fake_alarm_factory.h"
-#include "mir/test/doubles/explicit_executor.h"
-#include "mir/test/fake_shared.h"
+#include <mir/test/doubles/advanceable_clock.h>
+#include <mir/test/doubles/fake_alarm_factory.h>
+#include <mir/test/doubles/explicit_executor.h>
+#include <mir/test/fake_shared.h>
 
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
@@ -33,8 +33,8 @@ namespace
 {
 struct MockObserver: ms::IdleStateObserver
 {
-    MOCK_METHOD0(idle, void());
-    MOCK_METHOD0(active, void());
+    MOCK_METHOD(void, idle, (), (override));
+    MOCK_METHOD(void, active, (), (override));
 };
 
 struct BasicIdleHub: Test
