@@ -15,24 +15,23 @@
  */
 
 
-#include "mir/graphics/drm_formats.h"
-#include "src/server/scene/basic_surface.h"
+#include <mir/graphics/drm_formats.h>
+#include <mir/scene/basic_surface.h>
 #include "src/server/scene/surface_change_notification.h"
 
-#include "mir/events/event_private.h"
-#include "mir/frontend/event_sink.h"
-#include "mir/geometry/rectangle.h"
-#include "mir/geometry/displacement.h"
-#include "mir/scene/null_surface_observer.h"
-#include "mir/events/event_builders.h"
+#include <mir/frontend/event_sink.h>
+#include <mir/geometry/rectangle.h>
+#include <mir/geometry/displacement.h>
+#include <mir/scene/null_surface_observer.h>
+#include <mir/events/event_builders.h>
 
-#include "mir/test/doubles/fake_display_configuration_observer_registrar.h"
-#include "mir/test/doubles/stub_cursor_image.h"
-#include "mir/test/doubles/mock_buffer_stream.h"
-#include "mir/test/doubles/stub_buffer.h"
-#include "mir/test/doubles/stub_session.h"
-#include "mir/test/doubles/explicit_executor.h"
-#include "mir/test/geometry_matchers.h"
+#include <mir/test/doubles/fake_display_configuration_observer_registrar.h>
+#include <mir/test/doubles/stub_cursor_image.h>
+#include <mir/test/doubles/mock_buffer_stream.h>
+#include <mir/test/doubles/stub_buffer.h>
+#include <mir/test/doubles/stub_session.h>
+#include <mir/test/doubles/explicit_executor.h>
+#include <mir/test/geometry_matchers.h>
 
 #include "src/server/report/null_report_factory.h"
 
@@ -60,7 +59,7 @@ namespace
 class MockCallback
 {
 public:
-    MOCK_METHOD0(call, void());
+    MOCK_METHOD(void, call, (), ());
 };
 
 class MockSurfaceObserver : public ms::NullSurfaceObserver
@@ -100,8 +99,6 @@ struct BasicSurfaceTest : public testing::Test
         std::make_shared<mtd::FakeDisplayConfigurationObserverRegistrar>();
 
     ms::BasicSurface surface{
-        nullptr /* session */,
-        {} /* wayland_surface */,
         name,
         rect,
         mir_pointer_unconfined,
@@ -134,25 +131,6 @@ TEST_F(BasicSurfaceTest, basics)
         EXPECT_FALSE(renderable->shaped());
 }
 
-TEST_F(BasicSurfaceTest, can_be_created_with_session)
-{
-    using namespace testing;
-
-    auto const session = std::make_shared<mtd::StubSession>();
-    ms::BasicSurface surface{
-        session,
-        {} /* wayland_surface */,
-        name,
-        geom::Rectangle{{0,0}, {100,100}},
-        mir_pointer_unconfined,
-        streams,
-        std::shared_ptr<mg::CursorImage>(),
-        report,
-        display_config_registrar};
-
-    EXPECT_THAT(surface.session().lock(), Eq(session));
-}
-
 TEST_F(BasicSurfaceTest, buffer_stream_ids_always_unique)
 {
     int const n = 10;
@@ -162,8 +140,6 @@ TEST_F(BasicSurfaceTest, buffer_stream_ids_always_unique)
     for (auto& surface : surfaces)
     {
         surface = std::make_unique<ms::BasicSurface>(
-                nullptr /* session */,
-                mw::Weak<mf::WlSurface>{},
                 name,
                 rect,
                 mir_pointer_unconfined,
@@ -188,8 +164,6 @@ TEST_F(BasicSurfaceTest, id_never_invalid)
     for (auto& surface : surfaces)
     {
         surface = std::make_unique<ms::BasicSurface>(
-                nullptr /* session */,
-                mw::Weak<mf::WlSurface>{},
                 name,
                 rect,
                 mir_pointer_unconfined,
@@ -451,8 +425,6 @@ TEST_F(BasicSurfaceTest, test_surface_visibility)
 
     // Must be a fresh surface to guarantee no frames posted yet...
     ms::BasicSurface surface{
-        nullptr /* session */,
-        {} /* wayland_surface */,
         name,
         rect,
         mir_pointer_unconfined,
@@ -492,8 +464,6 @@ TEST_F(BasicSurfaceTest, default_region_is_surface_rectangle)
     geom::Point pt(1,1);
     geom::Size one_by_one{geom::Width{1}, geom::Height{1}};
     ms::BasicSurface surface{
-        nullptr /* session */,
-        {} /* wayland_surface */,
         name,
         geom::Rectangle{pt, one_by_one},
         mir_pointer_unconfined,
@@ -530,8 +500,6 @@ TEST_F(BasicSurfaceTest, default_region_is_surface_rectangle)
 TEST_F(BasicSurfaceTest, default_invisible_surface_doesnt_get_input)
 {
     ms::BasicSurface surface{
-        nullptr /* session */,
-        {} /* wayland_surface */,
         name,
         geom::Rectangle{{0,0}, {100,100}},
         mir_pointer_unconfined,
@@ -551,8 +519,6 @@ TEST_F(BasicSurfaceTest, default_invisible_surface_doesnt_get_input)
 TEST_F(BasicSurfaceTest, surface_doesnt_get_input_outside_clip_area)
 {
     ms::BasicSurface surface{
-        nullptr /* session */,
-        {} /* wayland_surface */,
         name,
         geom::Rectangle{{0,0}, {100,100}},
         mir_pointer_unconfined,
@@ -608,6 +574,35 @@ TEST_F(BasicSurfaceTest, set_input_region)
     }
 }
 
+struct InputRegionData
+{
+    MirOrientation orientation;
+    geom::Rectangle rect;
+};
+
+class BasicSurfaceOrientationTest : public BasicSurfaceTest, public testing::WithParamInterface<InputRegionData>
+{};
+
+TEST_P(BasicSurfaceOrientationTest, set_input_region_on_rotated_surface)
+{
+    auto const& param = GetParam();
+    std::vector<geom::Rectangle> const rectangles = {
+        param.rect
+    };
+
+    surface.set_orientation(param.orientation);
+    surface.set_input_region(rectangles);
+
+    auto const test_pt = rect.top_left + geom::Displacement{4, 1};
+    EXPECT_THAT(surface.input_area_contains(test_pt), testing::Eq(true));
+}
+
+INSTANTIATE_TEST_SUITE_P(BasicSurfaceOrientationTest, BasicSurfaceOrientationTest, ::testing::Values(
+    InputRegionData{mir_orientation_right, geom::Rectangle({ 0, 7 }, { 2, 2 })},
+    InputRegionData{mir_orientation_left, geom::Rectangle({ 13, 3 }, { 2, 2 })},
+    InputRegionData{mir_orientation_inverted, geom::Rectangle({ 6, 13 }, { 2, 2 })}
+));
+
 TEST_F(BasicSurfaceTest, updates_default_input_region_when_surface_is_resized_to_larger_size)
 {
     geom::Rectangle const new_rect{rect.top_left,{20,20}};
@@ -776,8 +771,6 @@ TEST_F(BasicSurfaceTest, stores_parent)
 {
     auto parent = mt::fake_shared(surface);
     ms::BasicSurface child{
-        nullptr /* session */,
-        {} /* wayland_surface */,
         name,
         geom::Rectangle{{0,0}, {100,100}},
         parent,
@@ -1357,8 +1350,6 @@ TEST_F(BasicSurfaceTest, registers_frame_callbacks_on_construction)
         .Times(AtLeast(1));
 
     ms::BasicSurface child{
-        nullptr /* session */,
-        {} /* wayland_surface */,
         name,
         geom::Rectangle{{0,0}, {100,100}},
         std::weak_ptr<ms::Surface>{},
@@ -1495,6 +1486,44 @@ TEST_F(BasicSurfaceTest, renderables_of_transparent_buffer_streams_are_shaped)
     EXPECT_THAT(renderables[1]->shaped(), true);
 }
 
+TEST_F(BasicSurfaceTest, renderables_of_new_buffers_are_normal)
+{
+    using namespace testing;
+    auto buffer_stream = std::make_shared<NiceMock<mtd::MockBufferStream>>();
+    geom::Displacement const d0{0,0};
+
+    ON_CALL(*buffer_stream->submission, pixel_format)
+        .WillByDefault(Return(mg::DRMFormat{DRM_FORMAT_ARGB8888}));
+
+    std::list<ms::StreamInfo> streams = {
+        { buffer_stream, d0}
+    };
+    surface.set_streams(streams);
+
+    auto renderables = surface.generate_renderables(this);
+    ASSERT_THAT(renderables.size(), Eq(1));
+    EXPECT_THAT(renderables[0]->orientation(), mir_orientation_normal);
+}
+
+TEST_F(BasicSurfaceTest, renderables_of_new_buffers_have_none_mirror_mode)
+{
+    using namespace testing;
+    auto buffer_stream = std::make_shared<NiceMock<mtd::MockBufferStream>>();
+    geom::Displacement const d0{0,0};
+
+    ON_CALL(*buffer_stream->submission, pixel_format)
+        .WillByDefault(Return(mg::DRMFormat{DRM_FORMAT_ARGB8888}));
+
+    std::list<ms::StreamInfo> streams = {
+        { buffer_stream, d0}
+    };
+    surface.set_streams(streams);
+
+    auto renderables = surface.generate_renderables(this);
+    ASSERT_THAT(renderables.size(), Eq(1));
+    EXPECT_THAT(renderables[0]->mirror_mode(), mir_mirror_mode_none);
+}
+
 namespace
 {
 struct VisibilityObserver : ms::NullSurfaceObserver
@@ -1552,8 +1581,6 @@ TEST_F(BasicSurfaceTest, buffer_can_be_submitted_to_original_stream_after_surfac
         .WillRepeatedly(SaveArg<0>(&callback));
 
     auto surface = std::make_unique<ms::BasicSurface>(
-        nullptr, // session
-        mw::Weak<mf::WlSurface>{},
         name,
         rect,
         mir_pointer_unconfined,
@@ -1579,8 +1606,6 @@ TEST_F(BasicSurfaceTest, buffer_can_be_submitted_to_set_stream_after_surface_des
         .WillRepeatedly(SaveArg<0>(&callback));
 
     auto surface = std::make_unique<ms::BasicSurface>(
-        nullptr, // session
-        mw::Weak<mf::WlSurface>{},
         name,
         rect,
         mir_pointer_unconfined,
@@ -1594,3 +1619,21 @@ TEST_F(BasicSurfaceTest, buffer_can_be_submitted_to_set_stream_after_surface_des
     surface.reset();
     callback({10, 10});
 }
+
+TEST_F(BasicSurfaceTest, setting_orientation_results_in_renderable_with_same_orientation)
+{
+    using namespace testing;
+    surface.set_orientation(mir_orientation_inverted);
+    auto renderables = surface.generate_renderables(this);
+    EXPECT_THAT(renderables.size(), Eq(1));
+    EXPECT_THAT(renderables[0]->orientation(), mir_orientation_inverted);
+}
+
+TEST_F(BasicSurfaceTest, setting_mirror_mode_results_in_renderable_with_same_mirror_mode)
+{
+    using namespace testing;
+    surface.set_mirror_mode(mir_mirror_mode_horizontal);
+    auto renderables = surface.generate_renderables(this);
+    EXPECT_THAT(renderables.size(), Eq(1));
+    EXPECT_THAT(renderables[0]->mirror_mode(), mir_mirror_mode_horizontal);
+}
