@@ -15,21 +15,21 @@
  */
 
 #include "src/server/scene/mediating_display_changer.h"
-#include "mir/scene/session_container.h"
-#include "mir/graphics/display_configuration_policy.h"
+#include <mir/scene/session_container.h>
+#include <mir/graphics/display_configuration_policy.h>
 #include "src/server/scene/broadcasting_session_event_sink.h"
-#include "mir/server_action_queue.h"
+#include <mir/server_action_queue.h>
 
-#include "mir/test/doubles/mock_display.h"
-#include "mir/test/doubles/mock_compositor.h"
-#include "mir/test/doubles/null_display_configuration.h"
-#include "mir/test/doubles/stub_display_configuration.h"
-#include "mir/test/doubles/mock_scene_session.h"
-#include "mir/test/doubles/stub_session.h"
-#include "mir/test/fake_shared.h"
-#include "mir/test/display_config_matchers.h"
-#include "mir/test/doubles/fake_alarm_factory.h"
-#include "mir/test/doubles/mock_display_configuration_observer.h"
+#include <mir/test/doubles/mock_display.h>
+#include <mir/test/doubles/mock_compositor.h>
+#include <mir/test/doubles/null_display_configuration.h>
+#include <mir/test/doubles/stub_display_configuration.h>
+#include <mir/test/doubles/mock_scene_session.h>
+#include <mir/test/doubles/stub_session.h>
+#include <mir/test/fake_shared.h>
+#include <mir/test/display_config_matchers.h>
+#include <mir/test/doubles/fake_alarm_factory.h>
+#include <mir/test/doubles/mock_display_configuration_observer.h>
 
 #include "gmock/gmock.h"
 #include <mutex>
@@ -254,20 +254,6 @@ TEST_F(MediatingDisplayChangerTest, sends_error_when_incomplete_fallback_configu
                        mt::fake_shared(conf));
 }
 
-TEST_F(MediatingDisplayChangerTest, sends_error_when_applying_new_configuration_for_focused_session_fails)
-{
-    mtd::NullDisplayConfiguration conf;
-    auto session = std::make_shared<mtd::MockSceneSession>();
-
-    ON_CALL(mock_display, configure(Ref(conf)))
-        .WillByDefault(InvokeWithoutArgs([]() { BOOST_THROW_EXCEPTION(std::runtime_error{"Ducks!"}); }));
-    EXPECT_CALL(*session, send_error(_));
-
-    session_event_sink.handle_focus_change(session);
-    changer->configure(session,
-                       mt::fake_shared(conf));
-}
-
 TEST_F(MediatingDisplayChangerTest, reapplies_old_config_when_applying_new_configuration_fails)
 {
     mtd::NullDisplayConfiguration conf;
@@ -537,27 +523,6 @@ TEST_F(MediatingDisplayChangerTest, focusing_a_session_with_db_invalidating_atta
     session_event_sink.handle_focus_change(session1);
 }
 
-TEST_F(MediatingDisplayChangerTest, failure_to_apply_session_config_on_focus_sends_error)
-{
-    auto conf = std::make_shared<mtd::NullDisplayConfiguration>();
-    auto session1 = std::make_shared<mtd::MockSceneSession>();
-
-    session_container.insert_session(session1);
-    changer->configure(session1, conf);
-
-    EXPECT_CALL(
-        mock_display,
-        configure(mt::DisplayConfigMatches(std::cref(*conf))))
-            .WillOnce(InvokeWithoutArgs([]() { BOOST_THROW_EXCEPTION(std::runtime_error{"Banana"}); }));
-    EXPECT_CALL(
-        mock_display,
-        configure(Not(mt::DisplayConfigMatches(std::cref(*conf)))))
-            .Times(AnyNumber());
-    EXPECT_CALL(*session1, send_error(_));
-
-    session_event_sink.handle_focus_change(session1);
-}
-
 TEST_F(MediatingDisplayChangerTest, focusing_a_session_without_attached_config_applies_base_config_pausing_if_db_invalidated)
 {
     auto conf = std::make_shared<mtd::NullDisplayConfiguration>();
@@ -932,167 +897,3 @@ TEST_F(MediatingDisplayChangerTest, notifies_observer_on_set_base_configuration)
 
     changer->set_base_configuration(mt::fake_shared(conf));
 }
-
-TEST_F(MediatingDisplayChangerTest, notifies_session_on_preview_base_configuration)
-{
-    mtd::NullDisplayConfiguration conf;
-    auto const mock_session = std::make_shared<NiceMock<mtd::MockSceneSession>>();
-
-    session_container.insert_session(mock_session);
-
-    EXPECT_CALL(display_configuration_observer, configuration_updated_for_session(Eq(mock_session), _));
-
-    changer->preview_base_configuration(
-        mock_session,
-        mt::fake_shared(conf),
-        std::chrono::seconds{1});
-}
-
-TEST_F(MediatingDisplayChangerTest, reverts_to_previous_configuration_on_timeout)
-{
-    auto new_config = std::make_shared<mtd::StubDisplayConfig>(1);
-    auto old_config = changer->base_configuration();
-
-    auto applied_config = old_config->clone();
-
-    ON_CALL(mock_display, configure(_))
-        .WillByDefault(Invoke([&applied_config](auto& conf) { applied_config = conf.clone(); }));
-
-    auto mock_session = std::make_shared<NiceMock<mtd::MockSceneSession>>();
-
-    session_container.insert_session(mock_session);
-
-    std::chrono::seconds const timeout{30};
-
-    changer->preview_base_configuration(
-        mock_session,
-        new_config,
-        timeout);
-
-    EXPECT_THAT(*applied_config, mt::DisplayConfigMatches(std::cref(*new_config)));
-
-    alarm_factory.advance_smoothly_by(timeout - std::chrono::milliseconds{1});
-    EXPECT_THAT(*applied_config, mt::DisplayConfigMatches(std::cref(*new_config)));
-
-    alarm_factory.advance_smoothly_by(std::chrono::milliseconds{2});
-    alarm_factory.advance_smoothly_by(timeout);
-    EXPECT_THAT(*applied_config, mt::DisplayConfigMatches(std::cref(*old_config)));
-}
-
-TEST_F(MediatingDisplayChangerTest, only_configuring_client_receives_preview_notifications)
-{
-    mtd::NullDisplayConfiguration conf;
-    auto const mock_session1 = std::make_shared<NiceMock<mtd::MockSceneSession>>();
-    auto const mock_session2 = std::make_shared<NiceMock<mtd::MockSceneSession>>();
-
-    auto new_config = std::make_shared<mtd::StubDisplayConfig>(1);
-    auto old_config = changer->base_configuration();
-
-    session_container.insert_session(mock_session1);
-    session_container.insert_session(mock_session2);
-
-    EXPECT_CALL(display_configuration_observer, configuration_updated_for_session(Eq(mock_session1), _))
-        .Times(AtLeast(1));
-    EXPECT_CALL(display_configuration_observer, configuration_updated_for_session(Eq(mock_session2), _))
-        .Times(0);
-
-    std::chrono::seconds const timeout{30};
-
-    changer->preview_base_configuration(
-        mock_session1,
-        new_config,
-        timeout);
-
-    alarm_factory.advance_smoothly_by(timeout + std::chrono::seconds{1});
-}
-
-TEST_F(MediatingDisplayChangerTest, only_one_client_can_preview_configuration_change_at_once)
-{
-    auto const mock_session1 = std::make_shared<NiceMock<mtd::MockSceneSession>>();
-    auto const mock_session2 = std::make_shared<NiceMock<mtd::MockSceneSession>>();
-
-    auto new_config = std::make_shared<mtd::StubDisplayConfig>(1);
-
-    session_container.insert_session(mock_session1);
-    session_container.insert_session(mock_session2);
-
-    std::chrono::seconds const timeout{30};
-
-    changer->preview_base_configuration(
-        mock_session1,
-        new_config,
-        timeout);
-
-    EXPECT_THROW(
-        {
-            changer->preview_base_configuration(
-                mock_session2,
-                new_config,
-                timeout);
-        },
-        std::runtime_error);
-}
-
-TEST_F(MediatingDisplayChangerTest, confirmed_configuration_doesnt_revert_after_timeout)
-{
-    auto new_config = std::make_shared<mtd::StubDisplayConfig>(1);
-    auto old_config = changer->base_configuration();
-
-    auto applied_config = old_config->clone();
-
-    ASSERT_THAT(applied_config, Not(Eq(nullptr)));
-
-    ON_CALL(mock_display, configure(_))
-        .WillByDefault(Invoke([&applied_config](auto& conf) { applied_config = conf.clone(); }));
-
-    auto mock_session = std::make_shared<NiceMock<mtd::MockSceneSession>>();
-
-    session_container.insert_session(mock_session);
-
-    std::chrono::seconds const timeout{30};
-
-    changer->preview_base_configuration(
-        mock_session,
-        new_config,
-        timeout);
-
-    EXPECT_THAT(*applied_config, mt::DisplayConfigMatches(std::cref(*new_config)));
-
-    changer->confirm_base_configuration(mock_session, new_config);
-
-    alarm_factory.advance_smoothly_by(timeout * 2);
-    EXPECT_THAT(*applied_config, mt::DisplayConfigMatches(std::cref(*new_config)));
-}
-
-TEST_F(MediatingDisplayChangerTest, all_sessions_get_notified_on_configuration_confirmation)
-{
-    mtd::NullDisplayConfiguration conf;
-    auto const mock_session1 = std::make_shared<NiceMock<mtd::MockSceneSession>>();
-    auto const mock_session2 = std::make_shared<NiceMock<mtd::MockSceneSession>>();
-
-    auto new_config = std::make_shared<mtd::StubDisplayConfig>(1);
-    auto old_config = changer->base_configuration();
-
-    session_container.insert_session(mock_session1);
-    session_container.insert_session(mock_session2);
-
-    std::unique_ptr<mg::DisplayConfiguration> received_configuration;
-
-    ON_CALL(display_configuration_observer, configuration_updated_for_session(Eq(mock_session2), _))
-        .WillByDefault(Invoke([&received_configuration](auto const&, auto const& config)
-            {
-                received_configuration = config->clone();
-            }));
-
-    changer->preview_base_configuration(
-        mock_session1,
-        new_config,
-        std::chrono::seconds{1});
-
-    EXPECT_THAT(received_configuration, Eq(nullptr));
-
-    changer->confirm_base_configuration(mock_session1, new_config);
-
-    ASSERT_THAT(received_configuration, Not(Eq(nullptr)));
-    EXPECT_THAT(*received_configuration, mt::DisplayConfigMatches(std::cref(*new_config)));
-}
