@@ -16,29 +16,28 @@
 
 #include "src/server/scene/session_manager.h"
 
-#include "mir/scene/session.h"
-#include "mir/scene/session_container.h"
-#include "mir/scene/null_session_listener.h"
-#include "mir/graphics/display_configuration_observer.h"
-#include "mir/compositor/buffer_stream.h"
-#include "mir/scene/null_surface_observer.h"
-#include "src/server/scene/basic_surface.h"
+#include <mir/scene/session.h>
+#include <mir/scene/session_container.h>
+#include <mir/scene/null_session_listener.h>
+#include <mir/graphics/display_configuration_observer.h>
+#include <mir/compositor/buffer_stream.h>
+#include <mir/scene/null_surface_observer.h>
+#include <mir/scene/basic_surface.h>
 #include "src/include/server/mir/scene/session_event_sink.h"
 #include "src/server/report/null_report_factory.h"
 
-#include "mir/test/doubles/mock_surface_stack.h"
-#include "mir/test/doubles/mock_session_listener.h"
-#include "mir/test/doubles/stub_buffer_stream.h"
-#include "mir/test/doubles/null_session_event_sink.h"
-#include "mir/test/doubles/null_event_sink.h"
-#include "mir/test/doubles/stub_surface_factory.h"
-#include "mir/test/doubles/null_application_not_responding_detector.h"
-#include "mir/test/doubles/stub_display.h"
-#include "mir/test/doubles/stub_buffer_allocator.h"
-#include "mir/test/doubles/stub_observer_registrar.h"
+#include <mir/test/doubles/mock_surface_stack.h>
+#include <mir/test/doubles/mock_session_listener.h>
+#include <mir/test/doubles/stub_buffer_stream.h>
+#include <mir/test/doubles/null_session_event_sink.h>
+#include <mir/test/doubles/null_event_sink.h>
+#include <mir/test/doubles/stub_surface_factory.h>
+#include <mir/test/doubles/stub_display.h>
+#include <mir/test/doubles/stub_buffer_allocator.h>
+#include <mir/test/doubles/stub_observer_registrar.h>
 
-#include "mir/test/fake_shared.h"
-#include "mir/test/make_surface_spec.h"
+#include <mir/test/fake_shared.h>
+#include <mir/test/make_surface_spec.h>
 
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
@@ -57,16 +56,14 @@ namespace
 {
 struct MockSessionEventSink : public ms::SessionEventSink
 {
-    MOCK_METHOD1(handle_focus_change, void(std::shared_ptr<ms::Session> const& session));
-    MOCK_METHOD0(handle_no_focus, void());
-    MOCK_METHOD1(handle_session_stopping, void(std::shared_ptr<ms::Session> const& session));
+    MOCK_METHOD(void, handle_focus_change, (std::shared_ptr<ms::Session> const& session), (override));
+    MOCK_METHOD(void, handle_no_focus, (), (override));
+    MOCK_METHOD(void, handle_session_stopping, (std::shared_ptr<ms::Session> const& session), (override));
 };
 
 struct SessionManagerSetup : public testing::Test
 {
     std::shared_ptr<ms::Surface> dummy_surface = std::make_shared<ms::BasicSurface>(
-        nullptr /* session */,
-        mw::Weak<mf::WlSurface>{},
         std::string("stub"),
         geom::Rectangle{{},{}},
         mir_pointer_unconfined,
@@ -89,7 +86,6 @@ struct SessionManagerSetup : public testing::Test
         std::make_shared<mtd::NullSessionEventSink>(),
         mt::fake_shared(session_listener),
         mt::fake_shared(display),
-        std::make_shared<mtd::NullANRDetector>(),
         mt::fake_shared(allocator),
         mt::fake_shared(display_config_registrar)};
 };
@@ -115,7 +111,6 @@ struct SessionManagerSessionListenerSetup : public testing::Test
         std::make_shared<mtd::NullSessionEventSink>(),
         mt::fake_shared(session_listener),
         mt::fake_shared(display),
-        std::make_shared<mtd::NullANRDetector>(),
         mt::fake_shared(allocator),
         mt::fake_shared(display_config_registrar)};
 };
@@ -128,7 +123,7 @@ TEST_F(SessionManagerSessionListenerSetup, session_listener_is_notified_of_lifec
     EXPECT_CALL(session_listener, starting(_)).Times(1);
     EXPECT_CALL(session_listener, stopping(_)).Times(1);
 
-    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
     session_manager.close_session(session);
 }
 
@@ -141,7 +136,7 @@ TEST_F(SessionManagerSessionListenerSetup, additional_listeners_receive_session_
     EXPECT_CALL(*additional_listener, stopping(_)).Times(1);
 
     session_manager.add_listener(additional_listener);
-    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
     session_manager.close_session(session);
 }
 
@@ -155,7 +150,7 @@ TEST_F(SessionManagerSessionListenerSetup, additional_listeners_receive_focus_ch
     EXPECT_CALL(*additional_listener, unfocused()).Times(1);
 
     session_manager.add_listener(additional_listener);
-    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
     session_manager.set_focus_to(session);
     session_manager.unset_focus();
 }
@@ -169,10 +164,10 @@ TEST_F(SessionManagerSessionListenerSetup, additional_listeners_receive_surface_
     EXPECT_CALL(*additional_listener, surface_created(_,_)).Times(1);
 
     session_manager.add_listener(additional_listener);
-    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
+    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
     auto bs = std::dynamic_pointer_cast<mc::BufferStream>(session->create_buffer_stream(
         mg::BufferProperties{{640, 480}, mir_pixel_format_abgr_8888, mg::BufferUsage::hardware}));
-    session->create_surface(nullptr, {}, mt::make_surface_spec(bs), mt::fake_shared(observer), nullptr);
+    session->create_surface(nullptr, mt::make_surface_spec(bs), mt::fake_shared(observer), nullptr);
 }
 
 namespace
@@ -195,7 +190,6 @@ struct SessionManagerSessionEventsSetup : public testing::Test
         mt::fake_shared(session_event_sink),
         mt::fake_shared(session_listener),
         mt::fake_shared(display),
-        std::make_shared<mtd::NullANRDetector>(),
         mt::fake_shared(allocator),
         mt::fake_shared(display_config_registrar)};
 };
@@ -205,8 +199,8 @@ TEST_F(SessionManagerSessionEventsSetup, session_event_sink_is_notified_of_lifec
 {
     using namespace ::testing;
 
-    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto session1 = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
+    auto session = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane");
+    auto session1 = session_manager.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla");
 
     Mock::VerifyAndClearExpectations(&session_event_sink);
 
