@@ -14,21 +14,21 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/test/doubles/stub_buffer.h"
+#include <mir/test/doubles/stub_buffer.h>
 #include "src/server/scene/surface_stack.h"
-#include "mir/graphics/buffer_properties.h"
-#include "mir/geometry/rectangle.h"
-#include "mir/scene/observer.h"
-#include "mir/compositor/scene_element.h"
+#include <mir/graphics/buffer_properties.h>
+#include <mir/geometry/rectangle.h>
+#include <mir/scene/observer.h>
+#include <mir/compositor/scene_element.h>
 #include "src/server/report/null_report_factory.h"
-#include "src/server/scene/basic_surface.h"
-#include "mir/test/fake_shared.h"
-#include "mir/test/doubles/fake_display_configuration_observer_registrar.h"
-#include "mir/test/doubles/stub_buffer_stream.h"
-#include "mir/test/doubles/stub_renderable.h"
-#include "mir/test/doubles/mock_buffer_stream.h"
-#include "mir/test/doubles/explicit_executor.h"
-#include "mir/executor.h"
+#include <mir/scene/basic_surface.h>
+#include <mir/test/fake_shared.h>
+#include <mir/test/doubles/fake_display_configuration_observer_registrar.h>
+#include <mir/test/doubles/stub_buffer_stream.h>
+#include <mir/test/doubles/stub_renderable.h>
+#include <mir/test/doubles/mock_buffer_stream.h>
+#include <mir/test/doubles/explicit_executor.h>
+#include <mir/executor.h>
 
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
@@ -70,26 +70,24 @@ MATCHER_P(LockedEq, value, "")
 
 struct MockCallback
 {
-    MOCK_METHOD0(call, void());
+    MOCK_METHOD(void, call, (), ());
 };
 
 struct MockSceneObserver : public ms::Observer
 {
-    MOCK_METHOD1(surface_added, void(std::shared_ptr<ms::Surface> const&));
-    MOCK_METHOD1(surface_removed, void(std::shared_ptr<ms::Surface> const&));
-    MOCK_METHOD1(surfaces_reordered, void(ms::SurfaceSet const&));
-    MOCK_METHOD0(scene_changed, void());
+    MOCK_METHOD(void, surface_added, (std::shared_ptr<ms::Surface> const&), (override));
+    MOCK_METHOD(void, surface_removed, (std::shared_ptr<ms::Surface> const&), (override));
+    MOCK_METHOD(void, surfaces_reordered, (ms::SurfaceSet const&), (override));
+    MOCK_METHOD(void, scene_changed, (), (override));
 
-    MOCK_METHOD1(surface_exists, void(std::shared_ptr<ms::Surface> const&));
-    MOCK_METHOD0(end_observation, void());
+    MOCK_METHOD(void, surface_exists, (std::shared_ptr<ms::Surface> const&), (override));
+    MOCK_METHOD(void, end_observation, (), (override));
 };
 
 struct StubSurface : public ms::BasicSurface
 {
     StubSurface(std::shared_ptr<mc::BufferStream> stream, mir::Executor& executor) :
         ms::BasicSurface(
-            {},
-            {},
             "stub",
             {{-1, -1}, {2, 2}},
             mir_pointer_unconfined,
@@ -320,8 +318,6 @@ TEST_F(SurfaceStack, generate_elementelements)
     for(auto i = 0u; i < num_surfaces; i++)
     {
         auto const surface = std::make_shared<ms::BasicSurface>(
-            nullptr /* session */,
-            mw::Weak<mf::WlSurface>{},
             std::string("stub"),
             geom::Rectangle{geom::Point{3 * i, 4 * i},geom::Size{1 * i, 2 * i}},
             mir_pointer_unconfined,
@@ -413,8 +409,8 @@ TEST_F(SurfaceStack, scene_observer_informed_of_existing_surfaces)
     MockSceneObserver observer;
 
     InSequence seq;
-    EXPECT_CALL(observer, surface_exists(stub_surface1)).Times(1);
     EXPECT_CALL(observer, surface_exists(stub_surface2)).Times(1);
+    EXPECT_CALL(observer, surface_exists(stub_surface1)).Times(1);
 
     stack.add_surface(stub_surface1, mi::InputReceptionMode::normal);
     stack.add_surface(stub_surface2, mi::InputReceptionMode::normal);
@@ -519,8 +515,6 @@ TEST_F(SurfaceStack, scene_elements_hold_snapshot_of_positioning_info)
     for(auto i = 0u; i < num_surfaces; i++)
     {
         auto const surface = std::make_shared<ms::BasicSurface>(
-            nullptr /* session */,
-            mw::Weak<mf::WlSurface>{},
             std::string("stub"),
             geom::Rectangle{geom::Point{3 * i, 4 * i},geom::Size{1 * i, 2 * i}},
             mir_pointer_unconfined,
@@ -551,8 +545,6 @@ TEST_F(SurfaceStack, generates_scene_elements_that_delay_buffer_acquisition)
     auto mock_stream = std::make_shared<NiceMock<mtd::MockBufferStream>>();
 
     auto const surface = std::make_shared<ms::BasicSurface>(
-        nullptr /* session */,
-        mw::Weak<mf::WlSurface>{},
         std::string("stub"),
         geom::Rectangle{geom::Point{3, 4},geom::Size{1, 2}},
         mir_pointer_unconfined,
@@ -576,8 +568,6 @@ TEST_F(SurfaceStack, generates_scene_elements_that_allow_only_one_buffer_acquisi
     auto mock_stream = std::make_shared<NiceMock<mtd::MockBufferStream>>();
 
     auto const surface = std::make_shared<ms::BasicSurface>(
-        nullptr /* session */,
-        mw::Weak<mf::WlSurface>{},
         std::string("stub"),
         geom::Rectangle{geom::Point{3, 4},geom::Size{1, 2}},
         mir_pointer_unconfined,
@@ -603,7 +593,7 @@ struct MockConfigureSurface : StubSurface
     {
     }
 
-    MOCK_METHOD2(configure, int(MirWindowAttrib, int));
+    MOCK_METHOD(int, configure, (MirWindowAttrib, int), (override));
 };
 }
 
