@@ -15,22 +15,22 @@
  */
 
 #include "src/server/shell/decoration/basic_decoration.h"
-#include "mir/scene/surface_observer.h"
-#include "mir/shell/surface_specification.h"
-#include "mir/input/cursor_images.h"
-#include "src/server/scene/basic_surface.h"
+#include <mir/scene/surface_observer.h>
+#include <mir/shell/surface_specification.h>
+#include <mir/input/cursor_images.h>
+#include "src/server/scene/wayland_basic_surface.h"
 #include "src/server/report/null_report_factory.h"
 
-#include "mir/test/fake_shared.h"
-#include "mir/test/doubles/fake_display_configuration_observer_registrar.h"
-#include "mir/test/doubles/stub_shell.h"
-#include "mir/test/doubles/mock_scene_session.h"
-#include "mir/test/doubles/mock_buffer_stream.h"
-#include "mir/test/doubles/stub_buffer_allocator.h"
-#include "mir/test/doubles/explicit_executor.h"
-#include "mir/test/doubles/stub_cursor_image.h"
-#include "mir/events/event_builders.h"
-#include "mir/events/event_helpers.h"
+#include <mir/test/fake_shared.h>
+#include <mir/test/doubles/fake_display_configuration_observer_registrar.h>
+#include <mir/test/doubles/stub_shell.h>
+#include <mir/test/doubles/mock_scene_session.h>
+#include <mir/test/doubles/mock_buffer_stream.h>
+#include <mir/test/doubles/stub_buffer_allocator.h>
+#include <mir/test/doubles/explicit_executor.h>
+#include <mir/test/doubles/stub_cursor_image.h>
+#include <mir/events/event_builders.h>
+#include <mir/events/event_helpers.h>
 
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
@@ -75,13 +75,12 @@ struct StubCursorImages
 };
 
 struct MockSurface
-    : ms::BasicSurface
+    : ms::WaylandBasicSurface
 {
     MockSurface(std::shared_ptr<ms::Session> const& session, mir::Executor& executor)
-        : ms::BasicSurface{
+        : ms::WaylandBasicSurface{
               session,
               {},
-              {},
               {{},{}},
               mir_pointer_unconfined,
               { { std::make_shared<testing::NiceMock<mtd::MockBufferStream>>(), {0, 0}} },
@@ -94,7 +93,7 @@ struct MockSurface
 
     void register_interest(std::weak_ptr<ms::SurfaceObserver> const& observer)
     {
-        BasicSurface::register_interest(observer, executor);
+        WaylandBasicSurface::register_interest(observer, executor);
     }
 
     void register_interest(std::weak_ptr<ms::SurfaceObserver> const& observer, mir::Executor&)
@@ -102,7 +101,7 @@ struct MockSurface
         register_interest(observer);
     }
 
-    MOCK_METHOD0(request_client_surface_close, void());
+    MOCK_METHOD(void, request_client_surface_close, (), (override));
 
     mir::Executor& executor;
 };
@@ -134,29 +133,30 @@ struct MockShell
         did_modify_surface(surface, original_spec);
     }
 
-    MOCK_METHOD2(did_modify_surface, void(
+    MOCK_METHOD(void, did_modify_surface, (
         std::shared_ptr<ms::Surface> const&,
         msh::SurfaceSpecification const&));
 
-    MOCK_METHOD3(request_move, void(
+    MOCK_METHOD(void, request_move, (
         std::shared_ptr<ms::Session> const&,
         std::shared_ptr<ms::Surface> const&,
         MirInputEvent const*));
 
-    MOCK_METHOD4(request_resize, void(
+    MOCK_METHOD(void, request_resize, (
         std::shared_ptr<ms::Session> const&,
         std::shared_ptr<ms::Surface> const&,
         MirInputEvent const*,
         MirResizeEdge));
 
-    MOCK_METHOD5(create_surface, std::shared_ptr<ms::Surface>(
-        std::shared_ptr<ms::Session> const&,
-        mw::Weak<mf::WlSurface> const&,
-        msh::SurfaceSpecification const&,
-        std::shared_ptr<ms::SurfaceObserver> const&,
-        mir::Executor*));
+    MOCK_METHOD(
+        std::shared_ptr<ms::Surface>,
+        create_surface,
+        (std::shared_ptr<ms::Session> const&,
+         msh::SurfaceSpecification const&,
+         std::shared_ptr<ms::SurfaceObserver> const&,
+         mir::Executor*));
 
-    MOCK_METHOD2(destroy_surface, void(
+    MOCK_METHOD(void, destroy_surface, (
         std::shared_ptr<ms::Session> const&,
         std::shared_ptr<ms::Surface> const&));
 };
@@ -166,10 +166,9 @@ struct DecorationBasicDecoration
 {
     void SetUp() override
     {
-        ON_CALL(shell, create_surface(_, _, _, _, _))
+        ON_CALL(shell, create_surface(_, _, _, _))
             .WillByDefault(Invoke([this](
                     std::shared_ptr<ms::Session> const&,
-                    mw::Weak<mf::WlSurface> const&,
                     msh::SurfaceSpecification const& params,
                     std::shared_ptr<ms::SurfaceObserver> const& observer,
                     mir::Executor*) -> std::shared_ptr<ms::Surface>
@@ -184,11 +183,10 @@ struct DecorationBasicDecoration
         window_surface.resize(default_window_size);
         basic_decoration = std::make_shared<msd::BasicDecoration>(
             mt::fake_shared(shell),
-            mt::fake_shared(buffer_allocator),
             mt::fake_shared(executor),
             mt::fake_shared(cursor_images),
             mt::fake_shared(window_surface),
-            msd::DecorationStrategy::default_decoration_strategy());
+            msd::DecorationStrategy::default_decoration_strategy(mt::fake_shared(buffer_allocator)));
         executor.execute();
     }
 
