@@ -1,5 +1,5 @@
 /*
- * Copyright © 2022 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -19,8 +19,8 @@
 #include <thread>
 #include <atomic>
 
-#include "mir/executor.h"
-#include "mir/test/signal.h"
+#include <mir/executor.h>
+#include <mir/test/signal.h>
 
 using namespace std::literals::chrono_literals;
 using namespace testing;
