@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -14,11 +14,11 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/lockable_callback_wrapper.h"
-#include "mir/basic_callback.h"
+#include <mir/lockable_callback_wrapper.h>
+#include <mir/basic_callback.h>
 
-#include "mir/test/fake_shared.h"
-#include "mir/test/doubles/mock_lockable_callback.h"
+#include <mir/test/fake_shared.h>
+#include <mir/test/doubles/mock_lockable_callback.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
