@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 or 3 as
@@ -15,8 +15,8 @@
  */
 
 #include "library_example.h"
-#include "mir/shared_library.h"
-#include "mir_test_framework/executable_path.h"
+#include <mir/shared_library.h>
+#include <mir_test_framework/executable_path.h>
 
 #include <gtest/gtest.h>
 
