@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -14,7 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/raii.h"
+#include <mir/raii.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
@@ -27,13 +27,13 @@ struct RaiiTest : public ::testing::Test
 {
     RaiiTest();
     ~RaiiTest();
-    MOCK_METHOD0(create_void, void());
-    MOCK_METHOD0(destroy_void, void());
+    MOCK_METHOD(void, create_void, (), ());
+    MOCK_METHOD(void, destroy_void, (), ());
 
-    MOCK_METHOD0(create_ptr, RaiiTest*());
-    MOCK_METHOD1(destroy_ptr, void (RaiiTest*));
+    MOCK_METHOD(RaiiTest*, create_ptr, (), ());
+    MOCK_METHOD(void, destroy_ptr, (RaiiTest*), ());
 
-    MOCK_METHOD0(test_call, void());
+    MOCK_METHOD(void, test_call, (), ());
 };
 
 RaiiTest* self = nullptr;
