@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -14,9 +14,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/shared_library_prober.h"
+#include <mir/shared_library_prober.h>
 
-#include "mir_test_framework/executable_path.h"
+#include <mir_test_framework/executable_path.h>
 
 #include <stdlib.h>
 #include <errno.h>
@@ -35,10 +35,10 @@ namespace
 class MockSharedLibraryProberReport : public mir::SharedLibraryProberReport
 {
 public:
-    MOCK_METHOD1(probing_path, void(boost::filesystem::path const&));
-    MOCK_METHOD2(probing_failed, void(boost::filesystem::path const&, std::exception const&));
-    MOCK_METHOD1(loading_library, void(boost::filesystem::path const&));
-    MOCK_METHOD2(loading_failed, void(boost::filesystem::path const&, std::exception const&));
+    MOCK_METHOD(void, probing_path, (std::filesystem::path const&), (override));
+    MOCK_METHOD(void, probing_failed, (std::filesystem::path const&, std::exception const&), (override));
+    MOCK_METHOD(void, loading_library, (std::filesystem::path const&), (override));
+    MOCK_METHOD(void, loading_failed, (std::filesystem::path const&, std::exception const&), (override));
 };
 
 class SharedLibraryProber : public testing::Test
