@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -14,8 +14,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mir/thread_safe_list.h"
-#include "mir/test/signal.h"
+#include <mir/thread_safe_list.h>
+#include <mir/test/signal.h>
 
 #include <gtest/gtest.h>
 #include <gmock/gmock.h>
