@@ -15,22 +15,58 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import logging
+import sys
+import os
 import argparse
 from pathlib import Path
 from typing import TypedDict, Optional
 from collections import OrderedDict
 import bisect
-import clang.cindex
-import os
 
+logging.basicConfig(level=logging.INFO)
 _logger = logging.getLogger(__name__)
 
+library_not_found_error_msg: str = """\
+    Please install libclang-19-dev and python3-clang-19.
+    Also, ensure that the required environment variables are set correctly. (e.g.)
+        export MIR_SYMBOLS_MAP_GENERATOR_CLANG_SO_PATH=/usr/lib/llvm-19/lib/libclang.so.1
+        export MIR_SYMBOLS_MAP_GENERATOR_CLANG_LIBRARY_PATH=/usr/lib/llvm-19/lib"""
+
+try:
+    import clang.cindex
+except ModuleNotFoundError as e:
+    _logger.error("Could not import clang in python.")
+    _logger.exception(e)
+    sys.exit(1)
+
+
 HIDDEN_SYMBOLS = {
     "miral::SessionLockListener::?SessionLockListener*;",
     "miral::WaylandExtensions::Context::?Context*;",
     "miral::WaylandExtensions::Context::Context*;",
     "vtable?for?miral::WaylandExtensions::Context;",
     "mir::DefaultServerConfiguration::pointer_input_dispatcher*;",
+    "miral::CursorScale::CursorScale*;",
+    "miral::Keymap::Keymap*;",
+    "miral::InputConfiguration::InputConfiguration*;",
+    "miral::OutputFilter::OutputFilter*;",
+
+    "miral::SimulatedSecondaryClick::SimulatedSecondaryClick*;",
+    "miral::SimulatedSecondaryClick::disable*;",
+    "miral::SimulatedSecondaryClick::disabled*;",
+    "miral::SimulatedSecondaryClick::displacement_threshold*;",
+    "miral::SimulatedSecondaryClick::enable*;",
+    "miral::SimulatedSecondaryClick::enabled*;",
+    "miral::SimulatedSecondaryClick::operator*;",
+    "mir::input::Transformer::?Transformer*;",
+    "non-virtual?thunk?to?mir::input::Transformer::?Transformer*;",
+    "typeinfo?for?mir::input::Transformer;",
+    "vtable?for?mir::input::Transformer;",
+    "miral::MouseKeysConfig::MouseKeysConfig*;",
+    "miral::MouseKeysConfig::disable*;",
+    "miral::MouseKeysConfig::disabled*;",
+    "miral::MouseKeysConfig::enable*;",
+    "miral::MouseKeysConfig::enabled*;",
 }
 
 class HeaderDirectory(TypedDict):
@@ -61,7 +97,7 @@ class Symbol:
     name: str
     version: str
     is_c_symbol: bool
-    
+
     def __init__(self, name: str, version: str, is_c_symbol: bool):
         self.name = name
         self.version = version
@@ -83,7 +119,7 @@ def is_operator(node: clang.cindex.Cursor) -> bool:
         remainder = node.spelling[len("operator"):]
         if any(not c.isalnum() for c in remainder):
             return True
-        
+
     return False
 
 
@@ -105,7 +141,7 @@ def has_vtable(node: clang.cindex.Cursor):
             or child.kind == clang.cindex.CursorKind.CONVERSION_FUNCTION)
             and child.is_virtual_method()):
             return True
-        
+
     # Otherwise, look up the tree
     base_classes: list[clang.cindex.Cursor] = []
     for child in node.semantic_parent.get_children():
@@ -141,7 +177,7 @@ def has_virtual_base_class(node: clang.cindex.Cursor):
                 continue
 
             result = has_virtual_base_class(class_or_struct_node)
-        
+
         if result:
             break
 
@@ -159,21 +195,21 @@ def is_function_inline(node: clang.cindex.CursorKind):
 def get_namespace_str(node: clang.cindex.Cursor) -> list[str]:
     if node.kind == clang.cindex.CursorKind.TRANSLATION_UNIT:
         return []
-    
+
     spelling = node.spelling
     if is_operator(node):
         spelling = "operator"
     elif node.kind == clang.cindex.CursorKind.DESTRUCTOR:
         spelling = f"?{node.spelling[1:]}"
-    
+
     return get_namespace_str(node.semantic_parent) + [spelling]
 
 
-def traverse_ast(node: clang.cindex.Cursor, filename: str, result: set[str]) -> set[str]:   
+def traverse_ast(node: clang.cindex.Cursor, filename: str, result: set[str]) -> set[str]:
     # Ignore private and protected variables
     if (node.access_specifier == clang.cindex.AccessSpecifier.PRIVATE):
         return result
-    
+
     # Check if we need to output a symbol
     if ((node.location.file is not None and node.location.file.name == filename)
         and ((node.kind == clang.cindex.CursorKind.FUNCTION_DECL and not is_function_inline(node))
@@ -185,7 +221,7 @@ def traverse_ast(node: clang.cindex.Cursor, filename: str, result: set[str]) ->
           or should_generate_as_class_or_struct(node))
           and not node.is_pure_virtual_method()
           and not node.is_anonymous()):
-        
+
         namespace_str = "::".join(get_namespace_str(node))
         _logger.debug(f"Emitting node {namespace_str} in file {node.location.file.name}")
 
@@ -205,7 +241,7 @@ def traverse_ast(node: clang.cindex.Cursor, filename: str, result: set[str]) ->
             def add_internal(s: str):
                 add_symbol_str(f"{s}*;")
             add_internal(namespace_str)
-            
+
             # Check if we're marked virtual
             is_virtual = False
             if ((node.kind == clang.cindex.CursorKind.CXX_METHOD
@@ -232,7 +268,7 @@ def traverse_ast(node: clang.cindex.Cursor, filename: str, result: set[str]) ->
                             or derived.kind == clang.cindex.CursorKind.STRUCT_DECL
                             or derived.kind == clang.cindex.CursorKind.CLASS_TEMPLATE
                             or derived.kind == clang.cindex.CursorKind.TYPEDEF_DECL)
-                    
+
                     # Find the base classes for the derived class
                     base_classes: list[clang.cindex.Cursor] = []
                     for child in derived.get_children():
@@ -253,25 +289,25 @@ def traverse_ast(node: clang.cindex.Cursor, filename: str, result: set[str]) ->
                                 add_internal(f"virtual?thunk?to?{namespace_str}")
                                 return True
 
-                    # Looks like it wasn't in any of our direct ancestors, so let's 
+                    # Looks like it wasn't in any of our direct ancestors, so let's
                     # try their ancestors too
                     for base in base_classes:
                         if search_class_hierarchy_for_virtual_thunk(base):
                             return True
-                        
+
                     return False
-                    
+
                 search_class_hierarchy_for_virtual_thunk(node.semantic_parent)
     elif node.location.file is not None:
         _logger.debug(f"NOT emitting node {node.spelling} in file {node.location.file.name}")
-                            
+
 
     # Traverse down the tree if we can
     is_file = node.kind == clang.cindex.CursorKind.TRANSLATION_UNIT
     is_containing_node = (node.kind == clang.cindex.CursorKind.CLASS_DECL
         or node.kind == clang.cindex.CursorKind.STRUCT_DECL
         or node.kind == clang.cindex.CursorKind.NAMESPACE)
-    if is_file or is_containing_node:        
+    if is_file or is_containing_node:
         if clang.cindex.conf.lib.clang_Location_isInSystemHeader(node.location):
             _logger.debug(f"Node is in a system header={node.location.file.name}")
             return result
@@ -298,8 +334,8 @@ def process_directory(directory: Path, search_dirs: Optional[list[str]]) -> set[
         file_args = args.copy()
         idx = clang.cindex.Index.create()
         tu = idx.parse(
-            file.as_posix(), 
-            args=file_args,  
+            file.as_posix(),
+            args=file_args,
             options=0)
         root = tu.cursor
         list(traverse_ast(root, file.as_posix(), result))
@@ -329,7 +365,7 @@ def read_symbols_from_file(f: argparse.FileType, library_name: str) -> list[Symb
             line = line.strip()
             if line.startswith("global:") or line.startswith("local:") or line == 'extern "C++" {' or line.startswith("}"):
                 continue
-            
+
             # This is a c-symbol
             assert line.endswith(';')
             retval.append(Symbol(line, version_str, True))
@@ -351,7 +387,7 @@ def report_symbols_diff(previous_symbols: list[Symbol], new_symbols: set[str], i
     Prints the diff between the previous symbols and the new symbols.
     """
     added_symbols = get_added_symbols(previous_symbols, new_symbols, is_internal)
-    
+
     print("")
     print("  \033[1mNew Symbols 🟢🟢🟢\033[0m")
     for s in added_symbols:
@@ -376,17 +412,13 @@ def report_symbols_diff(previous_symbols: list[Symbol], new_symbols: set[str], i
 
 def main():
     parser = argparse.ArgumentParser(description="This tool parses the header files of a provided in the Mir project "
-                                        "and process a list of new internal and external symbols. "
+                                        "and creates a list of new internal and external symbols.\n"
                                         "By default, the script updates the corresponding symbols.map file automatically. "
-                                        "To view this diff only, the user may provide the --diff option. "
-                                        "The tool uses https://pypi.org/project/libclang/ to process "
-                                        "the AST of the project's header files.\n\nIf the content of the outputted map "
-                                        "file appears incorrect, trying using a later version of clang (e.g. clang 19). You can do this "
-                                        "by specifying 'MIR_SYMBOLS_MAP_GENERATOR_CLANG_SO_PATH' along with 'MIR_SYMBOLS_MAP_GENERATOR_CLANG_LIBRARY_PATH'. "
-                                        "Note that you most likely must set both of these values so that libLLVM-XY.so can be resolved alongside clang. "
-                                        "As an example, I used this script (https://github.com/opencollab/llvm-jenkins.debian.net/blob/master/llvm.sh) "
-                                        "to install clang 19 (sudo ./llvm.sh 19), and I set the following:"
-                                        "\n\n    export MIR_SYMBOLS_MAP_GENERATOR_CLANG_SO_PATH=/usr/lib/llvm-19/lib/libclang.so.1"
+                                        "To view this diff only, the user may provide the --diff option.\n"
+                                        "Please install libclang-19-dev and python3-clang-19 before using this tool.\n"
+                                        "You must also specify the 'MIR_SYMBOLS_MAP_GENERATOR_CLANG_SO_PATH' and 'MIR_SYMBOLS_MAP_GENERATOR_CLANG_LIBRARY_PATH'"
+                                        " environment variables, for example:"
+                                        "\n    export MIR_SYMBOLS_MAP_GENERATOR_CLANG_SO_PATH=/usr/lib/llvm-19/lib/libclang.so.1"
                                         "\n    export MIR_SYMBOLS_MAP_GENERATOR_CLANG_LIBRARY_PATH=/usr/lib/llvm-19/lib"
                                         , formatter_class=argparse.RawTextHelpFormatter)
     parser.add_argument('--library-name', type=str,
@@ -410,32 +442,82 @@ def main():
                     help='if true a diff should be output to the console')
     parser.add_argument('--include-dirs', type=str, help="colon separated list of directories to search for symbols",
                         required=True, dest='include_dirs')
-    
+
     args = parser.parse_args()
-    logging.basicConfig(level=logging.INFO)
 
     if args.diff:
         _logger.info("symbols_map_generator is running in 'diff' mode")
     else:
         _logger.info("symbols_map_generator is running in 'output symbols' mode")
-    
+
     # Point libclang to a file on the system
     if 'MIR_SYMBOLS_MAP_GENERATOR_CLANG_SO_PATH' in os.environ:
         file_path = os.environ['MIR_SYMBOLS_MAP_GENERATOR_CLANG_SO_PATH']
         _logger.info(f"MIR_SYMBOLS_MAP_GENERATOR_CLANG_SO_PATH is {file_path}")
         clang.cindex.Config.set_library_file(file_path)
     else:
-        _logger.error("Expected MIR_SYMBOLS_MAP_GENERATOR_CLANG_SO_PATH to be defined in the environment")
-        exit(1)
-    
+        clang_so_paths = [
+            "/usr/lib/llvm-19/lib/libclang.so.1",
+            "/usr/lib/x86_64-linux-gnu/libclang-19.so.1",
+            "/usr/lib/aarch64-linux-gnu/libclang-19.so.1",
+            "/usr/lib/libclang-19.so.1",
+            "/usr/lib/llvm-18/lib/libclang-18.so.1",
+            "/usr/lib/x86_64-linux-gnu/libclang-18.so.1",
+            "/usr/lib/aarch64-linux-gnu/libclang-18.so.1",
+            "/usr/lib/libclang-18.so.1",
+        ]
+
+        # Find libclang.so.1
+        found_so = None
+        for path in clang_so_paths:
+            if os.path.isfile(path):
+                found_so = path
+                _logger.debug(f"Found libclang.so.1 at: {path}")
+                break
+
+        if found_so is not None:
+            clang.cindex.Config.set_library_file(found_so)
+            _logger.info(f"Using found libclang.so.1 at: {found_so}")
+        else:
+            _logger.error("Could not find libclang.so.1 in the environment. "
+                          "You may want to set MIR_SYMBOLS_MAP_GENERATOR_CLANG_SO_PATH "
+                          "if libclang.so.1 is manually installed in a non-standard directory.")
+            exit(1)
+
     if 'MIR_SYMBOLS_MAP_GENERATOR_CLANG_LIBRARY_PATH' in os.environ:
         library_path = os.environ['MIR_SYMBOLS_MAP_GENERATOR_CLANG_LIBRARY_PATH']
         _logger.info(f"MIR_SYMBOLS_MAP_GENERATOR_CLANG_LIBRARY_PATH is {library_path}")
         clang.cindex.Config.set_library_path(library_path)
     else:
-        _logger.error("Expected MIR_SYMBOLS_MAP_GENERATOR_CLANG_LIBRARY_PATH to be defined in the environment")
-        exit(1)
-    
+        clang_lib_dirs = [
+            "/usr/lib/llvm-19/lib",
+            "/usr/lib/llvm-18/lib",
+            "/usr/lib/x86_64-linux-gnu",
+            "/usr/lib/aarch64-linux-gnu",
+            "/usr/lib",
+        ]
+
+        # Find library directory
+        found_lib = None
+        for lib_dir in clang_lib_dirs:
+            if os.path.isdir(lib_dir):
+                # Check if directory contains libclang files
+                for file in os.listdir(lib_dir):
+                    if file.startswith('libclang') and '.so' in file:
+                        found_lib = lib_dir
+                        _logger.debug(f"Found clang library directory at: {lib_dir}")
+                        break
+            if found_lib:
+                break
+        if found_lib is not None:
+            clang.cindex.Config.set_library_path(found_lib)
+            _logger.info(f"Using found clang library directory at: {found_lib}")
+        else:
+            _logger.error("Could not find clang library directory. "
+                          "You may want to set MIR_SYMBOLS_MAP_GENERATOR_CLANG_LIBRARY_PATH "
+                          "if clang is not installed in the standard directory.")
+            exit(1)
+
     include_dirs = args.include_dirs.split(":")
     _logger.debug(f"Parsing with include directories: {include_dirs}")
 
@@ -465,7 +547,7 @@ def main():
             args.internal_headers,
             include_dirs
         )
-    
+
     previous_symbols = read_symbols_from_file(args.symbols_map_path, library)
 
     has_changed_symbols = False
@@ -501,7 +583,7 @@ def main():
                 symbol_version = f"{library.upper()}_{symbol.version}"
             else:
                 symbol_version = f"{library.upper()}_{version}"
-            
+
             if not symbol_version in data_to_output:
                 data_to_output[symbol_version] = {
                     "c": [],
@@ -542,7 +624,7 @@ def main():
             else:
                 closing_line = ""
 
-            # Add the correct previous version. This will depend on 
+            # Add the correct previous version. This will depend on
             is_internal = "_INTERNAL_" in version
             if is_internal:
                 if prev_internal_version_str is not None:
@@ -572,8 +654,12 @@ global:{c_symbols_str}
 '''
 
             f.write(output_str)
-    
+
         f.truncate()
 
 if __name__ == "__main__":
-    main()
+    try:
+        main()
+    except Exception as e:
+        _logger.exception(library_not_found_error_msg)
+        sys.exit(1)
